@@ -11,16 +11,18 @@
 #include "util/arg_auto_set.h"
 #include "Rev.h"
 
-#define version "2.2.3"
+#define version "2.3.1"
 
-#include "../src_3rd/puplug/scconfig_hooks.h"
-#include "../src_3rd/libfungw/scconfig_hooks.h"
-#include "../src_3rd/libporty_net/hooks_net.c"
+#define LIBRND_ROOT         "../src_3rd/librnd-local/src/librnd"
+#define LIBRND_PLUGIN_ROOT  "../src_3rd/librnd-local/src/librnd/plugins"
+#include "librnd-local/src_3rd/puplug/scconfig_hooks.h"
+#include "librnd-local/src_3rd/libfungw/scconfig_hooks.h"
+#include "librnd-local/src_3rd/libporty_net/hooks_net.c"
 
-#include "librnd/scconfig/plugin_3state.h"
-#include "librnd/scconfig/hooks_common.h"
-#include "librnd/scconfig/hooks_gui.c"
-#include "librnd/scconfig/rnd_hook_detect.h"
+#include "librnd-local/src/librnd/scconfig/plugin_3state.h"
+#include "librnd-local/src/librnd/scconfig/hooks_common.h"
+#include "librnd-local/src/librnd/scconfig/hooks_gui.c"
+#include "librnd-local/src/librnd/scconfig/rnd_hook_detect.h"
 
 const arg_auto_set_t disable_libs[] = { /* list of --disable-LIBs and the subtree they affect */
 	{"disable-gd",        "libs/gui/gd",                  arg_lib_nodes, "$do not use gd (many exporters need it)"},
@@ -85,6 +87,8 @@ int hook_postinit()
 	put("/local/pcb/want_byaccic", sfalse);
 	put("/local/pcb/dot_pcb_rnd", ".pcb-rnd");
 
+	put("/local/pcb/librnd_is_local", strue);
+	put("/local/pcb/librnd_root", "src_3rd/librnd-local/src");
 	return 0;
 }
 
@@ -231,7 +235,7 @@ int hook_detect_target()
 			put("/local/pcb/want_parsgen", strue);
 	}
 	else {
-		report("Bison/flex are disabled, among with parser generation.\n");
+		report("Bison/flex are disabled, along with parser generation.\n");
 		put("/local/pcb/want_parsgen", sfalse);
 	}
 
@@ -245,7 +249,7 @@ int hook_detect_target()
 			put("/local/pcb/want_parsgen_byaccic", strue);
 	}
 	else {
-		report("byaccic/ureglex are disabled, among with parser generation.\n");
+		report("byaccic/ureglex are disabled, along with parser generation.\n");
 		put("/local/pcb/want_parsgen_byaccic", sfalse);
 	}
 
@@ -306,37 +310,60 @@ int hook_generate()
 	put("/local/version",  version);
 	put("/local/version_major",  version_major);
 	put("/local/apiver", apiver);
-	put("/local/pup/sccbox", "../../scconfig/sccbox");
 
 	printf("\n");
+	if (istrue(get("/local/pcb/librnd_is_local"))) {
+		FILE *f;
+		put("/local/pup/sccbox", "../../../../scconfig/sccbox");
+
+		printf("Generating local librnd build files:\n");
+		printf("Generating librnd-local Makefile.conf (%d)\n", generr |= tmpasm("../src_3rd/librnd-local", "Makefile.conf.in", "Makefile.conf"));
+		printf("Generating librnd-local src/Makefile (%d)\n", generr |= tmpasm("../src_3rd/librnd-local/src", "Makefile.in", "Makefile"));
+
+		printf("Generating src_3rd/libporty_net/os_includes.h (%d)\n", generr |= generate("../src_3rd/librnd-local/src_3rd/libporty_net/os_includes.h.in", "../src_3rd/librnd-local/src_3rd/libporty_net/os_includes.h"));
+		printf("Generating src_3rd/libporty_net/pnet_config.h (%d)\n", generr |= generate("../src_3rd/librnd-local/src_3rd/libporty_net/pnet_config.h.in", "../src_3rd/librnd-local/src_3rd/libporty_net/pnet_config.h"));
+		printf("Generating src_3rd/libporty_net/phost_types.h (%d)\n", generr |= generate("../src_3rd/librnd-local/src_3rd/libporty_net/phost_types.h.in", "../src_3rd/librnd-local/src_3rd/libporty_net/phost_types.h"));
+
+		printf("Generating librnd config.h (%d)\n", generr |= tmpasm("../src_3rd/librnd-local", "config.h.in", "config.h"));
+
+		generr |= pup_hook_generate("../src_3rd/librnd-local/src_3rd/puplug");
+		if (!istrue(get("libs/script/fungw/presents")))
+			generr |= fungw_hook_generate("../src_3rd/librnd-local/src_3rd/libfungw");
+
+		f = fopen("../src_3rd/librnd-local/scconfig/revtest", "w");
+		fprintf(f, "#!/bin/sh\nexit 0\n\n");
+		fclose(f);
+		system("chmod 755 ../src_3rd/librnd-local/scconfig/revtest");
+
+		system("cd ../src_3rd/librnd-local/scconfig && make cquote && make sccbox");
+
+		printf("\n");
+
+		/* reset shared variables used in librnd, reused in pcb-rnd */
+		put("/local/pcb/buildin_pups", "");
+		put("/local/pcb/buildin_hidlib_pups", "");
+		put("/local/pcb/buildin_hidlib_pups_fullpath", "");
+		put("/local/pcb/SRCS", "");
+		put("/local/dep/SRCS", "");
+	}
+
+	put("/local/pup/sccbox", "../../scconfig/sccbox");
+
 
 	printf("Generating Makefile.conf (%d)\n", generr |= tmpasm("..", "Makefile.conf.in", "Makefile.conf"));
 
-	printf("Generating pcb/Makefile (%d)\n", generr |= tmpasm("../src", "Makefile.in", "Makefile"));
+	printf("Generating src/Makefile (%d)\n", generr |= tmpasm("../src", "Makefile.in", "Makefile"));
 
 	generr |= rnd_hook_generate();
 
 	printf("Generating util/gsch2pcb-rnd/Makefile (%d)\n", generr |= tmpasm("../util", "gsch2pcb-rnd/Makefile.in", "gsch2pcb-rnd/Makefile"));
 	printf("Generating util/bxl2txt/Makefile (%d)\n", generr |= tmpasm("../util", "bxl2txt/Makefile.in", "bxl2txt/Makefile"));
-	printf("Generating src_3rd/libporty_net/os_includes.h (%d)\n", generr |= generate("../src_3rd/libporty_net/os_includes.h.in", "../src_3rd/libporty_net/os_includes.h"));
-	printf("Generating src_3rd/libporty_net/pnet_config.h (%d)\n", generr |= generate("../src_3rd/libporty_net/pnet_config.h.in", "../src_3rd/libporty_net/pnet_config.h"));
-	printf("Generating src_3rd/libporty_net/phost_types.h (%d)\n", generr |= generate("../src_3rd/libporty_net/phost_types.h.in", "../src_3rd/libporty_net/phost_types.h"));
 
 	printf("Generating pcb-rnd config.h (%d)\n", generr |= tmpasm("..", "config.h.in", "config.h"));
 
-	printf("Generating opengl.h (%d)\n", generr |= tmpasm("../src_plugins/lib_hid_gl", "opengl.h.in", "opengl.h"));
-
-	printf("Generating tests/librnd/inc_all.h (%d)\n", generr |= tmpasm("../tests/librnd", "inc_all.h.in", "inc_all.h"));
-
 	if (plug_is_enabled("export_vfs_fuse"))
 		printf("Generating fuse_includes.h (%d)\n", generr |= tmpasm("../src_plugins/export_vfs_fuse", "fuse_includes.h.in", "fuse_includes.h"));
 
-	generr |= pup_hook_generate("../src_3rd/puplug");
-
-	if (!istrue(get("libs/script/fungw/presents")))
-		generr |= fungw_hook_generate("../src_3rd/libfungw");
-
-
 	if (!generr) {
 	printf("\n\n");
 	printf("=====================\n");
@@ -345,7 +372,7 @@ int hook_generate()
 
 	print_sum_setting("/local/pcb/want_parsgen",   "Regenerating languages with bison & flex");
 	print_sum_setting("/local/pcb/debug",          "Compilation for debugging");
-	print_sum_setting_or("/local/pcb/symbols",        "Include debug symbols", istrue(get("/local/pcb/debug")));
+	print_sum_setting_or("/local/pcb/symbols",     "Include debug symbols", istrue(get("/local/pcb/debug")));
 	print_sum_cfg_val("/local/pcb/coord_bits",     "Coordinate type bits");
 	print_sum_cfg_val("/local/pcb/dot_pcb_rnd",    ".pcb_rnd config dir under $HOME");
 
