@@ -34,6 +34,7 @@
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/paths.h>
+#include <librnd/core/hid_menu.h>
 #include <librnd/poly/rtree.h>
 #include "undo.h"
 #include "draw.h"
@@ -54,6 +55,7 @@ void pcb_board_free(pcb_board_t * pcb)
 	if (pcb == NULL)
 		return;
 
+	free(pcb->line_mod_merge);
 	free(pcb->hidlib.name);
 	free(pcb->hidlib.filename);
 	free(pcb->PrintFilename);
@@ -65,7 +67,7 @@ void pcb_board_free(pcb_board_t * pcb)
 	for (i = 0; i < PCB_NUM_NETLISTS; i++)
 		pcb_netlist_uninit(&(pcb->netlist[i]));
 	vtroutestyle_uninit(&pcb->RouteStyle);
-	rnd_attribute_free(&pcb->Attributes);
+	pcb_attribute_free(&pcb->Attributes);
 
 	pcb_layergroup_free_stack(&pcb->LayerGroups);
 
@@ -115,7 +117,9 @@ pcb_board_t *pcb_board_new(int inhibit_events)
 
 	dpcb = -1;
 	pcb_io_err_inhibit_inc();
+	rnd_hid_menu_merge_inhibit_inc();
 	rnd_conf_list_foreach_path_first(NULL, dpcb, &conf_core.rc.default_pcb_file, pcb_load_pcb(__path__, NULL, rnd_false, 1 | 0x10 | inh));
+	rnd_hid_menu_merge_inhibit_dec();
 	pcb_io_err_inhibit_dec();
 
 	if (dpcb != 0) { /* no default PCB in file, use embedded version */
@@ -185,15 +189,14 @@ void pcb_layer_colors_from_conf(pcb_board_t *ptr, int force)
 typedef struct {
 	int nplated;
 	int nunplated;
-} HoleCountStruct;
+} hole_count_t;
 
-TODO("padstack: move this to obj_pstk.c after pinvia removal")
 #include "obj_pstk_inlines.h"
 static rnd_r_dir_t hole_counting_callback(const rnd_box_t * b, void *cl)
 {
 	pcb_pstk_t *ps = (pcb_pstk_t *)b;
 	pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
-	HoleCountStruct *hcs = (HoleCountStruct *)cl;
+	hole_count_t *hcs = (hole_count_t *)cl;
 
 	if ((proto != NULL) && (proto->hdia > 0)) {
 		if (proto->hplated)
@@ -208,7 +211,7 @@ static rnd_r_dir_t slot_counting_callback(const rnd_box_t *b, void *cl)
 {
 	pcb_pstk_t *ps = (pcb_pstk_t *)b;
 	pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
-	HoleCountStruct *hcs = (HoleCountStruct *)cl;
+	hole_count_t *hcs = (hole_count_t *)cl;
 
 	if ((proto != NULL) && (proto->mech_idx >= 0)) {
 		if (proto->hplated)
@@ -221,7 +224,7 @@ static rnd_r_dir_t slot_counting_callback(const rnd_box_t *b, void *cl)
 
 void pcb_board_count_holes(pcb_board_t *pcb, int *plated, int *unplated, const rnd_box_t *within_area)
 {
-	HoleCountStruct hcs = { 0, 0 };
+	hole_count_t hcs = { 0, 0 };
 
 	rnd_r_search(pcb->Data->padstack_tree, within_area, NULL, hole_counting_callback, &hcs, NULL);
 
@@ -233,7 +236,7 @@ void pcb_board_count_holes(pcb_board_t *pcb, int *plated, int *unplated, const r
 
 void pcb_board_count_slots(pcb_board_t *pcb, int *plated, int *unplated, const rnd_box_t *within_area)
 {
-	HoleCountStruct hcs = { 0, 0 };
+	hole_count_t hcs = { 0, 0 };
 
 	rnd_r_search(pcb->Data->padstack_tree, within_area, NULL, slot_counting_callback, &hcs, NULL);
 
@@ -331,7 +334,7 @@ void pcb_board_set_line_width(rnd_coord_t Size)
 	if (Size >= PCB_MIN_THICKNESS && Size <= PCB_MAX_THICKNESS) {
 		rnd_conf_set_design("design/line_thickness", "%$mS", Size);
 		if (conf_core.editor.auto_drc)
-			pcb_crosshair_grid_fit(pcb_crosshair.X, pcb_crosshair.Y);
+			pcb_crosshair_grid_fit(PCB, pcb_crosshair.X, pcb_crosshair.Y);
 	}
 }
 
@@ -368,14 +371,17 @@ void pcb_board_set_text_scale(int Scale)
 }
 
 /* sets or resets changed flag and redraws status */
-void pcb_board_set_changed_flag(rnd_bool New)
+void pcb_board_set_changed_flag(pcb_board_t *pcb, rnd_bool New)
 {
-	rnd_bool old = PCB->Changed;
+	rnd_bool old = pcb->Changed;
 
-	PCB->Changed = New;
+	pcb->Changed = New;
 
 	if (old != New)
-		rnd_event(&PCB->hidlib, RND_EVENT_BOARD_META_CHANGED, NULL);
+		rnd_event(&pcb->hidlib, RND_EVENT_BOARD_META_CHANGED, NULL);
+
+	if (New)
+		rnd_event(&pcb->hidlib, PCB_EVENT_BOARD_EDITED, NULL);
 }
 
 
@@ -409,17 +415,6 @@ int pcb_board_normalize(pcb_board_t *pcb)
 	return chg;
 }
 
-TODO("Move this to layer_grp.[ch]");
-const char *pcb_layergrp_thickness_attr(pcb_layergrp_t *grp, const char *namespace)
-{
-	const char *s = NULL;
-	if (namespace != NULL)
-		s = rnd_attribute_get_namespace(&grp->Attributes, namespace, "thickness");
-	if (s == NULL)
-		s = rnd_attribute_get(&grp->Attributes, "thickness");
-	return s;
-}
-
 rnd_coord_t pcb_stack_thickness(pcb_board_t *pcb, const char *namespace, pcb_board_thickness_flags_t flags, rnd_layergrp_id_t from, rnd_bool include_from, rnd_layergrp_id_t to, rnd_bool include_to, pcb_layer_type_t accept)
 {
 	rnd_layergrp_id_t gid;
