@@ -4,7 +4,6 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996, 2004 Thomas Nau
- *  15 Oct 2008 Ineiev: add different crosshair shapes
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -51,7 +50,7 @@ enum {
 #include "vtroutestyle.h"
 #include "layer.h"
 #include "layer_grp.h"
-#include <librnd/core/attrib.h>
+#include "attrib.h"
 #include "rats_patch.h"
 #include "font.h"
 #include <librnd/core/hidlib.h>
@@ -84,17 +83,20 @@ struct pcb_board_s {
 	pcb_netlist_t netlist[PCB_NUM_NETLISTS];
 	/* htsp_t netlist_subc[PCB_NUM_NETLISTS]; hierarchic netlists */
 	pcb_ratspatch_line_t *NetlistPatches, *NetlistPatchLast;
-	rnd_attribute_list_t Attributes;
+	pcb_attribute_list_t Attributes;
 
 	pcb_data_t *Data;                               /* entire database */
 	rnd_bool is_footprint;                          /* If set, the user has loaded a footprint, not a pcb. */
 
-	const rnd_attribute_list_t *pen_attr;
+	const pcb_attribute_list_t *pen_attr;
 
 /* netlist states */
 	int netlist_frozen;                             /* counter */
 	unsigned netlist_needs_update:1;
 
+	/* delayed trace optimization */
+	int line_mod_merge_inhibit;
+	struct vtp0_s *line_mod_merge;
 
 	/* random */
 	unsigned suppress_warn_missing_font:1;          /* do not warn for missing font; useful for alien formats not having embedded font */
@@ -166,7 +168,7 @@ void pcb_board_set_text_scale(int Scale);
 int pcb_board_normalize(pcb_board_t *pcb);
 
 /* sets or resets changed flag and redraws status */
-void pcb_board_set_changed_flag(rnd_bool New);
+void pcb_board_set_changed_flag(pcb_board_t *pcb, rnd_bool New);
 
 /* Shorthand for emitting a board changed event (RND_EVENT_BOARD_CHANGED) */
 void pcb_board_changed(int reverted);
