@@ -53,7 +53,7 @@ typedef struct {
 static desc_t desc[] = {
 	{PCB_BRAVE_NOXOR, "noxor", "avoid xor drawing", "use alternative rendering instead of xor draw", 0},
 	{PCB_BRAVE_NOCLIPBATCH, "noclipbatch", "do not batch poly clipping", "skip optimization of batching polygon clipping in some expensive user operations", 0},
-	{PCB_BRAVE_LESSTIF_TREETABLE, "lesstifttbl", "lesstif tree table", "enable experimental lesstif tree table support", 0},
+	{PCB_BRAVE_ENFORCE_CLR_MOVE, "enforceclrmove", "enforce object clearance on line point or line move", 0},
 	{0, NULL, NULL, NULL}
 };
 
@@ -204,7 +204,7 @@ static int brave_interact(void)
 			for(d = desc, len=0; d->name != NULL; d++,len++) {
 				RND_DAD_LABEL(dlg, d->name);
 					RND_DAD_HELP(dlg, d->lng);
-				RND_DAD_BOOL(dlg, "");
+				RND_DAD_BOOL(dlg);
 					d->widget = RND_DAD_CURRENT(dlg);
 					RND_DAD_CHANGE_CB(dlg, brave_dialog_chg);
 					RND_DAD_HELP(dlg, d->lng);
