@@ -184,6 +184,7 @@ static void pcb_buffer_clear_(pcb_board_t *pcb, pcb_buffer_t *Buffer, rnd_bool b
 	}
 	Buffer->from_outside = 0;
 	free(Buffer->source_path); Buffer->source_path = NULL;
+	Buffer->X = Buffer->Y = 0;
 }
 
 void pcb_buffer_clear(pcb_board_t *pcb, pcb_buffer_t *Buffer)
@@ -202,8 +203,7 @@ static void pcb_buffer_toss_selected(pcb_opfunc_t *fnc, pcb_board_t *pcb, pcb_bu
 	ctx.buffer.removing = 0;
 
 	/* switch crosshair off because adding objects to the pastebuffer
-	 * may change the 'valid' area for the cursor
-	 */
+	   may change the 'valid' area for the cursor */
 	if (!LeaveSelected)
 		ctx.buffer.extraflg = PCB_FLAG_SELECTED;
 	else
@@ -274,9 +274,9 @@ fgw_error_t pcb_act_LoadFootprint(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 
 	s = pcb_subclist_first(&PCB_PASTEBUFFER->Data->subc);
-	rnd_attribute_put(&s->Attributes, "refdes", refdes);
-	rnd_attribute_put(&s->Attributes, "footprint", name);
-	rnd_attribute_put(&s->Attributes, "value", value);
+	pcb_attribute_put(&s->Attributes, "refdes", refdes);
+	pcb_attribute_put(&s->Attributes, "footprint", name);
+	pcb_attribute_put(&s->Attributes, "value", value);
 
 	RND_ACT_IRES(0);
 	return 0;
@@ -532,7 +532,7 @@ fgw_error_t pcb_act_FreeRotateBuffer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 typedef struct {
 	RND_DAD_DECL_NOINIT(dlg)
-	int wx, wy, wlock;
+	int wx, wy, wlock, wth, wrecurse;
 } scale_t;
 
 /* make sure x;y values are synced when lock is active */
@@ -556,7 +556,7 @@ static void scale_chg_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 }
 
 /* returns 0 on OK */
-static int pcb_actgui_ScaleBuffer(rnd_hidlib_t *hidlib, double *x, double *y)
+static int pcb_actgui_ScaleBuffer(rnd_hidlib_t *hidlib, double *x, double *y, double *th, int *recurse)
 {
 	scale_t ctx;
 	int res;
@@ -570,23 +570,33 @@ static int pcb_actgui_ScaleBuffer(rnd_hidlib_t *hidlib, double *x, double *y)
 			RND_DAD_COMPFLAG(ctx.dlg, RND_HATF_EXPFILL);
 
 			RND_DAD_LABEL(ctx.dlg, "scale X");
-			RND_DAD_REAL(ctx.dlg, "");
+			RND_DAD_REAL(ctx.dlg);
 				ctx.wx = RND_DAD_CURRENT(ctx.dlg);
 				RND_DAD_DEFAULT_NUM(ctx.dlg, 1);
 				RND_DAD_CHANGE_CB(ctx.dlg, scale_chg_cb);
 
 			RND_DAD_LABEL(ctx.dlg, "same");
-			RND_DAD_BOOL(ctx.dlg, "");
+			RND_DAD_BOOL(ctx.dlg);
 				ctx.wlock = RND_DAD_CURRENT(ctx.dlg);
 				RND_DAD_DEFAULT_NUM(ctx.dlg, 1);
 				RND_DAD_CHANGE_CB(ctx.dlg, scale_chg_cb);
 
 			RND_DAD_LABEL(ctx.dlg, "scale Y");
-			RND_DAD_REAL(ctx.dlg, "");
+			RND_DAD_REAL(ctx.dlg);
 				ctx.wy = RND_DAD_CURRENT(ctx.dlg);
 				RND_DAD_DEFAULT_NUM(ctx.dlg, 1);
 				RND_DAD_CHANGE_CB(ctx.dlg, scale_chg_cb);
 
+			RND_DAD_LABEL(ctx.dlg, "scale thickness");
+			RND_DAD_REAL(ctx.dlg);
+				ctx.wth = RND_DAD_CURRENT(ctx.dlg);
+				RND_DAD_DEFAULT_NUM(ctx.dlg, 1);
+
+			RND_DAD_LABEL(ctx.dlg, "subcircuits");
+			RND_DAD_BOOL(ctx.dlg);
+				ctx.wrecurse = RND_DAD_CURRENT(ctx.dlg);
+				RND_DAD_DEFAULT_NUM(ctx.dlg, 0);
+
 		RND_DAD_BUTTON_CLOSES(ctx.dlg, clbtn);
 	RND_DAD_END(ctx.dlg);
 
@@ -594,6 +604,8 @@ static int pcb_actgui_ScaleBuffer(rnd_hidlib_t *hidlib, double *x, double *y)
 	res = RND_DAD_RUN(ctx.dlg);
 	*x = ctx.dlg[ctx.wx].val.dbl;
 	*y = ctx.dlg[ctx.wy].val.dbl;
+	*th = ctx.dlg[ctx.wth].val.dbl;
+	*recurse = ctx.dlg[ctx.wrecurse].val.lng;
 	RND_DAD_FREE(ctx.dlg);
 	return res;
 }
@@ -621,11 +633,10 @@ fgw_error_t pcb_act_ScaleBuffer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		y = th = x;
 	}
 	else {
-		if (pcb_actgui_ScaleBuffer(RND_ACT_HIDLIB, &x, &y) != 0) {
+		if (pcb_actgui_ScaleBuffer(RND_ACT_HIDLIB, &x, &y, &th, &recurse) != 0) {
 			RND_ACT_IRES(-1);
 			return 0;
 		}
-		th = 1;
 	}
 
 	RND_ACT_MAY_CONVARG(2, FGW_DOUBLE, ScaleBuffer, y = argv[2].val.nat_double);
@@ -699,11 +710,6 @@ void pcb_buffer_scale(pcb_buffer_t *Buffer, double sx, double sy, double sth, in
 
 void pcb_buffer_flip_side(pcb_board_t *pcb, pcb_buffer_t *Buffer)
 {
-	int j, k;
-	rnd_layer_id_t SLayer = -1, CLayer = -1;
-	rnd_layergrp_id_t sgroup, cgroup;
-	pcb_layer_t swap;
-
 #if 0
 /* this results in saving flipped (bottom-side) footprints whenlooking at the board from the bottom */
 	PCB_SUBC_LOOP(Buffer->Data);
@@ -743,37 +749,6 @@ void pcb_buffer_flip_side(pcb_board_t *pcb, pcb_buffer_t *Buffer)
 	}
 	PCB_ENDALL_LOOP;
 
-	/* swap silkscreen layers */
-	pcb_layer_list(pcb, PCB_LYT_BOTTOM | PCB_LYT_SILK, &SLayer, 1);
-	pcb_layer_list(pcb, PCB_LYT_TOP | PCB_LYT_SILK, &CLayer, 1);
-	assert(SLayer != -1);
-	assert(CLayer != -1);
-	swap = Buffer->Data->Layer[SLayer];
-	Buffer->Data->Layer[SLayer] = Buffer->Data->Layer[CLayer];
-	Buffer->Data->Layer[CLayer] = swap;
-
-	/* swap layer groups when balanced */
-	sgroup = pcb_layer_get_group(pcb, SLayer);
-	cgroup = pcb_layer_get_group(pcb, CLayer);
-TODO("layer: revise this code for the generic physical layer support; move this code to layer*.c")
-	if (pcb->LayerGroups.grp[cgroup].len == pcb->LayerGroups.grp[sgroup].len) {
-		for (j = k = 0; j < pcb->LayerGroups.grp[sgroup].len; j++) {
-			rnd_layer_id_t cnumber = pcb->LayerGroups.grp[cgroup].lid[k];
-			rnd_layer_id_t snumber = pcb->LayerGroups.grp[sgroup].lid[j];
-
-			if ((pcb_layer_flags(pcb, snumber)) & PCB_LYT_SILK)
-				continue;
-			swap = Buffer->Data->Layer[snumber];
-
-			while ((pcb_layer_flags(pcb, cnumber)) & PCB_LYT_SILK) {
-				k++;
-				cnumber = pcb->LayerGroups.grp[cgroup].lid[k];
-			}
-			Buffer->Data->Layer[snumber] = Buffer->Data->Layer[cnumber];
-			Buffer->Data->Layer[cnumber] = swap;
-			k++;
-		}
-	}
 	pcb_set_buffer_bbox(Buffer);
 }
 
@@ -925,7 +900,6 @@ rnd_bool pcb_buffer_copy_to_layout(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t
 
 		/* set up a dummy board to work around that pcb_pstkop_copy() requires a
 		   pcb_board_t instead of a pcb_data_t */
-TODO("subc: fix this after the element removal")
 		if (pcb->is_footprint) {
 			pcb_subc_t *sc = pcb_subclist_first(&pcb->Data->subc);
 			if (sc != NULL) {
@@ -1196,7 +1170,7 @@ static fgw_error_t pcb_act_PasteBuffer(fgw_arg_t *res, int argc, fgw_arg_t *argv
 				oldx = x;
 				oldy = y;
 				if (pcb_buffer_copy_to_layout(PCB, x, y, rnd_false))
-					pcb_board_set_changed_flag(rnd_true);
+					pcb_board_set_changed_flag(PCB, rnd_true);
 			}
 			break;
 
