@@ -558,9 +558,9 @@ rnd_bool pcb_chg_selected_radius(int types, int is_start, rnd_angle_t Difference
 	return change;
 }
 
-TODO("subc: check if it is true:")
 /* ---------------------------------------------------------------------------
- * changes the size of the passed object; subc size is silk size (TODO: check if it is true)
+ * Changes the size of the passed object;
+ * subc size is line, arc and padstack sizes.
  * Returns rnd_true if anything is changed
  */
 rnd_bool pcb_chg_obj_size(int Type, void *Ptr1, void *Ptr2, void *Ptr3, rnd_coord_t Difference, rnd_bool fixIt)
@@ -581,9 +581,8 @@ rnd_bool pcb_chg_obj_size(int Type, void *Ptr1, void *Ptr2, void *Ptr3, rnd_coor
 	return change;
 }
 
-TODO("subc: check if it is true:")
 /* ---------------------------------------------------------------------------
- * changes the size of the passed object; element size is pin ring sizes
+ * changes the size of the passed object; subcircuits pass this on to their parts
  * Returns rnd_true if anything is changed
  */
 rnd_bool pcb_chg_obj_1st_size(int Type, void *Ptr1, void *Ptr2, void *Ptr3, rnd_coord_t Difference, rnd_bool fixIt)
@@ -938,7 +937,7 @@ static int undo_chg_attr_swap(void *udata)
 	char *curr_value = NULL, **slot;
 	const char *new_val;
 
-	slot = rnd_attribute_get_ptr(&ca->obj->Attributes, ca->key);
+	slot = pcb_attribute_get_ptr(&ca->obj->Attributes, ca->key);
 
 	/* temp save current state */
 	if (slot == NULL)
@@ -949,8 +948,8 @@ static int undo_chg_attr_swap(void *udata)
 	/* install ca in the slot */
 	if (!ca->delete) {
 		if (curr_delete) {
-			rnd_attribute_put(&ca->obj->Attributes, ca->key, NULL);
-			slot = rnd_attribute_get_ptr(&ca->obj->Attributes, ca->key);
+			pcb_attribute_put(&ca->obj->Attributes, ca->key, NULL);
+			slot = pcb_attribute_get_ptr(&ca->obj->Attributes, ca->key);
 		}
 		*slot = ca->value;
 		new_val = ca->value;
@@ -960,7 +959,7 @@ static int undo_chg_attr_swap(void *udata)
 	else {
 		*slot = NULL;
 		new_val = NULL;
-		rnd_attribute_remove(&ca->obj->Attributes, ca->key);
+		pcb_attribute_remove(&ca->obj->Attributes, ca->key);
 	}
 
 
@@ -1004,7 +1003,7 @@ int pcb_uchg_attr(pcb_board_t *pcb, pcb_any_obj_t *obj, const char *key, const c
 	if (key == NULL)
 		return -1;
 
-	curr = rnd_attribute_get(&obj->Attributes, key);
+	curr = pcb_attribute_get(&obj->Attributes, key);
 	if ((curr == NULL) && (new_value == NULL))
 		return 0; /* nothing to do: both delete */
 	if ((curr != NULL) && (new_value != NULL) && (strcmp(curr, new_value) == 0))
