@@ -36,8 +36,8 @@ typedef struct {
 		RND_CFT_BOOLEAN rubber_band_mode;      /* move, rotate use rubberband connections */
 		RND_CFT_BOOLEAN rubber_band_keep_midlinedir; /* keep line direction when a middle line is moved */
 		RND_CFT_BOOLEAN swap_start_direction;  /* change starting direction after each click */
-		RND_CFT_BOOLEAN show_drc;              /* show drc region on crosshair */
-		RND_CFT_BOOLEAN auto_drc;              /* when set, PCB doesn't let you place copper that violates DRC. */
+		RND_CFT_BOOLEAN show_drc;              /* (misnomer) show style clearance on crosshair */
+		RND_CFT_BOOLEAN auto_drc;              /* (misnomer) block drawing traces that get too close (according to style clearance) to other nets */
 		RND_CFT_BOOLEAN conn_find_rat;         /* connection find includes rats; when off, only existing galvanic connections are mapped */
 		RND_CFT_BOOLEAN show_number;           /* OBSOLETE: pinout shows number */
 		RND_CFT_BOOLEAN orthogonal_moves;      /* move items orthogonally. */
@@ -53,6 +53,7 @@ typedef struct {
 		RND_CFT_BOOLEAN hide_names;            /* when set, subc floater text objects (typical use case: refdes text) are not drawn. */
 		RND_CFT_BOOLEAN description;           /* obsolete - DO NOT USE - kept for compatibility */
 		RND_CFT_BOOLEAN name_on_pcb;           /* obsolete - DO NOT USE - kept for compatibility */
+		RND_CFT_BOOLEAN trace_auto_merge;      /* automatically merge trace overlapping trace lines while drawing or moving traces */
 		RND_CFT_STRING  subc_id;               /* subcircuit ID template for diplaying the subcircuit label on the subcircuit layer; default to displaying the refes, if empty; syntax if the same as for DYNTEXT */
 		RND_CFT_STRING  term_id;               /* terminal ID template for diplaying the subcircuit label on the subcircuit layer; default to displaying termid[intconn], if empty; syntax if the same as for DYNTEXT */
 		RND_CFT_BOOLEAN move_linepoint_uses_route;	/* Moving a line point calculates a new line route. This allows 45/90 line modes when editing lines. */
@@ -99,6 +100,10 @@ typedef struct {
 		struct {
 			RND_CFT_STRING method;             /* method/strategy of removal; one of: select, remove, list */
 		} footprint_removal;
+
+		struct {
+			RND_CFT_BOOLEAN poly_side_clearance; /* whether to load polygon-side clearances (when set in the file); when false, ignore them */
+		} alien_format;
 	} import;
 
 	const struct {                       /* rc */
@@ -149,13 +154,13 @@ typedef struct {
 		RND_CFT_COORD line_thickness;
 		RND_CFT_COORD clearance;
 
-		/* old drc settings */
-		RND_CFT_COORD bloat;                   /* minimum space between copper features on different networks */
-		RND_CFT_COORD shrink;                  /* minimum overlap between connected copper features */
-		RND_CFT_COORD min_wid;                 /* minimum copper width */
-		RND_CFT_COORD min_slk;                 /* minimum silk width */
-		RND_CFT_COORD min_drill;               /* minimum drill diameter */
-		RND_CFT_COORD min_ring;                /* minimum annular ring */
+		/* limiting sizes (old DRC) settings */
+		RND_CFT_COORD bloat;                   /* core: size of box-style clearance around text objects; old plugins: gap between copper features on different nets */
+		RND_CFT_COORD shrink;                  /* [OBSOLETE] minimum overlap between connected copper features */
+		RND_CFT_COORD min_wid;                 /* core: minimum copper thickness in stroked text, core+plugins: implicit outline rectangle thickness */
+		RND_CFT_COORD min_slk;                 /* core: minimum silk thickness in stroked text, core+plugins: implicit outline rectangle thickness on silk layers */
+		RND_CFT_COORD min_drill;               /* [OBSOLETE] minimum drill diameter */
+		RND_CFT_COORD min_ring;                /* [OBSOLETE] minimum annular ring */
 
 		struct {                           /* drc: new, flexible drc settings */
 			RND_CFT_COORD min_copper_clearance;  /* minimum space between copper features on different networks (default when the net attributes or other settings don't specify a different value) */
@@ -190,6 +195,8 @@ typedef struct {
 		RND_CFT_BOOLEAN subc_layer_per_side;   /* hide top or bottom placed subcircuit annotations if the view is showing the other side */
 		RND_CFT_BOOLEAN invis_other_groups;    /* render non-current group layers with the inivisble color */
 		RND_CFT_BOOLEAN black_current_group;   /* render all layers of the current group black, for maximum contrast */
+		RND_CFT_BOOLEAN smart_labels;          /* attempt to place terminal labels in a way they don't overlap (costs extra CPU cycles, may slow down on-screen rendering) */
+		RND_CFT_COORD label_thickness;         /* font thickness for labels (e.g. terminal labels); thinnest possible is 1nm */
 
 		struct {                           /* color */
 			RND_CFT_COLOR crosshair;             /* obsolete - DO NOT USE - kept for compatibility (use appearance/color/cross instead) */
