@@ -4,7 +4,6 @@
  *  pcb-rnd, interactive printed circuit board design
  *  (this file is based on PCB, interactive printed circuit board design)
  *  Copyright (C) 1994,1995,1996 Thomas Nau
- *  15 Oct 2008 Ineiev: add different crosshair shapes
  *  Copyright (C) 2020 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -33,6 +32,8 @@
 #include "conf_core.h"
 #include <librnd/core/hidlib_conf.h>
 
+#include "brave.h"
+
 #include "board.h"
 #include "crosshair.h"
 #include "data.h"
@@ -43,10 +44,11 @@
 #include <librnd/core/actions.h>
 #include <librnd/core/hid_inlines.h>
 #include <librnd/core/compat_misc.h>
-#include "vtonpoint.h"
+#include <librnd/poly/offset.h>
 #include "find.h"
 #include "undo.h"
 #include "event.h"
+#include "thermal.h"
 #include <librnd/core/grid.h>
 
 #include "obj_line_draw.h"
@@ -109,6 +111,28 @@ void pcb_xordraw_poly(pcb_poly_t *polygon, rnd_coord_t dx, rnd_coord_t dy, int d
 	}
 }
 
+void pcb_xordraw_pline(rnd_pline_t *pline, rnd_coord_t dx, rnd_coord_t dy)
+{
+	rnd_vnode_t *n = pline->head;
+	do {
+		rnd_render->draw_line(pcb_crosshair.GC,
+			 n->point[0] + dx, n->point[1] + dy,
+			 n->next->point[0] + dx, n->next->point[1] + dy);
+		n = n->next;
+	} while(n != pline->head);
+}
+
+void pcb_xordraw_polyarea(rnd_polyarea_t *parea, rnd_coord_t dx, rnd_coord_t dy)
+{
+	rnd_polyarea_t *pa = parea;
+	rnd_pline_t *pl;
+	do {
+		for(pl = pa->contours; pl != NULL; pl = pl->next)
+			pcb_xordraw_pline(pl, dx, dy);
+		pa = pa->f;
+	} while(pa != parea);
+}
+
 /* ---------------------------------------------------------------------------
  * creates a tmp polygon with coordinates converted to screen system, designed
  * for subc paste xor-draw
@@ -200,7 +224,7 @@ void pcb_xordraw_buffer(pcb_buffer_t *Buffer)
 			PCB_END_LOOP;
 			PCB_TEXT_LOOP(layer);
 			{
-				pcb_text_draw_xor(text, x, y);
+				pcb_text_draw_xor(text, x, y, 1);
 			}
 			PCB_END_LOOP;
 			/* the tmp polygon has n+1 points because the first
@@ -273,264 +297,372 @@ static void proj_extend(double *ox, double *oy, double vx, double vy, double dx,
 	*ox =nx * offs; *oy = ny * offs;
 }
 
-/* ---------------------------------------------------------------------------
- * draws the attached object while in tool mode move or copy
- */
-void pcb_xordraw_movecopy(void)
+
+/* extend the pine between px;py and (already moved) x;y knowing the previous
+   point beyond px;py (which is ppx;ppy) */
+static void perp_extend(rnd_coord_t ppx, rnd_coord_t ppy, rnd_coord_t *px, rnd_coord_t *py, rnd_coord_t x, rnd_coord_t y, rnd_coord_t dx, rnd_coord_t dy)
+{
+	rnd_coord_t ix, iy;
+
+	pcb_lines_intersect_at(ppx, ppy, *px, *py,   (*px) + dx, (*py) + dy, x, y,  &ix, &iy);
+
+	*px = ix;
+	*py = iy;
+}
+
+
+/*** draw the attached object while in tool mode move or copy ***/
+
+/* Some complex objects (padstacks, text, polygons) need to cache their
+   clearance outline because it's too expensive to calculate on every
+   screen update */
+typedef struct {
+	rnd_pline_t *pline;
+	rnd_polyarea_t *pa;
+} xordraw_cache_t;
+
+static xordraw_cache_t xordraw_cache;
+
+RND_INLINE void xordraw_movecopy_pstk(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	pcb_pstk_t *ps = (pcb_pstk_t *)pcb_crosshair.AttachedObject.Ptr2;
+	thindraw_moved_ps(ps, dx, dy);
+
+	if (conf_core.editor.show_drc) {
+		if (xordraw_cache.pa == NULL) {
+			static pcb_poly_t in_poly = {0};
+			rnd_layergrp_id_t gid;
+
+			/* build an union of all-layer clearances since a padstack affects multiple layers */
+			for(gid = 0; gid < PCB->LayerGroups.len; gid++) {
+				pcb_layergrp_t *g = &PCB->LayerGroups.grp[gid];
+				rnd_polyarea_t *cla, *tmp;
+				if (!(g->ltype & PCB_LYT_COPPER) || (g->len < 1))  continue;
+				cla = pcb_thermal_area_pstk(PCB, ps, g->lid[0], &in_poly);
+				if (xordraw_cache.pa != NULL) {
+					rnd_polyarea_boolean_free(xordraw_cache.pa, cla, &tmp, RND_PBO_UNITE);
+					xordraw_cache.pa = tmp;
+				}
+				else
+					xordraw_cache.pa = cla;
+			}
+		}
+		if (xordraw_cache.pa != NULL) {
+			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
+			pcb_xordraw_polyarea(xordraw_cache.pa, dx, dy);
+			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
+		}
+	}
+}
+
+RND_INLINE void xordraw_movecopy_line(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	/* We move a local copy of the line - the real line hasn't moved, only the preview. */
+	int constrained = 0;
+	pcb_line_t line;
+	rnd_coord_t dx1 = dx, dx2 = dx;
+	rnd_coord_t dy1 = dy, dy2 = dy;
+	
+	memcpy(&line, (pcb_line_t *)pcb_crosshair.AttachedObject.Ptr2, sizeof(line));
+
+	if(conf_core.editor.rubber_band_keep_midlinedir)
+		rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_CONSTRAIN_MAIN_LINE, "pppppp", &line, &constrained, &dx1, &dy1, &dx2, &dy2);
+	rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icccc", constrained, dx1, dy1, dx2, dy2);
+
+	*event_sent = 1;
+
+	line.Point1.X += dx1;
+	line.Point1.Y += dy1;
+	line.Point2.X += dx2;
+	line.Point2.Y += dy2;
+
+	pcb_draw_wireframe_line(pcb_crosshair.GC,
+		line.Point1.X, line.Point1.Y, line.Point2.X, line.Point2.Y,
+		line.Thickness, 0);
+
+	/* Draw the DRC outline if it is enabled */
+	if (conf_core.editor.show_drc) {
+		rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
+		pcb_draw_wireframe_line(pcb_crosshair.GC,
+			line.Point1.X, line.Point1.Y, line.Point2.X, line.Point2.Y,
+			line.Thickness + 2 * (line.Clearance/2 + 1), 0);
+		rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
+	}
+}
+
+RND_INLINE void xordraw_movecopy_arc(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	/* Make a temporary arc and move it by dx,dy */
+	pcb_arc_t arc = *((pcb_arc_t *)pcb_crosshair.AttachedObject.Ptr2);
+	rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icccc", 0, dx, dy, dx, dy);
+	*event_sent = 1;
+	
+	arc.X += dx;
+	arc.Y += dy;
+
+	pcb_draw_wireframe_arc(pcb_crosshair.GC, &arc, arc.Thickness);
+
+	/* Draw the DRC outline if it is enabled */
+	if (conf_core.editor.show_drc) {
+		rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
+		arc.Thickness += 2 * (arc.Clearance/2 + 1);
+		pcb_draw_wireframe_arc(pcb_crosshair.GC, &arc, arc.Thickness);
+		rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
+	}
+}
+
+
+RND_INLINE void xordraw_movecopy_poly(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	pcb_poly_t *polygon = (pcb_poly_t *)pcb_crosshair.AttachedObject.Ptr2;
+
+	/* the tmp polygon has n+1 points because the first and the last one are set to the same coordinates */
+	pcb_xordraw_poly(polygon, dx, dy, 0);
+
+	/* if show_drc is enabled and polygon is trying to clear other polygons,
+	   calculate the offset poly and cache */
+	if ((conf_core.editor.show_drc) && (PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, polygon))) {
+		if (xordraw_cache.pline == NULL) {
+			long n;
+			rnd_vector_t v;
+			rnd_pline_t *pl;
+
+			for(n = 0; n < polygon->PointN; n++) {
+				v[0] = polygon->Points[n].X; v[1] = polygon->Points[n].Y;
+				if (n == 0)
+					pl = rnd_poly_contour_new(v);
+				else
+					rnd_poly_vertex_include(pl->head->prev, rnd_poly_node_create(v));
+			}
+			rnd_poly_contour_pre(pl, 1);
+			if (pl->Flags.orient)
+				rnd_poly_contour_inv(pl);
+
+			xordraw_cache.pline = rnd_pline_dup_offset(pl, -(polygon->Clearance/2+1));
+			rnd_poly_contour_del(&pl);
+		}
+		
+		/* draw the clearance offset poly */
+		if (xordraw_cache.pline != NULL) {
+			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
+			pcb_xordraw_pline(xordraw_cache.pline, dx, dy);
+			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
+		}
+	}
+}
+
+RND_INLINE void xordraw_movecopy_text(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	int want_box = 1;
+	pcb_text_t *text = (pcb_text_t *)pcb_crosshair.AttachedObject.Ptr2;
+	if (conf_core.editor.show_drc) {
+		if (xordraw_cache.pa == NULL)
+			xordraw_cache.pa = pcb_poly_construct_text_clearance(text);
+		if (xordraw_cache.pa != NULL) {
+			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
+			pcb_xordraw_polyarea(xordraw_cache.pa, dx, dy);
+			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
+			want_box = 0;
+		}
+	}
+	pcb_text_draw_xor(text, dx, dy, want_box);
+}
+
+RND_INLINE void xordraw_movecopy_gfx(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	pcb_gfx_t *gfx = (pcb_gfx_t *)pcb_crosshair.AttachedObject.Ptr2;
+	pcb_gfx_draw_xor(gfx, dx, dy);
+}
+
+RND_INLINE void xordraw_movecopy_line_point(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	pcb_line_t *line;
+	rnd_point_t *point, *point1, point2;
+
+	line = (pcb_line_t *)pcb_crosshair.AttachedObject.Ptr2;
+	point = (rnd_point_t *)pcb_crosshair.AttachedObject.Ptr3;
+	point1 = (point == &line->Point1 ? &line->Point2 : &line->Point1);
+	point2 = *point;
+	point2.X += dx;
+	point2.Y += dy;
+
+	if(conf_core.editor.move_linepoint_uses_route == 0) { /* config setting for selecting new 45/90 method */
+		pcb_draw_wireframe_line(pcb_crosshair.GC,point1->X, point1->Y, point2.X, point2.Y, line->Thickness, 0);
+
+		/* Draw the DRC outline if it is enabled */
+		if (conf_core.editor.show_drc) {
+			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
+			pcb_draw_wireframe_line(pcb_crosshair.GC,point1->X, point1->Y, point2.X, point2.Y,line->Thickness + line->Clearance, 0);
+			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
+		}
+	}
+	else {
+		pcb_route_t route;
+		pcb_route_init(&route);
+		pcb_route_calculate(PCB,
+			&route, point1, &point2, pcb_layer_id(PCB->Data,(pcb_layer_t *)pcb_crosshair.AttachedObject.Ptr1),
+			line->Thickness, line->Clearance, line->Flags,
+			rnd_gui->shift_is_pressed(rnd_gui), rnd_gui->control_is_pressed(rnd_gui));
+		pcb_route_draw(&route,pcb_crosshair.GC);
+		if (conf_core.editor.show_drc) 
+			pcb_route_draw_drc(&route,pcb_crosshair.GC);
+		pcb_route_destroy(&route);
+	}
+}
+
+RND_INLINE void xordraw_movecopy_arc_point(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	pcb_arc_t arc = *((pcb_arc_t *)pcb_crosshair.AttachedObject.Ptr2);
+	rnd_coord_t ox1, ox2, oy1, oy2;
+	rnd_coord_t nx1, nx2, ny1, ny2;
+
+	/* Get the initial position of the arc point */
+	pcb_arc_get_end(&arc,0, &ox1, &oy1);
+	pcb_arc_get_end(&arc,1, &ox2, &oy2);
+
+	/* Update the attached arc point */
+	pcb_arc_ui_move_or_copy(&pcb_crosshair);
+
+	/* Update our local arc copy from the attached object */
+	if(pcb_crosshair.AttachedObject.radius != 0) {
+		arc.Width   = pcb_crosshair.AttachedObject.radius;
+		arc.Height  = pcb_crosshair.AttachedObject.radius;
+	}
+	else {
+		arc.StartAngle  = pcb_crosshair.AttachedObject.start_angle;
+		arc.Delta       = pcb_crosshair.AttachedObject.delta_angle;
+	}
+
+	pcb_draw_wireframe_arc(pcb_crosshair.GC, &arc, arc.Thickness);
+
+	/* Draw the DRC outline if it is enabled */
+	if (conf_core.editor.show_drc) {
+		rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
+		arc.Thickness += arc.Clearance;
+		pcb_draw_wireframe_arc(pcb_crosshair.GC, &arc, arc.Thickness);
+		rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
+	}
+
+	/* Get the new arc point positions, calculate the movement deltas and send them 
+	   in a rubber_move_draw event */
+	pcb_arc_get_end(&arc,0, &nx1, &ny1);
+	pcb_arc_get_end(&arc,1, &nx2, &ny2);
+
+	rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icccc", 0, nx1-ox1, ny1-oy1, nx2-ox2, ny2-oy2);
+	*event_sent = 1;
+}
+
+RND_INLINE void xordraw_movecopy_poly_point(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	pcb_poly_t *polygon;
+	rnd_point_t *point;
+	rnd_cardinal_t point_idx, prev, next, prev2, next2;
+	rnd_coord_t px, py, x, y, nx, ny;
+
+	polygon = (pcb_poly_t *) pcb_crosshair.AttachedObject.Ptr2;
+	point = (rnd_point_t *) pcb_crosshair.AttachedObject.Ptr3;
+	point_idx = pcb_poly_point_idx(polygon, point);
+
+	/* get previous and following point */
+	prev = pcb_poly_contour_prev_point(polygon, point_idx);
+	next = pcb_poly_contour_next_point(polygon, point_idx);
+
+	px = polygon->Points[prev].X; py = polygon->Points[prev].Y;
+	x = point->X + dx; y = point->Y + dy;
+	nx = polygon->Points[next].X; ny = polygon->Points[next].Y;
+
+	/* modified version: angle keeper; run only on every even call to not mess up the xor */
+	if (modifier && pcb_crosshair.edit_poly_point_extra.last_active) {
+		rnd_coord_t ppx, ppy, nnx, nny;
+
+		pcb_crosshair.edit_poly_point_extra.active = 1;
+		pcb_crosshair.edit_poly_point_extra.point[0] = &polygon->Points[prev];
+		pcb_crosshair.edit_poly_point_extra.point[1] = &polygon->Points[next];
+
+		prev2 = pcb_poly_contour_prev_point(polygon, prev);
+		next2 = pcb_poly_contour_next_point(polygon, next);
+		ppx = polygon->Points[prev2].X; ppy = polygon->Points[prev2].Y;
+		nnx = polygon->Points[next2].X; nny = polygon->Points[next2].Y;
+
+		perp_extend(ppx, ppy, &px, &py, x, y, dx, dy);
+		perp_extend(nnx, nny, &nx, &ny, x, y, dx, dy);
+
+		/* draw the extra two segments on prev-prev and next-next */
+		rnd_render->draw_line(pcb_crosshair.GC, ppx, ppy, px, py);
+		rnd_render->draw_line(pcb_crosshair.GC, nnx, nny, nx, ny);
+
+		pcb_crosshair.edit_poly_point_extra.dx[0] = px - polygon->Points[prev].X;
+		pcb_crosshair.edit_poly_point_extra.dy[0] = py - polygon->Points[prev].Y;
+		pcb_crosshair.edit_poly_point_extra.dx[1] = nx - polygon->Points[next].X;
+		pcb_crosshair.edit_poly_point_extra.dy[1] = ny - polygon->Points[next].Y;
+	}
+	else
+		pcb_crosshair.edit_poly_point_extra.active = 0;
+
+	pcb_crosshair.edit_poly_point_extra.last_active = modifier;
+
+	/* draw the two segments */
+	rnd_render->draw_line(pcb_crosshair.GC, px, py, x, y);
+	rnd_render->draw_line(pcb_crosshair.GC, x, y, nx, ny);
+}
+
+RND_INLINE void xordraw_movecopy_gfx_point(rnd_bool modifier, int *event_sent, rnd_coord_t dx, rnd_coord_t dy)
+{
+	pcb_gfx_t *gfx;
+	rnd_point_t *point, *prev, *next, *opp;
+	int point_idx, i;
+	double px, py, nx, ny, cx, cy;
+
+	gfx = (pcb_gfx_t *)pcb_crosshair.AttachedObject.Ptr2;
+	point = (rnd_point_t *)pcb_crosshair.AttachedObject.Ptr3;
+	point_idx = point - gfx->corner;
+	if ((point_idx < 0) || (point_idx > 3))
+		return;
+
+	cx = pcb_crosshair.X;
+	cy = pcb_crosshair.Y;
+
+	i = point_idx - 1;
+	if (i < 0) i = 3;
+	prev = gfx->corner + i;
+
+	i = (point_idx + 1) % 4;
+	next = gfx->corner + i;
+
+	i = (point_idx + 2) % 4;
+	opp = gfx->corner + i;
+
+	proj_extend(&px, &py, point->X - prev->X, point->Y - prev->Y, dx, dy);
+	proj_extend(&nx, &ny, point->X - next->X, point->Y - next->Y, dx, dy);
+
+	rnd_render->draw_line(pcb_crosshair.GC, opp->X, opp->Y, prev->X+px, prev->Y+py);
+	rnd_render->draw_line(pcb_crosshair.GC, opp->X, opp->Y, next->X+nx, next->Y+ny);
+	rnd_render->draw_line(pcb_crosshair.GC, cx, cy, prev->X+px, prev->Y+py);
+	rnd_render->draw_line(pcb_crosshair.GC, cx, cy, next->X+nx, next->Y+ny);
+}
+
+void pcb_xordraw_movecopy(rnd_bool modifier)
 {
 	rnd_coord_t dx = pcb_crosshair.AttachedObject.tx - pcb_crosshair.AttachedObject.X;
 	rnd_coord_t dy = pcb_crosshair.AttachedObject.ty - pcb_crosshair.AttachedObject.Y;
 	int event_sent = 0;
 	
 	switch (pcb_crosshair.AttachedObject.Type) {
-
-	case PCB_OBJ_PSTK:
-		{
-			pcb_pstk_t *ps = (pcb_pstk_t *) pcb_crosshair.AttachedObject.Ptr2;
-			thindraw_moved_ps(ps, dx, dy);
-			break;
-		}
-
-	case PCB_OBJ_LINE:
-		{
-			/* We move a local copy of the line -the real line hasn't moved, 
-			 * only the preview.
-			 */			
-			int constrained = 0;
-			pcb_line_t line;
-			
-			rnd_coord_t dx1 = dx, dx2 = dx;
-			rnd_coord_t dy1 = dy, dy2 = dy;
-			
-			memcpy(&line, (pcb_line_t *) pcb_crosshair.AttachedObject.Ptr2, sizeof(line));
-
-			if(conf_core.editor.rubber_band_keep_midlinedir)
-				rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_CONSTRAIN_MAIN_LINE, "pppppp", &line, &constrained, &dx1, &dy1, &dx2, &dy2);
-			rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icccc", constrained, dx1, dy1, dx2, dy2);
-
-			event_sent = 1;
-
-			line.Point1.X += dx1;
-			line.Point1.Y += dy1;
-			line.Point2.X += dx2;
-			line.Point2.Y += dy2;
-
-			pcb_draw_wireframe_line(pcb_crosshair.GC,
-															line.Point1.X, line.Point1.Y,
-															line.Point2.X, line.Point2.Y, 
-															line.Thickness, 0);
-			
-			/* Draw the DRC outline if it is enabled */
-			if (conf_core.editor.show_drc) {
-				rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
-				pcb_draw_wireframe_line(pcb_crosshair.GC,line.Point1.X, line.Point1.Y,
-																line.Point2.X, line.Point2.Y,
-																line.Thickness + 2 * (conf_core.design.bloat + 1), 0);
-				rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
-			}
-			break;
-		}
-
-	case PCB_OBJ_ARC:
-		{
-			/* Make a temporary arc and move it by dx,dy */
-			pcb_arc_t arc = *((pcb_arc_t *) pcb_crosshair.AttachedObject.Ptr2);
-			rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icccc", 0, dx, dy, dx, dy);
-			event_sent = 1;
-			
-			arc.X += dx;
-			arc.Y += dy;
-
-			pcb_draw_wireframe_arc(pcb_crosshair.GC, &arc, arc.Thickness);
-
-			/* Draw the DRC outline if it is enabled */
-			if (conf_core.editor.show_drc) {
-				rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
-				arc.Thickness += 2 * (conf_core.design.bloat + 1);
-				pcb_draw_wireframe_arc(pcb_crosshair.GC, &arc, arc.Thickness);
-				rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
-			}
-			break;
-		}
-
-	case PCB_OBJ_POLY:
-		{
-			pcb_poly_t *polygon = (pcb_poly_t *) pcb_crosshair.AttachedObject.Ptr2;
-
-			/* the tmp polygon has n+1 points because the first
-			 * and the last one are set to the same coordinates
-			 */
-			pcb_xordraw_poly(polygon, dx, dy, 0);
-			break;
-		}
-
-	case PCB_OBJ_TEXT:
-		{
-			pcb_text_t *text = (pcb_text_t *)pcb_crosshair.AttachedObject.Ptr2;
-			pcb_text_draw_xor(text, dx, dy);
-			break;
-		}
-
-	case PCB_OBJ_GFX:
-		{
-			pcb_gfx_t *gfx = (pcb_gfx_t *)pcb_crosshair.AttachedObject.Ptr2;
-			pcb_gfx_draw_xor(gfx, dx, dy);
-			break;
-		}
-
-
-	case PCB_OBJ_LINE_POINT:
-		{
-			pcb_line_t *line;
-			rnd_point_t *point,*point1,point2;
-
-			line = (pcb_line_t *) pcb_crosshair.AttachedObject.Ptr2;
-			point = (rnd_point_t *) pcb_crosshair.AttachedObject.Ptr3;
-			point1 = (point == &line->Point1 ? &line->Point2 : &line->Point1);
-			point2 = *point;
-			point2.X += dx;
-			point2.Y += dy;
-
-			if(conf_core.editor.move_linepoint_uses_route == 0) {/* config setting for selecting new 45/90 method */ 
-				pcb_draw_wireframe_line(pcb_crosshair.GC,point1->X, point1->Y, point2.X, point2.Y, line->Thickness, 0);
-
-				/* Draw the DRC outline if it is enabled */
-				if (conf_core.editor.show_drc) {
-					rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
-					pcb_draw_wireframe_line(pcb_crosshair.GC,point1->X, point1->Y, point2.X, 
-																	point2.Y,line->Thickness + 2 * (conf_core.design.bloat + 1), 0);
-					rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
-				}
-			}
-			else {
-				pcb_route_t	route;
-				pcb_route_init(&route);
-				pcb_route_calculate(	PCB,
-															&route,
-															point1,
-															&point2,
-															pcb_layer_id(PCB->Data,(pcb_layer_t *)pcb_crosshair.AttachedObject.Ptr1),
-															line->Thickness,
-															line->Clearance,
-															line->Flags,
-															rnd_gui->shift_is_pressed(rnd_gui),
-															rnd_gui->control_is_pressed(rnd_gui) );
-				pcb_route_draw(&route,pcb_crosshair.GC);
-				if (conf_core.editor.show_drc) 
-					pcb_route_draw_drc(&route,pcb_crosshair.GC);
-				pcb_route_destroy(&route);		
-			}
-
-			break;
-		}
-
-	case PCB_OBJ_ARC_POINT:
-		{
-			pcb_arc_t arc = *((pcb_arc_t *)pcb_crosshair.AttachedObject.Ptr2);
-			rnd_coord_t ox1,ox2,oy1,oy2;
-			rnd_coord_t nx1,nx2,ny1,ny2;
-
-			/* Get the initial position of the arc point */
-			pcb_arc_get_end(&arc,0, &ox1, &oy1);
-			pcb_arc_get_end(&arc,1, &ox2, &oy2);
-
-			/* Update the attached arc point */
-			pcb_arc_ui_move_or_copy(&pcb_crosshair);
-
-			/* Update our local arc copy from the attached object */
-			if(pcb_crosshair.AttachedObject.radius != 0) {
-				arc.Width   = pcb_crosshair.AttachedObject.radius;
-				arc.Height  = pcb_crosshair.AttachedObject.radius;
-			}
-			else {
-				arc.StartAngle  = pcb_crosshair.AttachedObject.start_angle;
-				arc.Delta       = pcb_crosshair.AttachedObject.delta_angle;
-			}
-
-			pcb_draw_wireframe_arc(pcb_crosshair.GC, &arc, arc.Thickness);
-
-			/* Draw the DRC outline if it is enabled */
-			if (conf_core.editor.show_drc) {
-				rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.drc);
-				arc.Thickness += 2 * (conf_core.design.bloat + 1);
-				pcb_draw_wireframe_arc(pcb_crosshair.GC, &arc, arc.Thickness);
-				rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
-			}
-
-			/* Get the new arc point positions, calculate the movement deltas and send them 
-			 * in a rubber_move_draw event */
-			pcb_arc_get_end(&arc,0, &nx1, &ny1);
-			pcb_arc_get_end(&arc,1, &nx2, &ny2);
-
-			rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icccc", 0, nx1-ox1,ny1-oy1,nx2-ox2,ny2-oy2);
-			event_sent = 1;
-			break;
-		}
-
-	case PCB_OBJ_POLY_POINT:
-		{
-			pcb_poly_t *polygon;
-			rnd_point_t *point;
-			rnd_cardinal_t point_idx, prev, next;
-
-			polygon = (pcb_poly_t *) pcb_crosshair.AttachedObject.Ptr2;
-			point = (rnd_point_t *) pcb_crosshair.AttachedObject.Ptr3;
-			point_idx = pcb_poly_point_idx(polygon, point);
-
-			/* get previous and following point */
-			prev = pcb_poly_contour_prev_point(polygon, point_idx);
-			next = pcb_poly_contour_next_point(polygon, point_idx);
-
-			/* draw the two segments */
-			rnd_render->draw_line(pcb_crosshair.GC, polygon->Points[prev].X, polygon->Points[prev].Y, point->X + dx, point->Y + dy);
-			rnd_render->draw_line(pcb_crosshair.GC, point->X + dx, point->Y + dy, polygon->Points[next].X, polygon->Points[next].Y);
-			break;
-		}
-
-	case PCB_OBJ_GFX_POINT:
-		{
-			pcb_gfx_t *gfx;
-			rnd_point_t *point, *prev, *next, *opp;
-			int point_idx, i;
-			double px, py, nx, ny, cx, cy;
-
-			gfx = (pcb_gfx_t *)pcb_crosshair.AttachedObject.Ptr2;
-			point = (rnd_point_t *)pcb_crosshair.AttachedObject.Ptr3;
-			point_idx = point - gfx->corner;
-			if ((point_idx < 0) || (point_idx > 3))
-				break;
-
-			cx = pcb_crosshair.X;
-			cy = pcb_crosshair.Y;
-
-			i = point_idx - 1;
-			if (i < 0) i = 3;
-			prev = gfx->corner + i;
-
-			i = (point_idx + 1) % 4;
-			next = gfx->corner + i;
-
-			i = (point_idx + 2) % 4;
-			opp = gfx->corner + i;
-
-			proj_extend(&px, &py, point->X - prev->X, point->Y - prev->Y, dx, dy);
-			proj_extend(&nx, &ny, point->X - next->X, point->Y - next->Y, dx, dy);
-
-			rnd_render->draw_line(pcb_crosshair.GC, opp->X, opp->Y, prev->X+px, prev->Y+py);
-			rnd_render->draw_line(pcb_crosshair.GC, opp->X, opp->Y, next->X+nx, next->Y+ny);
-			rnd_render->draw_line(pcb_crosshair.GC, cx, cy, prev->X+px, prev->Y+py);
-			rnd_render->draw_line(pcb_crosshair.GC, cx, cy, next->X+nx, next->Y+ny);
-		}
-		break;
-
-	case PCB_OBJ_SUBC:
-		pcb_xordraw_subc((pcb_subc_t *) pcb_crosshair.AttachedObject.Ptr2, dx, dy, 0);
-		break;
+		case PCB_OBJ_PSTK:        xordraw_movecopy_pstk(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_LINE:        xordraw_movecopy_line(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_ARC:         xordraw_movecopy_arc(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_POLY:        xordraw_movecopy_poly(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_TEXT:        xordraw_movecopy_text(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_GFX:         xordraw_movecopy_gfx(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_LINE_POINT:  xordraw_movecopy_line_point(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_ARC_POINT:   xordraw_movecopy_arc_point(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_POLY_POINT:  xordraw_movecopy_poly_point(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_GFX_POINT:   xordraw_movecopy_gfx_point(modifier, &event_sent, dx, dy); break;
+		case PCB_OBJ_SUBC:        pcb_xordraw_subc((pcb_subc_t *) pcb_crosshair.AttachedObject.Ptr2, dx, dy, 0); break;
 	}
 
 	/* floaters have a link back to their parent subc */
-	if (pcb_crosshair.AttachedObject.Ptr2 != NULL
-			&& PCB_FLAG_TEST(PCB_FLAG_FLOATER, (pcb_any_obj_t *)pcb_crosshair.AttachedObject.Ptr2)) {
+	if ((pcb_crosshair.AttachedObject.Ptr2 != NULL) && PCB_FLAG_TEST(PCB_FLAG_FLOATER, (pcb_any_obj_t *)pcb_crosshair.AttachedObject.Ptr2)) {
 		pcb_any_obj_t *obj = pcb_crosshair.AttachedObject.Ptr2;
 		if (obj->parent_type == PCB_PARENT_LAYER) {
 			pcb_data_t *data = obj->parent.layer->parent.data;
@@ -544,7 +676,16 @@ void pcb_xordraw_movecopy(void)
 	}
 
 	if(!event_sent)
-		rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icc", 0, dx, dy );
+		rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE_DRAW, "icc", 0, dx, dy);
+}
+
+void pcb_crosshair_attached_clean(rnd_hidlib_t *hidlib)
+{
+	if (xordraw_cache.pline != NULL)
+		rnd_poly_contour_del(&xordraw_cache.pline);
+
+	if (xordraw_cache.pa != NULL)
+		rnd_polyarea_free(&xordraw_cache.pa);
 }
 
 void rnd_draw_attached(rnd_hidlib_t *hidlib, rnd_bool inhibit_drawing_mode)
@@ -572,7 +713,6 @@ void rnd_draw_attached(rnd_hidlib_t *hidlib, rnd_bool inhibit_drawing_mode)
 		rnd_render->set_drawing_mode(rnd_gui, RND_HID_COMP_FLUSH, 1, NULL);
 }
 
-
 void rnd_draw_marks(rnd_hidlib_t *hidlib, rnd_bool inhibit_drawing_mode)
 {
 	rnd_coord_t ms = conf_core.appearance.mark_size, ms2 = ms / 2;
@@ -621,171 +761,6 @@ void pcb_notify_mark_change(rnd_bool changes_complete)
 		rnd_gui->notify_mark_change(rnd_gui, changes_complete);
 }
 
-
-/*
- * Below is the implementation of the "highlight on endpoint" functionality.
- * This highlights lines and arcs when the crosshair is on of their (two)
- * endpoints.
- */
-struct onpoint_search_info {
-	pcb_crosshair_t *crosshair;
-	rnd_coord_t X;
-	rnd_coord_t Y;
-};
-
-static rnd_r_dir_t onpoint_line_callback(const rnd_box_t * box, void *cl)
-{
-	struct onpoint_search_info *info = (struct onpoint_search_info *) cl;
-	pcb_crosshair_t *crosshair = info->crosshair;
-	pcb_line_t *line = (pcb_line_t *) box;
-
-#ifdef DEBUG_ONPOINT
-	printf("X=%ld Y=%ld    X1=%ld Y1=%ld X2=%ld Y2=%ld\n", info->X, info->Y,
-				 line->Point1.X, line->Point1.Y, line->Point2.X, line->Point2.Y);
-#endif
-	if ((line->Point1.X == info->X && line->Point1.Y == info->Y) || (line->Point2.X == info->X && line->Point2.Y == info->Y)) {
-		pcb_onpoint_t op;
-		op.type = PCB_OBJ_LINE;
-		op.obj.line = line;
-		vtop_append(&crosshair->onpoint_objs, op);
-		PCB_FLAG_SET(PCB_FLAG_ONPOINT, (pcb_any_obj_t *) line);
-		pcb_line_invalidate_draw(NULL, line);
-		return RND_R_DIR_FOUND_CONTINUE;
-	}
-	else {
-		return RND_R_DIR_NOT_FOUND;
-	}
-}
-
-#define close_enough(v1, v2) (coord_abs((v1)-(v2)) < 10)
-
-static rnd_r_dir_t onpoint_arc_callback(const rnd_box_t * box, void *cl)
-{
-	struct onpoint_search_info *info = (struct onpoint_search_info *) cl;
-	pcb_crosshair_t *crosshair = info->crosshair;
-	pcb_arc_t *arc = (pcb_arc_t *) box;
-	rnd_coord_t p1x, p1y, p2x, p2y;
-
-	p1x = arc->X - arc->Width * cos(RND_TO_RADIANS(arc->StartAngle));
-	p1y = arc->Y + arc->Height * sin(RND_TO_RADIANS(arc->StartAngle));
-	p2x = arc->X - arc->Width * cos(RND_TO_RADIANS(arc->StartAngle + arc->Delta));
-	p2y = arc->Y + arc->Height * sin(RND_TO_RADIANS(arc->StartAngle + arc->Delta));
-
-	/* printf("p1=%ld;%ld p2=%ld;%ld info=%ld;%ld\n", p1x, p1y, p2x, p2y, info->X, info->Y); */
-
-	if ((close_enough(p1x, info->X) && close_enough(p1y, info->Y)) || (close_enough(p2x, info->X) && close_enough(p2y, info->Y))) {
-		pcb_onpoint_t op;
-		op.type = PCB_OBJ_ARC;
-		op.obj.arc = arc;
-		vtop_append(&crosshair->onpoint_objs, op);
-		PCB_FLAG_SET(PCB_FLAG_ONPOINT, (pcb_any_obj_t *) arc);
-		pcb_arc_invalidate_draw(NULL, arc);
-		return RND_R_DIR_FOUND_CONTINUE;
-	}
-	else {
-		return RND_R_DIR_NOT_FOUND;
-	}
-}
-
-void DrawLineOrArc(int type, void *obj)
-{
-	switch (type) {
-	case PCB_OBJ_LINE_POINT:
-		/* Attention: We can use a NULL pointer here for the layer,
-		 * because it is not used in the pcb_line_invalidate_draw() function anyways.
-		 * ATM pcb_line_invalidate_draw() only calls AddPart() internally, which invalidates
-		 * the area specified by the line's bounding box.
-		 */
-		pcb_line_invalidate_draw(NULL, (pcb_line_t *) obj);
-		break;
-	case PCB_OBJ_ARC_POINT:
-		/* See comment above */
-		pcb_arc_invalidate_draw(NULL, (pcb_arc_t *) obj);
-		break;
-	}
-}
-
-
-#define op_swap(crosshair) \
-do { \
-	vtop_t __tmp__ = crosshair->onpoint_objs; \
-	crosshair->onpoint_objs = crosshair->old_onpoint_objs; \
-	crosshair->old_onpoint_objs = __tmp__; \
-} while(0)
-
-static void *onpoint_find(vtop_t *vect, void *obj_ptr)
-{
-	int i;
-
-	for (i = 0; i < vect->used; i++) {
-		pcb_onpoint_t *op = &(vect->array[i]);
-		if (op->obj.any == obj_ptr)
-			return op;
-	}
-	return NULL;
-}
-
-/*
- * Searches for lines or arcs which have points that are exactly
- * at the given coordinates and adds them to the crosshair's
- * object list along with their respective type.
- */
-static void onpoint_work(pcb_crosshair_t * crosshair, rnd_coord_t X, rnd_coord_t Y)
-{
-	rnd_box_t SearchBox = rnd_point_box(X, Y);
-	struct onpoint_search_info info;
-	int i;
-	rnd_bool redraw = rnd_false;
-
-	op_swap(crosshair);
-
-	/* Do not truncate to 0 because that may free the array */
-	vtop_truncate(&crosshair->onpoint_objs, 1);
-	crosshair->onpoint_objs.used = 0;
-
-
-	info.crosshair = crosshair;
-	info.X = X;
-	info.Y = Y;
-
-	for (i = 0; i < pcb_max_layer(PCB); i++) {
-		pcb_layer_t *layer = &PCB->Data->Layer[i];
-		/* Only find points of arcs and lines on currently visible layers. */
-		if (!layer->meta.real.vis)
-			continue;
-		rnd_r_search(layer->line_tree, &SearchBox, NULL, onpoint_line_callback, &info, NULL);
-		rnd_r_search(layer->arc_tree, &SearchBox, NULL, onpoint_arc_callback, &info, NULL);
-	}
-
-	/* Undraw the old objects */
-	for (i = 0; i < crosshair->old_onpoint_objs.used; i++) {
-		pcb_onpoint_t *op = &crosshair->old_onpoint_objs.array[i];
-
-		/* only remove and redraw those which aren't in the new list */
-		if (onpoint_find(&crosshair->onpoint_objs, op->obj.any) != NULL)
-			continue;
-
-		PCB_FLAG_CLEAR(PCB_FLAG_ONPOINT, (pcb_any_obj_t *) op->obj.any);
-		DrawLineOrArc(op->type, op->obj.any);
-		redraw = rnd_true;
-	}
-
-	/* draw the new objects */
-	for (i = 0; i < crosshair->onpoint_objs.used; i++) {
-		pcb_onpoint_t *op = &crosshair->onpoint_objs.array[i];
-
-		/* only draw those which aren't in the old list */
-		if (onpoint_find(&crosshair->old_onpoint_objs, op->obj.any) != NULL)
-			continue;
-		DrawLineOrArc(op->type, op->obj.any);
-		redraw = rnd_true;
-	}
-
-	if (redraw) {
-		rnd_hid_redraw(PCB);
-	}
-}
-
 static double square(double x)
 {
 	return x * x;
@@ -930,19 +905,22 @@ static void check_snap_offgrid_line(pcb_board_t *pcb, struct snap_data *snap_dat
 /* ---------------------------------------------------------------------------
  * recalculates the passed coordinates to fit the current grid setting
  */
-void pcb_crosshair_grid_fit(rnd_coord_t X, rnd_coord_t Y)
+void pcb_crosshair_grid_fit(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t Y)
 {
-	rnd_hidlib_t *hidlib = &PCB->hidlib;
-	rnd_coord_t nearest_grid_x, nearest_grid_y;
+	rnd_hidlib_t *hidlib = &pcb->hidlib;
+	rnd_coord_t nearest_grid_x, nearest_grid_y, oldx, oldy;
 	void *ptr1, *ptr2, *ptr3;
 	struct snap_data snap_data;
-	int ans;
+	int ans, newpos, enfmode;
 
-	PCB->hidlib.ch_x = pcb_crosshair.X = RND_CLAMP(X, -PCB->hidlib.size_x/2, PCB->hidlib.size_x*3/2);
-	PCB->hidlib.ch_y = pcb_crosshair.Y = RND_CLAMP(Y, -PCB->hidlib.size_y/2, PCB->hidlib.size_y*3/2);
+	oldx = pcb_crosshair.X;
+	oldy = pcb_crosshair.Y;
+	pcb->hidlib.ch_x = pcb_crosshair.X = RND_CLAMP(X, -pcb->hidlib.size_x/2, pcb->hidlib.size_x*3/2);
+	pcb->hidlib.ch_y = pcb_crosshair.Y = RND_CLAMP(Y, -pcb->hidlib.size_y/2, pcb->hidlib.size_y*3/2);
+
+	nearest_grid_x = rnd_grid_fit(pcb_crosshair.X, pcb->hidlib.grid, pcb->hidlib.grid_ox);
+	nearest_grid_y = rnd_grid_fit(pcb_crosshair.Y, pcb->hidlib.grid, pcb->hidlib.grid_oy);
 
-	nearest_grid_x = rnd_grid_fit(pcb_crosshair.X, PCB->hidlib.grid, PCB->hidlib.grid_ox);
-	nearest_grid_y = rnd_grid_fit(pcb_crosshair.Y, PCB->hidlib.grid, PCB->hidlib.grid_oy);
 
 	if (pcb_marked.status && conf_core.editor.orthogonal_moves) {
 		rnd_coord_t dx = pcb_crosshair.X - hidlib->tool_grabbed.X;
@@ -962,7 +940,7 @@ void pcb_crosshair_grid_fit(rnd_coord_t X, rnd_coord_t Y)
 	snap_data.max_sq_dist = snap_data.max_sq_dist * snap_data.max_sq_dist;
 
 	ans = PCB_OBJ_VOID;
-	if (!PCB->RatDraw)
+	if (!pcb->RatDraw)
 		ans = pcb_search_grid_slop(X, Y, PCB_OBJ_SUBC, &ptr1, &ptr2, &ptr3);
 
 	hidlib->tool_snapped_obj_bbox = NULL;
@@ -1036,7 +1014,7 @@ void pcb_crosshair_grid_fit(rnd_coord_t X, rnd_coord_t Y)
 
 	/* Snap to offgrid points on lines. */
 	if (conf_core.editor.snap_offgrid_line)
-		check_snap_offgrid_line(PCB, &snap_data, nearest_grid_x, nearest_grid_y);
+		check_snap_offgrid_line(pcb, &snap_data, nearest_grid_x, nearest_grid_y);
 
 	ans = PCB_OBJ_VOID;
 	if (conf_core.editor.snap_pin)
@@ -1047,11 +1025,13 @@ void pcb_crosshair_grid_fit(rnd_coord_t X, rnd_coord_t Y)
 		check_snap_object(&snap_data, pnt->X, pnt->Y, rnd_true, NULL);
 	}
 
-	PCB->hidlib.ch_x = pcb_crosshair.X = snap_data.x;
-	PCB->hidlib.ch_y = pcb_crosshair.Y = snap_data.y;
+	newpos = (snap_data.x != oldx) || (snap_data.y != oldy);
 
-	if (conf_core.editor.highlight_on_point)
-		onpoint_work(&pcb_crosshair, pcb_crosshair.X, pcb_crosshair.Y);
+	pcb->hidlib.ch_x = pcb_crosshair.X = snap_data.x;
+	pcb->hidlib.ch_y = pcb_crosshair.Y = snap_data.y;
+
+	if (newpos)
+		rnd_event(hidlib, PCB_EVENT_CROSSHAIR_NEW_POS, "pcc", &pcb_crosshair, oldx, oldy);
 
 	if (rnd_conf.editor.mode == pcb_crosshair.tool_arrow) {
 		ans = pcb_search_grid_slop(X, Y, PCB_OBJ_LINE_POINT, &ptr1, &ptr2, &ptr3);
@@ -1065,8 +1045,19 @@ void pcb_crosshair_grid_fit(rnd_coord_t X, rnd_coord_t Y)
 		}
 	}
 
-	if (rnd_conf.editor.mode == pcb_crosshair.tool_line && pcb_crosshair.AttachedLine.State != PCB_CH_STATE_FIRST && conf_core.editor.auto_drc)
-		pcb_line_enforce_drc(PCB);
+	enfmode  = (rnd_conf.editor.mode == pcb_crosshair.tool_line) && pcb_crosshair.AttachedLine.State != PCB_CH_STATE_FIRST;
+	if (pcb_brave & PCB_BRAVE_ENFORCE_CLR_MOVE)
+		enfmode |= (rnd_conf.editor.mode == pcb_crosshair.tool_move) && (pcb_crosshair.AttachedObject.Type == PCB_OBJ_LINE_POINT);
+	if (enfmode && conf_core.editor.auto_drc) {
+		rnd_coord_t thick;
+		
+		if (rnd_conf.editor.mode == pcb_crosshair.tool_move)
+			thick = pcb_crosshair.AttachedLine.tot_thick;
+		else
+			thick = conf_core.design.line_thickness + 2 * (conf_core.design.clearance + 1);
+
+		pcb_line_enforce_drc(pcb, thick);
+	}
 
 	rnd_gui->set_crosshair(rnd_gui, pcb_crosshair.X, pcb_crosshair.Y, HID_SC_DO_NOTHING);
 }
@@ -1076,33 +1067,33 @@ void pcb_crosshair_grid_fit(rnd_coord_t X, rnd_coord_t Y)
  */
 void pcb_crosshair_move_relative(rnd_coord_t DeltaX, rnd_coord_t DeltaY)
 {
-	pcb_crosshair_grid_fit(pcb_crosshair.X + DeltaX, pcb_crosshair.Y + DeltaY);
+	pcb_crosshair_grid_fit(PCB, pcb_crosshair.X + DeltaX, pcb_crosshair.Y + DeltaY);
 }
 
 /* ---------------------------------------------------------------------------
  * move crosshair absolute
  * return rnd_true if the crosshair was moved from its existing position
  */
-rnd_bool pcb_crosshair_move_absolute(rnd_coord_t X, rnd_coord_t Y)
+rnd_bool pcb_crosshair_move_absolute(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t Y)
 {
 	rnd_coord_t x, y, z;
 	pcb_crosshair.ptr_x = X;
 	pcb_crosshair.ptr_y = Y;
 	x = pcb_crosshair.X;
 	y = pcb_crosshair.Y;
-	pcb_crosshair_grid_fit(X, Y);
+	pcb_crosshair_grid_fit(pcb, X, Y);
 	if (pcb_crosshair.X != x || pcb_crosshair.Y != y) {
 		/* back up to old position to notify the GUI
 		 * (which might want to erase the old crosshair) */
 		z = pcb_crosshair.X;
-		PCB->hidlib.ch_x = pcb_crosshair.X = x;
+		pcb->hidlib.ch_x = pcb_crosshair.X = x;
 		x = z;
 		z = pcb_crosshair.Y;
-		PCB->hidlib.ch_y = pcb_crosshair.Y = y;
-		rnd_hid_notify_crosshair_change(&PCB->hidlib, rnd_false); /* Our caller notifies when it has done */
+		pcb->hidlib.ch_y = pcb_crosshair.Y = y;
+		rnd_hid_notify_crosshair_change(&pcb->hidlib, rnd_false); /* Our caller notifies when it has done */
 		/* now move forward again */
-		PCB->hidlib.ch_x = pcb_crosshair.X = x;
-		PCB->hidlib.ch_y = pcb_crosshair.Y = z;
+		pcb->hidlib.ch_x = pcb_crosshair.X = x;
+		pcb->hidlib.ch_y = pcb_crosshair.Y = z;
 		return rnd_true;
 	}
 	return rnd_false;
@@ -1111,14 +1102,14 @@ rnd_bool pcb_crosshair_move_absolute(rnd_coord_t X, rnd_coord_t Y)
 /* ---------------------------------------------------------------------------
  * centers the displayed PCB around the specified point (X,Y)
  */
-void pcb_center_display(rnd_coord_t X, rnd_coord_t Y)
+void pcb_center_display(pcb_board_t *pcb, rnd_coord_t X, rnd_coord_t Y)
 {
-	rnd_coord_t save_grid = PCB->hidlib.grid;
-	PCB->hidlib.grid = 1;
-	if (pcb_crosshair_move_absolute(X, Y))
-		rnd_hid_notify_crosshair_change(&PCB->hidlib, rnd_true);
+	rnd_coord_t save_grid = pcb->hidlib.grid;
+	pcb->hidlib.grid = 1;
+	if (pcb_crosshair_move_absolute(pcb, X, Y))
+		rnd_hid_notify_crosshair_change(&pcb->hidlib, rnd_true);
 	rnd_gui->set_crosshair(rnd_gui, pcb_crosshair.X, pcb_crosshair.Y, HID_SC_WARP_POINTER);
-	PCB->hidlib.grid = save_grid;
+	pcb->hidlib.grid = save_grid;
 }
 
 /* allocate GC only when the GUI is already up and running */
@@ -1138,10 +1129,6 @@ static void pcb_crosshair_gui_init(rnd_hidlib_t *hidlib, void *user_data, int ar
  */
 void pcb_crosshair_init(void)
 {
-	/* Initialize the onpoint data. */
-	memset(&pcb_crosshair.onpoint_objs, 0, sizeof(vtop_t));
-	memset(&pcb_crosshair.old_onpoint_objs, 0, sizeof(vtop_t));
-
 	/* clear the mark */
 	pcb_marked.status = rnd_false;
 
@@ -1192,7 +1179,7 @@ void pcb_crosshair_set_local_ref(rnd_coord_t X, rnd_coord_t Y, rnd_bool Showing)
 
 static void pcb_event_move_crosshair(rnd_coord_t ev_x, rnd_coord_t ev_y)
 {
-	if (pcb_crosshair_move_absolute(ev_x, ev_y)) {
+	if (pcb_crosshair_move_absolute(PCB, ev_x, ev_y)) {
 		/* update object position and cursor location */
 		rnd_tool_adjust_attached(&PCB->hidlib);
 		rnd_event(&PCB->hidlib, PCB_EVENT_DRAW_CROSSHAIR_CHATT, NULL);
@@ -1238,7 +1225,7 @@ void rnd_hidlib_crosshair_move_to(rnd_hidlib_t *hl, rnd_coord_t abs_x, rnd_coord
 {
 	if (!mouse_mot) {
 		rnd_hid_notify_crosshair_change(hl, rnd_false);
-		if (pcb_crosshair_move_absolute(abs_x, abs_y))
+		if (pcb_crosshair_move_absolute((pcb_board_t *)hl, abs_x, abs_y))
 			rnd_hid_notify_crosshair_change(hl, rnd_true);
 		rnd_hid_notify_crosshair_change(hl, rnd_true);
 	}
