@@ -219,6 +219,7 @@ static void draw_virtual_layers(pcb_draw_info_t *info, const legacy_vlayer_t *lv
 
 	if (set_vlayer(info, lvly_drawn->top_fab, lvly_drawn->top_fab_enable, PCB_VLY_FAB)) {
 		xform_setup(info, &tmp, NULL);
+		rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_POSITIVE, pcb_draw_out.direct, info->drawn_area);
 		pcb_stub_draw_fab(info, pcb_draw_out.fgGC, &hid_exp);
 		rnd_render->end_layer(rnd_render);
 		info->xform = NULL; info->layer = NULL;
@@ -288,7 +289,7 @@ static void draw_xor_marks(pcb_draw_info_t *info)
 		pcb_draw_pstk_marks(info);
 	}
 
-	rnd_event(&PCB->hidlib, RND_EVENT_GUI_DRAW_OVERLAY_XOR, "p", &pcb_draw_out.fgGC, NULL);
+	rnd_event(&PCB->hidlib, RND_EVENT_GUI_DRAW_OVERLAY_XOR, "pp", &pcb_draw_out.fgGC, info, NULL);
 
 	rnd_hid_set_draw_xor(pcb_draw_out.fgGC, 0);
 	rnd_render->set_drawing_mode(rnd_render, RND_HID_COMP_FLUSH, pcb_draw_out.direct, info->drawn_area);
@@ -624,6 +625,8 @@ static void pcb_draw_ppv(pcb_draw_info_t *info, rnd_layergrp_id_t group)
 	}
 }
 
+#include "draw_label_smart.c"
+
 /* ---------------------------------------------------------------------------
  * Draws padstacks' names - Always draws for non-gui HIDs,
  * otherwise drawing depends on PCB->pstk_on
@@ -635,6 +638,7 @@ void pcb_draw_pstk_names(pcb_draw_info_t *info, rnd_layergrp_id_t group, const r
 		for(n = 0; n < delayed_labels.used; n++)
 			pcb_draw_obj_label(info, group, delayed_labels.array[n]);
 	}
+	pcb_label_smart_flush(info);
 	delayed_labels.used = 0;
 }
 
@@ -1065,6 +1069,8 @@ void pcb_draw_obj(pcb_any_obj_t *obj)
 
 static void pcb_draw_obj_label(pcb_draw_info_t *info, rnd_layergrp_id_t gid, pcb_any_obj_t *obj)
 {
+	rnd_bool vis_side = 1;
+
 	if (pcb_hidden_floater(obj, info))
 		return;
 
@@ -1072,16 +1078,16 @@ static void pcb_draw_obj_label(pcb_draw_info_t *info, rnd_layergrp_id_t gid, pcb
 	if ((!pcb_draw_force_termlab) && (obj->parent_type == PCB_PARENT_LAYER)) {
 		pcb_layer_t *ly = pcb_layer_get_real(obj->parent.layer);
 		if ((ly != NULL) && (ly->meta.real.grp != gid))
-			return;
+			vis_side = 0;
 	}
 
 	switch(obj->type) {
-		case PCB_OBJ_LINE:    pcb_line_draw_label(info, (pcb_line_t *)obj); return;
-		case PCB_OBJ_ARC:     pcb_arc_draw_label(info, (pcb_arc_t *)obj); return;
-		case PCB_OBJ_GFX:     pcb_gfx_draw_label(info, (pcb_gfx_t *)obj); return;
-		case PCB_OBJ_POLY:    pcb_poly_draw_label(info, (pcb_poly_t *)obj); return;
-		case PCB_OBJ_TEXT:    pcb_text_draw_label(info, (pcb_text_t *)obj); return;
-		case PCB_OBJ_PSTK:    pcb_pstk_draw_label(info, (pcb_pstk_t *)obj); return;
+		case PCB_OBJ_LINE:    pcb_line_draw_label(info, (pcb_line_t *)obj, vis_side); return;
+		case PCB_OBJ_ARC:     pcb_arc_draw_label(info, (pcb_arc_t *)obj, vis_side); return;
+		case PCB_OBJ_GFX:     pcb_gfx_draw_label(info, (pcb_gfx_t *)obj, vis_side); return;
+		case PCB_OBJ_POLY:    pcb_poly_draw_label(info, (pcb_poly_t *)obj, vis_side); return;
+		case PCB_OBJ_TEXT:    pcb_text_draw_label(info, (pcb_text_t *)obj, vis_side); return;
+		case PCB_OBJ_PSTK:    pcb_pstk_draw_label(info, (pcb_pstk_t *)obj, vis_side); return;
 		default: break;
 	}
 }
@@ -1099,7 +1105,10 @@ static void expose_begin(pcb_output_t *save, rnd_hid_t *hid)
 	vtp0_truncate(&delayed_labels, 0);
 	vtp0_truncate(&delayed_objs, 0);
 
-	rnd_render = pcb_draw_out.hid = hid;
+	if ((rnd_render != NULL) && (!rnd_render->override_render))
+		rnd_render = hid;
+	pcb_draw_out.hid = rnd_render;
+
 	pcb_draw_out.fgGC = rnd_hid_make_gc();
 	pcb_draw_out.padGC = rnd_hid_make_gc();
 	pcb_draw_out.backpadGC = rnd_hid_make_gc();
@@ -1179,6 +1188,7 @@ void pcb_draw_setup_default_xform_info(rnd_hid_t *hid, pcb_draw_info_t *info)
 	}
 }
 
+int pcb_draw_stamp = 0;
 void rnd_expose_main(rnd_hid_t * hid, const rnd_hid_expose_ctx_t *ctx, rnd_xform_t *xform_caller)
 {
 	if (!pcb_draw_inhibit) {
@@ -1191,6 +1201,7 @@ void rnd_expose_main(rnd_hid_t * hid, const rnd_hid_expose_ctx_t *ctx, rnd_xform
 		info.xform_caller = xform_caller;
 		info.xform = info.xform_exporter = NULL;
 		info.layer = NULL;
+		info.draw_stamp = ++pcb_draw_stamp;
 
 		pcb_draw_setup_default_xform_info(hid, &info);
 
@@ -1265,23 +1276,30 @@ static const char *lab_with_intconn(const pcb_any_obj_t *term, int intconn, cons
 	}
 
 
-void pcb_label_draw(pcb_draw_info_t *info, rnd_coord_t x, rnd_coord_t y, double scale, rnd_bool vert, rnd_bool centered, const char *label)
+void pcb_label_draw(pcb_draw_info_t *info, rnd_coord_t x, rnd_coord_t y, double scale, rnd_bool vert, rnd_bool centered, const char *label, int prio)
 {
 	int mirror, direction;
+
 	PCB_TERM_LABEL_SETUP((const unsigned char *)label);
 
-	mirror = (flip_x ^ flip_y) ? PCB_TXT_MIRROR_Y : 0;
+	mirror = (flip_x ? PCB_TXT_MIRROR_X : 0) | (flip_y ? PCB_TXT_MIRROR_Y : 0);
 	direction = (vert ? 1 : 0);
 
-	rnd_render->set_color(pcb_draw_out.fgGC, &conf_core.appearance.color.pin_name);
+	if (!conf_core.appearance.smart_labels) {
 
-	if (rnd_render->gui)
-		pcb_draw_force_termlab++;
-	pcb_text_draw_string(info, font, (unsigned const char *)label, x, y, scale/100, scale/100, direction*90.0, mirror, 1, 0, 0, 0, 0, PCB_TXT_TINY_HIDE);
-	if (rnd_render->gui)
-		pcb_draw_force_termlab--;
+		rnd_render->set_color(pcb_draw_out.fgGC, &conf_core.appearance.color.pin_name);
+
+		if (rnd_render->gui)
+			pcb_draw_force_termlab++;
+		pcb_text_draw_string(info, font, (unsigned const char *)label, x, y, scale/100, scale/100, direction*90.0, mirror, conf_core.appearance.label_thickness, 0, 0, 0, 0, PCB_TXT_TINY_HIDE);
+		if (rnd_render->gui)
+			pcb_draw_force_termlab--;
+	}
+	else
+		pcb_label_smart_add(info, x, y, scale/100.0, direction*90.0, mirror, w, h, label, prio);
 }
 
+
 void pcb_label_invalidate(rnd_coord_t x, rnd_coord_t y, double scale, rnd_bool vert, rnd_bool centered, const char *label)
 {
 	rnd_coord_t ox = x, oy = y, margin = 0;
@@ -1301,8 +1319,30 @@ void pcb_label_invalidate(rnd_coord_t x, rnd_coord_t y, double scale, rnd_bool v
 void pcb_term_label_draw(pcb_draw_info_t *info, rnd_coord_t x, rnd_coord_t y, double scale, rnd_bool vert, rnd_bool centered, const pcb_any_obj_t *obj)
 {
 	char buff[128];
+	int prio = 1; /* slightly lower prio than subc */
+	int on_bottom, flips;
 	const char *label = lab_with_intconn(obj, obj->intconn, obj->term, buff, sizeof(buff));
-	pcb_label_draw(info, x, y, scale, vert, centered, label);
+
+	flips = !!(rnd_conf.editor.view.flip_x ^ rnd_conf.editor.view.flip_y);
+
+	switch(obj->type) {
+		case PCB_OBJ_PSTK: /* top prio */
+			break;
+		case PCB_OBJ_LINE:
+		case PCB_OBJ_ARC:
+		case PCB_OBJ_TEXT:
+		case PCB_OBJ_POLY:
+		case PCB_OBJ_GFX:
+			on_bottom = !!(pcb_layer_flags_(obj->parent.layer) & PCB_LYT_BOTTOM);
+			if (on_bottom == flips)
+				prio += 1;
+			else
+				prio += 2; /* other-side object penalty */
+			break;
+		default:
+			prio += 10;
+	}
+	pcb_label_draw(info, x, y, scale, vert, centered, label, prio);
 }
 
 void pcb_term_label_invalidate(rnd_coord_t x, rnd_coord_t y, double scale, rnd_bool vert, rnd_bool centered, const pcb_any_obj_t *obj)
