@@ -39,6 +39,7 @@ enum {
 	PCB_EVENT_LAYERVIS_CHANGED,           /* called after the visibility of layers has changed */
 	PCB_EVENT_LIBRARY_CHANGED,            /* called after a change in the footprint lib (used to be the LibraryChanged action) */
 	PCB_EVENT_FONT_CHANGED,               /* called when a font has changed; argument is the font ID */
+	PCB_EVENT_BOARD_EDITED,               /* called after any edit on the board */
 
 	PCB_EVENT_UNDO_POST,                  /* called after an undo/redo operation; argument is an integer pcb_undo_ev_t */
 
@@ -53,12 +54,14 @@ enum {
 
 	PCB_EVENT_DRAW_CROSSHAIR_CHATT,       /* called from crosshair code upon attached object recalculation; event handlers can use this hook to enforce various geometric restrictions */
 
-	PCB_EVENT_DRC_RUN,                    /* called from core to run all configured DRCs (implemented in plugins) */
+	PCB_EVENT_DRC_RUN,                    /* called from core to run all configured DRCs (implemented in plugins). Args: (int *) that each DRC plugin shall increase if it did any check */
 
 	PCB_EVENT_NET_INDICATE_SHORT,         /* called by core to get a shortcircuit indicated (e.g. by mincut). Args: (pcb_net_t *net, pcb_any_obj_t *offending_term, pcb_net_t *offending_net, int *handled, int *cancel) - if *handled is non-zero, the short is already indicated; if *cancel is non-zero the whole process is cancelled, no more advanced short checking should take place in this session */
 
 	PCB_EVENT_LAYER_KEY_CHANGE,           /* called by core if a pcb-rnd::key::* attribute on a layer changes */
 
+	PCB_EVENT_CROSSHAIR_NEW_POS,          /* called when the crosshair is moved to a new position; screen indications may need to be updated; args: (pcb_crosshair_t *), pcb_coord_t oldx, pcb_coord_t oldy */
+
 	PCB_EVENT_last                        /* not a real event */
 };
 
