@@ -150,15 +150,18 @@ fgw_error_t pcb_act_ExtobjConvFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
-
 static const char pcb_acts_ExtobjGUIPropEdit[] = "ExtobjGUIPropEdit([object, [idpath]])";
 static const char pcb_acth_ExtobjGUIPropEdit[] = "Invoke the extobj-implementation-specific GUI property editor, if available";
-fgw_error_t pcb_act_ExtobjGUIPropEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+
+static int exto_get_obj(fgw_arg_t *res, int argc, fgw_arg_t *argv, pcb_subc_t **dst_obj, pcb_extobj_t **dst_eo, rnd_bool require_extobj)
 {
-	pcb_extobj_t *eo;
 	int op = F_Object;
+	pcb_extobj_t *eo;
 	pcb_subc_t *obj;
 
+	*dst_obj = NULL;
+	*dst_eo = NULL;
+
 	RND_ACT_MAY_CONVARG(1, FGW_KEYWORD, ExtobjGUIPropEdit, op = fgw_keyword(&argv[1]));
 
 	switch(op) {
@@ -192,19 +195,42 @@ fgw_error_t pcb_act_ExtobjGUIPropEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			RND_ACT_FAIL(ExtobjConvFrom);
 	}
 
-	if ((obj == NULL) || (obj->type != PCB_OBJ_SUBC) || (obj->extobj == NULL)) {
-		rnd_message(RND_MSG_ERROR, "Object is not an extended object");
-		RND_ACT_IRES(1);
+	if ((obj == NULL) || (obj->type != PCB_OBJ_SUBC)) {
+		rnd_message(RND_MSG_ERROR, "Object is not an extended object (not even a subcircuit)\n");
+		RND_ACT_IRES(-1);
+		return 0;
+	}
+
+	if (require_extobj &&  (obj->extobj == NULL)) {
+		rnd_message(RND_MSG_ERROR, "Subcircuit is not an extended object\n");
+		RND_ACT_IRES(-1);
 		return 0;
 	}
 
 	eo = pcb_extobj_get(obj);
-	if (eo == NULL) {
-		rnd_message(RND_MSG_ERROR, "Extended object '%s' is not available", obj->extobj);
+	if (require_extobj && (eo == NULL)) {
+		rnd_message(RND_MSG_ERROR, "Extended object '%s' is not available\n", obj->extobj);
 		RND_ACT_IRES(1);
 		return 0;
 	}
 
+
+	*dst_obj = obj;
+	*dst_eo = eo;
+	return 0;
+}
+
+fgw_error_t pcb_act_ExtobjGUIPropEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	pcb_extobj_t *eo;
+	pcb_subc_t *obj;
+	int rv = exto_get_obj(res, argc, argv, &obj, &eo, 1);
+
+	if (obj == NULL) {
+		RND_ACT_IRES(1);
+		return rv;
+	}
+
 	if (eo->gui_propedit != NULL)
 		eo->gui_propedit(obj);
 	else
@@ -214,9 +240,45 @@ fgw_error_t pcb_act_ExtobjGUIPropEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
+static const char pcb_acts_ExtobjToggle[] = "ExtobjToggle([object, [idpath]])";
+static const char pcb_acth_ExtobjToggle[] = "Convert an extobj into a plain subc or back";
+fgw_error_t pcb_act_ExtobjToggle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	pcb_extobj_t *eo;
+	pcb_subc_t *obj;
+	int rv = exto_get_obj(res, argc, argv, &obj, &eo, 0);
+
+	if (obj == NULL) {
+		RND_ACT_IRES(1);
+		return rv;
+	}
+
+	if (eo != NULL) {
+		pcb_attribute_put(&obj->Attributes, "disabled_extobj", obj->extobj);
+		pcb_attribute_remove(&obj->Attributes, "extobj");
+		PCB_FLAG_CLEAR(PCB_FLAG_LOCK, obj);
+	}
+	else {
+		const char *type = pcb_attribute_get(&obj->Attributes, "disabled_extobj");
+		if (type == NULL) {
+			rnd_message(RND_MSG_ERROR, "Subcircuit was not an extended object\n");
+			RND_ACT_IRES(1);
+			return 0;
+		}
+		pcb_attribute_put(&obj->Attributes, "extobj", type);
+		pcb_attribute_remove(&obj->Attributes, "disabled_extobj");
+		PCB_FLAG_SET(PCB_FLAG_LOCK, obj);
+	}
+
+	RND_ACT_IRES(0);
+	return 0;
+}
+
+
 static rnd_action_t pcb_extobj_action_list[] = {
 	{"ExtobjConvFrom", pcb_act_ExtobjConvFrom, pcb_acth_ExtobjConvFrom, pcb_acts_ExtobjConvFrom},
-	{"ExtobjGUIPropEdit", pcb_act_ExtobjGUIPropEdit, pcb_acth_ExtobjGUIPropEdit, pcb_acts_ExtobjGUIPropEdit}
+	{"ExtobjGUIPropEdit", pcb_act_ExtobjGUIPropEdit, pcb_acth_ExtobjGUIPropEdit, pcb_acts_ExtobjGUIPropEdit},
+	{"ExtobjToggle", pcb_act_ExtobjToggle, pcb_acth_ExtobjToggle, pcb_acts_ExtobjToggle}
 };
 
 void pcb_extobj_act_init2(void)
