@@ -27,6 +27,7 @@
 /* Follow galvanic connections through overlapping objects */
 
 #include "config.h"
+#include <genht/ht_utils.h>
 #include "find.h"
 #include "undo.h"
 #include "obj_subc_parent.h"
@@ -36,6 +37,215 @@ const pcb_find_t pcb_find0_, *pcb_find0 = &pcb_find0_;
 #include "find_geo.c"
 #include "find_any_isect.c"
 
+/* Multimark flags for a given object. This struct is used to store
+   partial marks for objects that have multiple independently connected
+   components: when such an object has the mark set that only means at
+   least one component is found. But then which components are found needs
+   to be looked up in an object-type-specific way from this struct. Multiple
+   component objects:
+    - padstacks: each (copper) layer may have a shape that is connected or not
+                 (through a hole/slot) to others shapes; there can be only one
+                 group of connections realized by the hole/slot and zero or
+                 more independent shapes
+    - text: each drawing primitive should be a separate component (not yet implemented)
+    - poly: if fullpoly is on, each island is a separate component (not yet implemented)
+*/
+typedef union pcb_find_mm_s {
+	unsigned char layers[(PCB_MAX_LAYER / 8)+1]; /* for pstk */
+} pcb_find_mm_t;
+
+/* Retrieve (or allocate) the multimark structure for a given object, storing
+   it in a cache in ctx. Also init the cache as needed */
+RND_INLINE pcb_find_mm_t *pcb_find_get_mm(pcb_find_t *ctx, pcb_any_obj_t *obj)
+{
+	pcb_find_mm_t *mm;
+
+	if (!ctx->multimark_inited) {
+		htpp_init(&ctx->multimark, ptrhash, ptrkeyeq);
+		ctx->multimark_inited = 1;
+		mm = NULL;
+	}
+	else
+		mm = htpp_get(&ctx->multimark, obj);
+
+	if (mm != NULL)
+		return mm;
+
+	mm = calloc(sizeof(pcb_find_mm_t), 1);
+	htpp_set(&ctx->multimark, obj, mm);
+	return mm;
+}
+
+/* Padstack: take all layers that are connected by a hole/slot and mark all
+   them. Useful when any of them gets marked, this is how the mark propagates
+   through the plated hole/slot */
+RND_INLINE void mark_all_hole_connections(pcb_find_t *ctx, pcb_pstk_t *ps, pcb_find_mm_t *mm)
+{
+	rnd_layer_id_t lid;
+
+	for(lid = 0; lid < ctx->pcb->Data->LayerN; lid++) {
+		pcb_layer_t *ly = &ctx->pcb->Data->Layer[lid];
+		pcb_pstk_shape_t *shp = pcb_pstk_shape_at(ctx->pcb, ps, ly);
+		if ((shp != NULL) && shp->hconn)
+			mm->layers[lid / 8] |= (1 << (lid % 8));
+	}
+}
+
+/* Set mark on components of a padstak: on the component that's on the same
+   layer as arrived_from, and any hole/slot connected other shapes */
+RND_INLINE void pcb_find_mark_set_pstk(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_any_obj_t *arrived_from)
+{
+	pcb_find_mm_t *mm;
+	pcb_pstk_proto_t *proto = pcb_pstk_get_proto((pcb_pstk_t *)obj);
+	pcb_layer_t *ly;
+	pcb_data_t *data;
+	rnd_layer_id_t lid;
+	pcb_pstk_shape_t *shp;
+
+	/* do anything only if there are disjoint copper shapes */
+	if ((proto == NULL) || (proto->all_copper_connd && proto->hplated) || ((pcb_pstk_t *)obj)->term)
+		return;
+
+	mm = pcb_find_get_mm(ctx, obj);
+	if (arrived_from != NULL) {
+		switch(arrived_from->type) {
+			case PCB_OBJ_LINE:
+			case PCB_OBJ_ARC:
+			case PCB_OBJ_TEXT:
+			case PCB_OBJ_POLY:
+			case PCB_OBJ_GFX:
+				/* single layer */
+				ly = arrived_from->parent.layer;
+				assert(arrived_from->parent_type == PCB_PARENT_LAYER);
+				data = ly->parent.data;
+				lid = ly - data->Layer;
+				if ((lid < 0) || (lid >= PCB_MAX_LAYER)) {
+					assert(!"pcb_find_mark_set: invalid layer to arrive from");
+					goto fallback1;
+				}
+				mm->layers[lid / 8] |= (1 << (lid % 8));
+
+				/* propagate the mark if the shape is connected to the hole/slot
+				   (hconn) and the hole/slot is 
+				   plated */
+				if ((ctx->pcb != NULL) && (proto->hplated)) {
+					shp = pcb_pstk_shape_at(ctx->pcb, (pcb_pstk_t *)obj, ly);
+					if (shp->hconn)
+						mark_all_hole_connections(ctx, (pcb_pstk_t *)obj, mm);
+				}
+				break;
+			case PCB_OBJ_PSTK:
+				if (arrived_from != obj)
+					rnd_message(RND_MSG_ERROR, "BUG: disjoint padstack overlap with disjoint padstack - not handled correctly\nPlease report htis bug with your board file!\n");
+				goto fallback1;
+			default:
+				assert(!"pcb_find_mark_set: invalid arrived_from object type");
+				goto fallback1;
+		}
+	}
+	else {
+		/* coming from NULL means starting object - mark all layers found */
+		fallback1:;
+		memset(&mm->layers, 0xff, sizeof(mm->layers));
+	}
+}
+
+
+/* Set found mark on an object. If arrived_from is NULL, obj is a starting
+   point for the search */
+RND_INLINE void pcb_find_mark_set(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_any_obj_t *arrived_from)
+{
+	PCB_DFLAG_SET(&obj->Flags, ctx->mark);
+	switch(obj->type) {
+		case PCB_OBJ_PSTK: pcb_find_mark_set_pstk(ctx, obj, arrived_from); break;
+		default: break;
+	}
+}
+
+/* Return whether pstk is marked on the layer(s) specified by arrived_from.
+   If arrived_from is NULL, obj is a starting object and is always found. */
+RND_INLINE int pcb_find_mark_get_pstk(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_any_obj_t *arrived_from)
+{
+	pcb_find_mm_t *mm;
+	pcb_pstk_proto_t *proto = pcb_pstk_get_proto((pcb_pstk_t *)obj);
+	pcb_layer_t *ly;
+	pcb_data_t *data;
+	rnd_layer_id_t lid;
+
+	/* do anything only if there are disjoint copper shapes */
+	if ((proto == NULL) || (proto->all_copper_connd && proto->hplated) || ((pcb_pstk_t *)obj)->term)
+		return 1;
+
+	mm = pcb_find_get_mm(ctx, obj);
+	if (arrived_from != NULL) {
+		switch(arrived_from->type) {
+			case PCB_OBJ_LINE:
+			case PCB_OBJ_ARC:
+			case PCB_OBJ_TEXT:
+			case PCB_OBJ_POLY:
+			case PCB_OBJ_GFX:
+				/* single layer */
+				ly = arrived_from->parent.layer;
+				assert(arrived_from->parent_type == PCB_PARENT_LAYER);
+				data = ly->parent.data;
+				lid = ly - data->Layer;
+				if ((lid < 0) || (lid >= PCB_MAX_LAYER)) {
+					assert(!"pcb_find_mark_get: invalid layer to arrive from");
+					return 1;
+				}
+				return !!(mm->layers[lid / 8] & (1 << (lid % 8)));
+			case PCB_OBJ_PSTK:
+				if (arrived_from != obj)
+					rnd_message(RND_MSG_ERROR, "BUG: disjoint padstack overlap with disjoint padstack - not handled correctly\nPlease report htis bug with your board file!\n");
+				return 1;
+			default:
+				assert(!"pcb_find_mark_get: invalid arrived_from object type");
+				return 1;
+		}
+	}
+	/* coming from NULL means starting object - assume all layers affected */
+	return 1;
+}
+
+/* a variant of pcb_find_mark_get_pstk() where the target layer is explicitly
+   named instead of using an arrived_from object. ly can not be NULL */
+RND_INLINE int pcb_find_mark_get_pstk_on_layer(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_layer_t *ly)
+{
+	pcb_find_mm_t *mm;
+	pcb_pstk_proto_t *proto = pcb_pstk_get_proto((pcb_pstk_t *)obj);
+	pcb_data_t *data;
+	rnd_layer_id_t lid;
+
+	/* do anything only if there are disjoint copper shapes */
+	if ((proto == NULL) || (proto->all_copper_connd && proto->hplated) || ((pcb_pstk_t *)obj)->term)
+		return 1;
+
+	mm = pcb_find_get_mm(ctx, obj);
+
+	data = ly->parent.data;
+	lid = ly - data->Layer;
+	if ((lid < 0) || (lid >= PCB_MAX_LAYER)) {
+		assert(!"pcb_find_mark_get: invalid layer to arrive from");
+		return 1;
+	}
+	return !!(mm->layers[lid / 8] & (1 << (lid % 8)));
+}
+
+/* Return whether object is marked on any component related to arrived_from.
+   If arrived_from is NULL, obj is a starting object and is always found. */
+RND_INLINE int pcb_find_mark_get(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_any_obj_t *arrived_from)
+{
+	if (PCB_DFLAG_TEST(&obj->Flags, ctx->mark) == 0)
+		return 0;
+
+	switch(obj->type) {
+		case PCB_OBJ_PSTK: return pcb_find_mark_get_pstk(ctx, obj, arrived_from);
+		default: break;
+	}
+
+	return 1;
+}
+
 /* trickery: keeping vtp0 is reentrant and is cheaper than keeping lists,
    at least for appending. But as long as only the last item is removed,
    it's also cheap on remove! */
@@ -69,10 +279,10 @@ static int pcb_find_found(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_any_obj_t *ar
 	return 0;
 }
 
-
 static int pcb_find_addobj(pcb_find_t *ctx, pcb_any_obj_t *obj, pcb_any_obj_t *arrived_from, pcb_found_conn_type_t ctype, int jump)
 {
-	PCB_DFLAG_SET(&obj->Flags, ctx->mark);
+	pcb_find_mark_set(ctx, obj, arrived_from);
+
 	if (jump)
 		vtp0_append(&ctx->open, obj);
 
@@ -95,6 +305,10 @@ static void find_int_conn(pcb_find_t *ctx, pcb_any_obj_t *from_)
 
 	ic = from_->intconn;
 
+	/* it is okay to test for mark directly here: internal connection
+	   assumes all-layer affection as it is a special case mostly used for SMD pads
+	   and thru-hole pins; the flag means "found in any way" */
+
 	PCB_PADSTACK_LOOP(s->data);
 	{
 		if ((padstack != from) && (padstack->term != NULL) && (padstack->intconn == ic) && (!(PCB_DFLAG_TEST(&(padstack->Flags), ctx->mark))))
@@ -163,7 +377,7 @@ static rnd_bool int_noconn(pcb_any_obj_t *a, pcb_any_obj_t *b)
 #define PCB_FIND_CHECK(ctx, curr, obj, ctype, retstmt) \
 	do { \
 		pcb_any_obj_t *__obj__ = (pcb_any_obj_t *)obj; \
-		if (!(PCB_DFLAG_TEST(&(__obj__->Flags), ctx->mark))) { \
+		if (!pcb_find_mark_get(ctx, __obj__, (curr))) { \
 			if (!INOCONN(curr, obj) && (pcb_intersect_obj_obj(ctx, curr, __obj__))) {\
 				if (pcb_find_addobj(ctx, __obj__, curr, ctype, 1) != 0) { retstmt; } \
 				if ((__obj__->term != NULL) && (!ctx->ignore_intconn) && (__obj__->intconn > 0)) \
@@ -175,7 +389,7 @@ static rnd_bool int_noconn(pcb_any_obj_t *a, pcb_any_obj_t *b)
 #define PCB_FIND_CHECK_RAT(ctx, curr, obj, ctype, retstmt) \
 	do { \
 		pcb_any_obj_t *__obj__ = (pcb_any_obj_t *)obj; \
-		if (!(PCB_DFLAG_TEST(&(__obj__->Flags), ctx->mark))) { \
+		if (!pcb_find_mark_get(ctx, __obj__, (curr))) { \
 			if (!INOCONN(curr, obj) && (pcb_intersect_obj_obj(ctx, curr, __obj__))) {\
 				if (pcb_find_addobj(ctx, __obj__, curr, ctype, ctx->consider_rats) != 0) { retstmt; } \
 				if ((__obj__->term != NULL) && (!ctx->ignore_intconn) && (__obj__->intconn > 0)) \
@@ -189,29 +403,21 @@ void pcb_find_on_layer(pcb_find_t *ctx, pcb_layer_t *l, pcb_any_obj_t *curr, rnd
 	rnd_rtree_it_t it;
 	rnd_box_t *n;
 
-	if (l->line_tree != NULL) {
+	if (l->line_tree != NULL)
 		for(n = rnd_rtree_first(&it, l->line_tree, sb); n != NULL; n = rnd_rtree_next(&it))
 			PCB_FIND_CHECK(ctx, curr, n, ctype, return);
-		rnd_r_end(&it);
-	}
 
-	if (l->arc_tree != NULL) {
+	if (l->arc_tree != NULL)
 		for(n = rnd_rtree_first(&it, l->arc_tree, sb); n != NULL; n = rnd_rtree_next(&it))
 			PCB_FIND_CHECK(ctx, curr, n, ctype, return);
-		rnd_r_end(&it);
-	}
 
-	if (l->polygon_tree != NULL) {
+	if (l->polygon_tree != NULL)
 		for(n = rnd_rtree_first(&it, l->polygon_tree, sb); n != NULL; n = rnd_rtree_next(&it))
 			PCB_FIND_CHECK(ctx, curr, n, ctype, return);
-		rnd_r_end(&it);
-	}
 
-	if (l->text_tree != NULL) {
+	if (l->text_tree != NULL)
 		for(n = rnd_rtree_first(&it, l->text_tree, sb); n != NULL; n = rnd_rtree_next(&it))
 			PCB_FIND_CHECK(ctx, curr, n, ctype, return);
-		rnd_r_end(&it);
-	}
 }
 
 void pcb_find_on_layergrp(pcb_find_t *ctx, pcb_layergrp_t *g, pcb_any_obj_t *curr, rnd_rtree_box_t *sb, pcb_found_conn_type_t ctype)
@@ -263,19 +469,14 @@ static unsigned long pcb_find_exec(pcb_find_t *ctx)
 			rnd_box_t *n;
 			rnd_rtree_box_t *sb = (rnd_rtree_box_t *)&curr->bbox_naked;
 
-			if (PCB->Data->padstack_tree != NULL) {
+			if (PCB->Data->padstack_tree != NULL)
 				for(n = rnd_rtree_first(&it, PCB->Data->padstack_tree, sb); n != NULL; n = rnd_rtree_next(&it))
 					PCB_FIND_CHECK(ctx, curr, n, ctype, return ctx->nfound);
-				rnd_r_end(&it);
-			}
 
-			if ((ctx->consider_rats || ctx->only_mark_rats) && (PCB->Data->rat_tree != NULL)) {
-				if (PCB->Data->padstack_tree != NULL) {
+			if ((ctx->consider_rats || ctx->only_mark_rats) && (PCB->Data->rat_tree != NULL))
+				if (PCB->Data->padstack_tree != NULL)
 					for(n = rnd_rtree_first(&it, PCB->Data->rat_tree, sb); n != NULL; n = rnd_rtree_next(&it))
 						PCB_FIND_CHECK_RAT(ctx, curr, n, PCB_FCT_RAT, return ctx->nfound);
-					rnd_r_end(&it);
-				}
-			}
 
 			if (curr->type == PCB_OBJ_PSTK) {
 				int li;
@@ -289,6 +490,8 @@ static unsigned long pcb_find_exec(pcb_find_t *ctx)
 							if (!(lyt & PCB_LYT_COPPER))
 								continue;
 						}
+						if (!pcb_find_mark_get_pstk_on_layer(ctx, curr, l))
+							continue; /* padstack is not really found on this specific layer (it is marked found on other layers) */
 						if (pcb_pstk_shape_at_(ctx->pcb, (pcb_pstk_t *)curr, l, 0))
 							pcb_find_on_layer(ctx, l, curr, sb, ctype);
 						else if (proto->hplated) { /* consider plated slots */
@@ -389,6 +592,12 @@ void pcb_find_free(pcb_find_t *ctx)
 {
 	if (!ctx->in_use)
 		return;
+	if (ctx->multimark_inited) {
+		genht_uninit_deep(htpp, &ctx->multimark, {
+			free(htent->value);
+		}); \
+		ctx->multimark_inited = 0;
+	}
 	if (ctx->list_found)
 		vtp0_uninit(&ctx->found);
 	vtp0_uninit(&ctx->open);
