@@ -29,6 +29,7 @@
 #ifndef PCB_FIND2_H
 #define PCB_FIND2_H
 
+#include <genht/htpp.h>
 #include <genvector/vtp0.h>
 #include "global_typedefs.h"
 #include "flag.h"
@@ -83,10 +84,18 @@ struct pcb_find_s {
 	pcb_data_t *data;
 	pcb_board_t *pcb;
 	pcb_layergrp_t *start_layergrp;
+
+	/* marks if the object is ever found; in some cases this can be partial:
+	   e.g. in some padstacks not all copper shapes are connected and there's
+	   an extra bitfield for per-layer found bool; the extra per-component
+	   found flags are stored in multimark */
 	pcb_dynf_t mark;
+	htpp_t multimark; /* key=(pcb_any_obj_t *), value=(pcb_find_mm_t *), private to find.c */
+
 	unsigned long nfound;
 	unsigned in_use:1;
 	unsigned aborted:1;
+	unsigned multimark_inited:1;
 };
 
 extern const pcb_find_t *pcb_find0; /* nop-configuration for calling isc functions */
@@ -112,6 +121,10 @@ rnd_bool pcb_isc_arc_polyarea(const pcb_find_t *ctx, pcb_arc_t *Arc, rnd_polyare
 rnd_bool pcb_isc_line_poly(const pcb_find_t *ctx, pcb_line_t *Line, pcb_poly_t *Polygon);
 rnd_bool pcb_isc_poly_poly(const pcb_find_t *ctx, pcb_poly_t *P1, pcb_poly_t *P2);
 rnd_bool_t pcb_isc_pstk_line(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_line_t *line, rnd_bool anylayer);
+#ifdef PCB_OBJ_PSTK_STRUCT_DECLARED
+rnd_bool_t pcb_isc_pstk_line_shp(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_line_t *line, pcb_pstk_shape_t *shape);
+rnd_polyarea_t *pcb_pstk_shape2polyarea(pcb_pstk_t *ps, pcb_pstk_shape_t *shape);
+#endif
 
 /* Return whether obj is marked as already visited by the current search context */
 #define PCB_FIND_IS_MARKED(ctx, obj) PCB_DFLAG_TEST(&((obj)->Flags), (ctx)->mark)
