@@ -651,7 +651,7 @@ rnd_bool pcb_isc_arc_poly(const pcb_find_t *ctx, pcb_arc_t *Arc, pcb_poly_t *Pol
 	rnd_box_t *Box = (rnd_box_t *) Arc;
 
 	/* arcs with clearance never touch polys */
-	if (!ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLY, Polygon) && PCB_OBJ_HAS_CLEARANCE(Arc))
+	if ((Bloat == 0) && !ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLY, Polygon) && PCB_OBJ_HAS_CLEARANCE(Arc))
 		return rnd_false;
 	if (!Polygon->Clipped)
 		return rnd_false;
@@ -698,7 +698,7 @@ rnd_bool pcb_isc_line_poly(const pcb_find_t *ctx, pcb_line_t *Line, pcb_poly_t *
 	rnd_polyarea_t *lp;
 
 	/* lines with clearance never touch polygons */
-	if (!ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLY, Polygon) && PCB_OBJ_HAS_CLEARANCE(Line))
+	if ((Bloat == 0) && !ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLY, Polygon) && PCB_OBJ_HAS_CLEARANCE(Line))
 		return rnd_false;
 	if (!Polygon->Clipped)
 		return rnd_false;
@@ -757,7 +757,7 @@ rnd_bool pcb_isc_poly_poly(const pcb_find_t *ctx, pcb_poly_t *P1, pcb_poly_t *P2
 
 	/* cheat: poly-clear-poly means we did generate the clearance; this
 	   shall happen only if there's exactly one poly that is clearing the other */
-	if (!ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, P1)) {
+	if ((Bloat == 0) && !ctx->ignore_clearance && PCB_FLAG_TEST(PCB_FLAG_CLEARPOLYPOLY, P1)) {
 		pcp_cnt++;
 		pcp_gap = pcb_obj_clearance_p2(P1, P2) / 2.0;
 	}
@@ -884,7 +884,7 @@ RND_INLINE rnd_bool_t pcb_isc_line_polyline(const pcb_find_t *ctx, rnd_pline_t *
 		pcb_line.Flags = shape_line.square ? pcb_flag_make(PCB_FLAG_SQUARE) : pcb_no_flags(); \
 	} while(0)
 
-static rnd_bool_t pcb_isc_pstk_line_shp(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_line_t *line, pcb_pstk_shape_t *shape)
+rnd_bool_t pcb_isc_pstk_line_shp(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_line_t *line, pcb_pstk_shape_t *shape)
 {
 	if (shape == NULL) goto noshape;
 
@@ -1111,6 +1111,43 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_poly_shp(const pcb_find_t *ctx, pcb_pstk_t *p
 	return rnd_false;
 }
 
+rnd_polyarea_t *pcb_pstk_shape2polyarea(pcb_pstk_t *ps, pcb_pstk_shape_t *shape)
+{
+	pcb_line_t tmp;
+	pcb_pstk_proto_t *proto;
+	pcb_pstk_shape_t sltmp;
+	int tries = 0;
+
+	if (shape == NULL) return NULL;
+
+	retry:;
+	if (tries++ > 16) {
+		rnd_message(RND_MSG_ERROR, "pcb_pstk_shape2polyarea(): PCB_PSSH_HSHADOW recursion too deep\nPlease report this bug!\n");
+		return NULL;
+	}
+	switch(shape->shape) {
+		case PCB_PSSH_POLY:
+			return pcb_pstk_shp_poly2area(ps, shape);
+		case PCB_PSSH_LINE:
+			shape_line_to_pcb_line(ps, shape->data.line, tmp);
+			goto retline;
+		case PCB_PSSH_CIRC:
+			tmp.type = PCB_OBJ_LINE;
+			tmp.Point1.X = tmp.Point2.X = shape->data.circ.x + ps->x;
+			tmp.Point1.Y = tmp.Point2.Y = shape->data.circ.y + ps->y;
+			tmp.Clearance = 0;
+			tmp.Thickness = shape->data.circ.dia;
+			tmp.Flags = pcb_no_flags();
+			retline:;
+			return pcb_poly_from_pcb_line(&tmp, tmp.Thickness);
+		case PCB_PSSH_HSHADOW:
+			proto = pcb_pstk_get_proto(ps);
+			shape = pcb_pstk_shape_mech_or_hole_(ps, proto, &sltmp);
+			goto retry;
+	}
+	return NULL;
+}
+
 RND_INLINE rnd_bool_t pcb_isc_pstk_poly(const pcb_find_t *ctx, pcb_pstk_t *ps, pcb_poly_t *poly, rnd_bool anylayer)
 {
 	pcb_pstk_shape_t *shape;
@@ -1153,7 +1190,7 @@ RND_INLINE rnd_bool_t pstk_shape_isc_circ_line(const pcb_find_t *ctx, pcb_pstk_t
 	return pcb_is_point_in_line(sc->data.circ.x + c->x, sc->data.circ.y + c->y, sc->data.circ.dia/2, &tmp);
 }
 
-RND_INLINE rnd_bool_t pcb_pstk_shape_intersect(const pcb_find_t *ctx, pcb_pstk_t *ps1, pcb_pstk_shape_t *shape1, pcb_pstk_t *ps2, pcb_pstk_shape_t *shape2)
+RND_INLINE rnd_bool_t pcb_pstk_shape_intersect_(const pcb_find_t *ctx, pcb_pstk_t *ps1, pcb_pstk_shape_t *shape1, pcb_pstk_t *ps2, pcb_pstk_shape_t *shape2)
 {
 	if ((shape1->shape == PCB_PSSH_POLY) && (shape1->data.poly.pa == NULL))
 		pcb_pstk_shape_update_pa(&shape1->data.poly);
@@ -1223,6 +1260,13 @@ RND_INLINE rnd_bool_t pcb_pstk_shape_intersect(const pcb_find_t *ctx, pcb_pstk_t
 	return rnd_false;
 }
 
+rnd_bool_t pcb_pstk_shape_intersect(pcb_pstk_t *ps1, pcb_pstk_shape_t *shape1, pcb_pstk_t *ps2, pcb_pstk_shape_t *shape2)
+{
+	static const pcb_find_t ctx = {0};
+	return pcb_pstk_shape_intersect_(&ctx, ps1, shape1, ps2, shape2);
+}
+
+
 RND_INLINE rnd_bool_t pcb_isc_pstk_pstk(const pcb_find_t *ctx, pcb_pstk_t *ps1, pcb_pstk_t *ps2, rnd_bool anylayer)
 {
 	pcb_layer_t *ly;
@@ -1234,7 +1278,7 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_pstk(const pcb_find_t *ctx, pcb_pstk_t *ps1,
 		pcb_pstk_tshape_t *tshp1 = pcb_pstk_get_tshape(ps1), *tshp2 = pcb_pstk_get_tshape(ps2);
 		for(n1 = 0; n1 < tshp1->len; n1++) {
 			for(n2 = 0; n2 < tshp2->len; n2++) {
-				if (pcb_pstk_shape_intersect(ctx, ps1, &tshp1->shape[n1], ps2, &tshp2->shape[n2]))
+				if (pcb_pstk_shape_intersect_(ctx, ps1, &tshp1->shape[n1], ps2, &tshp2->shape[n2]))
 					return rnd_true;
 			}
 		}
@@ -1255,16 +1299,16 @@ RND_INLINE rnd_bool_t pcb_isc_pstk_pstk(const pcb_find_t *ctx, pcb_pstk_t *ps1,
 		shape1 = pcb_pstk_shape_at(PCB, ps1, ly);
 		shape2 = pcb_pstk_shape_at(PCB, ps2, ly);
 
-		if ((shape1 != NULL) && (shape2 != NULL) && pcb_pstk_shape_intersect(ctx, ps1, shape1, ps2, shape2)) return rnd_true;
+		if ((shape1 != NULL) && (shape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, shape1, ps2, shape2)) return rnd_true;
 
 		if (proto1->hplated)
 			slshape1 = pcb_pstk_shape_mech_or_hole_at(PCB, ps1, ly, &sltmp1);
 		if (proto2->hplated)
 			slshape2 = pcb_pstk_shape_mech_or_hole_at(PCB, ps2, ly, &sltmp2);
 
-		if ((slshape1 != NULL) && (shape2 != NULL) && pcb_pstk_shape_intersect(ctx, ps1, slshape1, ps2, shape2)) return rnd_true;
-		if ((slshape2 != NULL) && (shape1 != NULL) && pcb_pstk_shape_intersect(ctx, ps2, slshape2, ps1, shape1)) return rnd_true;
-		if ((slshape1 != NULL) && (slshape2 != NULL) && pcb_pstk_shape_intersect(ctx, ps1, slshape1, ps2, slshape2)) return rnd_true;
+		if ((slshape1 != NULL) && (shape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, slshape1, ps2, shape2)) return rnd_true;
+		if ((slshape2 != NULL) && (shape1 != NULL) && pcb_pstk_shape_intersect_(ctx, ps2, slshape2, ps1, shape1)) return rnd_true;
+		if ((slshape1 != NULL) && (slshape2 != NULL) && pcb_pstk_shape_intersect_(ctx, ps1, slshape1, ps2, slshape2)) return rnd_true;
 	}
 	return rnd_false;
 }
