@@ -26,8 +26,8 @@
 #include "config.h"
 #include <stdlib.h>
 #include "board.h"
-#include "actions.h"
-#include "error.h"
+#include <librnd/core/actions.h>
+#include <librnd/core/error.h>
 #include "font.h"
 #include "conf_core.h"
 #include "plug_io.h"
@@ -46,14 +46,14 @@ fgw_error_t pcb_act_load_font_from(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	pcb_font_t *fnt;
 	int r;
 
-	PCB_ACT_MAY_CONVARG(1, FGW_STR, load_font_from, fname = argv[1].val.str);
-	PCB_ACT_MAY_CONVARG(2, FGW_STR, load_font_from, sid = argv[2].val.str);
+	RND_ACT_MAY_CONVARG(1, FGW_STR, load_font_from, fname = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(2, FGW_STR, load_font_from, sid = argv[2].val.str);
 
 	if (sid != NULL) {
 		char *end;
 		fid = strtol(sid, &end, 10);
 		if (*end != '\0') {
-			pcb_message(PCB_MSG_ERROR, "LoadFontFrom(): when second argument is present, it must be an integer\n");
+			rnd_message(RND_MSG_ERROR, "LoadFontFrom(): when second argument is present, it must be an integer\n");
 			return 1;
 		}
 		if (pcb_font(PCB_ACT_BOARD, fid, 0) != NULL) { /* font already exists */
@@ -69,16 +69,16 @@ fgw_error_t pcb_act_load_font_from(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		static const char *flt_pcb[]   = {"*.font", "*.pcb_font", NULL};
 		static const char *flt_fonts[] = {"*.lht", "*.font", "*.pcb_font", NULL};
 		static const char *flt_any[] = {"*", "*.*", NULL};
-		const pcb_hid_fsd_filter_t flt[] = {
+		const rnd_hid_fsd_filter_t flt[] = {
 			{"any font",            NULL, flt_fonts},
 			{"lihata pcb-rnd font", NULL, flt_lht},
 			{"gEDA pcb font",       NULL, flt_pcb},
 			{"all",                 NULL, flt_any},
 			{NULL, NULL,NULL}
 		};
-		fname = pcb_gui->fileselect(pcb_gui,
+		fname = rnd_gui->fileselect(rnd_gui,
 			"Load PCB font file...", "Picks a PCB font file to load.\n",
-			default_file, ".font", flt, "pcbfont", PCB_HID_FSD_READ, NULL);
+			default_file, ".font", flt, "pcbfont", RND_HID_FSD_READ, NULL);
 		if (fname == NULL)
 			return 0; /* cancel */
 		if (default_file != NULL) {
@@ -89,14 +89,14 @@ fgw_error_t pcb_act_load_font_from(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	fnt = pcb_new_font(&PCB_ACT_BOARD->fontkit, fid, NULL);
 	if (fnt == NULL) {
-		pcb_message(PCB_MSG_ERROR, "LoadFontFrom(): unable to allocate font\n");
+		rnd_message(RND_MSG_ERROR, "LoadFontFrom(): unable to allocate font\n");
 		return 1;
 	}
 	
 	r = pcb_parse_font(fnt, fname);
-	pcb_event(PCB_ACT_HIDLIB, PCB_EVENT_FONT_CHANGED, "i", fnt->id);
+	rnd_event(RND_ACT_HIDLIB, PCB_EVENT_FONT_CHANGED, "i", fnt->id);
 	if (r != 0) {
-		pcb_message(PCB_MSG_ERROR, "LoadFontFrom(): failed to load font from %s\n", fname);
+		rnd_message(RND_MSG_ERROR, "LoadFontFrom(): failed to load font from %s\n", fname);
 		pcb_del_font(&PCB_ACT_BOARD->fontkit, fnt->id);
 		return 1;
 	}
@@ -106,8 +106,8 @@ fgw_error_t pcb_act_load_font_from(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 	
 	fid = dst_fid == 0 ? 0 : fnt->id;
-	pcb_message(PCB_MSG_INFO, "LoadFontFrom(): new font (ID %d) successfully loaded from file %s\n", fid, fname);
-	PCB_ACT_IRES(0);
+	rnd_message(RND_MSG_INFO, "LoadFontFrom(): new font (ID %d) successfully loaded from file %s\n", fid, fname);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -123,18 +123,18 @@ fgw_error_t pcb_act_save_font_to(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	pcb_font_t *fnt;
 	int r;
 
-	PCB_ACT_MAY_CONVARG(1, FGW_STR, load_font_from, fname = argv[1].val.str);
-	PCB_ACT_MAY_CONVARG(2, FGW_STR, load_font_from, sid = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(1, FGW_STR, load_font_from, fname = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(2, FGW_STR, load_font_from, sid = argv[1].val.str);
 
 	if (sid != NULL) {
 		char *end;
 		fid = strtol(sid, &end, 10);
 		if (*end != '\0') {
-			pcb_message(PCB_MSG_ERROR, "SaveFontTo(): when second argument is present, it must be an integer\n");
+			rnd_message(RND_MSG_ERROR, "SaveFontTo(): when second argument is present, it must be an integer\n");
 			return 1;
 		}
 		if (pcb_font(PCB_ACT_BOARD, fid, 0) == NULL) {
-			pcb_message(PCB_MSG_ERROR, "SaveFontTo(): can not fetch font ID %d\n", fid);
+			rnd_message(RND_MSG_ERROR, "SaveFontTo(): can not fetch font ID %d\n", fid);
 			return 1;
 		}
 	}
@@ -143,16 +143,16 @@ fgw_error_t pcb_act_save_font_to(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	fnt = pcb_font(PCB_ACT_BOARD, fid, 0);
 	if (fnt == NULL) {
-		pcb_message(PCB_MSG_ERROR, "SaveFontTo(): failed to fetch font %d\n", fid);
+		rnd_message(RND_MSG_ERROR, "SaveFontTo(): failed to fetch font %d\n", fid);
 		return 1;
 	}
 
 	if (!fname || !*fname) {
-		fname = pcb_gui->fileselect(pcb_gui, "Save PCB font file...",
+		fname = rnd_gui->fileselect(rnd_gui, "Save PCB font file...",
 																"Picks a PCB font file to save.\n",
-																default_file, ".font", NULL, "pcbfont", PCB_HID_FSD_MAY_NOT_EXIST, NULL);
+																default_file, ".font", NULL, "pcbfont", RND_HID_FSD_MAY_NOT_EXIST, NULL);
 		if (fname == NULL)
-			PCB_ACT_FAIL(save_font_to);
+			RND_ACT_FAIL(save_font_to);
 		if (default_file != NULL) {
 			free(default_file);
 			default_file = NULL;
@@ -161,18 +161,21 @@ fgw_error_t pcb_act_save_font_to(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	r = pcb_write_font(fnt, fname, "lihata");
 	if (r != 0) {
-		pcb_message(PCB_MSG_ERROR, "SaveFontTo(): failed to save font to %s\n", fname);
+		rnd_message(RND_MSG_ERROR, "SaveFontTo(): failed to save font to %s\n", fname);
 		return 1;
 	}
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
 
-pcb_action_t font_action_list[] = {
+static rnd_action_t font_action_list[] = {
 	{"LoadFontFrom", pcb_act_load_font_from, pcb_acth_load_font_from, pcb_acts_load_font_from},
 	{"SaveFontTo", pcb_act_save_font_to, pcb_acth_save_font_to, pcb_acts_save_font_to}
 };
 
-PCB_REGISTER_ACTIONS_FUNC(font_action_list, NULL)
+void pcb_font_act_init2(void)
+{
+	RND_REGISTER_ACTIONS(font_action_list, NULL);
+}
