@@ -24,8 +24,7 @@ action_entry(All)
 action_entry(AllConnections)
 action_entry(AllRats)
 action_entry(AllUnusedPins)
-action_entry(Arc)
-action_entry(Arrow)
+action_entry(AutoLen)
 action_entry(Block)
 action_entry(Buffer)
 action_entry(Cancel)
@@ -39,11 +38,9 @@ action_entry(CloseHole)
 action_entry(Connection)
 action_entry(Convert)
 action_entry(ConvertSubc)
-action_entry(Copy)
 action_entry(CycleClip)
 action_entry(CycleCrosshair)
 action_entry(DeleteRats)
-action_entry(Delta)
 action_entry(Done)
 action_entry(Drag)
 action_entry(DrillReport)
@@ -64,9 +61,7 @@ action_entry(Freeze)
 action_entry(GetSource)
 action_entry(Grid)
 action_entry(Hash)
-action_entry(InsertPoint)
 action_entry(Invert)
-action_entry(Iseq)
 action_entry(Layer)
 action_entry(Layout)
 action_entry(LayoutAs)
@@ -75,18 +70,18 @@ action_entry(Lihata)
 action_entry(Line)
 action_entry(LineSize)
 action_entry(LoadAll)
-action_entry(Lock)
 action_entry(Loose)
 action_entry(Merge)
 action_entry(Mirror)
-action_entry(Move)
 action_entry(MoveSelected)
 action_entry(Native)
 action_entry(Netlist)
 action_entry(Need)
-action_entry(None)
+action_entry(Next)
+action_entry(NoAutoLen)
 action_entry(Normalize)
 action_entry(Notify)
+action_entry(NoAllRats)
 action_entry(NoRats)
 action_entry(Object)
 action_entry(Off)
@@ -95,27 +90,25 @@ action_entry(Pan)
 action_entry(PasteBuffer)
 action_entry(PinOrPadName)
 action_entry(Pinout)
-action_entry(Polygon)
-action_entry(PolygonHole)
 action_entry(Pop)
+action_entry(Press)
 action_entry(PreviousPoint)
+action_entry(Prev)
 action_entry(Push)
 action_entry(Rats)
 action_entry(RatsNest)
-action_entry(Rectangle)
 action_entry(Redraw)
 action_entry(Refdes)
 action_entry(Release)
 action_entry(Revert)
-action_entry(Remove)
 action_entry(RemoveSelected)
 action_entry(Rename)
 action_entry(Report)
-action_entry(Reset)
 action_entry(ResetLayerObjects)
 action_entry(ResetLinesAndPolygons)
 action_entry(ResetPadstacks)
 action_entry(ResetPinsViasAndPads)
+action_entry(Resize)
 action_entry(Restore)
 action_entry(Ripup)
 action_entry(Rotate)
@@ -134,7 +127,6 @@ action_entry(SelectedPadstacks)
 action_entry(SelectedTexts)
 action_entry(SelectedVias)
 action_entry(SelectedRats)
-action_entry(Set)
 action_entry(Sides)
 action_entry(Sort)
 action_entry(Start)
@@ -150,9 +142,7 @@ action_entry(TermID)
 action_entry(Text)
 action_entry(TextScale)
 action_entry(Thaw)
-action_entry(Thermal)
 action_entry(ToLayout)
-action_entry(Toggle)
 action_entry(ToggleAllDirections)
 action_entry(ToggleAutoDRC)
 action_entry(ToggleClearLine)
@@ -180,6 +170,7 @@ action_entry(ToggleLocalRef)
 action_entry(ToggleCheckPlanes)
 action_entry(ToggleUniqueNames)
 action_entry(ToggleStroke)
+action_entry(Transparent)
 action_entry(Unselect)
 action_entry(UnFreeze)
 action_entry(Via)
