@@ -56,7 +56,7 @@
 #include "layer_ui.h"
 #include "layer_grp.h"
 #include "layer_vis.h"
-#include <librnd/core/attrib.h>
+#include "attrib.h"
 #include <librnd/core/hid_attrib.h>
 #include "operation.h"
 #include "obj_subc_op.h"
@@ -71,7 +71,7 @@
 static const char pcb_acts_Display[] =
 	"Display(SubcID, template)\n"
 	"Display(Grid|Redraw|Pinout|PinOrPadName)\n"
-	"Display(CycleClip|CycleCrosshair|ToggleAllDirections|ToggleStartDirection)\n"
+	"Display(CycleClip|ToggleAllDirections|ToggleStartDirection)\n"
 	"Display(ToggleGrid|ToggleRubberBandMode|ToggleUniqueNames)\n"
 	"Display(ToggleName|ToggleClearLine|ToggleFullPoly|ToggleSnapPin)\n"
 	"Display(ToggleSnapOffGridLine|ToggleHighlightOnPoint|ToggleCheckPlanes)\n"
@@ -80,28 +80,10 @@ static const char pcb_acts_Display[] =
 
 static const char pcb_acth_Display[] = "Several display-related actions.";
 /* DOC: display.html */
-static enum rnd_crosshair_shape_e CrosshairShapeIncrement(enum rnd_crosshair_shape_e shape)
-{
-	switch (shape) {
-	case rnd_ch_shape_basic:
-		shape = rnd_ch_shape_union_jack;
-		break;
-	case rnd_ch_shape_union_jack:
-		shape = rnd_ch_shape_dozen;
-		break;
-	case rnd_ch_shape_dozen:
-		shape = rnd_ch_shape_NUM;
-		break;
-	case rnd_ch_shape_NUM:
-		shape = rnd_ch_shape_basic;
-		break;
-	}
-	return shape;
-}
-
 extern pcb_opfunc_t ChgFlagFunctions;
 static fgw_error_t pcb_act_Display(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
+	pcb_board_t *pcb = PCB_ACT_BOARD;
 	const char *str_dir = NULL;
 	int id;
 	int err = 0;
@@ -161,11 +143,7 @@ static fgw_error_t pcb_act_Display(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			break;
 
 		case F_CycleCrosshair:
-			rnd_hid_notify_crosshair_change(RND_ACT_HIDLIB, rnd_false);
-			rnd_conf_setf(RND_CFR_CLI, "editor/crosshair_shape_idx", 0, "%d", CrosshairShapeIncrement(rnd_conf.editor.crosshair_shape_idx));
-			if (rnd_ch_shape_NUM == rnd_conf.editor.crosshair_shape_idx)
-				rnd_conf_set(RND_CFR_CLI, "editor/crosshair_shape_idx", 0, "0", RND_POL_OVERWRITE);
-			rnd_hid_notify_crosshair_change(RND_ACT_HIDLIB, rnd_true);
+			rnd_message(RND_MSG_ERROR, "CycleCrosshair: not supported any more\n");
 			break;
 
 		case F_ToggleRubberBandMode:
@@ -296,7 +274,7 @@ static fgw_error_t pcb_act_Display(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				   crosshair is snapped, we are aligning to an object(point), else
 				   we are aligning to whatever fine point the user clicked */
 				rnd_hid_get_coords("Click to set the grid origin", &x, &y, 1);
-				if (pcb_crosshair_move_absolute(pcb_crosshair.X, pcb_crosshair.Y))
+				if (pcb_crosshair_move_absolute(PCB_ACT_BOARD, pcb_crosshair.X, pcb_crosshair.Y))
 					rnd_hid_notify_crosshair_change(RND_ACT_HIDLIB, rnd_true); /* first notify was in MoveCrosshairAbs */
 				rnd_hidlib_set_grid(RND_ACT_HIDLIB, old_grid, rnd_true, pcb_crosshair.X, pcb_crosshair.Y);
 
@@ -351,7 +329,7 @@ static fgw_error_t pcb_act_Display(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 					pcb_undo_add_obj_to_flag(ptr2);
 					PCB_FLAG_TOGGLE(PCB_FLAG_TERMNAME, obj);
-					pcb_board_set_changed_flag(rnd_true);
+					pcb_board_set_changed_flag(pcb, rnd_true);
 					pcb_undo_inc_serial();
 					pcb_draw();
 				}
@@ -414,6 +392,7 @@ static fgw_error_t pcb_act_CycleDrag(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			/* line has two endpoints, check which one is close to the original x;y */
 			pcb_line_t *l = ptr2;
 			if (close_enough(hidlib->tool_x, l->Point1.X) && close_enough(hidlib->tool_y, l->Point1.Y)) {
+				pcb_crosshair_attached_clean(hidlib);
 				pcb_crosshair.AttachedObject.Type = PCB_OBJ_LINE_POINT;
 				pcb_crosshair.AttachedObject.Ptr1 = ptr1;
 				pcb_crosshair.AttachedObject.Ptr2 = ptr2;
@@ -421,6 +400,7 @@ static fgw_error_t pcb_act_CycleDrag(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				goto switched;
 			}
 			if (close_enough(hidlib->tool_x, l->Point2.X) && close_enough(hidlib->tool_y, l->Point2.Y)) {
+				pcb_crosshair_attached_clean(hidlib);
 				pcb_crosshair.AttachedObject.Type = PCB_OBJ_LINE_POINT;
 				pcb_crosshair.AttachedObject.Ptr1 = ptr1;
 				pcb_crosshair.AttachedObject.Ptr2 = ptr2;
@@ -432,6 +412,7 @@ static fgw_error_t pcb_act_CycleDrag(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			rnd_coord_t ex, ey;
 			pcb_arc_get_end((pcb_arc_t *)ptr2, 0, &ex, &ey);
 			if (close_enough(hidlib->tool_x, ex) && close_enough(hidlib->tool_y, ey)) {
+				pcb_crosshair_attached_clean(hidlib);
 				pcb_crosshair.AttachedObject.Type = PCB_OBJ_ARC_POINT;
 				pcb_crosshair.AttachedObject.Ptr1 = ptr1;
 				pcb_crosshair.AttachedObject.Ptr2 = ptr2;
@@ -440,6 +421,7 @@ static fgw_error_t pcb_act_CycleDrag(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			}
 			pcb_arc_get_end((pcb_arc_t *)ptr2, 1, &ex, &ey);
 			if (close_enough(hidlib->tool_x, ex) && close_enough(hidlib->tool_y, ey)) {
+				pcb_crosshair_attached_clean(hidlib);
 				pcb_crosshair.AttachedObject.Type = PCB_OBJ_ARC_POINT;
 				pcb_crosshair.AttachedObject.Ptr1 = ptr1;
 				pcb_crosshair.AttachedObject.Ptr2 = ptr2;
@@ -448,6 +430,7 @@ static fgw_error_t pcb_act_CycleDrag(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			}
 		}
 		else if (pcb_search_obj_by_id(PCB->Data, &ptr1, &ptr2, &ptr3, pcb_crosshair.drags[pcb_crosshair.drags_current], PCB_OBJ_ARC) != PCB_OBJ_VOID) {
+				pcb_crosshair_attached_clean(hidlib);
 			pcb_crosshair.AttachedObject.Type = PCB_OBJ_ARC;
 			pcb_crosshair.AttachedObject.Ptr1 = ptr1;
 			pcb_crosshair.AttachedObject.Ptr2 = ptr2;
@@ -520,8 +503,11 @@ static fgw_error_t pcb_act_MarkCrosshair(fgw_arg_t *res, int argc, fgw_arg_t *ar
 
 /* --------------------------------------------------------------------------- */
 
-static const char pcb_acts_RouteStyle[] = "RouteStyle(style_id|style_name|current, [set|get, width|clearance, [value]])";
+static const char pcb_acts_RouteStyle[] = 
+	"RouteStyle(style_id|style_name|@current, [set|get|del], [trace-thickness|trace-clearance|text-thickness|text-scale|name], [value]])\n"
+	"RouteStyle(new, [name])";
 static const char pcb_acth_RouteStyle[] = "Without second argument: copies the indicated routing style into the current pen; with second argument sets or gets a field of the routing style.";
+/* DOC: routestyle.html */
 static fgw_error_t pcb_act_RouteStyle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	char *end;
@@ -535,6 +521,14 @@ static fgw_error_t pcb_act_RouteStyle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_MAY_CONVARG(2, FGW_STR, RouteStyle, cmd = argv[2].val.str);
 	RND_ACT_MAY_CONVARG(3, FGW_STR, RouteStyle, sfield = argv[3].val.str);
 
+	if (strcmp(str, "new") == 0) {
+		str = "new style";
+		RND_ACT_MAY_CONVARG(2, FGW_STR, RouteStyle, str = argv[2].val.str);
+		res->type = FGW_INT;
+		res->val.nat_int = pcb_route_style_new(PCB, str, 1);
+		return 0;
+	}
+
 	is_curr = (strcmp(str, "@current") == 0);
 	if (!is_curr) {
 		number = strtol(str, &end, 10);
@@ -570,16 +564,34 @@ static fgw_error_t pcb_act_RouteStyle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			pcb_board_set_via_drilling_hole(rts->Hole, rnd_true);
 			pcb_board_set_clearance(rts->Clearance);
 			break;
+		case 'd': /* del */
+			res->type = FGW_INT;
+			res->val.nat_int = pcb_route_style_del(PCB, number-1, 1);
+			return 0;
 		case 's': /* set */
 			if (sfield == NULL) goto err_missing_field;
 
 			if (strcmp(sfield, "trace-thickness") == 0) {
 				RND_ACT_CONVARG(4, FGW_COORD, RouteStyle, c = fgw_coord(&argv[4]));
-				rts->Thick = c;
+				pcb_route_style_change(PCB, number-1, &c, NULL, NULL, NULL, NULL, 1);
+			}
+			else if (strcmp(sfield, "text-thickness") == 0) {
+				RND_ACT_CONVARG(4, FGW_COORD, RouteStyle, c = fgw_coord(&argv[4]));
+				pcb_route_style_change(PCB, number-1, NULL, &c, NULL, NULL, NULL, 1);
+			}
+			else if (strcmp(sfield, "text-scale") == 0) {
+				int sc;
+				RND_ACT_CONVARG(4, FGW_COORD, RouteStyle, sc = argv[4].val.nat_int);
+				pcb_route_style_change(PCB, number-1, NULL, NULL, &sc, NULL, NULL, 1);
 			}
 			else if (strcmp(sfield, "trace-clearance") == 0) {
 				RND_ACT_CONVARG(4, FGW_COORD, RouteStyle, c = fgw_coord(&argv[4]));
-				rts->Clearance = c;
+				pcb_route_style_change(PCB, number-1, NULL, NULL, NULL, &c, NULL, 1);
+			}
+			else if (strcmp(sfield, "name") == 0) {
+				const char *new_name;
+				RND_ACT_CONVARG(4, FGW_STR, RouteStyle, new_name = argv[4].val.cstr);
+				pcb_route_style_change_name(PCB, number-1, new_name, 1);
 			}
 			else goto err_bad_field;
 			rnd_event(&PCB->hidlib, PCB_EVENT_ROUTE_STYLES_CHANGED, NULL);
@@ -592,10 +604,22 @@ static fgw_error_t pcb_act_RouteStyle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				res->type = FGW_COORD;
 				fgw_coord(res) = rts->Thick;
 			}
+			else if (strcmp(sfield, "text-thickness") == 0) {
+				res->type = FGW_COORD;
+				fgw_coord(res) = rts->textt;
+			}
+			else if (strcmp(sfield, "text-scale") == 0) {
+				res->type = FGW_INT;
+				res->val.nat_int = rts->texts;
+			}
 			else if (strcmp(sfield, "trace-clearance") == 0) {
 				res->type = FGW_COORD;
 				fgw_coord(res) = rts->Clearance;
 			}
+			else if (strcmp(sfield, "name") == 0) {
+				res->type = FGW_STR;
+				res->val.cstr = rts->name;
+			}
 			else goto err_bad_field;
 			break;
 		default:
@@ -689,6 +713,7 @@ static const char pcb_acts_EditLayer[] = "Editlayer([@layer], [name=text|auto=[0
 static const char pcb_acth_EditLayer[] = "Change a property or attribute of a layer. If the first argument starts with @, it is taken as the layer name to manipulate, else the action uses the current layer. Without arguments or if only a layer name is specified, interactive runs editing.";
 static fgw_error_t pcb_act_EditLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
+	pcb_board_t *pcb = PCB_ACT_BOARD;
 	int ret = 0, n, interactive = 1, explicit = 0;
 	pcb_layer_t *ly = PCB_CURRLAYER(PCB_ACT_BOARD);
 
@@ -707,7 +732,7 @@ static fgw_error_t pcb_act_EditLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		else if (strncmp(arg, "name=", 5) == 0) {
 			interactive = 0;
 			ret |= pcb_layer_rename_(ly, rnd_strdup(arg+5), 1);
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(pcb, rnd_true);
 		}
 		else if (strncmp(arg, "auto=", 5) == 0) {
 			interactive = 0;
@@ -715,7 +740,7 @@ static fgw_error_t pcb_act_EditLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				ly->comb |= PCB_LYC_AUTO;
 			else
 				ly->comb &= ~PCB_LYC_AUTO;
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(pcb, rnd_true);
 		}
 		else if (strncmp(arg, "sub=", 4) == 0) {
 			interactive = 0;
@@ -723,7 +748,7 @@ static fgw_error_t pcb_act_EditLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				ly->comb |= PCB_LYC_SUB;
 			else
 				ly->comb &= ~PCB_LYC_SUB;
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(pcb, rnd_true);
 		}
 		else if (strncmp(arg, "attrib", 6) == 0) {
 			char *key, *val;
@@ -742,11 +767,11 @@ static fgw_error_t pcb_act_EditLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					val = NULL;
 			}
 			if (val == NULL)
-				ret |= rnd_attribute_remove(&ly->Attributes, key);
+				ret |= pcb_attribute_remove(&ly->Attributes, key);
 			else
-				ret |= rnd_attribute_put(&ly->Attributes, key, val);
+				ret |= pcb_attribute_put(&ly->Attributes, key, val);
 			free(key);
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(pcb, rnd_true);
 		}
 		else {
 			rnd_message(RND_MSG_ERROR, "Invalid EditLayer() command: %s\n", arg);
@@ -781,6 +806,7 @@ static const char pcb_acts_EditGroup[] = "Editgroup([@group], [name=text|type=+b
 static const char pcb_acth_EditGroup[] = "Change a property or attribute of a layer group. If the first argument starts with @, it is taken as the group name to manipulate, else the action uses the current layer's group. Without arguments or if only a layer name is specified, interactive runs editing.";
 static fgw_error_t pcb_act_EditGroup(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
+	pcb_board_t *pcb = PCB_ACT_BOARD;
 	int ret = 0, n, interactive = 1, explicit = 0;
 	pcb_layergrp_t *g = NULL;
 
@@ -813,7 +839,7 @@ static fgw_error_t pcb_act_EditGroup(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		else if (strncmp(arg, "name=", 5) == 0) {
 			interactive = 0;
 			ret |= pcb_layergrp_rename_(g, rnd_strdup(arg+5), 1);
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(pcb, rnd_true);
 		}
 		else if (strncmp(arg, "type=", 5) == 0) {
 			const char *sbit = arg+5;
@@ -832,7 +858,7 @@ static fgw_error_t pcb_act_EditGroup(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				case '-': g->ltype &= ~bit; break;
 			}
 			interactive = 0;
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(pcb, rnd_true);
 		}
 		else if (strncmp(arg, "attrib", 6) == 0) {
 			char *key, *val;
@@ -852,9 +878,9 @@ static fgw_error_t pcb_act_EditGroup(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					val = NULL;
 			}
 			if (val == NULL)
-				ret |= rnd_attribute_remove(&g->Attributes, key);
+				ret |= pcb_attribute_remove(&g->Attributes, key);
 			else
-				ret |= rnd_attribute_put(&g->Attributes, key, val);
+				ret |= pcb_attribute_put(&g->Attributes, key, val);
 			free(key);
 		}
 		else {
@@ -1030,7 +1056,7 @@ static fgw_error_t pcb_act_NewGroup(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				}
 				else
 					val = "";
-				rnd_attribute_put(&g->Attributes, curr, val);
+				pcb_attribute_put(&g->Attributes, curr, val);
 			}
 			free(attrs);
 		}
@@ -1172,6 +1198,7 @@ const char pcb_acth_chklayer[] = "Returns 1 if the specified layer is the active
 /* DOC: chklayer.html */
 static fgw_error_t pcb_act_ChkLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
+	pcb_board_t *pcb = PCB_ACT_BOARD;
 	rnd_layer_id_t lid;
 	pcb_layer_t *ly;
 	char *end;
@@ -1185,7 +1212,7 @@ static fgw_error_t pcb_act_ChkLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		ml = pcb_menu_layer_find(name);
 		if (ml != NULL) {
 			if (ml->sel_offs != 0) {
-				rnd_bool *s = (rnd_bool *)((char *)PCB + ml->sel_offs);
+				rnd_bool *s = (rnd_bool *)((char *)pcb + ml->sel_offs);
 				RND_ACT_IRES(*s);
 			}
 			else
@@ -1199,7 +1226,7 @@ static fgw_error_t pcb_act_ChkLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	/* if any virtual is selected, do not accept PCB_CURRLAYER(PCB_ACT_BOARD) as selected */
 	for(ml = pcb_menu_layers; ml->name != NULL; ml++) {
-		rnd_bool *s = (rnd_bool *)((char *)PCB + ml->sel_offs);
+		rnd_bool *s = (rnd_bool *)((char *)pcb + ml->sel_offs);
 		if ((ml->sel_offs != 0) && (*s)) {
 			RND_ACT_IRES(0);
 			return 0;
@@ -1207,7 +1234,7 @@ static fgw_error_t pcb_act_ChkLayer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 
 	lid--;
-	ly = pcb_get_layer(PCB->Data, lid);
+	ly = pcb_get_layer(pcb->Data, lid);
 	if (ly == NULL)
 		RND_ACT_IRES(-1);
 	else
@@ -1305,6 +1332,7 @@ const char pcb_acth_chkview[] = "Return 1 if layerid is visible.";
 /* DOC: chkview.html */
 static fgw_error_t pcb_act_ChkView(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
+	pcb_board_t *pcb = PCB_ACT_BOARD;
 	rnd_layer_id_t lid;
 	pcb_layer_t *ly;
 	char *end;
@@ -1328,7 +1356,7 @@ static fgw_error_t pcb_act_ChkView(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		const pcb_menu_layers_t *ml = pcb_menu_layer_find(name);
 
 		if (ml != NULL) {
-			rnd_bool *v = (rnd_bool *)((char *)PCB + ml->vis_offs);
+			rnd_bool *v = (rnd_bool *)((char *)pcb + ml->vis_offs);
 			RND_ACT_IRES(*v);
 			return 0;
 		}
@@ -1338,7 +1366,7 @@ static fgw_error_t pcb_act_ChkView(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 
 	lid--;
-	ly = pcb_get_layer(PCB->Data, lid);
+	ly = pcb_get_layer(pcb->Data, lid);
 	if (ly == NULL) {
 		RND_ACT_IRES(-1);
 		return 0;
