@@ -25,9 +25,9 @@
  */
 
 #include "board.h"
-#include "tool.h"
+#include <librnd/core/tool.h>
 
-void pcb_hidlib_adjust_attached_objects(pcb_hidlib_t *hl)
+void rnd_hidlib_adjust_attached_objects(rnd_hidlib_t *hl)
 {
-	pcb_tool_adjust_attached_objects(hl);
+	rnd_tool_adjust_attached(hl);
 }
