@@ -39,7 +39,7 @@
 #include "board.h"
 #include "data.h"
 #include "layer.h"
-#include "pcb-printf.h"
+#include <librnd/core/rnd_printf.h>
 
 static int idpath_map(pcb_idpath_t *idp, pcb_any_obj_t *obj, int level, int *numlevels)
 {
@@ -130,51 +130,68 @@ pcb_idpath_t *pcb_obj2idpath(pcb_any_obj_t *obj)
 
 pcb_idpath_t *pcb_str2idpath(pcb_board_t *pcb, const char *str)
 {
-	const char *s;
+	const char *s, *ps;
 	char *next;
 	int data_addr, n, len = 1;
 	pcb_idpath_t *idp;
 
-	for(s = str; *s == '/'; s++)
+	for(ps = str; *ps == '/'; ps++) ;
 
-	data_addr = pcb_data_addr_by_name(pcb, &s);
+	data_addr = pcb_data_addr_by_name(pcb, &ps);
 
-	for(; *s != '\0'; s++) {
+	for(s = ps; *s != '\0'; s++) {
 		if ((s[0] == '/') && (s[1] != '/') && (s[1] != '\0'))
 			len++;
+		else if ((!isdigit(*s)) && (*s != '/')) {
+			rnd_trace("bad idpath: '%s' in '%s'\n", s, ps);
+			return NULL;
+		}
 	}
 
 	idp = pcb_idpath_alloc(len);
 	idp->data_addr = data_addr;
 
-	for(s = str, n = 0; *s != '\0'; s++,n++) {
+	for(s = ps, n = 0; *s != '\0'; s++,n++) {
 		while(*s == '/') s++;
 		if (*s == '\0')
 			break;
 		idp->id[n] = strtol(s, &next, 10);
 		s = (const char *)next;
+		if (*s == '\0')
+			break;
 	}
 	return idp;
 }
 
 
-char *pcb_idpath2str(const pcb_idpath_t *idp, pcb_bool relative)
+void pcb_append_idpath(gds_t *dst, const pcb_idpath_t *idp, rnd_bool relative)
+{
+	int n;
+
+	if (!relative) {
+		size_t end = dst->used;
+		gds_enlarge(dst, dst->used + 32);
+		dst->used = end;
+		pcb_data_name_by_addr(idp->data_addr, dst->array+end);
+		dst->used += strlen(dst->array+end);
+	}
+
+	for(n = 0; n < idp->len; n++)
+		rnd_append_printf(dst, "/%ld", idp->id[n]);
+}
+
+char *pcb_idpath2str(const pcb_idpath_t *idp, rnd_bool relative)
 {
 	gds_t tmp;
-	int n;
 
 	gds_init(&tmp);
 	gds_enlarge(&tmp, 32);
-
-	if (!relative)
-		tmp.used = strlen(pcb_data_name_by_addr(idp->data_addr, tmp.array));
-
-	for(n = 0; n < idp->len; n++)
-		pcb_append_printf(&tmp, "/%ld", idp->id[n]);
-
+	tmp.used = 0;
+	pcb_append_idpath(&tmp, idp, relative);
 	return tmp.array;
 }
 
+
 static pcb_any_obj_t *idpath2obj(pcb_data_t *data, const pcb_idpath_t *path, int level)
 {
 
