@@ -43,7 +43,7 @@
 #include <stdlib.h>
 
 #include "intersect.h"
-#include "box.h"
+#include <librnd/core/box.h>
 
 static int compareleft(const void *ptr1, const void *ptr2);
 static int compareright(const void *ptr1, const void *ptr2);
@@ -51,9 +51,9 @@ static int comparepos(const void *ptr1, const void *ptr2);
 static int nextpwrof2(int i);
 
 typedef struct {
-	pcb_coord_t left, right;
+	rnd_coord_t left, right;
 	int covered;
-	pcb_coord_t area;
+	rnd_coord_t area;
 } SegmentTreeNode;
 
 typedef struct {
@@ -62,21 +62,21 @@ typedef struct {
 } SegmentTree;
 
 typedef struct {
-	pcb_coord_t *p;
+	rnd_coord_t *p;
 	int size;
 } LocationList;
 
 /* ---------------------------------------------------------------------------
  * Create a sorted list of unique y coords from a BoxList.
  */
-static LocationList createSortedYList(pcb_box_list_t *boxlist)
+static LocationList createSortedYList(rnd_box_list_t *boxlist)
 {
 	LocationList yCoords;
-	pcb_coord_t last;
+	rnd_coord_t last;
 	int i, n;
 	/* create sorted list of Y coordinates */
 	yCoords.size = 2 * boxlist->BoxN;
-	yCoords.p = (pcb_coord_t *) calloc(yCoords.size, sizeof(*yCoords.p));
+	yCoords.p = (rnd_coord_t *) calloc(yCoords.size, sizeof(*yCoords.p));
 	for (i = 0; i < boxlist->BoxN; i++) {
 		yCoords.p[2 * i] = boxlist->Box[i].Y1;
 		yCoords.p[2 * i + 1] = boxlist->Box[i].Y2;
@@ -94,7 +94,7 @@ static LocationList createSortedYList(pcb_box_list_t *boxlist)
 /* ---------------------------------------------------------------------------
  * Create an empty segment tree from the given sorted list of uniq y coords.
  */
-static SegmentTree createSegmentTree(pcb_coord_t * yCoords, int N)
+static SegmentTree createSegmentTree(rnd_coord_t * yCoords, int N)
 {
 	SegmentTree st;
 	int i;
@@ -118,9 +118,9 @@ static SegmentTree createSegmentTree(pcb_coord_t * yCoords, int N)
 	return st;
 }
 
-void insertSegment(SegmentTree * st, int n, pcb_coord_t Y1, pcb_coord_t Y2)
+void insertSegment(SegmentTree * st, int n, rnd_coord_t Y1, rnd_coord_t Y2)
 {
-	pcb_coord_t discriminant;
+	rnd_coord_t discriminant;
 	if (st->nodes[n].left >= Y1 && st->nodes[n].right <= Y2) {
 		st->nodes[n].covered++;
 	}
@@ -137,9 +137,9 @@ void insertSegment(SegmentTree * st, int n, pcb_coord_t Y1, pcb_coord_t Y2)
 		(st->nodes[n].right - st->nodes[n].left) : (n >= st->size / 2) ? 0 : st->nodes[n * 2].area + st->nodes[n * 2 + 1].area;
 }
 
-void deleteSegment(SegmentTree * st, int n, pcb_coord_t Y1, pcb_coord_t Y2)
+void deleteSegment(SegmentTree * st, int n, rnd_coord_t Y1, rnd_coord_t Y2)
 {
-	pcb_coord_t discriminant;
+	rnd_coord_t discriminant;
 	if (st->nodes[n].left >= Y1 && st->nodes[n].right <= Y2) {
 		assert(st->nodes[n].covered);
 		--st->nodes[n].covered;
@@ -164,9 +164,9 @@ void deleteSegment(SegmentTree * st, int n, pcb_coord_t Y1, pcb_coord_t Y2)
  * etc.).
  * Runs in O(N ln N) time.
  */
-double pcb_intersect_box_box(pcb_box_list_t *boxlist)
+double pcb_intersect_box_box(rnd_box_list_t *boxlist)
 {
-	pcb_cardinal_t i;
+	rnd_cardinal_t i;
 	double area = 0.0;
 	/* first get the aggregate area. */
 	for (i = 0; i < boxlist->BoxN; i++)
@@ -179,13 +179,13 @@ double pcb_intersect_box_box(pcb_box_list_t *boxlist)
  * Compute the area of the union of the given rectangles.
  * O(N ln N) time.
  */
-double pcb_union_box_box(pcb_box_list_t *boxlist)
+double pcb_union_box_box(rnd_box_list_t *boxlist)
 {
-	pcb_box_t **rectLeft, **rectRight;
-	pcb_cardinal_t i, j;
+	rnd_box_t **rectLeft, **rectRight;
+	rnd_cardinal_t i, j;
 	LocationList yCoords;
 	SegmentTree segtree;
-	pcb_coord_t lastX;
+	rnd_coord_t lastX;
 	double area = 0.0;
 
 	if (boxlist->BoxN == 0)
@@ -196,8 +196,8 @@ double pcb_union_box_box(pcb_box_list_t *boxlist)
 	segtree = createSegmentTree(yCoords.p, yCoords.size);
 	free(yCoords.p);
 	/* create sorted list of left and right X coordinates of rectangles */
-	rectLeft = (pcb_box_t **) calloc(boxlist->BoxN, sizeof(*rectLeft));
-	rectRight = (pcb_box_t **) calloc(boxlist->BoxN, sizeof(*rectRight));
+	rectLeft = (rnd_box_t **) calloc(boxlist->BoxN, sizeof(*rectLeft));
+	rectRight = (rnd_box_t **) calloc(boxlist->BoxN, sizeof(*rectRight));
 	for (i = 0; i < boxlist->BoxN; i++) {
 		assert(boxlist->Box[i].X1 <= boxlist->Box[i].X2);
 		assert(boxlist->Box[i].Y1 <= boxlist->Box[i].Y2);
@@ -213,7 +213,7 @@ double pcb_union_box_box(pcb_box_list_t *boxlist)
 		/* i will step through rectLeft, j will through rectRight */
 		if (i == boxlist->BoxN || rectRight[j]->X2 < rectLeft[i]->X1) {
 			/* right edge of rectangle */
-			pcb_box_t *b = rectRight[j++];
+			rnd_box_t *b = rectRight[j++];
 			/* check lastX */
 			if (b->X2 != lastX) {
 				assert(lastX < b->X2);
@@ -225,7 +225,7 @@ double pcb_union_box_box(pcb_box_list_t *boxlist)
 		}
 		else {
 			/* left edge of rectangle */
-			pcb_box_t *b = rectLeft[i++];
+			rnd_box_t *b = rectLeft[i++];
 			/* check lastX */
 			if (b->X1 != lastX) {
 				assert(lastX < b->X1);
@@ -244,19 +244,19 @@ double pcb_union_box_box(pcb_box_list_t *boxlist)
 
 static int compareleft(const void *ptr1, const void *ptr2)
 {
-	pcb_box_t **b1 = (pcb_box_t **) ptr1, **b2 = (pcb_box_t **) ptr2;
+	rnd_box_t **b1 = (rnd_box_t **) ptr1, **b2 = (rnd_box_t **) ptr2;
 	return (*b1)->X1 - (*b2)->X1;
 }
 
 static int compareright(const void *ptr1, const void *ptr2)
 {
-	pcb_box_t **b1 = (pcb_box_t **) ptr1, **b2 = (pcb_box_t **) ptr2;
+	rnd_box_t **b1 = (rnd_box_t **) ptr1, **b2 = (rnd_box_t **) ptr2;
 	return (*b1)->X2 - (*b2)->X2;
 }
 
 static int comparepos(const void *ptr1, const void *ptr2)
 {
-	return *((pcb_coord_t *) ptr1) - *((pcb_coord_t *) ptr2);
+	return *((rnd_coord_t *) ptr1) - *((rnd_coord_t *) ptr2);
 }
 
 static int nextpwrof2(int n)
