@@ -127,7 +127,7 @@ static void obj_free_undoable(pcb_any_obj_t *obj)
 }
 
 
-static void layer_post_change(rnd_attribute_list_t *list, const char *name, const char *value)
+static void layer_post_change(pcb_attribute_list_t *list, const char *name, const char *value)
 {
 	if (strncmp(name, "pcb-rnd::key::", 14) == 0)
 		rnd_event(&PCB->hidlib, PCB_EVENT_LAYER_KEY_CHANGE, NULL);
@@ -138,7 +138,7 @@ static void layer_post_change(rnd_attribute_list_t *list, const char *name, cons
 void pcb_layer_free_fields(pcb_layer_t *layer, rnd_bool undoable)
 {
 	if (!layer->is_bound)
-		rnd_attribute_free(&layer->Attributes);
+		pcb_attribute_free(&layer->Attributes);
 
 	list_map0(&layer->Line, pcb_line_t, undoable ? UFC(obj_free_undoable) : UFC(pcb_line_free));
 	list_map0(&layer->Arc,  pcb_arc_t,  undoable ? UFC(obj_free_undoable) : UFC(pcb_arc_free));
@@ -550,7 +550,7 @@ rnd_layer_id_t pcb_layer_create(pcb_board_t *pcb, rnd_layergrp_id_t grp, const c
 	pcb->Data->Layer[id].Attributes.post_change = layer_post_change;
 
 	if (pcb == PCB)
-		pcb_board_set_changed_flag(1);
+		pcb_board_set_changed_flag(pcb, 1);
 
 	if (undoable)
 		pcb_layer_undoable_created(pcb, &pcb->Data->Layer[id]);
@@ -696,6 +696,69 @@ int pcb_layer_recolor(pcb_data_t *data, rnd_layer_id_t layer, const char *color,
 	return pcb_layer_recolor_(&data->Layer[layer], &clr, undoable);
 }
 
+/*** undoable layer comb changes ***/
+typedef struct {
+	pcb_layer_t *layer;
+	pcb_layer_combining_t comb;
+} undo_layer_recomb_t;
+
+
+static int undo_layer_recomb_swap(void *udata)
+{
+	pcb_layer_combining_t old;
+	undo_layer_recomb_t *r = udata;
+
+	old = r->layer->comb;
+	r->layer->comb = r->comb;
+	r->comb = old;
+	if (!r->layer->is_bound) {
+		assert((r->layer->parent_type == PCB_PARENT_DATA) && (r->layer->parent.data->parent_type == PCB_PARENT_BOARD));
+		pcb_layergrp_notify_chg(r->layer->parent.data->parent.board);
+	}
+	return 0;
+}
+
+static void undo_layer_recomb_print(void *udata, char *dst, size_t dst_len)
+{
+	undo_layer_recomb_t *r = udata;
+	rnd_snprintf(dst, dst_len, "recomb layer: '%x' -> '%x'", r->layer->comb, r->comb);
+}
+
+static const uundo_oper_t undo_layer_recomb = {
+	core_layer_cookie,
+	NULL,
+	undo_layer_recomb_swap,
+	undo_layer_recomb_swap,
+	undo_layer_recomb_print
+};
+
+
+int pcb_layer_recomb(pcb_layer_t *Layer, pcb_layer_combining_t comb, rnd_bool undoable)
+{
+	undo_layer_recomb_t rtmp, *r = &rtmp;
+
+	if (Layer->is_bound)
+		return -1;
+
+	if (Layer->comb == comb)
+		return 0;
+
+	if (undoable) {
+		pcb_board_t *pcb = pcb_data_get_top(Layer->parent.data);
+		if (pcb != NULL)
+			r = pcb_undo_alloc(pcb, &undo_layer_recomb, sizeof(undo_layer_recomb_t));
+	}
+
+	r->layer = Layer;
+	r->comb = comb;
+
+	undo_layer_recomb_swap(r);
+	if (undoable)
+		pcb_undo_inc_serial();
+
+	return 0;
+}
+
 #undef APPEND
 
 static int is_last_top_copper_layer(pcb_board_t *pcb, int layer)
@@ -1115,6 +1178,19 @@ pcb_layer_t *pcb_get_layer(pcb_data_t *data, rnd_layer_id_t id)
 	return NULL;
 }
 
+rnd_layer_id_t pcb_layer2id(pcb_data_t *data, pcb_layer_t *ly)
+{
+	long lid;
+
+	if (ly == NULL) return -1;
+
+	lid = ly - data->Layer;
+	if ((lid < 0) || (lid >= data->LayerN))
+		return -1;
+
+	return lid;
+}
+
 void pcb_layer_link_trees(pcb_layer_t *dst, pcb_layer_t *src)
 {
 	/* we can't link non-existing trees - make sure src does have the trees initialized */
@@ -1485,13 +1561,6 @@ int pcb_layer_gui_set_g_ui(pcb_layer_t *first, int is_empty, rnd_xform_t **xform
 	return 1;
 }
 
-void pcb_layer_edit_attrib(pcb_layer_t *layer)
-{
-	char *buf = rnd_strdup_printf("Layer %s Attributes", layer->name);
-	rnd_gui->edit_attributes(rnd_gui, buf, &(layer->Attributes));
-	free(buf);
-}
-
 const pcb_menu_layers_t *pcb_menu_layer_find(const char *name_or_abbrev)
 {
 	const pcb_menu_layers_t *ml;
