@@ -109,8 +109,8 @@ typedef enum { /* bitfield */
 
 #include "globalconst.h"
 #include <librnd/core/global_typedefs.h>
-#include <librnd/core/attrib.h>
 #include <librnd/core/color.h>
+#include "attrib.h"
 #include "obj_common.h"
 #include "obj_arc_list.h"
 #include "obj_line_list.h"
@@ -206,6 +206,9 @@ void pcb_layer_free_fields(pcb_layer_t *layer, rnd_bool undoable);
 /* Return the layer pointer (or NULL on invalid or virtual layers) for an id */
 pcb_layer_t *pcb_get_layer(pcb_data_t *data, rnd_layer_id_t id);
 
+/* Return the layer ID within data, or -1 if ly is not in data */
+rnd_layer_id_t pcb_layer2id(pcb_data_t *data, pcb_layer_t *ly);
+
 /* Return the name of a layer (real or virtual) or NULL on error
    NOTE: layer names may not be unique; returns the first case sensitive hit;
    slow linear search */
@@ -291,6 +294,10 @@ const rnd_color_t *pcb_layer_default_color(int idx, pcb_layer_type_t lyt);
 int pcb_layer_rename(pcb_data_t *data, rnd_layer_id_t layer, const char *lname, rnd_bool undoable);
 int pcb_layer_recolor(pcb_data_t *data, rnd_layer_id_t layer, const char *lcolor, rnd_bool undoable);
 
+/* Change the combination flags of a layer */
+int pcb_layer_recomb(pcb_layer_t *Layer, pcb_layer_combining_t comb, rnd_bool undoable);
+
+
 /* changes the color of a layer; string has to be allocated by the caller (pcb_strdup) */
 int pcb_layer_rename_(pcb_layer_t *Layer, char *Name, rnd_bool undoable);
 
@@ -327,9 +334,6 @@ pcb_layer_type_t pcb_layer_mirror_type(pcb_layer_type_t lyt);
 /* Modify tree pointers in dst to point to src's; allocates trees for src if they are not yet allocated */
 void pcb_layer_link_trees(pcb_layer_t *dst, pcb_layer_t *src);
 
-/* Open the attribute editor for a layer */
-void pcb_layer_edit_attrib(pcb_layer_t *layer);
-
 /* How deep subcs can be nested */
 #define PCB_MAX_BOUND_LAYER_RECURSION 128
 
