@@ -32,14 +32,14 @@
 #define PCB_LAYER_UI_H
 
 /* Virtual layers for UI and debug */
-#include "global_typedefs.h"
+#include <librnd/core/global_typedefs.h>
 
 #include "genvector/vtp0.h"
 
 /* list of all UI layers - each item is a persistent pointer to a layer struct */
 extern vtp0_t pcb_uilayers;
 
-pcb_layer_t *pcb_uilayer_alloc(const char *cookie, const char *name, const pcb_color_t *color);
+pcb_layer_t *pcb_uilayer_alloc(const char *cookie, const char *name, const rnd_color_t *color);
 void pcb_uilayer_free(pcb_layer_t *l);
 void pcb_uilayer_free_all_cookie(const char *cookie);
 void pcb_uilayer_uninit(void);
