@@ -46,7 +46,7 @@ static const char *EXPERIMENTAL = NULL;
 #include "crosshair.h"
 #include <librnd/core/compat_lrealpath.h>
 #include "polygon.h"
-#include "buildin.h"
+#include <librnd/core/buildin.hidlib.h>
 #include "build_run.h"
 #include <librnd/core/file_loaded.h>
 #include "flag.h"
@@ -77,6 +77,15 @@ static const char *EXPERIMENTAL = NULL;
 #include "tool_logic.h"
 #include "pixmap_pcb.h"
 
+TODO("librnd: remove this once librnd is not extern anymore")
+#include <genregex/regex_se.h>
+#include <puplug/util.h>
+#include <genvector/vtl0.h>
+
+#define pup_buildins pcb_rnd_buildins
+#include "buildin.c"
+#undef pup_buildins
+
 const char *rnd_menu_file_paths[4];
 const char *rnd_menu_name_fmt = "pcb-menu-%s.lht";
 
@@ -345,6 +354,8 @@ void pcb_main_uninit(void)
 	}
 	PCB = NULL;
 
+	pcb_extobj_uninit();
+
 	rnd_hidlib_uninit(); /* plugin unload */
 
 	rnd_funchash_uninit();
@@ -353,7 +364,6 @@ void pcb_main_uninit(void)
 	rnd_cli_uninit();
 	pcb_dynflag_uninit();
 
-	pcb_extobj_uninit();
 	pcb_import_uninit();
 	pcb_pixmap_uninit();
 	pcb_io_uninit();
@@ -384,11 +394,6 @@ const char *pcb_action_args[] = {
 	NULL, NULL, NULL, NULL, NULL /* terminator */
 };
 
-void print_pup_err(pup_err_stack_t *entry, char *string)
-{
-	rnd_message(RND_MSG_ERROR, "puplug: %s\n", string);
-}
-
 #include "funchash_core.h"
 #define action_entry(x) { #x, F_ ## x},
 static rnd_funchash_table_t Functions[] = {
@@ -399,7 +404,7 @@ static rnd_funchash_table_t Functions[] = {
 int main(int argc, char *argv[])
 {
 	int n;
-	char **sp, *exec_prefix, *command_line_pcb = NULL;
+	char *exec_prefix, *command_line_pcb = NULL;
 
 	rnd_main_args_t ga;
 
@@ -426,6 +431,35 @@ int main(int argc, char *argv[])
 	pcb_extobj_init();
 
 	rnd_hidlib_init1(conf_core_init);
+
+	{
+		extern const char *lhtpers_early_end[];
+		extern void vti0_init();
+		extern volatile const unsigned char ureglex_nfa_str[];
+		extern int ureglex_strtree_exec();
+		volatile void *p0;
+		volatile void (*p1)();
+		volatile int (*p2)();
+		volatile size_t (*p3)();
+		unsigned char c;
+		volatile void *dummy;
+		
+TODO("librnd: remove this once librnd is not extern anymore");
+		rnd_plugin_add_dir("../src_3rd/librnd-local/src/plugins");
+
+		/* temporary workaround: make sure objects from .a are linked even
+		   if pcb-rnd code didn't need them (some plugins will) */
+		p0 = lhtpers_early_end; dummy = rnd_cast_f2d(p0);
+		p1 = vti0_init; dummy = rnd_cast_f2d(p1);
+		p2 = re_se_exec; dummy = rnd_cast_f2d(p2);
+		p2 = ureglex_strtree_exec; dummy = rnd_cast_f2d(p2);
+		p1 = pup_list_parse_pups; dummy = rnd_cast_f2d(p1);
+		p3 = vtl0_len; dummy = rnd_cast_f2d(p3);
+		c = ureglex_nfa_str[0];
+		
+		(void)c; (void)dummy;
+	}
+
 	pcb_event_init_app();
 	rnd_conf_set(RND_CFR_INTERNAL, "rc/path/exec_prefix", -1, exec_prefix, RND_POL_OVERWRITE);
 	free(exec_prefix);
@@ -442,7 +476,7 @@ int main(int argc, char *argv[])
 	rnd_tool_init();
 	pcb_tool_logic_init();
 
-	rnd_hidlib_init2(pup_buildins, NULL);
+	rnd_hidlib_init2(pup_buildins, pcb_rnd_buildins);
 	pcb_actions_init_pcb_only();
 
 	setbuf(stdout, 0);
@@ -462,19 +496,7 @@ int main(int argc, char *argv[])
 
 	pcb_text_init();
 
-	if (rnd_pup.err_stack != NULL) {
-		rnd_message(RND_MSG_ERROR, "Some of the static linked buildins could not be loaded:\n");
-		pup_err_stack_process_str(&rnd_pup, print_pup_err);
-	}
-
-	for(sp = rnd_pup_paths; *sp != NULL; sp++) {
-		rnd_message(RND_MSG_DEBUG, "Loading plugins from '%s'\n", *sp);
-		pup_autoload_dir(&rnd_pup, *sp, (const char **)rnd_pup_paths);
-	}
-	if (rnd_pup.err_stack != NULL) {
-		rnd_message(RND_MSG_ERROR, "Some of the dynamic linked plugins could not be loaded:\n");
-		pup_err_stack_process_str(&rnd_pup, print_pup_err);
-	}
+	rnd_hidlib_init3_auto();
 
 	if (rnd_main_args_setup1(&ga) != 0) {
 		pcb_main_uninit();
