@@ -236,11 +236,13 @@ void *pcb_move_obj_and_rubberband(int Type, void *Ptr1, void *Ptr2, void *Ptr3,
 					ctx.move.dx = dx2;
 					ctx.move.dy = dy2;
 					ptr2 = pcb_lineop_move_point(&ctx, Ptr1, line, &line->Point2);
+					pcb_line_mod_merge(line, 1);
 				}
 				/* Otherwise make a normal move */
 				else {
 					pcb_undo_add_obj_to_move(Type, Ptr1, Ptr2, Ptr3, dx1, dy1);
 					ptr2 = pcb_object_operation(&MoveFunctions, &ctx, Type, Ptr1, Ptr2, Ptr3);
+					pcb_line_mod_merge(ptr2, 1);
 				}
 			}
 			break;
@@ -249,6 +251,8 @@ void *pcb_move_obj_and_rubberband(int Type, void *Ptr1, void *Ptr2, void *Ptr3,
 			rnd_event(&PCB->hidlib, PCB_EVENT_RUBBER_MOVE, "icc", 0, DX, DY);
 			pcb_undo_add_obj_to_move(Type, Ptr1, Ptr2, Ptr3, DX, DY);
 			ptr2 = pcb_object_operation(&MoveFunctions, &ctx, Type, Ptr1, Ptr2, Ptr3);
+			if (((pcb_any_obj_t *)ptr2)->type == PCB_OBJ_LINE)
+				pcb_line_mod_merge(ptr2, 1);
 			break;
 	}
 
