@@ -33,31 +33,31 @@
 
 /*** move ***/
 #define	PCB_MOVE_TYPES \
-	(PCB_OBJ_PSTK | PCB_OBJ_LINE | PCB_OBJ_TEXT | PCB_OBJ_SUBC | \
+	(PCB_OBJ_PSTK | PCB_OBJ_LINE | PCB_OBJ_TEXT | PCB_OBJ_GFX | PCB_OBJ_GFX_POINT | PCB_OBJ_SUBC | \
 	PCB_OBJ_POLY | PCB_OBJ_POLY_POINT | PCB_OBJ_LINE_POINT | PCB_OBJ_ARC | PCB_OBJ_ARC_POINT)
 #define	PCB_MOVETOLAYER_TYPES \
-	(PCB_OBJ_LINE | PCB_OBJ_TEXT | PCB_OBJ_POLY | PCB_OBJ_RAT | PCB_OBJ_ARC)
+	(PCB_OBJ_LINE | PCB_OBJ_TEXT | PCB_OBJ_POLY | PCB_OBJ_RAT | PCB_OBJ_ARC | PCB_OBJ_GFX)
 
 
 /* undoably moves an object by relative DX and DY. Doesn't bump
    the undo serial. Operation wrapper. The rubberband version also moves
    or modifies connected objects. */
-void *pcb_move_obj(int Type, void *Ptr1, void *Ptr2, void *Ptr3, pcb_coord_t DX, pcb_coord_t DY);
-void *pcb_move_obj_and_rubberband(int Type, void *Ptr1, void *Ptr2, void *Ptr3, pcb_coord_t DX, pcb_coord_t DY);
+void *pcb_move_obj(int Type, void *Ptr1, void *Ptr2, void *Ptr3, rnd_coord_t DX, rnd_coord_t DY);
+void *pcb_move_obj_and_rubberband(int Type, void *Ptr1, void *Ptr2, void *Ptr3, rnd_coord_t DX, rnd_coord_t DY);
 
 /* undoably moves objects to a different layer. Doesn't bump
    the undo serial. Operation wrapper. */
-void *pcb_move_obj_to_layer(int Type, void *Ptr1, void *Ptr2, void *Ptr3, pcb_layer_t *Target, pcb_bool enmasse);
-pcb_bool pcb_move_selected_objs_to_layer(pcb_layer_t *Target);
+void *pcb_move_obj_to_layer(int Type, void *Ptr1, void *Ptr2, void *Ptr3, pcb_layer_t *Target, rnd_bool enmasse);
+rnd_bool pcb_move_selected_objs_to_layer(pcb_layer_t *Target);
 
 
 /*** copy ***/
 #define	PCB_COPY_TYPES              \
 	(PCB_OBJ_PSTK | PCB_OBJ_LINE | PCB_OBJ_TEXT | \
-	PCB_OBJ_SUBC | PCB_OBJ_POLY | PCB_OBJ_ARC)
+	PCB_OBJ_SUBC | PCB_OBJ_POLY | PCB_OBJ_ARC | PCB_OBJ_GFX)
 
 /* Undoably copies (duplicates) an object; the new objects is moved by DX,DY
    (operation wrapper) */
-void *pcb_copy_obj(int Type, void *Ptr1, void *Ptr2, void *Ptr3, pcb_coord_t DX, pcb_coord_t DY);
+void *pcb_copy_obj(int Type, void *Ptr1, void *Ptr2, void *Ptr3, rnd_coord_t DX, rnd_coord_t DY);
 
 #endif
