@@ -56,7 +56,7 @@ static const char core_net_cookie[] = "core-net";
 
 void pcb_net_term_free_fields(pcb_net_term_t *term)
 {
-	rnd_attribute_free(&term->Attributes);
+	pcb_attribute_free(&term->Attributes);
 	free(term->refdes);
 	free(term->term);
 }
@@ -421,7 +421,7 @@ pcb_net_t *pcb_net_get_user(pcb_board_t *pcb, pcb_netlist_t *nl, const char *nam
 
 void pcb_net_free_fields(pcb_net_t *net)
 {
-	rnd_attribute_free(&net->Attributes);
+	pcb_attribute_free(&net->Attributes);
 	free(net->name);
 	for(;;) {
 		pcb_net_term_t *term = pcb_termlist_first(&net->conns);
@@ -576,7 +576,7 @@ static int net_short_check(pcb_find_t *fctx, pcb_any_obj_t *new_obj, pcb_any_obj
 		pcb_short_ctx_t *sctx = fctx->user_data;
 		pcb_subc_t *sc = pcb_obj_parent_subc(new_obj);
 
-		if ((sc == NULL) || (sc->refdes == NULL))
+		if ((sc == NULL) || (sc->refdes == NULL) || PCB_FLAG_TEST(PCB_FLAG_NONETLIST, sc))
 			return 0;
 
 		/* if new_obj is a terminal on our net, return */
@@ -669,7 +669,7 @@ pcb_net_term_t *pcb_net_find_by_obj(const pcb_netlist_t *nl, const pcb_any_obj_t
 		return NULL;
 
 	sc = pcb_obj_parent_subc(obj);
-	if (sc == NULL)
+	if ((sc == NULL) || (sc->refdes == NULL))
 		return NULL;
 
 	return pcb_net_find_by_refdes_term(nl, sc->refdes, obj->term);
@@ -928,11 +928,11 @@ void pcb_netlist_copy(pcb_board_t *pcb, pcb_netlist_t *dst, pcb_netlist_t *src)
 		dst_net = pcb_net_alloc(pcb, dst, src_net->name, PCB_NETA_ALLOC);
 		dst_net->export_tmp = src_net->export_tmp;
 		dst_net->inhibit_rats = src_net->inhibit_rats;
-		rnd_attribute_copy_all(&dst_net->Attributes, &src_net->Attributes);
+		pcb_attribute_copy_all(&dst_net->Attributes, &src_net->Attributes);
 
 		for(src_term = pcb_termlist_first(&src_net->conns); src_term != NULL; src_term = pcb_termlist_next(src_term)) {
 			dst_term = pcb_net_term_alloc(dst_net, src_term->refdes, src_term->term);
-			rnd_attribute_copy_all(&dst_term->Attributes, &src_term->Attributes);
+			pcb_attribute_copy_all(&dst_term->Attributes, &src_term->Attributes);
 		}
 	}
 }
@@ -1116,7 +1116,7 @@ rnd_cardinal_t pcb_net_ripup(pcb_board_t *pcb, pcb_net_t *net)
 	lasto = NULL;
 	o = pcb_data_first(&it, pcb->Data, PCB_OBJ_CLASS_REAL & (~PCB_OBJ_SUBC));
 	for(;;) {
-		if ((lasto != NULL) && (PCB_DFLAG_TEST(&lasto->Flags, fctx.mark))) {
+		if ((lasto != NULL) && (PCB_FIND_IS_MARKED(&fctx, lasto))) {
 			pcb_remove_object(lasto->type, lasto->parent.any, lasto, lasto);
 			res++;
 		}
