@@ -253,7 +253,7 @@ static void pcb_netlist_clear(pcb_net_t *net, pcb_net_term_t *term)
 
 static void pcb_netlist_style(pcb_net_t *new_net, const char *style)
 {
-	rnd_attribute_put(&new_net->Attributes, "style", style);
+	pcb_attribute_put(&new_net->Attributes, "style", style);
 }
 
 static void pcb_netlist_ripup(pcb_net_t *new_net, pcb_net_term_t *term)
