@@ -49,8 +49,6 @@
 #include "obj_subc_parent.h"
 #include "obj_hash.h"
 
-/* TODO: could be removed if draw.c could be split up */
-#include "draw.h"
 #include "obj_arc_draw.h"
 
 
@@ -230,9 +228,27 @@ pcb_arc_t *pcb_arc_new(pcb_layer_t *Layer, rnd_coord_t X1, rnd_coord_t Y1, rnd_c
 
 		for(o = rnd_rtree_first(&it, Layer->arc_tree, (rnd_rtree_box_t *)&b); o != NULL; o = rnd_rtree_next(&it)) {
 			pcb_arc_t *arc = (pcb_arc_t *)o;
-TODO(": this does not catch all cases; there are more ways two arcs can be the same because of the angles")
-			if (arc->X == X1 && arc->Y == Y1 && arc->Width == width && rnd_normalize_angle(arc->StartAngle) == rnd_normalize_angle(sa) && arc->Delta == dir)
-				return NULL; /* prevent stacked arcs */
+			if ((arc->X == X1) && (arc->Y == Y1) && (arc->Width == width)) {
+				double s1, s2, d1 = arc->Delta, d2 = dir;
+
+				/* there are two ways normalized arcs can be the same: with + and with - delta */
+				if (d1 < 0) {
+					s1 = rnd_normalize_angle(arc->StartAngle + d1);
+					d1 = -d1;
+				}
+				else
+					s1 = rnd_normalize_angle(arc->StartAngle);
+
+				if (d2 < 0) {
+					s2 = rnd_normalize_angle(sa + d2);
+					d2 = -d2;
+				}
+				else
+					s2 = rnd_normalize_angle(sa);
+
+				if ((s1 == s2) && (d1 == d2))
+					return NULL; /* prevent stacked arcs */
+			}
 		}
 	}
 
@@ -257,7 +273,7 @@ static pcb_arc_t *pcb_arc_copy_meta(pcb_arc_t *dst, pcb_arc_t *src)
 {
 	if (dst == NULL)
 		return NULL;
-	rnd_attribute_copy_all(&dst->Attributes, &src->Attributes);
+	pcb_attribute_copy_all(&dst->Attributes, &src->Attributes);
 	return dst;
 }
 
@@ -293,7 +309,7 @@ void pcb_arc_free(pcb_arc_t *arc)
 {
 	if ((arc->parent.layer != NULL) && (arc->parent.layer->arc_tree != NULL))
 		rnd_r_delete_entry(arc->parent.layer->arc_tree, (rnd_box_t *)arc);
-	rnd_attribute_free(&arc->Attributes);
+	pcb_attribute_free(&arc->Attributes);
 	pcb_arc_unreg(arc);
 	pcb_obj_common_free((pcb_any_obj_t *)arc);
 	free(arc);
@@ -1008,7 +1024,7 @@ void pcb_arc_approx(const pcb_arc_t *arc, double res, int reverse, void *uctx, i
 	if (ea > sa) {
 		if (step < 0) step = -step;
 		ea2 = ea - step/3;
-		for(a = arc->StartAngle; a < ea2; a += step)
+		for(a = sa; a < ea2; a += step)
 			if (cb(uctx, rnd_round((double)arc->X - (double)arc->Width * cos(a * RND_M180)), rnd_round((double)arc->Y + (double)arc->Height * sin(a * RND_M180))) != 0)
 				return;
 	}
@@ -1034,25 +1050,40 @@ void pcb_arc_name_invalidate_draw(pcb_arc_t *arc)
 	}
 }
 
-void pcb_arc_draw_label(pcb_draw_info_t *info, pcb_arc_t *arc)
+void pcb_arc_draw_label(pcb_draw_info_t *info, pcb_arc_t *arc, rnd_bool vis_side)
 {
-	if (arc->term != NULL) {
+	if ((arc->term != NULL) && vis_side) {
 		rnd_coord_t x0, y0;
 		rnd_bool_t vert;
 
 		arc_label_pos(arc, &x0, &y0, &vert);
 		pcb_term_label_draw(info, x0, y0, conf_core.appearance.term_label_size, vert, rnd_true, (pcb_any_obj_t *)arc);
 	}
-	if (arc->noexport) {
+	if (arc->noexport && vis_side) {
 		rnd_coord_t cx, cy;
 		pcb_arc_middle(arc, &cx, &cy);
 		pcb_obj_noexport_mark(arc, cx, cy);
 	}
+
+	if (arc->ind_editpoint) {
+		rnd_coord_t x1, y1, x2, y2;
+		pcb_obj_editpont_setup();
+
+		pcb_arc_get_end(arc, 0, &x1, &y1);
+		pcb_arc_get_end(arc, 1, &x2, &y2);
+
+		pcb_obj_editpont_cross(arc->X, arc->Y);
+		if ((arc->X != x1) || (arc->Y != y1))
+			pcb_obj_editpont_cross(x1, y1);
+		if ((x2 != x1) || (y2 != y1))
+			pcb_obj_editpont_cross(x2, y2);
+	}
 }
 
 void pcb_arc_draw_(pcb_draw_info_t *info, pcb_arc_t *arc, int allow_term_gfx)
 {
 	rnd_coord_t thickness = arc->Thickness;
+	int draw_lab;
 
 	if (arc->Thickness < 0)
 		return;
@@ -1094,10 +1125,12 @@ void pcb_arc_draw_(pcb_draw_info_t *info, pcb_arc_t *arc, int allow_term_gfx)
 		if(info->xform->wireframe)
 			pcb_draw_wireframe_arc(pcb_draw_out.fgGC, arc, thickness);
 	}
-	if (arc->term != NULL) {
-		if ((pcb_draw_force_termlab) || PCB_FLAG_TEST(PCB_FLAG_TERMNAME, arc))
-			pcb_draw_delay_label_add((pcb_any_obj_t *)arc);
-	}
+
+	draw_lab = (arc->term != NULL) && ((pcb_draw_force_termlab) || PCB_FLAG_TEST(PCB_FLAG_TERMNAME, arc));
+	draw_lab |= arc->ind_editpoint;
+
+	if (draw_lab)
+		pcb_draw_delay_label_add((pcb_any_obj_t *)arc);
 }
 
 static void pcb_arc_draw(pcb_draw_info_t *info, pcb_arc_t *arc, int allow_term_gfx)
@@ -1131,7 +1164,7 @@ static void pcb_arc_draw(pcb_draw_info_t *info, pcb_arc_t *arc, int allow_term_g
 	else
 		color = &layer->meta.real.color;
 
-	if (info->xform->flag_color && PCB_FLAG_TEST(PCB_FLAG_ONPOINT, arc)) {
+	if (info->xform->flag_color && arc->ind_onpoint) {
 		pcb_lighten_color(color, &buf, 1.75);
 		color = &buf;
 	}
