@@ -36,11 +36,11 @@
 
 struct pcb_arc_s {       /* holds information about arcs */
 	PCB_ANY_PRIMITIVE_FIELDS;
-	pcb_coord_t Thickness, Clearance;
-	pcb_coord_t Width, Height,					/* length of axis */
-	  X, Y;												/* center coordinates */
-	pcb_angle_t StartAngle, Delta;			/* the two limiting angles in degrees */
-	gdl_elem_t link;              /* an arc is in a list: either on a layer or in an element or in a font */
+	rnd_coord_t Thickness, Clearance;
+	rnd_coord_t Width, Height;     /* length of axis */
+	rnd_coord_t X, Y;              /* center coordinates */
+	rnd_angle_t StartAngle, Delta; /* the two limiting angles in degrees */
+	gdl_elem_t link;               /* an arc is in a list: either on a layer or in an element or in a font */
 };
 
 /*** Memory ***/
@@ -48,9 +48,9 @@ pcb_arc_t *pcb_arc_alloc(pcb_layer_t *);
 pcb_arc_t *pcb_arc_alloc_id(pcb_layer_t *layer, long int id);
 void pcb_arc_free(pcb_arc_t *data);
 
-pcb_arc_t *pcb_arc_new(pcb_layer_t *Layer, pcb_coord_t center_x, pcb_coord_t center_y, pcb_coord_t width_r, pcb_coord_t height_r, pcb_angle_t start_angle, pcb_angle_t delta_angle, pcb_coord_t Thickness, pcb_coord_t Clearance, pcb_flag_t Flags, pcb_bool prevent_dups);
+pcb_arc_t *pcb_arc_new(pcb_layer_t *Layer, rnd_coord_t center_x, rnd_coord_t center_y, rnd_coord_t width_r, rnd_coord_t height_r, rnd_angle_t start_angle, rnd_angle_t delta_angle, rnd_coord_t Thickness, rnd_coord_t Clearance, pcb_flag_t Flags, rnd_bool prevent_dups);
 pcb_arc_t *pcb_arc_dup(pcb_layer_t *dst, pcb_arc_t *src);
-pcb_arc_t *pcb_arc_dup_at(pcb_layer_t *dst, pcb_arc_t *src, pcb_coord_t dx, pcb_coord_t dy);
+pcb_arc_t *pcb_arc_dup_at(pcb_layer_t *dst, pcb_arc_t *src, rnd_coord_t dx, rnd_coord_t dy);
 void *pcb_arc_destroy(pcb_layer_t *Layer, pcb_arc_t *Arc);
 
 void pcb_arc_reg(pcb_layer_t *layer, pcb_arc_t *arc);
@@ -62,12 +62,12 @@ void pcb_add_arc_on_layer(pcb_layer_t *Layer, pcb_arc_t *Arc);
 
 /*** Utility ***/
 void pcb_arc_bbox(pcb_arc_t *Arc);
-void pcb_arc_rotate90(pcb_arc_t *Arc, pcb_coord_t X, pcb_coord_t Y, unsigned Number);
-void pcb_arc_rotate(pcb_layer_t *layer, pcb_arc_t *arc, pcb_coord_t X, pcb_coord_t Y, double cosa, double sina, pcb_angle_t angle);
-void pcb_arc_mirror(pcb_layer_t *layer, pcb_arc_t *arc, pcb_coord_t y_offs);
+void pcb_arc_rotate90(pcb_arc_t *Arc, rnd_coord_t X, rnd_coord_t Y, unsigned Number);
+void pcb_arc_rotate(pcb_layer_t *layer, pcb_arc_t *arc, rnd_coord_t X, rnd_coord_t Y, double cosa, double sina, rnd_angle_t angle);
+void pcb_arc_mirror(pcb_arc_t *arc, rnd_coord_t y_offs, rnd_bool undoable);
 void pcb_arc_flip_side(pcb_layer_t *layer, pcb_arc_t *arc);
 void pcb_arc_scale(pcb_arc_t *arc, double sx, double sy, double sth);
-pcb_box_t pcb_arc_mini_bbox(const pcb_arc_t *arc);
+rnd_box_t pcb_arc_mini_bbox(const pcb_arc_t *arc);
 
 
 /*** hash and eq ***/
@@ -77,22 +77,22 @@ unsigned int pcb_arc_hash(const pcb_host_trans_t *tr, const pcb_arc_t *a);
 
 /* Return the x;y coordinate of the endpoint of an arc; if which is 0, return
    the endpoint that corresponds to StartAngle, else return the end angle's. */
-void pcb_arc_get_end(pcb_arc_t *Arc, int which, pcb_coord_t *x, pcb_coord_t *y);
-void pcb_arc_middle(const pcb_arc_t *arc, pcb_coord_t *x, pcb_coord_t *y);
+void pcb_arc_get_end(pcb_arc_t *Arc, int which, rnd_coord_t *x, rnd_coord_t *y);
+void pcb_arc_middle(const pcb_arc_t *arc, rnd_coord_t *x, rnd_coord_t *y);
 
 /* Call cb() with coords of approximation for an arc from start to end, or
    end to start (if reverse is true). Resolution is set by res: if it is positive,
-   it is an angle in degrees; if negative, it's an edge length in pcb_coord_t; if
+   it is an angle in degrees; if negative, it's an edge length in rnd_coord_t; if
    zero, the default 1 mm resolution is used. If cb returns non-zero, the loop
    quits immediately. Even stepping is not guaranteed, but visiting the exact
    arc start and end point is. */
-void pcb_arc_approx(const pcb_arc_t *arc, double res, int reverse, void *uctx, int (*cb)(void *uctx, pcb_coord_t x, pcb_coord_t y));
+void pcb_arc_approx(const pcb_arc_t *arc, double res, int reverse, void *uctx, int (*cb)(void *uctx, rnd_coord_t x, rnd_coord_t y));
 
 
-void pcb_arc_set_angles(pcb_layer_t *Layer, pcb_arc_t *a, pcb_angle_t new_sa, pcb_angle_t new_da);
-void pcb_arc_set_radii(pcb_layer_t *Layer, pcb_arc_t *a, pcb_coord_t new_width, pcb_coord_t new_height);
+void pcb_arc_set_angles(pcb_layer_t *Layer, pcb_arc_t *a, rnd_angle_t new_sa, rnd_angle_t new_da);
+void pcb_arc_set_radii(pcb_layer_t *Layer, pcb_arc_t *a, rnd_coord_t new_width, rnd_coord_t new_height);
 
-pcb_coord_t pcb_arc_length(const pcb_arc_t *arc);
+rnd_coord_t pcb_arc_length(const pcb_arc_t *arc);
 double pcb_arc_area(const pcb_arc_t *arc);
 
 /* ptr3 values for start and end point */
@@ -106,11 +106,11 @@ void pcb_arc_post(pcb_arc_t *arc);
 
 #define	pcb_arc_move(a,dx,dy)                                     \
 	do {                                                            \
-		pcb_coord_t __dx__ = (dx), __dy__ = (dy);                     \
+		rnd_coord_t __dx__ = (dx), __dy__ = (dy);                     \
 		pcb_arc_t *__a__ = (a);                                       \
-		PCB_MOVE_POINT((__a__)->X,(__a__)->Y,__dx__,__dy__);          \
-		PCB_BOX_MOVE_LOWLEVEL(&((__a__)->BoundingBox),__dx__,__dy__); \
-		PCB_BOX_MOVE_LOWLEVEL(&((__a__)->bbox_naked),__dx__,__dy__); \
+		RND_MOVE_POINT((__a__)->X,(__a__)->Y,__dx__,__dy__);          \
+		RND_BOX_MOVE_LOWLEVEL(&((__a__)->BoundingBox),__dx__,__dy__); \
+		RND_BOX_MOVE_LOWLEVEL(&((__a__)->bbox_naked),__dx__,__dy__); \
 	} while(0)
 
 #define PCB_ARC_LOOP(element) do {                                      \
@@ -119,14 +119,14 @@ void pcb_arc_post(pcb_arc_t *arc);
   linelist_foreach(&(element)->Arc, &__it__, arc) {
 
 #define PCB_ARC_ALL_LOOP(top) do {		\
-	pcb_cardinal_t		l;			\
+	rnd_cardinal_t		l;			\
 	pcb_layer_t *layer = (top)->Layer;		\
 	for (l =0; l < ((top)->LayerN > 0 ? (top)->LayerN : PCB->Data->LayerN); l++, layer++)		\
 	{ \
 		PCB_ARC_LOOP(layer)
 
 #define PCB_ARC_COPPER_LOOP(top) do	{		\
-	pcb_cardinal_t		l;			\
+	rnd_cardinal_t		l;			\
 	pcb_layer_t *layer = (top)->Layer;		\
 	for (l =0; l < ((top)->LayerN > 0 ? (top)->LayerN : PCB->Data->LayerN); l++, layer++)		\
 	{ \
@@ -134,7 +134,7 @@ void pcb_arc_post(pcb_arc_t *arc);
 		PCB_ARC_LOOP(layer)
 
 #define PCB_ARC_SILK_LOOP(top) do	{		\
-	pcb_cardinal_t		l;			\
+	rnd_cardinal_t		l;			\
 	pcb_layer_t *layer = (top)->Layer;		\
 	for (l = 0; l < ((top)->LayerN > 0 ? (top)->LayerN : PCB->Data->LayerN); l++, layer++)	\
 	{ \
@@ -142,7 +142,7 @@ void pcb_arc_post(pcb_arc_t *arc);
 		PCB_ARC_LOOP(layer)
 
 #define PCB_ARC_VISIBLE_LOOP(top) do	{		\
-	pcb_cardinal_t		l;			\
+	rnd_cardinal_t		l;			\
 	pcb_layer_t *layer = (top)->Layer;		\
 	for (l = 0; l < ((top)->LayerN > 0 ? (top)->LayerN : PCB->Data->LayerN); l++, layer++)	\
 	{ \
