@@ -32,7 +32,7 @@
 #include <math.h>
 #include <string.h>
 #include "flag.h"
-#include <librnd/core/attrib.h>
+#include "attrib.h"
 #include "global_typedefs.h"
 #include "data_parent.h"
 
@@ -205,7 +205,7 @@ long int pcb_create_ID_get(void);
    is not NULL, it is the source object - be smart about extobj and other
    attribute side effects (some of those will not be copied or will be
    changed); src_obj should be the objec src attributes are coming from */
-void pcb_obj_add_attribs(pcb_any_obj_t *obj, const rnd_attribute_list_t *src, pcb_any_obj_t *src_obj);
+void pcb_obj_add_attribs(pcb_any_obj_t *obj, const pcb_attribute_list_t *src, pcb_any_obj_t *src_obj);
 
 /* ---------------------------------------------------------------------------
  * Do not change the following definitions even if they're not very
@@ -223,7 +223,9 @@ void pcb_obj_add_attribs(pcb_any_obj_t *obj, const rnd_attribute_list_t *src, pc
 	pcb_parenttype_t     parent_type; \
 	pcb_parent_t         parent; \
 	rnd_box_t            bbox_naked; \
-	rnd_attribute_list_t Attributes \
+	unsigned             ind_onpoint:1; \
+	unsigned             ind_editpoint:1; \
+	pcb_attribute_list_t Attributes \
 
 #define PCB_ANY_PRIMITIVE_FIELDS \
 	PCB_ANY_OBJ_FIELDS; \
@@ -264,7 +266,7 @@ rnd_coord_t pcb_obj_clearance_at(pcb_board_t *pcb, const pcb_any_obj_t *o, pcb_l
 unsigned char *pcb_obj_common_get_thermal(pcb_any_obj_t *obj, unsigned long lid, rnd_bool_t alloc);
 
 /* Update cached attributes (->term) */
-void pcb_obj_attrib_post_change(rnd_attribute_list_t *list, const char *name, const char *value);
+void pcb_obj_attrib_post_change(pcb_attribute_list_t *list, const char *name, const char *value);
 
 /* Returns the first invalid character of an ID (terminal, refdes) or NULL */
 const char *pcb_obj_id_invalid(const char *id);
@@ -326,7 +328,7 @@ void pcb_obj_update_bbox(pcb_board_t *pcb, pcb_any_obj_t *obj);
 do { \
 	if (obj->noexport) { \
 		if (info->exporting) { \
-			if (!obj->noexport_named || (rnd_attribute_get(&obj->Attributes, info->noexport_name) != NULL)) { \
+			if (!obj->noexport_named || (pcb_attribute_get(&obj->Attributes, info->noexport_name) != NULL)) { \
 				inhibit; \
 			} \
 		} \
@@ -346,6 +348,21 @@ do { \
 	rnd_render->draw_line(pcb_draw_out.fgGC, cx+radius, cy-radius, cx-radius, cy+radius); \
 } while(0)
 
+#define pcb_obj_editpont_setup() \
+do { \
+	rnd_render->set_color(pcb_draw_out.fgGC, &conf_core.appearance.color.subc); \
+	rnd_hid_set_line_cap(pcb_draw_out.fgGC, rnd_cap_round); \
+	rnd_hid_set_line_width(pcb_draw_out.fgGC, -2); \
+} while(0)
+
+#define pcb_obj_editpont_cross(x, y) \
+do { \
+	static const rnd_coord_t radius = RND_MM_TO_COORD(0.2); \
+	rnd_render->draw_line(pcb_draw_out.fgGC, (x)-radius, (y), (x)+radius, (y)); \
+	rnd_render->draw_line(pcb_draw_out.fgGC, (x), (y)-radius, (x), (y)+radius); \
+} while(0)
+
+
 #define pcb_hidden_floater(obj,info) ((info)->xform->hide_floaters &&  PCB_FLAG_TEST(PCB_FLAG_FLOATER, (obj)))
 #define pcb_hidden_floater_gui(obj) (conf_core.editor.hide_names &&  PCB_FLAG_TEST(PCB_FLAG_FLOATER, (obj)))
 #define pcb_partial_export(obj,info) (((info)->xform != NULL) && (info)->xform->partial_export && (!PCB_FLAG_TEST(PCB_FLAG_EXPORTSEL, (obj))))
