@@ -160,7 +160,7 @@ static pcb_gfx_t *pcb_gfx_copy_meta(pcb_gfx_t *dst, pcb_gfx_t *src)
 {
 	if (dst == NULL)
 		return NULL;
-	rnd_attribute_copy_all(&dst->Attributes, &src->Attributes);
+	pcb_attribute_copy_all(&dst->Attributes, &src->Attributes);
 	return dst;
 }
 
@@ -207,7 +207,7 @@ void pcb_gfx_free(pcb_gfx_t *gfx)
 {
 	if ((gfx->parent.layer != NULL) && (gfx->parent.layer->gfx_tree != NULL))
 		rnd_r_delete_entry(gfx->parent.layer->gfx_tree, (rnd_box_t *)gfx);
-	rnd_attribute_free(&gfx->Attributes);
+	pcb_attribute_free(&gfx->Attributes);
 	pcb_gfx_unreg(gfx);
 	pcb_obj_common_free((pcb_any_obj_t *)gfx);
 	free(gfx);
@@ -870,10 +870,10 @@ void pcb_gfx_name_invalidate_draw(pcb_gfx_t *gfx)
 	/* ->term: can't be a terminal, no label to draw */
 }
 
-void pcb_gfx_draw_label(pcb_draw_info_t *info, pcb_gfx_t *gfx)
+void pcb_gfx_draw_label(pcb_draw_info_t *info, pcb_gfx_t *gfx, rnd_bool vis_side)
 {
 	/* ->term: can't be a terminal, no label to draw */
-	if (gfx->noexport)
+	if (gfx->noexport && vis_side)
 		pcb_obj_noexport_mark(gfx, gfx->cx, gfx->cy);
 }
 
