@@ -51,8 +51,6 @@
 #include "obj_subc_parent.h"
 #include "obj_hash.h"
 
-/* TODO: maybe remove this and move lines from draw here? */
-#include "draw.h"
 #include "draw_wireframe.h"
 #include "obj_line_draw.h"
 #include "obj_rat_draw.h"
@@ -72,8 +70,11 @@ void pcb_line_reg(pcb_layer_t *layer, pcb_line_t *line)
 	if (layer->parent_type == PCB_PARENT_UI)
 		return;
 
-	if (layer->parent_type == PCB_PARENT_DATA)
+	if (layer->parent_type == PCB_PARENT_DATA) {
 		pcb_obj_id_reg(layer->parent.data, line);
+		pcb_obj_id_reg(layer->parent.data, &line->Point1);
+		pcb_obj_id_reg(layer->parent.data, &line->Point2);
+	}
 }
 
 void pcb_line_unreg(pcb_line_t *line)
@@ -84,6 +85,8 @@ void pcb_line_unreg(pcb_line_t *line)
 	if (layer->parent_type != PCB_PARENT_UI) {
 		assert(layer->parent_type == PCB_PARENT_DATA);
 		pcb_obj_id_del(layer->parent.data, line);
+		pcb_obj_id_del(layer->parent.data, &line->Point1);
+		pcb_obj_id_del(layer->parent.data, &line->Point2);
 	}
 	PCB_CLEAR_PARENT(line);
 }
@@ -111,7 +114,7 @@ void pcb_line_free(pcb_line_t *line)
 {
 	if ((line->parent.layer != NULL) && (line->parent.layer->line_tree != NULL))
 		rnd_r_delete_entry(line->parent.layer->line_tree, (rnd_box_t *)line);
-	rnd_attribute_free(&line->Attributes);
+	pcb_attribute_free(&line->Attributes);
 	pcb_line_unreg(line);
 	pcb_obj_common_free((pcb_any_obj_t *)line);
 	free(line);
@@ -172,8 +175,14 @@ struct line_info {
 	jmp_buf env;
 };
 
-RND_INLINE int can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new_line, pcb_line_t *out)
+RND_INLINE pcb_line_merge_t can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new_line, pcb_line_t *out)
 {
+	int ov_n1o, ov_n2o, ov_o1n, ov_o2n;
+	pcb_line_t tmp;
+
+	if (!conf_core.editor.trace_auto_merge)
+		return PCB_LINMER_NONE;
+
 	/* do not merge to subc parts or terminals */
 	if ((pcb_obj_parent_subc((pcb_any_obj_t *)old_line) != NULL) || (old_line->term != NULL))
 		return PCB_LINMER_NONE;
@@ -196,6 +205,9 @@ RND_INLINE int can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new
 	if (PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, old_line) != PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, new_line))
 		return PCB_LINMER_NONE;
 
+	/*** matching endpoint ***/
+	out->Thickness = 4; /* theoretical line for the on-point check should have small thicnkess - but leave some room for rouding errors */
+
 	/* remove unnecessary line points */
 	if (old_line->Point1.X == new_line->Point1.X && old_line->Point1.Y == new_line->Point1.Y) {
 		out->Point1.X = old_line->Point2.X;
@@ -204,6 +216,7 @@ RND_INLINE int can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new
 		out->Point2.Y = new_line->Point2.Y;
 		if (pcb_is_point_on_line(new_line->Point1.X, new_line->Point1.Y, 1, out))
 			return PCB_LINMER_REMPT;
+		return PCB_LINMER_NONE;
 	}
 	else if (old_line->Point2.X == new_line->Point1.X && old_line->Point2.Y == new_line->Point1.Y) {
 		out->Point1.X = old_line->Point1.X;
@@ -212,6 +225,7 @@ RND_INLINE int can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new
 		out->Point2.Y = new_line->Point2.Y;
 		if (pcb_is_point_on_line(new_line->Point1.X, new_line->Point1.Y, 1, out))
 			return PCB_LINMER_REMPT;
+		return PCB_LINMER_NONE;
 	}
 	else if (old_line->Point1.X == new_line->Point2.X && old_line->Point1.Y == new_line->Point2.Y) {
 		out->Point1.X = old_line->Point2.X;
@@ -220,6 +234,7 @@ RND_INLINE int can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new
 		out->Point2.Y = new_line->Point1.Y;
 		if (pcb_is_point_on_line(new_line->Point2.X, new_line->Point2.Y, 1, out))
 			return PCB_LINMER_REMPT;
+		return PCB_LINMER_NONE;
 	}
 	else if (old_line->Point2.X == new_line->Point2.X && old_line->Point2.Y == new_line->Point2.Y) {
 		out->Point1.X = old_line->Point1.X;
@@ -228,16 +243,198 @@ RND_INLINE int can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new
 		out->Point2.Y = new_line->Point1.Y;
 		if (pcb_is_point_on_line(new_line->Point2.X, new_line->Point2.Y, 1, out))
 			return PCB_LINMER_REMPT;
+		return PCB_LINMER_NONE;
 	}
 
+	/*** Partial overlap ***/
+
+	tmp = *old_line;
+	tmp.Thickness = 4;
+	ov_n1o = pcb_is_point_on_line(new_line->Point1.X, new_line->Point1.Y, 1, &tmp);
+	ov_n2o = pcb_is_point_on_line(new_line->Point2.X, new_line->Point2.Y, 1, &tmp);
+
+	/* new line fully within old line */
+	if (ov_n1o && ov_n2o)
+		return PCB_LINMER_SKIP;
+
+	tmp = *new_line;
+	tmp.Thickness = 4;
+	ov_o1n = pcb_is_point_on_line(old_line->Point1.X, old_line->Point1.Y, 1, &tmp);
+	ov_o2n = pcb_is_point_on_line(old_line->Point2.X, old_line->Point2.Y, 1, &tmp);
+
+	/* old line fully covered by the new line */
+	if (ov_o1n && ov_o2n) {
+		*out = *new_line;
+		return PCB_LINMER_REMPT;
+	}
+
+	/* common overlapping segment */
+	if (ov_o1n && ov_n2o) {
+		out->Point1.X = old_line->Point2.X;
+		out->Point1.Y = old_line->Point2.Y;
+		out->Point2.X = new_line->Point1.X;
+		out->Point2.Y = new_line->Point1.Y;
+		return PCB_LINMER_REMPT;
+	}
+
+	if (ov_o1n && ov_n1o) {
+		out->Point1.X = old_line->Point2.X;
+		out->Point1.Y = old_line->Point2.Y;
+		out->Point2.X = new_line->Point2.X;
+		out->Point2.Y = new_line->Point2.Y;
+		return PCB_LINMER_REMPT;
+	}
+
+	if (ov_o2n && ov_n2o) {
+		out->Point1.X = old_line->Point1.X;
+		out->Point1.Y = old_line->Point1.Y;
+		out->Point2.X = new_line->Point1.X;
+		out->Point2.Y = new_line->Point1.Y;
+		return PCB_LINMER_REMPT;
+	}
+
+	if (ov_o2n && ov_n1o) {
+		out->Point1.X = old_line->Point1.X;
+		out->Point1.Y = old_line->Point1.Y;
+		out->Point2.X = new_line->Point2.X;
+		out->Point2.Y = new_line->Point2.Y;
+		return PCB_LINMER_REMPT;
+	}
+
+
 	return PCB_LINMER_NONE;
 }
 
-int pcb_line_can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new_line, pcb_line_t *out)
+pcb_line_merge_t pcb_line_can_merge_lines(const pcb_line_t *old_line, const pcb_line_t *new_line, pcb_line_t *out)
 {
 	return can_merge_lines(old_line, new_line, out);
 }
 
+static void maybe_move_line_pt(pcb_layer_t *layer, pcb_line_t *line, rnd_point_t *pt, rnd_point_t *new_loc)
+{
+	rnd_coord_t dx = new_loc->X - pt->X, dy = new_loc->Y - pt->Y;
+	if ((dx == 0) && (dy == 0))
+		return;
+	pcb_move_obj(PCB_OBJ_LINE_POINT, layer, line, pt, dx, dy);
+}
+
+
+void pcb_line_mod_merge_inhibit_inc(pcb_board_t *pcb)
+{
+	if (pcb->line_mod_merge_inhibit > 8192) {
+		rnd_message(RND_MSG_ERROR, "internal error: pcb_line_mod_merge_inhibit_dec overflow\n");
+		return;
+	}
+	pcb->line_mod_merge_inhibit++;
+}
+
+void pcb_line_mod_merge_inhibit_dec(pcb_board_t *pcb)
+{
+	if (pcb->line_mod_merge_inhibit == 0) {
+		rnd_message(RND_MSG_ERROR, "internal error: pcb_line_mod_merge_inhibit_dec underflow\n");
+		return;
+	}
+	pcb->line_mod_merge_inhibit--;
+	if (pcb->line_mod_merge_inhibit == 0) {
+		long n;
+		if (pcb->line_mod_merge == NULL)
+			return;
+		for(n = 0; n < pcb->line_mod_merge->used; n++)
+			if (pcb->line_mod_merge->array[n] != NULL)
+				pcb_line_mod_merge(pcb->line_mod_merge->array[n], 1);
+		pcb->line_mod_merge->used = 0;
+	}
+}
+
+static void line_mod_merge_removed(pcb_board_t *pcb, pcb_line_t *line)
+{
+	long n;
+	if (pcb->line_mod_merge == NULL)
+		return;
+	for(n = 0; n < pcb->line_mod_merge->used; n++) {
+		if (pcb->line_mod_merge->array[n] == line) {
+			pcb->line_mod_merge->array[n] = NULL;
+			return;
+		}
+	}
+}
+
+void pcb_line_mod_merge(pcb_line_t *line, rnd_bool undoable)
+{
+	pcb_layer_t *layer = line->parent.layer;
+	rnd_rtree_it_t it;
+	pcb_line_t *l2, *old_line, *new_line, out;
+	rnd_box_t search;
+	int retries = 16;
+	pcb_board_t *pcb;
+
+	if (!conf_core.editor.trace_auto_merge)
+		return;
+
+	pcb = pcb_data_get_top(line->parent.layer->parent.data);
+	if (pcb == NULL)
+		return;
+
+	if (pcb->line_mod_merge_inhibit) { /* delay removal */
+		long n;
+		if (pcb->line_mod_merge == NULL)
+			pcb->line_mod_merge = calloc(sizeof(vtp0_t), 1);
+		for(n = 0; n < pcb->line_mod_merge->used; n++)
+			if (pcb->line_mod_merge->array[n] == line)
+				return;
+		vtp0_append(pcb->line_mod_merge, line);
+		return;
+	}
+
+	assert(undoable); /* non-undoable is not yet supported */
+
+	retry:;
+	if (retries-- == 0)
+		return; /* fallback: avoid infinite loop in any case */
+
+	search.X1 = MIN(line->Point1.X, line->Point2.X);
+	search.X2 = MAX(line->Point1.X, line->Point2.X);
+	search.Y1 = MIN(line->Point1.Y, line->Point2.Y);
+	search.Y2 = MAX(line->Point1.Y, line->Point2.Y);
+	if (search.Y2 == search.Y1)
+		search.Y2++;
+	if (search.X2 == search.X1)
+		search.X2++;
+
+	for(l2 = rnd_rtree_first(&it, layer->line_tree, (rnd_rtree_box_t *)&search); l2 != NULL; l2 = rnd_rtree_next(&it)) {
+		pcb_line_merge_t res;
+
+		if (line == l2)
+			continue;
+
+		if (line->ID < l2->ID) {
+			old_line = line;
+			new_line = l2;
+		}
+		else {
+			old_line = l2;
+			new_line = line;
+		}
+
+		res = can_merge_lines(old_line, new_line, &out);
+		switch(res) {
+			case PCB_LINMER_NONE: break;
+			case PCB_LINMER_REMPT:
+				pcb_undo_move_obj_to_remove(PCB_OBJ_LINE, layer, new_line, new_line);
+				line_mod_merge_removed(pcb, new_line);
+				maybe_move_line_pt(layer, old_line, &old_line->Point1, &out.Point1);
+				maybe_move_line_pt(layer, old_line, &old_line->Point2, &out.Point2);
+				line = old_line;
+				goto retry;
+
+			case PCB_LINMER_SKIP:
+				pcb_undo_move_obj_to_remove(PCB_OBJ_LINE, layer, new_line, new_line);
+				line_mod_merge_removed(pcb, new_line);
+				break;
+		}
+	}
+}
+
 
 static rnd_r_dir_t line_callback(const rnd_box_t * b, void *cl)
 {
@@ -262,6 +459,9 @@ pcb_line_t *pcb_line_new_merge(pcb_layer_t *Layer, rnd_coord_t X1, rnd_coord_t Y
 	struct line_info info = {0};
 	rnd_box_t search;
 
+	if (!conf_core.editor.trace_auto_merge)
+		return pcb_line_new(Layer, X1, Y1, X2, Y2, Thickness, Clearance, Flags);
+
 	search.X1 = MIN(X1, X2);
 	search.X2 = MAX(X1, X2);
 	search.Y1 = MIN(Y1, Y2);
@@ -316,7 +516,6 @@ pcb_line_t *pcb_line_new(pcb_layer_t *Layer, rnd_coord_t X1, rnd_coord_t Y1, rnd
 	Line->Clearance = Clearance;
 	Line->Point1.X = X1;
 	Line->Point1.Y = Y1;
-TODO("ID: register points too")
 	Line->Point1.ID = pcb_create_ID_get();
 	Line->Point2.X = X2;
 	Line->Point2.Y = Y2;
@@ -329,7 +528,7 @@ static pcb_line_t *pcb_line_copy_meta(pcb_line_t *dst, pcb_line_t *src)
 {
 	if (dst == NULL)
 		return NULL;
-	rnd_attribute_copy_all(&dst->Attributes, &src->Attributes);
+	pcb_attribute_copy_all(&dst->Attributes, &src->Attributes);
 	return dst;
 }
 
@@ -413,10 +612,7 @@ unsigned int pcb_line_hash(const pcb_host_trans_t *tr, const pcb_line_t *l)
 
 rnd_coord_t pcb_line_length(const pcb_line_t *line)
 {
-	rnd_coord_t dx = line->Point1.X - line->Point2.X;
-	rnd_coord_t dy = line->Point1.Y - line->Point2.Y;
-TODO(": use the distance func instead")
-	return rnd_round(sqrt((double)dx*(double)dx + (double)dy*(double)dy));
+	return rnd_round(rnd_distance((double)line->Point1.X, (double)line->Point1.Y, (double)line->Point2.X, (double)line->Point2.Y));
 }
 
 double pcb_line_area(const pcb_line_t *line)
@@ -778,7 +974,7 @@ static rnd_r_dir_t moveline_callback(const rnd_box_t * b, void *cl)
 	struct via_info *i = (struct via_info *) cl;
 	pcb_pstk_t *ps;
 
-TODO("pdstk TODO #21: do not work in comp mode, use a pstk proto - scconfig also has TODO #21, fix it there too")
+TODO("pstk TODO #21: do not work in comp mode, use a pstk proto - scconfig also has TODO #21, fix it there too")
 	if ((ps = pcb_pstk_new_compat_via(PCB->Data, -1, i->X, i->Y, conf_core.design.via_drilling_hole, conf_core.design.via_thickness, conf_core.design.clearance, 0, PCB_PSTK_COMPAT_ROUND, rnd_true)) != NULL) {
 		pcb_undo_add_obj_to_create(PCB_OBJ_PSTK, ps, ps, ps);
 		pcb_pstk_invalidate_draw(ps);
@@ -1165,19 +1361,27 @@ void pcb_line_name_invalidate_draw(pcb_line_t *line)
 	}
 }
 
-void pcb_line_draw_label(pcb_draw_info_t *info, pcb_line_t *line)
+void pcb_line_draw_label(pcb_draw_info_t *info, pcb_line_t *line, rnd_bool vis_side)
 {
-	if (line->term != NULL)
+	if ((line->term != NULL) && vis_side)
 		pcb_term_label_draw(info, (line->Point1.X + line->Point2.X)/2, (line->Point1.Y + line->Point2.Y)/2,
 			conf_core.appearance.term_label_size, is_line_term_vert(line), rnd_true, (pcb_any_obj_t *)line);
-	if (line->noexport)
+	if (line->noexport && vis_side)
 		pcb_obj_noexport_mark(line, (line->Point1.X+line->Point2.X)/2, (line->Point1.Y+line->Point2.Y)/2);
+
+	if (line->ind_editpoint) {
+		pcb_obj_editpont_setup();
+		pcb_obj_editpont_cross(line->Point1.X, line->Point1.Y);
+		if ((line->Point1.X != line->Point2.X) || (line->Point1.Y != line->Point2.Y))
+			pcb_obj_editpont_cross(line->Point2.X, line->Point2.Y);
+	}
 }
 
 
 void pcb_line_draw_(pcb_draw_info_t *info, pcb_line_t *line, int allow_term_gfx)
 {
 	rnd_coord_t thickness = line->Thickness;
+	int draw_lab;
 
 	if (delayed_terms_enabled && (line->term != NULL)) {
 		pcb_draw_delay_obj_add((pcb_any_obj_t *)line);
@@ -1215,10 +1419,11 @@ void pcb_line_draw_(pcb_draw_info_t *info, pcb_line_t *line, int allow_term_gfx)
 		}
 	}
 
-	if (line->term != NULL) {
-		if ((pcb_draw_force_termlab) || PCB_FLAG_TEST(PCB_FLAG_TERMNAME, line))
-			pcb_draw_delay_label_add((pcb_any_obj_t *)line);
-	}
+	draw_lab = (line->term != NULL) && ((pcb_draw_force_termlab) || PCB_FLAG_TEST(PCB_FLAG_TERMNAME, line));
+	draw_lab |= line->ind_editpoint;
+
+	if (draw_lab)
+		pcb_draw_delay_label_add((pcb_any_obj_t *)line);
 }
 
 static void pcb_line_draw(pcb_draw_info_t *info, pcb_line_t *line, int allow_term_gfx)
@@ -1252,7 +1457,7 @@ static void pcb_line_draw(pcb_draw_info_t *info, pcb_line_t *line, int allow_ter
 	else
 		color = &layer->meta.real.color;
 
-	if (info->xform->flag_color && PCB_FLAG_TEST(PCB_FLAG_ONPOINT, line)) {
+	if (info->xform->flag_color && line->ind_onpoint) {
 		pcb_lighten_color(color, &buf, 1.75);
 		color = &buf;
 	}
