@@ -49,13 +49,11 @@
 #include "obj_poly_op.h"
 #include "obj_poly_list.h"
 #include "obj_poly_draw.h"
+#include "obj_term.h"
 
 #include "obj_subc_parent.h"
 #include "obj_hash.h"
 
-/* TODO: get rid of these: */
-#include "draw.h"
-
 #define	STEP_POLYGONPOINT	10
 #define	STEP_POLYGONHOLEINDEX	10
 
@@ -78,6 +76,8 @@ void pcb_poly_reg(pcb_layer_t *layer, pcb_poly_t *poly)
 void pcb_poly_unreg(pcb_poly_t *poly)
 {
 	pcb_layer_t *layer = poly->parent.layer;
+
+	pcb_term_del_auto((pcb_any_obj_t *)poly);
 	assert(poly->parent_type == PCB_PARENT_LAYER);
 	polylist_remove(poly);
 	if (layer->parent_type != PCB_PARENT_UI) {
@@ -111,7 +111,7 @@ void pcb_poly_free(pcb_poly_t *poly)
 {
 	if ((poly->parent.layer != NULL) && (poly->parent.layer->polygon_tree != NULL))
 		rnd_r_delete_entry(poly->parent.layer->polygon_tree, (rnd_box_t *)poly);
-	rnd_attribute_free(&poly->Attributes);
+	pcb_attribute_free(&poly->Attributes);
 	pcb_poly_unreg(poly);
 	pcb_obj_common_free((pcb_any_obj_t *)poly);
 	free(poly);
@@ -506,7 +506,7 @@ static pcb_poly_t *pcb_poly_copy_meta(pcb_poly_t *dst, pcb_poly_t *src)
 {
 	if (dst == NULL)
 		return NULL;
-	rnd_attribute_copy_all(&dst->Attributes, &src->Attributes);
+	pcb_attribute_copy_all(&dst->Attributes, &src->Attributes);
 	return dst;
 }
 
@@ -841,7 +841,7 @@ void *pcb_polyop_insert_point(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *
 			Polygon->HoleIndex[n]++;
 
 	Polygon->Points[ctx->insert.idx] = save;
-	pcb_board_set_changed_flag(rnd_true);
+	pcb_board_set_changed_flag(PCB, rnd_true);
 	pcb_undo_add_obj_to_insert_point(PCB_OBJ_POLY_POINT, Layer, Polygon, &Polygon->Points[ctx->insert.idx]);
 
 	pcb_poly_bbox(Polygon);
@@ -984,6 +984,7 @@ void *pcb_polyop_move_to_layer(pcb_opctx_t *ctx, pcb_layer_t * Layer, pcb_poly_t
 /* destroys a polygon from a layer */
 void *pcb_polyop_destroy(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_poly_t *Polygon)
 {
+	pcb_term_del_auto((pcb_any_obj_t *)Polygon);
 	rnd_r_delete_entry(Layer->polygon_tree, (rnd_box_t *) Polygon);
 	pcb_poly_free_fields(Polygon);
 
@@ -1299,14 +1300,21 @@ void pcb_poly_name_invalidate_draw(pcb_poly_t *poly)
 	}
 }
 
-void pcb_poly_draw_label(pcb_draw_info_t *info, pcb_poly_t *poly)
+void pcb_poly_draw_label(pcb_draw_info_t *info, pcb_poly_t *poly, rnd_bool vis_side)
 {
-	if (poly->term != NULL)
+	if ((poly->term != NULL) && (vis_side))
 		pcb_term_label_draw(info, (poly->BoundingBox.X1 + poly->BoundingBox.X2)/2, (poly->BoundingBox.Y1 + poly->BoundingBox.Y2)/2,
 			conf_core.appearance.term_label_size, is_poly_term_vert(poly), rnd_true, (pcb_any_obj_t *)poly);
 
-	if (poly->noexport)
+	if (poly->noexport && vis_side)
 		pcb_obj_noexport_mark(poly, (poly->BoundingBox.X1 + poly->BoundingBox.X2)/2, (poly->BoundingBox.Y1 + poly->BoundingBox.Y2)/2);
+
+	if (poly->ind_editpoint) {
+		long n;
+		pcb_obj_editpont_setup();
+		for(n = 0; n < poly->PointN; n++)
+			pcb_obj_editpont_cross(poly->Points[n].X, poly->Points[n].Y);
+	}
 }
 
 void pcb_poly_draw_annotation(pcb_draw_info_t *info, pcb_poly_t *poly)
@@ -1401,6 +1409,7 @@ static pcb_poly_t *pcb_poly_draw_tr(pcb_draw_info_t *info, pcb_poly_t *polygon)
 void pcb_poly_draw_(pcb_draw_info_t *info, pcb_poly_t *polygon, int allow_term_gfx)
 {
 	pcb_poly_t *trpoly = NULL;
+	int draw_lab;
 
 	if (delayed_terms_enabled && (polygon->term != NULL)) {
 		pcb_draw_delay_obj_add((pcb_any_obj_t *)polygon);
@@ -1451,10 +1460,11 @@ TODO("subc: check if x;y is within the poly, but use a cheaper method than the o
 			pcb_dhlp_thindraw_pcb_polygon(pcb_draw_out.fgGC, &poly, info->drawn_area);
 	}
 
-	if (polygon->term != NULL) {
-		if ((pcb_draw_force_termlab) || PCB_FLAG_TEST(PCB_FLAG_TERMNAME, polygon))
-			pcb_draw_delay_label_add((pcb_any_obj_t *)polygon);
-	}
+	draw_lab = (polygon->term != NULL) && ((pcb_draw_force_termlab) || PCB_FLAG_TEST(PCB_FLAG_TERMNAME, polygon));
+	draw_lab |= polygon->ind_editpoint;
+
+	if (draw_lab)
+		pcb_draw_delay_label_add((pcb_any_obj_t *)polygon);
 
 	if (trpoly != NULL)
 		pcb_poly_free(trpoly);
@@ -1481,7 +1491,7 @@ static void pcb_poly_draw(pcb_draw_info_t *info, pcb_poly_t *polygon, int allow_
 	}
 	else if (info->xform->flag_color && PCB_FLAG_TEST(PCB_FLAG_FOUND, polygon))
 		color = &conf_core.appearance.color.connected;
-	else if (info->xform->flag_color && PCB_FLAG_TEST(PCB_FLAG_ONPOINT, polygon)) {
+	else if (info->xform->flag_color && polygon->ind_onpoint) {
 		pcb_lighten_color(color, &buf, 1.75);
 		color = &buf;
 	}
