@@ -34,22 +34,23 @@
 #include "config.h"
 #include <genlist/gendlist.h>
 #include "obj_common.h"
-#include "polyarea.h"
+#include <librnd/poly/polyarea.h>
 
-struct pcb_poly_s  {           /* holds information about a polygon */
+struct pcb_poly_s  {               /* holds information about a polygon */
 	PCB_ANY_PRIMITIVE_FIELDS;
-	pcb_coord_t Clearance;
-	pcb_cardinal_t PointN;       /* number of points in polygon */
-	pcb_cardinal_t PointMax;     /* max number from malloc() */
-	pcb_polyarea_t *Clipped;     /* the clipped region of this polygon */
-	pcb_pline_t *NoHoles;        /* the polygon broken into hole-less regions */
-	int NoHolesValid;            /* Is the NoHoles polygon up to date? */
-	pcb_point_t *Points;         /* data */
-	pcb_cardinal_t *HoleIndex;   /* Index of hole data within the Points array */
-	pcb_cardinal_t HoleIndexN;   /* number of holes in polygon */
-	pcb_cardinal_t HoleIndexMax; /* max number from malloc() */
-	unsigned clip_dirty:1;       /* 1 if polygon should be reclipped after clipping inhibit is over */
-	gdl_elem_t link;             /* a poly is in a list of a layer */
+	rnd_coord_t Clearance;
+	rnd_coord_t enforce_clearance;   /* all objects within this polygon needs to have at least this much clearance; WARNING: true gap value, not *2 as with the Clearance fields */
+	rnd_cardinal_t PointN;           /* number of points in polygon */
+	rnd_cardinal_t PointMax;         /* max number from malloc() */
+	rnd_polyarea_t *Clipped;         /* the clipped region of this polygon */
+	rnd_pline_t *NoHoles;            /* the polygon broken into hole-less regions */
+	int NoHolesValid;                /* Is the NoHoles polygon up to date? */
+	rnd_point_t *Points;             /* data */
+	rnd_cardinal_t *HoleIndex;       /* Index of hole data within the Points array */
+	rnd_cardinal_t HoleIndexN;       /* number of holes in polygon */
+	rnd_cardinal_t HoleIndexMax;     /* max number from malloc() */
+	unsigned clip_dirty:1;           /* 1 if polygon should be reclipped after clipping inhibit is over */
+	gdl_elem_t link;                 /* a poly is in a list of a layer */
 };
 
 
@@ -57,31 +58,31 @@ struct pcb_poly_s  {           /* holds information about a polygon */
 pcb_poly_t *pcb_poly_alloc(pcb_layer_t * layer);
 pcb_poly_t *pcb_poly_alloc_id(pcb_layer_t *layer, long int id);
 void pcb_poly_free(pcb_poly_t * data);
-pcb_point_t *pcb_poly_point_alloc(pcb_poly_t *Polygon);
-pcb_cardinal_t *pcb_poly_holeidx_new(pcb_poly_t *Polygon);
+rnd_point_t *pcb_poly_point_alloc(pcb_poly_t *Polygon);
+rnd_cardinal_t *pcb_poly_holeidx_new(pcb_poly_t *Polygon);
 void pcb_poly_free_fields(pcb_poly_t * polygon);
 
 void pcb_poly_reg(pcb_layer_t *layer, pcb_poly_t *poly);
 void pcb_poly_unreg(pcb_poly_t *poly);
 
 void pcb_poly_bbox(pcb_poly_t *Polygon);
-pcb_poly_t *pcb_poly_new_from_rectangle(pcb_layer_t *Layer, pcb_coord_t X1, pcb_coord_t Y1, pcb_coord_t X2, pcb_coord_t Y2, pcb_coord_t Clearance, pcb_flag_t Flags);
-pcb_poly_t *pcb_poly_new_from_poly(pcb_layer_t *Layer, pcb_poly_t *src, pcb_coord_t offs, pcb_coord_t Clearance, pcb_flag_t Flags);
-pcb_poly_t *pcb_poly_new(pcb_layer_t *Layer, pcb_coord_t Clearance, pcb_flag_t Flags);
+pcb_poly_t *pcb_poly_new_from_rectangle(pcb_layer_t *Layer, rnd_coord_t X1, rnd_coord_t Y1, rnd_coord_t X2, rnd_coord_t Y2, rnd_coord_t Clearance, pcb_flag_t Flags);
+pcb_poly_t *pcb_poly_new_from_poly(pcb_layer_t *Layer, pcb_poly_t *src, rnd_coord_t offs, rnd_coord_t Clearance, pcb_flag_t Flags);
+pcb_poly_t *pcb_poly_new(pcb_layer_t *Layer, rnd_coord_t Clearance, pcb_flag_t Flags);
 pcb_poly_t *pcb_poly_dup(pcb_layer_t *dst, pcb_poly_t *src);
-pcb_poly_t *pcb_poly_dup_at(pcb_layer_t *dst, pcb_poly_t *src, pcb_coord_t dx, pcb_coord_t dy);
-pcb_point_t *pcb_poly_point_new(pcb_poly_t *Polygon, pcb_coord_t X, pcb_coord_t Y);
+pcb_poly_t *pcb_poly_dup_at(pcb_layer_t *dst, pcb_poly_t *src, rnd_coord_t dx, rnd_coord_t dy);
+rnd_point_t *pcb_poly_point_new(pcb_poly_t *Polygon, rnd_coord_t X, rnd_coord_t Y);
 pcb_poly_t *pcb_poly_hole_new(pcb_poly_t * Polygon);
 void *pcb_poly_remove(pcb_layer_t *Layer, pcb_poly_t *Polygon);
 
-void pcb_poly_rotate90(pcb_poly_t *Polygon, pcb_coord_t X, pcb_coord_t Y, unsigned Number);
-void pcb_poly_rotate(pcb_layer_t *layer, pcb_poly_t *poly, pcb_coord_t X, pcb_coord_t Y, double cosa, double sina);
-void pcb_poly_mirror(pcb_layer_t *layer, pcb_poly_t *polygon, pcb_coord_t y_offs);
+void pcb_poly_rotate90(pcb_poly_t *Polygon, rnd_coord_t X, rnd_coord_t Y, unsigned Number);
+void pcb_poly_rotate(pcb_layer_t *layer, pcb_poly_t *poly, rnd_coord_t X, rnd_coord_t Y, double cosa, double sina);
+void pcb_poly_mirror(pcb_poly_t *polygon, rnd_coord_t y_offs, rnd_bool undoable);
 void pcb_poly_flip_side(pcb_layer_t *layer, pcb_poly_t *polygon);
 void pcb_poly_scale(pcb_poly_t *poly, double sx, double sy);
 
-void pcb_poly_move(pcb_poly_t *Polygon, pcb_coord_t DX, pcb_coord_t DY);
-pcb_poly_t *pcb_poly_copy(pcb_poly_t *Dest, pcb_poly_t *Src, pcb_coord_t dx, pcb_coord_t dy);
+void pcb_poly_move(pcb_poly_t *Polygon, rnd_coord_t DX, rnd_coord_t DY);
+pcb_poly_t *pcb_poly_copy(pcb_poly_t *Dest, pcb_poly_t *Src, rnd_coord_t dx, rnd_coord_t dy);
 
 void pcb_poly_pre(pcb_poly_t *poly);
 void pcb_poly_post(pcb_poly_t *poly);
@@ -95,6 +96,10 @@ void pcb_add_poly_on_layer(pcb_layer_t *Layer, pcb_poly_t *polygon);
 
 double pcb_poly_area(const pcb_poly_t *poly);
 
+/* Returns whether p is valid, without ever asserting */
+int pcb_poly_is_valid(pcb_poly_t *p);
+
+
 /* called from main.c to free some caches */
 void pcb_poly_uninit(void);
 
@@ -112,20 +117,23 @@ typedef enum {
 } pcb_poly_event_t;
 
 /* return non-zero to quit mapping immediatley */
-typedef int pcb_poly_map_cb_t(pcb_poly_t *p, void *ctx, pcb_poly_event_t ev, pcb_coord_t x, pcb_coord_t y);
+typedef int pcb_poly_map_cb_t(pcb_poly_t *p, void *ctx, pcb_poly_event_t ev, rnd_coord_t x, rnd_coord_t y);
 
 /* call cb for each point of each island and cutout */
 void pcb_poly_map_contours(pcb_poly_t *p, void *ctx, pcb_poly_map_cb_t *cb);
 
 typedef struct pcb_poly_it_s {
 	const pcb_poly_t *p;
-	pcb_polyarea_t *pa;
-	pcb_pline_t *cntr;
-	pcb_vnode_t *v;
+	rnd_polyarea_t *pa;
+	rnd_pline_t *cntr;
+	rnd_vnode_t *v;
 } pcb_poly_it_t;
 
+/* WARNING: if the poly is not a FULLPOLY, quit after the first island else
+   invisible islands are returned */
+
 /* Set the iterator to the first island of the polygon; returns NULL if no contour available */
-PCB_INLINE pcb_polyarea_t *pcb_poly_island_first(const pcb_poly_t *p, pcb_poly_it_t *it)
+RND_INLINE rnd_polyarea_t *pcb_poly_island_first(const pcb_poly_t *p, pcb_poly_it_t *it)
 {
 	it->p = p;
 	it->pa = p->Clipped;
@@ -135,7 +143,7 @@ PCB_INLINE pcb_polyarea_t *pcb_poly_island_first(const pcb_poly_t *p, pcb_poly_i
 }
 
 /* Set the iterator to the next island of the polygon; returns NULL if no more */
-PCB_INLINE pcb_polyarea_t *pcb_poly_island_next(pcb_poly_it_t *it)
+RND_INLINE rnd_polyarea_t *pcb_poly_island_next(pcb_poly_it_t *it)
 {
 	if (it->pa->f == it->p->Clipped)
 		return NULL;
@@ -146,21 +154,21 @@ PCB_INLINE pcb_polyarea_t *pcb_poly_island_next(pcb_poly_it_t *it)
 }
 
 /* Set the iterator to trace the outer contour of the current island */
-PCB_INLINE pcb_pline_t *pcb_poly_contour(pcb_poly_it_t *it)
+RND_INLINE rnd_pline_t *pcb_poly_contour(pcb_poly_it_t *it)
 {
 	it->v = NULL;
 	return it->cntr = it->pa->contours;
 }
 
 /* Set the iterator to trace the first hole of the current island; returns NULL if there are no holes */
-PCB_INLINE pcb_pline_t *pcb_poly_hole_first(pcb_poly_it_t *it)
+RND_INLINE rnd_pline_t *pcb_poly_hole_first(pcb_poly_it_t *it)
 {
 	it->v = NULL;
 	return it->cntr = it->pa->contours->next;
 }
 
 /* Set the iterator to trace the next hole of the current island; returns NULL if there are were more holes */
-PCB_INLINE pcb_pline_t *pcb_poly_hole_next(pcb_poly_it_t *it)
+RND_INLINE rnd_pline_t *pcb_poly_hole_next(pcb_poly_it_t *it)
 {
 	it->v = NULL;
 	return it->cntr = it->cntr->next;
@@ -168,7 +176,7 @@ PCB_INLINE pcb_pline_t *pcb_poly_hole_next(pcb_poly_it_t *it)
 
 /* Set the iterator to the first point of the last selected contour or hole;
    read the coords into x,y; returns 1 on success, 0 if there are no points */
-PCB_INLINE int pcb_poly_vect_first(pcb_poly_it_t *it, pcb_coord_t *x, pcb_coord_t *y)
+RND_INLINE int pcb_poly_vect_first(pcb_poly_it_t *it, rnd_coord_t *x, rnd_coord_t *y)
 {
 	it->v = it->cntr->head->next;
 	if (it->v == NULL)
@@ -181,7 +189,7 @@ PCB_INLINE int pcb_poly_vect_first(pcb_poly_it_t *it, pcb_coord_t *x, pcb_coord_
 
 /* Set the iterator to the next point of the last selected contour or hole;
    read the coords into x,y; returns 1 on success, 0 if there are were more points */
-PCB_INLINE int pcb_poly_vect_next(pcb_poly_it_t *it, pcb_coord_t *x, pcb_coord_t *y)
+RND_INLINE int pcb_poly_vect_next(pcb_poly_it_t *it, rnd_coord_t *x, rnd_coord_t *y)
 {
 	it->v = it->v->next;
 	if (it->v == it->cntr->head->next)
@@ -192,21 +200,21 @@ PCB_INLINE int pcb_poly_vect_next(pcb_poly_it_t *it, pcb_coord_t *x, pcb_coord_t
 }
 
 /* read the previous contour/hole coords into x,y, without bumping the iterator */
-PCB_INLINE void pcb_poly_vect_peek_prev(pcb_poly_it_t *it, pcb_coord_t *x, pcb_coord_t *y)
+RND_INLINE void pcb_poly_vect_peek_prev(pcb_poly_it_t *it, rnd_coord_t *x, rnd_coord_t *y)
 {
 	*x = it->v->prev->point[0];
 	*y = it->v->prev->point[1];
 }
 
 /* read the next contour/hole coords into x,y, without bumping the iterator */
-PCB_INLINE void pcb_poly_vect_peek_next(pcb_poly_it_t *it, pcb_coord_t *x, pcb_coord_t *y)
+RND_INLINE void pcb_poly_vect_peek_next(pcb_poly_it_t *it, rnd_coord_t *x, rnd_coord_t *y)
 {
 	*x = it->v->next->point[0];
 	*y = it->v->next->point[1];
 }
 
 /* Set the iterator to a polyarea*/
-PCB_INLINE pcb_polyarea_t *pcb_poly_iterate_polyarea(pcb_polyarea_t *pa, pcb_poly_it_t *it)
+RND_INLINE rnd_polyarea_t *pcb_poly_iterate_polyarea(rnd_polyarea_t *pa, pcb_poly_it_t *it)
 {
 	it->p = NULL;
 	it->pa = pa;
@@ -217,7 +225,7 @@ PCB_INLINE pcb_polyarea_t *pcb_poly_iterate_polyarea(pcb_polyarea_t *pa, pcb_pol
 
 /* construct the full poly clearance cutout for the pa in the iterator and add
    it to dst - implemented in polygon.c */
-void pcb_poly_pa_clearance_construct(pcb_polyarea_t **dst, pcb_poly_it_t *it, pcb_coord_t clearance);
+void pcb_poly_pa_clearance_construct(rnd_polyarea_t **dst, pcb_poly_it_t *it, rnd_coord_t clearance);
 
 
 #define pcb_poly_ppclear_at(poly, layer) \
@@ -261,21 +269,21 @@ do { \
   linelist_foreach(&(layer)->Polygon, &__it__, polygon) {
 
 #define	PCB_POLY_POINT_LOOP(polygon) do	{	\
-	pcb_cardinal_t			n;		\
-	pcb_point_t *point;				\
+	rnd_cardinal_t			n;		\
+	rnd_point_t *point;				\
 	for (n = (polygon)->PointN-1; n != -1; n--)	\
 	{						\
 		point = &(polygon)->Points[n]
 
 #define	PCB_POLY_ALL_LOOP(top)	do {		\
-	pcb_cardinal_t		l;			\
+	rnd_cardinal_t		l;			\
 	pcb_layer_t *layer = (top)->Layer;		\
 	for (l = 0; l < ((top)->LayerN > 0 ? (top)->LayerN : PCB->Data->LayerN) ; l++, layer++)	\
 	{ \
 		PCB_POLY_LOOP(layer)
 
 #define	PCB_POLY_COPPER_LOOP(top) do	{		\
-	pcb_cardinal_t		l;			\
+	rnd_cardinal_t		l;			\
 	pcb_layer_t *layer = (top)->Layer;		\
 	for (l = 0; l < ((top)->LayerN > 0 ? (top)->LayerN : PCB->Data->LayerN); l++, layer++)	\
 	{ \
@@ -283,7 +291,7 @@ do { \
 		PCB_POLY_LOOP(layer)
 
 #define	PCB_POLY_SILK_LOOP(top) do	{		\
-	pcb_cardinal_t		l;			\
+	rnd_cardinal_t		l;			\
 	pcb_layer_t *layer = (top)->Layer;		\
 	for (l = 0; l < ((top)->LayerN > 0 ? (top)->LayerN : PCB->Data->LayerN); l++, layer++)	\
 	{ \
@@ -291,7 +299,7 @@ do { \
 		PCB_POLY_LOOP(layer)
 
 #define	PCB_POLY_VISIBLE_LOOP(top) do	{	\
-	pcb_cardinal_t		l;			\
+	rnd_cardinal_t		l;			\
 	pcb_layer_t *layer = (top)->Layer;		\
 	for (l = 0; l < ((top)->LayerN > 0 ? (top)->LayerN : PCB->Data->LayerN); l++, layer++)	\
 	{ \
