@@ -29,32 +29,32 @@
  */
 
 #include "config.h"
-#include "hid.h"
+#include <librnd/core/hid.h>
 #include "polygon.h"
 #include "obj_poly.h"
-#include "hid_inlines.h"
+#include <librnd/core/hid_inlines.h>
 
-static pcb_coord_t *fc_x = NULL, *fc_y = NULL;
+static rnd_coord_t *fc_x = NULL, *fc_y = NULL;
 static size_t fc_alloced = 0;
 
 
 /* call this before the loop */
 #define vert_opt_begin() \
 	{ \
-		pcb_coord_t last_x, last_y, this_x, this_y, next_x, next_y, mindist; \
+		rnd_coord_t last_x, last_y, this_x, this_y, next_x, next_y, mindist; \
 		last_x = pl->head->point[0]; \
 		last_y = pl->head->point[1]; \
 		v = pl->head->next; \
-		mindist = pcb_render->coord_per_pix * 2; \
+		mindist = rnd_render->coord_per_pix * 2; \
 
 /* call this before drawing the next vertex */
 #define vert_opt_loop1(v, force, skip_stmt) \
 		this_x = v->point[0]; \
 		this_y = v->point[1]; \
-		if ((!force) && (PCB_ABS(this_x - last_x) < mindist) && (PCB_ABS(this_y - last_y) < mindist)) { \
+		if ((!force) && (RND_ABS(this_x - last_x) < mindist) && (RND_ABS(this_y - last_y) < mindist)) { \
 			next_x = v->next->point[0]; \
 			next_y = v->next->point[1]; \
-			if ((PCB_ABS(this_x - next_x) < mindist) && (PCB_ABS(this_y - next_y) < mindist)) \
+			if ((RND_ABS(this_x - next_x) < mindist) && (RND_ABS(this_y - next_y) < mindist)) \
 				{ skip_stmt; } \
 		} \
 
@@ -69,10 +69,10 @@ static size_t fc_alloced = 0;
 	}
 
 
-static void fill_contour(pcb_hid_gc_t gc, pcb_pline_t * pl)
+static void fill_contour(rnd_hid_gc_t gc, rnd_pline_t * pl)
 {
 	size_t n, i = 0;
-	pcb_vnode_t *v;
+	rnd_vnode_t *v;
 	int first = 1;
 
 	n = pl->Count;
@@ -80,15 +80,15 @@ static void fill_contour(pcb_hid_gc_t gc, pcb_pline_t * pl)
 	if (n > fc_alloced) {
 		free(fc_x);
 		free(fc_y);
-		fc_x = (pcb_coord_t *) malloc(n * sizeof(pcb_coord_t));
-		fc_y = (pcb_coord_t *) malloc(n * sizeof(pcb_coord_t));
+		fc_x = (rnd_coord_t *) malloc(n * sizeof(rnd_coord_t));
+		fc_y = (rnd_coord_t *) malloc(n * sizeof(rnd_coord_t));
 		fc_alloced = n;
 	}
 
 	vert_opt_begin();
 	do {
 		vert_opt_loop1(v, first, continue);
-		if (pcb_render->gui)
+		if (rnd_render->gui)
 			first = 0; /* if gui, turn on optimization and start to omit vertices */
 		fc_x[i] = this_x;
 		fc_y[i++] = this_y;
@@ -97,28 +97,28 @@ static void fill_contour(pcb_hid_gc_t gc, pcb_pline_t * pl)
 	while ((v = v->next) != pl->head->next);
 
 	if (i < 3) {
-		pcb_hid_set_line_width(gc, PCB_MM_TO_COORD(0.01));
-		pcb_hid_set_line_cap(gc, pcb_cap_round);
-		pcb_render->draw_line(gc, last_x, last_y, this_x, this_y);
+		rnd_hid_set_line_width(gc, RND_MM_TO_COORD(0.01));
+		rnd_hid_set_line_cap(gc, rnd_cap_round);
+		rnd_render->draw_line(gc, last_x, last_y, this_x, this_y);
 	}
 	else
-		pcb_render->fill_polygon(gc, i, fc_x, fc_y);
+		rnd_render->fill_polygon(gc, i, fc_x, fc_y);
 
 	vert_opt_end();
 }
 
 
-static void thindraw_contour(pcb_hid_gc_t gc, pcb_pline_t * pl)
+static void thindraw_contour(rnd_hid_gc_t gc, rnd_pline_t * pl)
 {
-	pcb_vnode_t *v;
+	rnd_vnode_t *v;
 
 
-	pcb_hid_set_line_width(gc, 0);
-	pcb_hid_set_line_cap(gc, pcb_cap_round);
+	rnd_hid_set_line_width(gc, 0);
+	rnd_hid_set_line_cap(gc, rnd_cap_round);
 
 	/* If the contour is round, use an arc drawing routine. */
 	if (pl->is_round) {
-		pcb_render->draw_arc(gc, pl->cx, pl->cy, pl->radius, pl->radius, 0, 360);
+		rnd_render->draw_arc(gc, pl->cx, pl->cy, pl->radius, pl->radius, 0, 360);
 		return;
 	}
 
@@ -129,29 +129,29 @@ static void thindraw_contour(pcb_hid_gc_t gc, pcb_pline_t * pl)
 	vert_opt_begin();
 	do {
 		vert_opt_loop1(v, 0, continue);
-		pcb_render->draw_line(gc, last_x, last_y, this_x, this_y);
+		rnd_render->draw_line(gc, last_x, last_y, this_x, this_y);
 		vert_opt_loop2();
 	}
 	while ((v = v->next) != pl->head->next);
 	vert_opt_end();
 }
 
-static void fill_contour_cb(pcb_pline_t * pl, void *user_data)
+static void fill_contour_cb(rnd_pline_t * pl, void *user_data)
 {
-	pcb_hid_gc_t gc = (pcb_hid_gc_t) user_data;
-	pcb_pline_t *local_pl = pl;
+	rnd_hid_gc_t gc = (rnd_hid_gc_t) user_data;
+	rnd_pline_t *local_pl = pl;
 
 	fill_contour(gc, pl);
-	pcb_poly_contours_free(&local_pl);
+	rnd_poly_contours_free(&local_pl);
 }
 
-static void fill_clipped_contour(pcb_hid_gc_t gc, pcb_pline_t * pl, const pcb_box_t * clip_box)
+static void fill_clipped_contour(rnd_hid_gc_t gc, rnd_pline_t * pl, const rnd_box_t * clip_box)
 {
-	pcb_pline_t *pl_copy;
-	pcb_polyarea_t *clip_poly;
-	pcb_polyarea_t *piece_poly;
-	pcb_polyarea_t *clipped_pieces;
-	pcb_polyarea_t *draw_piece;
+	rnd_pline_t *pl_copy;
+	rnd_polyarea_t *clip_poly;
+	rnd_polyarea_t *piece_poly;
+	rnd_polyarea_t *clipped_pieces;
+	rnd_polyarea_t *draw_piece;
 	int x;
 
 	/* Optimization: the polygon has no holes; if it is smaller the clip_box,
@@ -161,12 +161,12 @@ static void fill_clipped_contour(pcb_hid_gc_t gc, pcb_pline_t * pl, const pcb_bo
 		return;
 	}
 
-	clip_poly = pcb_poly_from_rect(clip_box->X1, clip_box->X2, clip_box->Y1, clip_box->Y2);
-	pcb_poly_contour_copy(&pl_copy, pl);
-	piece_poly = pcb_polyarea_create();
-	pcb_polyarea_contour_include(piece_poly, pl_copy);
-	x = pcb_polyarea_boolean_free(piece_poly, clip_poly, &clipped_pieces, PCB_PBO_ISECT);
-	if (x != pcb_err_ok || clipped_pieces == NULL)
+	clip_poly = rnd_poly_from_rect(clip_box->X1, clip_box->X2, clip_box->Y1, clip_box->Y2);
+	rnd_poly_contour_copy(&pl_copy, pl);
+	piece_poly = rnd_polyarea_create();
+	rnd_polyarea_contour_include(piece_poly, pl_copy);
+	x = rnd_polyarea_boolean_free(piece_poly, clip_poly, &clipped_pieces, RND_PBO_ISECT);
+	if (x != rnd_err_ok || clipped_pieces == NULL)
 		return;
 
 	draw_piece = clipped_pieces;
@@ -175,16 +175,16 @@ static void fill_clipped_contour(pcb_hid_gc_t gc, pcb_pline_t * pl, const pcb_bo
 		fill_contour(gc, draw_piece->contours);
 	}
 	while ((draw_piece = draw_piece->f) != clipped_pieces);
-	pcb_polyarea_free(&clipped_pieces);
+	rnd_polyarea_free(&clipped_pieces);
 }
 
 /* If at least 50% of the bounding box of the polygon is on the screen,
  * lets compute the complete no-holes polygon.
  */
 #define BOUNDS_INSIDE_CLIP_THRESHOLD 0.5
-static int should_compute_no_holes(pcb_poly_t * poly, const pcb_box_t * clip_box)
+static int should_compute_no_holes(pcb_poly_t * poly, const rnd_box_t * clip_box)
 {
-	pcb_coord_t x1, x2, y1, y2;
+	rnd_coord_t x1, x2, y1, y2;
 	double poly_bounding_area;
 	double clipped_poly_area;
 
@@ -214,7 +214,7 @@ static int should_compute_no_holes(pcb_poly_t * poly, const pcb_box_t * clip_box
 
 #undef BOUNDS_INSIDE_CLIP_THRESHOLD
 
-static void pcb_dhlp_fill_pcb_polygon(pcb_hid_gc_t gc, pcb_poly_t * poly, const pcb_box_t * clip_box)
+static void pcb_dhlp_fill_pcb_polygon(rnd_hid_gc_t gc, pcb_poly_t * poly, const rnd_box_t * clip_box)
 {
 	if (!poly->NoHolesValid) {
 		/* If enough of the polygon is on-screen, compute the entire
@@ -227,7 +227,7 @@ static void pcb_dhlp_fill_pcb_polygon(pcb_hid_gc_t gc, pcb_poly_t * poly, const
 			pcb_poly_no_holes_dicer(poly, clip_box, fill_contour_cb, gc);
 	}
 	if (poly->NoHolesValid && poly->NoHoles) {
-		pcb_pline_t *pl;
+		rnd_pline_t *pl;
 
 		for (pl = poly->NoHoles; pl != NULL; pl = pl->next) {
 			if (clip_box == NULL)
@@ -247,14 +247,14 @@ static void pcb_dhlp_fill_pcb_polygon(pcb_hid_gc_t gc, pcb_poly_t * poly, const
 	}
 }
 
-static int thindraw_hole_cb(pcb_pline_t * pl, void *user_data)
+static int thindraw_hole_cb(rnd_pline_t * pl, void *user_data)
 {
-	pcb_hid_gc_t gc = (pcb_hid_gc_t) user_data;
+	rnd_hid_gc_t gc = (rnd_hid_gc_t) user_data;
 	thindraw_contour(gc, pl);
 	return 0;
 }
 
-static void pcb_dhlp_thindraw_pcb_polygon(pcb_hid_gc_t gc, pcb_poly_t * poly, const pcb_box_t * clip_box)
+static void pcb_dhlp_thindraw_pcb_polygon(rnd_hid_gc_t gc, pcb_poly_t * poly, const rnd_box_t * clip_box)
 {
 	thindraw_contour(gc, poly->Clipped->contours);
 	pcb_poly_holes(poly, clip_box, thindraw_hole_cb, gc);
