@@ -107,7 +107,7 @@ void pcb_pstk_free(pcb_pstk_t *ps)
 {
 	if ((ps->parent.data != NULL) && (ps->parent.data->padstack_tree != NULL))
 		rnd_r_delete_entry(ps->parent.data->padstack_tree, (rnd_box_t *)ps);
-	rnd_attribute_free(&ps->Attributes);
+	pcb_attribute_free(&ps->Attributes);
 	pcb_pstk_unreg(ps);
 	free(ps->thermals.shape);
 	pcb_obj_common_free((pcb_any_obj_t *)ps);
@@ -269,7 +269,7 @@ pcb_pstk_t *pcb_pstk_copy_meta(pcb_pstk_t *dst, pcb_pstk_t *src)
 {
 	if (dst == NULL)
 		return NULL;
-	rnd_attribute_copy_all(&dst->Attributes, &src->Attributes);
+	pcb_attribute_copy_all(&dst->Attributes, &src->Attributes);
 	dst->thermals.used = src->thermals.used;
 	if (dst->thermals.used > 0) {
 		dst->thermals.shape = malloc(dst->thermals.used * sizeof(dst->thermals.shape[0]));
@@ -365,7 +365,7 @@ static void set_ps_color(pcb_pstk_t *ps, int is_current, pcb_layer_type_t lyt, c
 			else
 				color = &conf_core.appearance.color.connected;
 
-			if (PCB_FLAG_TEST(PCB_FLAG_ONPOINT, ps)) {
+			if (ps->ind_onpoint) {
 				pcb_lighten_color(color, &buf, 1.75);
 				color = &buf;
 			}
@@ -391,7 +391,7 @@ static void set_ps_color(pcb_pstk_t *ps, int is_current, pcb_layer_type_t lyt, c
 			else
 				color = &conf_core.appearance.color.connected;
 
-			if (PCB_FLAG_TEST(PCB_FLAG_ONPOINT, ps)) {
+			if (ps->ind_onpoint) {
 				pcb_lighten_color(color, &buf, 1.75);
 				color = &buf;
 			}
@@ -573,6 +573,10 @@ rnd_r_dir_t pcb_pstk_draw_callback(const rnd_box_t *b, void *cl)
 		}
 		else
 			pcb_pstk_draw_shape_solid(info, pcb_draw_out.fgGC, ps, shape);
+		ps->draw_stamp = info->draw_stamp;
+
+		if (ps->ind_editpoint)
+			pcb_draw_delay_label_add((pcb_any_obj_t *)ps);
 	}
 
 	return RND_R_DIR_FOUND_CONTINUE;
@@ -613,11 +617,18 @@ rnd_r_dir_t pcb_pstk_draw_label_callback(const rnd_box_t *b, void *cl)
 {
 	pcb_draw_info_t *info = cl;
 	pcb_pstk_t *ps = (pcb_pstk_t *)b;
+	int is_drawn = (ps->draw_stamp == info->draw_stamp);
+
+	/* do not draw any label if the padstack is not visible, to avoid overlapping
+	   term labels of sides: two SMD pads on the two sides, turn off bottom to
+	   see top only */
+	if (!is_drawn)
+		return RND_R_DIR_FOUND_CONTINUE;
 
 	/* draw the label if enabled, after everything else is drawn */
 	if (ps->term != NULL) {
 		if ((pcb_draw_force_termlab) || PCB_FLAG_TEST(PCB_FLAG_TERMNAME, ps))
-			pcb_pstk_draw_label(info, ps);
+			pcb_pstk_draw_label(info, ps, 1);
 	}
 
 	if (ps->noexport)
@@ -759,7 +770,7 @@ void pcb_pstk_thindraw(pcb_draw_info_t *info, rnd_hid_gc_t gc, pcb_pstk_t *ps)
 		pcb_pstk_draw_shape_thin(info, gc, ps, shape);
 }
 
-void pcb_pstk_draw_label(pcb_draw_info_t *info, pcb_pstk_t *ps)
+void pcb_pstk_draw_label(pcb_draw_info_t *info, pcb_pstk_t *ps, rnd_bool vis_side)
 {
 	rnd_bool vert;
 	rnd_coord_t dx, dy;
@@ -1070,27 +1081,6 @@ int pcb_is_point_in_pstk(rnd_coord_t x, rnd_coord_t y, rnd_coord_t radius, pcb_p
 	return pcb_is_point_in_pstk_(ps, x, y, radius, shp);
 }
 
-int pcb_pstk_drc_check_clearance(pcb_pstk_t *ps, pcb_poly_t *polygon, rnd_coord_t min_clr)
-{
-	int n;
-	pcb_pstk_tshape_t *ts;
-
-	/* global clearance */
-	if (ps->Clearance > 0)
-		return pcb_obj_clearance(ps, polygon) < 2 * conf_core.design.bloat;
-
-	/* else check each shape; it's safest to run this check on the canonical
-	   transformed shape, that's always available */
-	ts = pcb_pstk_get_tshape_(ps->parent.data, ps->proto, 0);
-	for(n = 0; n < ts->len; n++) {
-		rnd_coord_t clr = RND_MAX(ts->shape[n].clearance, polygon->enforce_clearance);
-		if ((clr > 0) && (clr < 2 * conf_core.design.bloat))
-			return 1;
-	}
-
-	return 0;
-}
-
 /* Check the minimum distance between a hole's edge and a shape's edge and
    indicate error if it's smaller than min */
 static rnd_bool pcb_pstk_shape_hole_break(pcb_pstk_shape_t *shp, rnd_coord_t hdia, rnd_coord_t min)
