@@ -46,6 +46,7 @@ struct pcb_pstk_s {
 		unsigned long used;
 		unsigned char *shape;        /* indexed by layer ID */
 	} thermals;
+	int draw_stamp;                /* temp: remembers the stamp of the last draw */
 	gdl_elem_t link;               /* a padstack is in a list in pcb_data_t as a global object */
 };
 #endif
@@ -63,7 +64,7 @@ struct pcb_pstk_s {
 #include "obj_pstk_shape.h"
 #include "vtpadstack_t.h"
 
-typedef struct pcb_pstk_proto_s {
+struct pcb_pstk_proto_s {
 	unsigned in_use:1;             /* 1 if the slot is in use */
 
 	unsigned hplated:1;            /* if > 0, whether the hole is plated */
@@ -77,7 +78,8 @@ typedef struct pcb_pstk_proto_s {
 	unsigned long hash;            /* optimization: linear search compare speeded up: go into detailed match only if hash matches */
 	pcb_data_t *parent;
 	int mech_idx;                  /* -1 or index to the first shape[] that is of PCB_LYT_MECH */
-} pcb_pstk_proto_t;
+	unsigned all_copper_connd:1;   /* 1 if all copper shapes are connected by the hole/slot (regardless of plating!) */
+};
 
 /* Whether a proto cuts through board layers (has a hole or slot) */
 #define PCB_PSTK_PROTO_CUTS(proto) (((proto)->hdia > 0) || ((proto)->mech_idx >= 0))
@@ -160,9 +162,6 @@ void pcb_pstk_shape_free_poly(pcb_pstk_poly_t *poly);
 int pcb_pstk_near_box(pcb_pstk_t *ps, rnd_box_t *box, pcb_layer_t *layer);
 int pcb_is_point_in_pstk(rnd_coord_t x, rnd_coord_t y, rnd_coord_t radius, pcb_pstk_t *ps, pcb_layer_t *layer);
 
-/* Check if padstack has the proper clearance against polygon; returns 0 if everything's fine */
-int pcb_pstk_drc_check_clearance(pcb_pstk_t *ps, pcb_poly_t *polygon, rnd_coord_t min_clr);
-
 /* Check all possible local drc errors regarding to pad stacks - errors that
    depend only on the padstack, not on other objects. load err_minring and
    err_minhole with the relevant data for the report when ring or hole rules
