@@ -43,7 +43,7 @@ rnd_r_dir_t pcb_pstk_clear_callback(const rnd_box_t *b, void *cl);
 
 rnd_r_dir_t pcb_pstk_draw_mark_callback(const rnd_box_t *b, void *cl);
 rnd_r_dir_t pcb_pstk_draw_label_callback(const rnd_box_t *b, void *cl);
-void pcb_pstk_draw_label(pcb_draw_info_t *info, pcb_pstk_t *ps);
+void pcb_pstk_draw_label(pcb_draw_info_t *info, pcb_pstk_t *ps, rnd_bool vis_side);
 void pcb_pstk_invalidate_erase(pcb_pstk_t *ps);
 void pcb_pstk_invalidate_draw(pcb_pstk_t *ps);
 
