@@ -65,19 +65,50 @@ void pcb_pstk_proto_free_fields(pcb_pstk_proto_t *dst)
 
 void pcb_pstk_proto_update(pcb_pstk_proto_t *dst)
 {
+	static pcb_pstk_t dummy_ps = {0};
 	pcb_pstk_tshape_t *ts = &dst->tr.array[0];
-	unsigned int n;
+	unsigned int n, coppers = 0;
 
 	dst->hash = pcb_pstk_proto_hash(dst);
 	dst->mech_idx = -1;
 
 	if (ts != NULL) {
+		pcb_pstk_shape_t *hole, holetmp;
+
+		/* find and cache the index of the mech shape (slot) */
 		for(n = 0; n < ts->len; n++) {
 			if (ts->shape[n].layer_mask & PCB_LYT_MECH) {
 				dst->mech_idx = n;
 				break;
 			}
 		}
+
+/*rnd_trace("pstk_upd:\n");*/
+
+		/* mark each shape with whether it overlaps with the hole/mech shape or not */
+		hole = pcb_pstk_shape_mech_or_hole_(NULL, dst, &holetmp);
+		dst->all_copper_connd = (hole != NULL);
+		for(n = 0; n < ts->len; n++) {
+			if ((ts->shape[n].layer_mask & PCB_LYT_COPPER) && !(ts->shape[n].layer_mask & PCB_LYT_INTERN))
+				coppers++;
+			if (hole == &ts->shape[n])
+				ts->shape[n].hconn = 1;
+			else if (hole != NULL) {
+				ts->shape[n].hconn = pcb_pstk_shape_intersect(&dummy_ps, &ts->shape[n], &dummy_ps, hole);
+				if ((ts->shape[n].layer_mask & PCB_LYT_COPPER) && !ts->shape[n].hconn)
+					dst->all_copper_connd = 0;
+			}
+			else
+				ts->shape[n].hconn = 0;
+/*rnd_trace(" [%d]: %d\n", n, ts->shape[n].hconn);*/
+		}
+		
+		/* special case: if there's only one non-intern copper shape and no hole/slot
+		   (which is the common "SMD pad" case), allow find.c to run the quick
+		   code by admitting all copper shapes are connected */
+		if ((hole == NULL) && (coppers == 1))
+			dst->all_copper_connd = 1;
+/*rnd_trace(" all: %d\n", dst->all_copper_connd);*/
 	}
 }
 
@@ -452,7 +483,7 @@ TODO("layer: make a real scoring mechanism here instead of ly1, ly2, ly3")
 				continue;
 		}
 		if (src->term != NULL)
-			rnd_attribute_put(&no->Attributes, "term", src->term);
+			pcb_attribute_put(&no->Attributes, "term", src->term);
 	}
 
 	if (remove_src) {
@@ -623,21 +654,29 @@ void pcb_pstk_tshape_xmirror(pcb_pstk_tshape_t *ts)
 	}
 }
 
+RND_INLINE void pcb_pstk_shape_smirror_(pcb_pstk_shape_t *sh)
+{
+	if (sh->layer_mask & PCB_LYT_TOP) {
+		sh->layer_mask &= ~PCB_LYT_TOP;
+		sh->layer_mask |= PCB_LYT_BOTTOM;
+	}
+	else if (sh->layer_mask & PCB_LYT_BOTTOM) {
+		sh->layer_mask &= ~PCB_LYT_BOTTOM;
+		sh->layer_mask |= PCB_LYT_TOP;
+	}
+}
+
+void pcb_pstk_shape_smirror(pcb_pstk_shape_t *sh)
+{
+	pcb_pstk_shape_smirror_(sh);
+}
+
 void pcb_pstk_tshape_smirror(pcb_pstk_tshape_t *ts)
 {
 	int n;
 
-	for(n = 0; n < ts->len; n++) {
-		pcb_pstk_shape_t *sh = &ts->shape[n];
-		if (sh->layer_mask & PCB_LYT_TOP) {
-			sh->layer_mask &= ~PCB_LYT_TOP;
-			sh->layer_mask |= PCB_LYT_BOTTOM;
-		}
-		else if (sh->layer_mask & PCB_LYT_BOTTOM) {
-			sh->layer_mask &= ~PCB_LYT_BOTTOM;
-			sh->layer_mask |= PCB_LYT_TOP;
-		}
-	}
+	for(n = 0; n < ts->len; n++)
+		pcb_pstk_shape_smirror_(&ts->shape[n]);
 }
 
 void pcb_pstk_proto_copy(pcb_pstk_proto_t *dst, const pcb_pstk_proto_t *src)
@@ -934,6 +973,9 @@ static int undo_change_hole_swap(void *udata)
 	swap(proto->hdia,    u->hdia,    rnd_coord_t);
 	swap(proto->htop,    u->htop,    int);
 	swap(proto->hbottom, u->hbottom, int);
+
+	pcb_pstk_proto_update(proto);
+
 	return 0;
 }
 
@@ -1121,6 +1163,8 @@ static void pcb_pstk_poly_center(const pcb_pstk_poly_t *poly, rnd_coord_t *cx, r
 	*cy = rnd_round(y);
 }
 
+
+
 void pcb_pstk_shape_grow_(pcb_pstk_shape_t *shp, rnd_bool is_absolute, rnd_coord_t val)
 {
 	rnd_coord_t cx, cy;
@@ -1149,9 +1193,29 @@ void pcb_pstk_shape_grow_(pcb_pstk_shape_t *shp, rnd_bool is_absolute, rnd_coord
 			pcb_pstk_poly_center(&shp->data.poly, &cx, &cy);
 			rnd_polyarea_free(&shp->data.poly.pa);
 			if (is_absolute) {
-TODO("TODO")
+				int n;
+				double maxs2 = 0;
+				/* determine the max edge center distance from the shape center; this
+				   is effectivel the "radius" of the shape measured on sides, not on corners */
+				for(n = 0; n < shp->data.poly.len; n++) {
+					double s2, x = shp->data.poly.x[n], y = shp->data.poly.y[n], xn = shp->data.poly.x[(n+1) % shp->data.poly.len], yn = shp->data.poly.y[(n+1) % shp->data.poly.len];
+					x = (x+xn)/2.0; y = (y+yn)/2.0;
+					s2 = rnd_distance2(cx, cy, x, y);
+					if (s2 > maxs2)
+						maxs2 = s2;
+					
+				}
+				if (maxs2 == 0)
+					break;
+
+				/* calculate the delta value: biggest side distance should match the expected val */
+				val = val - (sqrt(maxs2) * 2);
+
+				/* fall through to relative grow */
 			}
-			else {
+			
+			/* relative growth */
+			{
 				rnd_polo_t *p, p_st[32];
 				double vl = rnd_round(val/2);
 
@@ -1451,6 +1515,8 @@ void pcb_pstk_shape_derive(pcb_pstk_proto_t *proto, int dst_idx, int src_idx, rn
 		pcb_pstk_shape_copy(&proto->tr.array[n].shape[d], &proto->tr.array[n].shape[src_idx]);
 		proto->tr.array[n].shape[d].layer_mask = mask;
 		proto->tr.array[n].shape[d].comb = comb;
+		if (proto->tr.array[n].smirror)
+			pcb_pstk_shape_smirror_(&proto->tr.array[n].shape[d]);
 		if (bloat != 0)
 			pcb_pstk_shape_grow(proto, n, d, rnd_false, bloat, undoable);
 	}
