@@ -27,12 +27,16 @@
 #include "config.h"
 
 #include <genvector/vtp0.h>
+#include <genht/htip.h>
+#include <genht/hash.h>
+#include <genht/ht_utils.h>
 
 #include "buffer.h"
 #include "board.h"
 #include "crosshair.h"
 #include "brave.h"
 #include "data.h"
+#include "data_it.h"
 #include <librnd/core/error.h>
 #include "obj_subc.h"
 #include "obj_subc_op.h"
@@ -51,6 +55,7 @@
 #include "polygon.h"
 #include "operation.h"
 #include "undo.h"
+#include "move.h"
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/math_helper.h>
 #include "pcb_minuid.h"
@@ -90,7 +95,7 @@ static void pcb_box_bump_box_noflt(rnd_box_t *dst, rnd_box_t *src)
 /* update cached values: e.g. looking up refdes in attributes each time the
    netlist code needs it would be too expensive. Instead, we maintain a
    read-only ->refdes field and update it any time attributes change. */
-static void pcb_subc_attrib_post_change(rnd_attribute_list_t *list, const char *name, const char *value)
+static void pcb_subc_attrib_post_change(pcb_attribute_list_t *list, const char *name, const char *value)
 {
 	pcb_subc_t *sc = (pcb_subc_t *)(((char *)list) - offsetof(pcb_subc_t, Attributes));
 	if (strcmp(name, "refdes") == 0) {
@@ -136,7 +141,7 @@ void pcb_subc_free(pcb_subc_t *sc)
 	pcb_extobj_del_pre(sc);
 	if ((sc->parent.data != NULL) && (sc->parent.data->subc_tree != NULL))
 		rnd_r_delete_entry(sc->parent.data->subc_tree, (rnd_box_t *)sc);
-	rnd_attribute_free(&sc->Attributes);
+	pcb_attribute_free(&sc->Attributes);
 	if (sc->parent_type != PCB_PARENT_INVALID)
 		pcb_subc_unreg(sc);
 	pcb_data_free(sc->data);
@@ -185,7 +190,7 @@ pcb_layer_t *pcb_subc_layer_create(pcb_subc_t *sc, const char *name, pcb_layer_t
 static pcb_line_t *add_aux_line(pcb_layer_t *aux, const char *key, const char *val, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2)
 {
 	pcb_line_t *l = pcb_line_new(aux, x1, y1, x2, y2, RND_MM_TO_COORD(0.1), 0, pcb_no_flags());
-	rnd_attribute_put(&l->Attributes, key, val);
+	pcb_attribute_put(&l->Attributes, key, val);
 	return l;
 }
 
@@ -194,7 +199,7 @@ static pcb_line_t *find_aux_line(pcb_layer_t *aux, const char *key)
 	pcb_line_t *line;
 	gdl_iterator_t it;
 	linelist_foreach(&aux->Line, &it, line) {
-		const char *val = rnd_attribute_get(&line->Attributes, "subc-role");
+		const char *val = pcb_attribute_get(&line->Attributes, "subc-role");
 		if ((val != NULL) && (strcmp(val, key) == 0))
 			return line;
 	}
@@ -399,7 +404,7 @@ static pcb_poly_t *sqline2term(pcb_layer_t *dst, pcb_line_t *line)
 	for(n = 0; n < 4; n++)
 		pcb_poly_point_new(poly, x[n], y[n]);
 	PCB_FLAG_SET(PCB_FLAG_CLEARPOLYPOLY, poly);
-	rnd_attribute_copy_all(&poly->Attributes, &line->Attributes);
+	pcb_attribute_copy_all(&poly->Attributes, &line->Attributes);
 
 	pcb_poly_init_clip(dst->parent.data, dst, poly);
 	pcb_add_poly_on_layer(dst, poly);
@@ -453,7 +458,7 @@ void pcb_subc_as_board_update(pcb_board_t *pcb)
 
 static rnd_coord_t read_mask(pcb_any_obj_t *obj)
 {
-	const char *smask = rnd_attribute_get(&obj->Attributes, "elem_smash_pad_mask");
+	const char *smask = pcb_attribute_get(&obj->Attributes, "elem_smash_pad_mask");
 	rnd_coord_t mask = 0;
 
 	if (smask != NULL) {
@@ -557,7 +562,7 @@ int pcb_subc_convert_from_buffer(pcb_buffer_t *buffer)
 			char *np, *sq, *termpad;
 			const char *term;
 
-			termpad = rnd_attribute_get(&line->Attributes, "elem_smash_pad");
+			termpad = pcb_attribute_get(&line->Attributes, "elem_smash_pad");
 			if (termpad != NULL) {
 				if (ltype & PCB_LYT_TOP)
 					top_pads++;
@@ -565,9 +570,9 @@ int pcb_subc_convert_from_buffer(pcb_buffer_t *buffer)
 					bottom_pads++;
 				mask = read_mask((pcb_any_obj_t *)line);
 			}
-			term = rnd_attribute_get(&line->Attributes, "term");
-			np = rnd_attribute_get(&line->Attributes, "elem_smash_nopaste");
-			sq = rnd_attribute_get(&line->Attributes, "elem_smash_shape_square");
+			term = pcb_attribute_get(&line->Attributes, "term");
+			np = pcb_attribute_get(&line->Attributes, "elem_smash_nopaste");
+			sq = pcb_attribute_get(&line->Attributes, "elem_smash_shape_square");
 			if ((sq != NULL) && (*sq == '1')) { /* convert to polygon */
 				poly = sqline2term(dst, line);
 				if (termpad != NULL) {
@@ -579,7 +584,7 @@ int pcb_subc_convert_from_buffer(pcb_buffer_t *buffer)
 						line->Thickness = mask;
 						poly = sqline2term(dst, line);
 						if (term != NULL)
-							rnd_attribute_put(&poly->Attributes, "term", term);
+							pcb_attribute_put(&poly->Attributes, "term", term);
 						vtp0_append(&mask_pads, poly);
 					}
 				}
@@ -600,7 +605,7 @@ int pcb_subc_convert_from_buffer(pcb_buffer_t *buffer)
 						nl = pcb_line_dup(dst, line);
 						nl->Thickness = mask;
 						if (term != NULL)
-							rnd_attribute_put(&nl->Attributes, "term", term);
+							pcb_attribute_put(&nl->Attributes, "term", term);
 						vtp0_append(&mask_pads, nl);
 					}
 				}
@@ -676,7 +681,7 @@ int pcb_subc_convert_from_buffer(pcb_buffer_t *buffer)
 	/* Add refdes */
 	if ((conf_core.editor.subc_conv_refdes != NULL) && (*conf_core.editor.subc_conv_refdes != '\0')) {
 		if (strcmp(conf_core.editor.subc_conv_refdes, "<?>") != 0)
-			rnd_attribute_put(&sc->Attributes, "refdes", conf_core.editor.subc_conv_refdes);
+			pcb_attribute_put(&sc->Attributes, "refdes", conf_core.editor.subc_conv_refdes);
 		if (!has_refdes_text) {
 			if (dst_top_silk == NULL)
 				dst_top_silk = pcb_layer_new_bound(sc->data, PCB_LYT_TOP | PCB_LYT_SILK, "top-silk", NULL);
@@ -815,10 +820,10 @@ TODO(": The wireframe arc drawing code cannot draw ellipses yet so draw the elli
 				t.BoundingBox.X2 = PCB_CSWAP_X(text->BoundingBox.X2, w, mirr);
 				t.BoundingBox.Y2 = PCB_CSWAP_Y(text->BoundingBox.Y2, h, mirr);
 				PCB_FLAG_TOGGLE(PCB_FLAG_ONSOLDER, &t);
-				pcb_text_draw_xor(&t, DX, DY);
+				pcb_text_draw_xor(&t, DX, DY, 1);
 			}
 			else
-				pcb_text_draw_xor(text, DX, DY);
+				pcb_text_draw_xor(text, DX, DY, 1);
 		}
 	}
 
@@ -853,6 +858,25 @@ TODO(": The wireframe arc drawing code cannot draw ellipses yet so draw the elli
 	pcb_subc_draw_origin(pcb_crosshair.GC, sc, DX, DY);
 }
 
+pcb_layer_t *pcb_subc_alloc_layer_like(pcb_subc_t *subc, const pcb_layer_t *sl)
+{
+	pcb_layer_t *dl;
+
+	if (subc->data->LayerN >= PCB_MAX_LAYER)
+		return NULL;
+
+	dl = &subc->data->Layer[subc->data->LayerN++];
+	dl->is_bound = 1;
+	dl->type = PCB_OBJ_LAYER;
+	memcpy(&dl->meta.bound, &sl->meta.bound, sizeof(sl->meta.bound));
+	dl->name = rnd_strdup(sl->name);
+	dl->comb = sl->comb;
+	if (dl->meta.bound.real != NULL)
+		pcb_layer_link_trees(dl, dl->meta.bound.real);
+
+	return dl;
+}
+
 #define MAYBE_KEEP_ID(dst, src) \
 do { \
 	if ((keep_ids) && (dst != NULL)) \
@@ -863,10 +887,88 @@ pcb_subc_t *pcb_subc_copy_meta(pcb_subc_t *dst, const pcb_subc_t *src)
 {
 	if (dst == NULL)
 		return NULL;
-	rnd_attribute_copy_all(&dst->Attributes, &src->Attributes);
+	pcb_attribute_copy_all(&dst->Attributes, &src->Attributes);
 	return dst;
 }
 
+void pcb_subc_dup_layer_objs(pcb_subc_t *dst_sc, pcb_layer_t *dl, pcb_layer_t *sl, rnd_coord_t dx, rnd_coord_t dy, rnd_bool keep_ids)
+{
+	pcb_line_t *line, *nline;
+	pcb_text_t *text, *ntext;
+	pcb_arc_t *arc, *narc;
+	pcb_gfx_t *gfx, *ngfx;
+	gdl_iterator_t it;
+	pcb_board_t *pcb = NULL;
+
+	assert(dst_sc->parent_type == PCB_PARENT_DATA);
+	if (dst_sc->parent.data->parent_type != PCB_PARENT_INVALID) {
+		assert(dst_sc->parent.data->parent_type == PCB_PARENT_BOARD);
+		pcb = dst_sc->parent.data->parent.board;
+	}
+
+	if (pcb != NULL)
+		pcb_data_clip_inhibit_inc(pcb->Data);
+
+	linelist_foreach(&sl->Line, &it, line) {
+		nline = pcb_line_dup_at(dl, line, dx, dy);
+		MAYBE_KEEP_ID(nline, line);
+		if (nline != NULL) {
+			PCB_SET_PARENT(nline, layer, dl);
+			if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, nline)) {
+				pcb_box_bump_box_noflt(&dst_sc->BoundingBox, &nline->BoundingBox);
+				pcb_box_bump_box_noflt(&dst_sc->bbox_naked, &nline->bbox_naked);
+			}
+			if (pcb != NULL)
+				pcb_poly_clear_from_poly(pcb->Data, PCB_OBJ_LINE, dl, nline);
+		}
+	}
+
+	arclist_foreach(&sl->Arc, &it, arc) {
+		narc = pcb_arc_dup_at(dl, arc, dx, dy);
+		MAYBE_KEEP_ID(narc, arc);
+		if (narc != NULL) {
+			PCB_SET_PARENT(narc, layer, dl);
+			if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, narc)) {
+				pcb_box_bump_box_noflt(&dst_sc->BoundingBox, &narc->BoundingBox);
+				pcb_box_bump_box_noflt(&dst_sc->bbox_naked, &narc->bbox_naked);
+			}
+			if (pcb != NULL)
+				pcb_poly_clear_from_poly(pcb->Data, PCB_OBJ_ARC, dl, narc);
+		}
+	}
+
+	gfxlist_foreach(&sl->Gfx, &it, gfx) {
+		ngfx = pcb_gfx_dup_at(dl, gfx, dx, dy);
+		MAYBE_KEEP_ID(ngfx, gfx);
+		if (ngfx != NULL) {
+			PCB_SET_PARENT(ngfx, layer, dl);
+			if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, ngfx)) {
+				pcb_box_bump_box_noflt(&dst_sc->BoundingBox, &ngfx->BoundingBox);
+				pcb_box_bump_box_noflt(&dst_sc->bbox_naked, &ngfx->bbox_naked);
+			}
+			if (pcb != NULL)
+				pcb_poly_clear_from_poly(pcb->Data, PCB_OBJ_GFX, dl, ngfx);
+		}
+	}
+
+	textlist_foreach(&sl->Text, &it, text) {
+		ntext = pcb_text_dup_at(dl, text, dx, dy);
+		MAYBE_KEEP_ID(ntext, text);
+		if (ntext != NULL) {
+			PCB_SET_PARENT(ntext, layer, dl);
+			if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, ntext)) {
+				pcb_box_bump_box_noflt(&dst_sc->BoundingBox, &ntext->BoundingBox);
+				pcb_box_bump_box_noflt(&dst_sc->bbox_naked, &ntext->bbox_naked);
+			}
+			if (pcb != NULL)
+				pcb_poly_clear_from_poly(pcb->Data, PCB_OBJ_TEXT, dl, ntext);
+		}
+	}
+
+
+	if (pcb != NULL)
+		pcb_data_clip_inhibit_dec(pcb->Data, 0);
+}
 
 pcb_subc_t *pcb_subc_dup_at(pcb_board_t *pcb, pcb_data_t *dst, const pcb_subc_t *src, rnd_coord_t dx, rnd_coord_t dy, rnd_bool keep_ids, rnd_bool undoable)
 {
@@ -898,11 +1000,6 @@ pcb_subc_t *pcb_subc_dup_at(pcb_board_t *pcb, pcb_data_t *dst, const pcb_subc_t
 	for(n = 0; n < src->data->LayerN; n++) {
 		pcb_layer_t *sl = src->data->Layer + n;
 		pcb_layer_t *dl = sc->data->Layer + n;
-		pcb_line_t *line, *nline;
-		pcb_text_t *text, *ntext;
-		pcb_arc_t *arc, *narc;
-		pcb_gfx_t *gfx, *ngfx;
-		gdl_iterator_t it;
 
 		/* bind layer/resolve layers */
 		dl->is_bound = 1;
@@ -941,55 +1038,7 @@ pcb_subc_t *pcb_subc_dup_at(pcb_board_t *pcb, pcb_data_t *dst, const pcb_subc_t
 			dl->comb = sl->comb;
 		}
 
-
-		linelist_foreach(&sl->Line, &it, line) {
-			nline = pcb_line_dup_at(dl, line, dx, dy);
-			MAYBE_KEEP_ID(nline, line);
-			if (nline != NULL) {
-				PCB_SET_PARENT(nline, layer, dl);
-				if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, nline)) {
-					pcb_box_bump_box_noflt(&sc->BoundingBox, &nline->BoundingBox);
-					pcb_box_bump_box_noflt(&sc->bbox_naked, &nline->bbox_naked);
-				}
-			}
-		}
-
-		arclist_foreach(&sl->Arc, &it, arc) {
-			narc = pcb_arc_dup_at(dl, arc, dx, dy);
-			MAYBE_KEEP_ID(narc, arc);
-			if (narc != NULL) {
-				PCB_SET_PARENT(narc, layer, dl);
-				if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, narc)) {
-					pcb_box_bump_box_noflt(&sc->BoundingBox, &narc->BoundingBox);
-					pcb_box_bump_box_noflt(&sc->bbox_naked, &narc->bbox_naked);
-				}
-			}
-		}
-
-		gfxlist_foreach(&sl->Gfx, &it, gfx) {
-			ngfx = pcb_gfx_dup_at(dl, gfx, dx, dy);
-			MAYBE_KEEP_ID(ngfx, gfx);
-			if (ngfx != NULL) {
-				PCB_SET_PARENT(ngfx, layer, dl);
-				if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, ngfx)) {
-					pcb_box_bump_box_noflt(&sc->BoundingBox, &ngfx->BoundingBox);
-					pcb_box_bump_box_noflt(&sc->bbox_naked, &ngfx->bbox_naked);
-				}
-			}
-		}
-
-		textlist_foreach(&sl->Text, &it, text) {
-			ntext = pcb_text_dup_at(dl, text, dx, dy);
-			MAYBE_KEEP_ID(ntext, text);
-			if (ntext != NULL) {
-				PCB_SET_PARENT(ntext, layer, dl);
-				if (!PCB_FLAG_TEST(PCB_FLAG_FLOATER, ntext)) {
-					pcb_box_bump_box_noflt(&sc->BoundingBox, &ntext->BoundingBox);
-					pcb_box_bump_box_noflt(&sc->bbox_naked, &ntext->bbox_naked);
-				}
-			}
-		}
-
+		pcb_subc_dup_layer_objs(sc, dl, sl, dx, dy, keep_ids);
 	}
 	sc->data->LayerN = src->data->LayerN;
 
@@ -1185,8 +1234,22 @@ void *pcb_subc_op(pcb_data_t *Data, pcb_subc_t *sc, pcb_opfunc_t *opfunc, pcb_op
 
 	rnd_close_box(&sc->BoundingBox);
 	rnd_close_box(&sc->bbox_naked);
-	if (pcb_data_get_top(Data) != NULL)
-		rnd_r_insert_entry(Data->subc_tree, (rnd_box_t *)sc);
+	if (pcb_data_get_top(Data) != NULL) {
+		int doit = 1;
+		if (sc->extobj != NULL) { /* ugly corner case: extobj calls may have added the subc to the rtree already, do not add it twice */
+			rnd_rtree_it_t it;
+			rnd_box_t *b;
+
+			for(b = rnd_r_first(Data->subc_tree, &it); b != NULL; b = rnd_r_next(&it)) {
+				if (b == (rnd_box_t *)sc) {
+					doit = 0;
+					break;
+				}
+			}
+		}
+		if (doit)
+			rnd_r_insert_entry(Data->subc_tree, (rnd_box_t *)sc);
+	}
 
 	sc->part_changed_bbox_dirty = 0; /* we've just recalculated the bbox */
 	pcb_subc_part_changed_inhibit_dec(sc);
@@ -1796,10 +1859,12 @@ void *pcb_subcop_change_2nd_size(pcb_opctx_t *ctx, pcb_subc_t *sc)
 
 void *pcb_subcop_change_nonetlist(pcb_opctx_t *ctx, pcb_subc_t *sc)
 {
-TODO("subc: add undo")
+	pcb_undo_add_obj_to_flag(sc);
+
 	if (PCB_FLAG_TEST(PCB_FLAG_LOCK, sc))
 		return NULL;
 	PCB_FLAG_TOGGLE(PCB_FLAG_NONETLIST, sc);
+
 	return sc;
 }
 
@@ -1807,10 +1872,10 @@ void *pcb_subcop_change_name(pcb_opctx_t *ctx, pcb_subc_t *sc)
 {
 	void *old;
 	if (sc->refdes != NULL)
-		old = rnd_strdup(sc->refdes); /* strdup because the rnd_attribute_put() is going to free the original */
+		old = rnd_strdup(sc->refdes); /* strdup because the pcb_attribute_put() is going to free the original */
 	else
 		old = NULL;
-	rnd_attribute_put(&sc->Attributes, "refdes", ctx->chgname.new_name);
+	pcb_attribute_put(&sc->Attributes, "refdes", ctx->chgname.new_name);
 	return old;
 }
 
@@ -1858,8 +1923,10 @@ TODO("subc: subc-in-subc: can a whole subc be a floater? - add undo!")
 	}
 
 	pcb_subc_op(ctx->chgflag.pcb->Data, sc, &ChgFlagFunctions, ctx, PCB_SUBCOP_UNDO_NORMAL);
-	if ((ctx->chgflag.flag & pcb_subc_flags) == ctx->chgflag.flag)
+	if ((ctx->chgflag.flag & pcb_subc_flags) == ctx->chgflag.flag) {
+		pcb_undo_add_obj_to_flag(sc);
 		PCB_FLAG_CHANGE(ctx->chgflag.how, ctx->chgflag.flag, sc);
+	}
 	return sc;
 }
 
@@ -2114,7 +2181,7 @@ rnd_r_dir_t draw_subc_label_callback(const rnd_box_t *b, void *cl)
 					next++;
 					ctrl = 1;
 				}
-				pcb_label_draw(info, x, y, conf_core.appearance.term_label_size/2, 0, 0, curr);
+				pcb_label_draw(info, x, y, conf_core.appearance.term_label_size/2, 0, 0, curr, 0);
 				if (ctrl) {
 					switch(*next) {
 						case 'n': y += dy; x = x0; break;
@@ -2124,10 +2191,10 @@ rnd_r_dir_t draw_subc_label_callback(const rnd_box_t *b, void *cl)
 			}
 		}
 		else
-			pcb_label_draw(info, x0, y0, conf_core.appearance.term_label_size/2.0, 0, 0, "<err>");
+			pcb_label_draw(info, x0, y0, conf_core.appearance.term_label_size/2.0, 0, 0, "<err>", 0);
 	}
 	else if (subc->refdes != NULL)
-		pcb_label_draw(info, x0, y0, conf_core.appearance.term_label_size/2.0, 0, 0, subc->refdes);
+		pcb_label_draw(info, x0, y0, conf_core.appearance.term_label_size/2.0, 0, 0, subc->refdes, 0);
 
 	return RND_R_DIR_FOUND_CONTINUE;
 }
@@ -2188,7 +2255,7 @@ void pcb_subc_draw_preview(const pcb_subc_t *sc, const rnd_box_t *drawn_area)
 
 pcb_subc_t *pcb_subc_by_refdes(pcb_data_t *base, const char *name)
 {
-TODO("subc: hierarchy")
+TODO("subc: subc-in-subc hierarchy")
 	PCB_SUBC_LOOP(base);
 	{
 		if ((subc->refdes != NULL) && (RND_NSTRCMP(subc->refdes, name) == 0))
@@ -2207,7 +2274,7 @@ pcb_subc_t *pcb_subc_by_id(pcb_data_t *base, long int ID)
 	   the subc is being rotated.
 	
 	   The solution will be the ID hash. */
-TODO("subc: hierarchy")
+TODO("subc: subc-in-subc hierarchy")
 	PCB_SUBC_LOOP(base);
 	{
 		if (subc->ID == ID)
@@ -2310,17 +2377,269 @@ const char *pcb_subc_name(pcb_subc_t *subc, const char *local_name)
 	const char *val;
 
 	if (local_name != NULL) {
-		val = rnd_attribute_get(&subc->Attributes, local_name);
+		val = pcb_attribute_get(&subc->Attributes, local_name);
 		if (val != NULL)
 			return val;
 	}
-	val = rnd_attribute_get(&subc->Attributes, "visible_footprint");
+	val = pcb_attribute_get(&subc->Attributes, "visible_footprint");
 	if (val != NULL)
 		return val;
-	val = rnd_attribute_get(&subc->Attributes, "footprint");
+	val = pcb_attribute_get(&subc->Attributes, "footprint");
 	return val;
 }
 
+/*** subc replace: in-place replacement of a subcircuit with another, trying to keep as much local changes as possible ***/
+
+typedef struct pcb_sucbrepl_floater_s pcb_sucbrepl_floater_t;
+
+struct pcb_sucbrepl_floater_s { /* digest of a floater for matching up */
+	/* desired state */
+	rnd_coord_t x, y;
+	double rot;
+
+	/* admiin */
+	pcb_sucbrepl_floater_t *next;
+
+	/* matching */
+	pcb_objtype_t type;
+	rnd_layer_id_t lid;
+	char str[1]; /* dynamic length */
+};
+
+typedef struct {
+	pcb_board_t *pcb;
+	htsp_t thermal;        /* value is (char *) thermal shapes; it's as long as many layers pcb currently has */
+	pcb_sucbrepl_floater_t *flt;
+} pcb_subc_replace_t;
+
+static void pcb_subcrepl_map_floater(pcb_subc_replace_t *repl, const pcb_subc_t *src, pcb_any_obj_t *o)
+{
+	pcb_sucbrepl_floater_t *f;
+	pcb_text_t *txt = (pcb_text_t *)o;
+
+	if ((txt->type == PCB_OBJ_TEXT) && (txt->TextString != NULL) && (*txt->TextString != '\0')) {
+		long len = strlen(txt->TextString);
+		f = malloc(sizeof(pcb_sucbrepl_floater_t) + len + 1);
+		strcpy(f->str, txt->TextString);
+	}
+	else {
+		f = malloc(sizeof(pcb_sucbrepl_floater_t));
+		f->str[0] = '\0';
+	}
+
+	f->type = o->type;
+	if (PCB_OBJ_CLASS_LAYER & o->type)
+		f->lid = pcb_layer2id(repl->pcb->Data, pcb_layer_get_real(o->parent.layer));
+	else
+		f->lid = -1;
+
+	switch(o->type) {
+		case PCB_OBJ_ARC:
+			f->x = ((pcb_arc_t *)o)->X;
+			f->y = ((pcb_arc_t *)o)->Y;
+			break;
+		case PCB_OBJ_LINE:
+			f->x = ((pcb_line_t *)o)->Point1.X;
+			f->y = ((pcb_line_t *)o)->Point1.Y;
+			break;
+		case PCB_OBJ_TEXT:
+			f->x = ((pcb_text_t *)o)->X;
+			f->y = ((pcb_text_t *)o)->Y;
+			f->rot = ((pcb_text_t *)o)->rot;
+			break;
+		case PCB_OBJ_PSTK:
+			f->x = ((pcb_pstk_t *)o)->x;
+			f->y = ((pcb_pstk_t *)o)->y;
+			f->rot = ((pcb_pstk_t *)o)->rot;
+			break;
+		case PCB_OBJ_GFX:
+			f->x = ((pcb_gfx_t *)o)->cx;
+			f->y = ((pcb_gfx_t *)o)->cy;
+			f->rot = ((pcb_gfx_t *)o)->rot;
+			break;
+
+		case PCB_OBJ_SUBC: /* may matter in subc-in-subc, for subc terminals */
+		case PCB_OBJ_POLY: /* no idea which point to use */
+		case PCB_OBJ_RAT:
+		case PCB_OBJ_NET:
+		case PCB_OBJ_NET_TERM:
+		case PCB_OBJ_LAYER:
+		case PCB_OBJ_LAYERGRP:
+		case PCB_OBJ_VOID:
+			break;
+	}
+	f->next = repl->flt;
+	repl->flt = f;
+}
+
+static void pcb_subcrepl_apply_floater(pcb_subc_replace_t *repl, const pcb_subc_t *src, pcb_any_obj_t *o)
+{
+	pcb_sucbrepl_floater_t *n;
+	rnd_layer_id_t lid;
+
+	for(n = repl->flt; n != NULL; n = n->next) {
+		if (n->type != o->type) continue;
+
+		if (PCB_OBJ_CLASS_LAYER & o->type)
+			lid = pcb_layer2id(repl->pcb->Data, pcb_layer_get_real(o->parent.layer));
+		else
+			lid = -1;
+		if (n->lid != lid) continue;
+
+		if (o->type == PCB_OBJ_TEXT) {
+			const char *s = ((pcb_text_t *)o)->TextString;
+			if (s == NULL) s = "";
+			if (strcmp(n->str, s) != 0) continue;
+		}
+
+		/* match! */
+		switch(o->type) {
+			case PCB_OBJ_ARC:
+				pcb_move_obj(o->type, o->parent.any, o, o, n->x - ((pcb_arc_t *)o)->X, n->y - ((pcb_arc_t *)o)->Y);
+				break;
+			case PCB_OBJ_LINE:
+				pcb_move_obj(o->type, o->parent.any, o, o, n->x - ((pcb_line_t *)o)->Point1.X, n->y - ((pcb_line_t *)o)->Point1.Y);
+				break;
+			case PCB_OBJ_TEXT:
+				pcb_move_obj(o->type, o->parent.any, o, o, n->x - ((pcb_text_t *)o)->X, n->y - ((pcb_text_t *)o)->Y);
+				if (n->rot != ((pcb_text_t *)o)->rot) {
+					double ang = n->rot - ((pcb_text_t *)o)->rot;
+					pcb_text_rotate((pcb_text_t *)o, ((pcb_text_t *)o)->X, ((pcb_text_t *)o)->Y, cos(ang), sin(ang), ang);
+				}
+				break;
+			case PCB_OBJ_PSTK:
+				pcb_move_obj(o->type, o->parent.any, o, o, n->x - ((pcb_pstk_t *)o)->x, n->y - ((pcb_pstk_t *)o)->y);
+				if (n->rot != ((pcb_pstk_t *)o)->rot) {
+					double ang = n->rot - ((pcb_text_t *)o)->rot;
+					pcb_pstk_rotate((pcb_pstk_t *)o, ((pcb_pstk_t *)o)->x, ((pcb_pstk_t *)o)->y, cos(ang), sin(ang), ang);
+				}
+				break;
+			case PCB_OBJ_GFX:
+				pcb_gfx_chg_geo((pcb_gfx_t *)o, n->x, n->y, ((pcb_gfx_t *)o)->sx, ((pcb_gfx_t *)o)->sy,  n->rot, 0);
+				break;
+
+			case PCB_OBJ_SUBC: /* may matter in subc-in-subc, for subc terminals */
+			case PCB_OBJ_POLY: /* no idea which point to use */
+			case PCB_OBJ_RAT:
+			case PCB_OBJ_NET:
+			case PCB_OBJ_NET_TERM:
+			case PCB_OBJ_LAYER:
+			case PCB_OBJ_LAYERGRP:
+			case PCB_OBJ_VOID:
+				break;
+		}
+
+		n->type = PCB_OBJ_VOID; /* use each input floater only once */
+	}
+}
+
+static void pcb_subcrepl_free_floaters(pcb_subc_replace_t *repl)
+{
+	pcb_sucbrepl_floater_t *n, *next;
+	for(n = repl->flt; n != NULL; n = next) {
+		next = n->next;
+		free(n);
+	}
+}
+
+
+/* map thermals and floaters of src to repl */
+static void pcb_subcrepl_map_thermals_floaters(pcb_subc_replace_t *repl, const pcb_subc_t *src)
+{
+	pcb_any_obj_t *o;
+	pcb_data_it_t it;
+	char *s;
+
+	htsp_init(&repl->thermal, strhash, strkeyeq);
+
+	for(o = pcb_data_first(&it, src->data, PCB_OBJ_CLASS_LAYER); o != NULL; o = pcb_data_next(&it)) {
+		rnd_layer_id_t lid;
+
+		if (PCB_FLAG_TEST(PCB_FLAG_FLOATER, o))
+			pcb_subcrepl_map_floater(repl, src, o);
+
+		if ((o->term == NULL) || (o->thermal == 0)) continue;
+		s = htsp_get(&repl->thermal, o->term);
+		if (s != NULL) continue; /* save the "first" only */
+
+		lid = pcb_layer2id(repl->pcb->Data, pcb_layer_get_real(o->parent.layer));
+		if (lid == -1) continue;
+
+		s = calloc(repl->pcb->Data->LayerN, 1);
+		s[lid] = o->thermal;
+		htsp_set(&repl->thermal, rnd_strdup(o->term), s);
+	}
+
+	for(o = pcb_data_first(&it, src->data, PCB_OBJ_PSTK); o != NULL; o = pcb_data_next(&it)) {
+		pcb_pstk_t *ps = (pcb_pstk_t *)o;
+
+		if (PCB_FLAG_TEST(PCB_FLAG_FLOATER, o))
+			pcb_subcrepl_map_floater(repl, src, o);
+
+		if ((o->term == NULL) || (ps->thermals.used == 0)) continue;
+		s = htsp_get(&repl->thermal, o->term);
+		if (s != NULL) continue; /* save the "first" only */
+
+		s = calloc(repl->pcb->Data->LayerN, 1);
+		memcpy(s, ps->thermals.shape, ps->thermals.used);
+		htsp_set(&repl->thermal, rnd_strdup(o->term), s);
+	}
+}
+
+/* Set thermals on the new subc terminals from repl; return 1 if there was any
+   thermal set (and thus polygons need to be updated); also move/rotate floaters
+   trying to match the original placement */
+static int pcb_subcrepl_apply_thermals_floaters(pcb_subc_replace_t *repl, pcb_subc_t *placed)
+{
+	pcb_any_obj_t *o;
+	pcb_data_it_t it;
+	htsp_entry_t *e;
+	int has_thermal = 0;
+
+	for(o = pcb_data_first(&it, placed->data, PCB_OBJ_CLASS_LAYER); o != NULL; o = pcb_data_next(&it)) {
+		rnd_layer_id_t lid;
+		char *s;
+
+		if (PCB_FLAG_TEST(PCB_FLAG_FLOATER, o))
+			pcb_subcrepl_apply_floater(repl, placed, o);
+
+		if ((o->term == NULL) || (o->thermal == 0)) continue;
+		e = htsp_popentry(&repl->thermal, o->term);
+		if (e == NULL) continue; /* save the "first" only */
+
+		lid = pcb_layer2id(repl->pcb->Data, pcb_layer_get_real(o->parent.layer));
+		if (lid == -1) continue;
+
+		s = e->value;
+		o->thermal = s[lid];
+		free(e->key);
+		free(e->value);
+		has_thermal = 1;
+	}
+
+	for(o = pcb_data_first(&it, placed->data, PCB_OBJ_PSTK); o != NULL; o = pcb_data_next(&it)) {
+		pcb_pstk_t *ps = (pcb_pstk_t *)o;
+
+		if (PCB_FLAG_TEST(PCB_FLAG_FLOATER, o))
+			pcb_subcrepl_apply_floater(repl, placed, o);
+
+		if ((o->term == NULL) || (ps->thermals.used == 0)) continue;
+		e = htsp_popentry(&repl->thermal, o->term);
+		if (e == NULL) continue; /* save the "first" only */
+		ps->thermals.used = repl->pcb->Data->LayerN;
+		ps->thermals.shape = e->value;
+		
+		free(e->key);
+		has_thermal = 1;
+	}
+
+	genht_uninit_deep(htsp, &repl->thermal, {
+		free(htent->key);
+		free(htent->value);
+	});
+	pcb_subcrepl_free_floaters(repl);
+	return has_thermal;
+}
 
 pcb_subc_t *pcb_subc_replace(pcb_board_t *pcb, pcb_subc_t *dst, pcb_subc_t *src, rnd_bool add_undo, rnd_bool dumb)
 {
@@ -2333,6 +2652,7 @@ pcb_subc_t *pcb_subc_replace(pcb_board_t *pcb, pcb_subc_t *dst, pcb_subc_t *src,
 	static const pcb_flag_values_t fmask = PCB_FLAG_SELECTED | \
 		PCB_FLAG_ONSOLDER | PCB_FLAG_AUTO | PCB_FLAG_NONETLIST;
 	pcb_flag_values_t flags;
+	pcb_subc_replace_t repl = {0};
 
 	assert(dst->parent_type == PCB_PARENT_DATA);
 	assert(src != NULL);
@@ -2350,6 +2670,9 @@ pcb_subc_t *pcb_subc_replace(pcb_board_t *pcb, pcb_subc_t *dst, pcb_subc_t *src,
 		pcb_subc_get_side(dst, &dst_on_bottom);
 	}
 
+	repl.pcb = pcb;
+	pcb_subcrepl_map_thermals_floaters(&repl, dst);
+
 	if (pcb_subc_get_origin(src, &osx, &osy) != 0) {
 		osx = (dst->BoundingBox.X1 + dst->BoundingBox.X2) / 2;
 		osy = (dst->BoundingBox.Y1 + dst->BoundingBox.Y2) / 2;
@@ -2361,10 +2684,10 @@ pcb_subc_t *pcb_subc_replace(pcb_board_t *pcb, pcb_subc_t *dst, pcb_subc_t *src,
 
 	{ /* copy attributes */
 		int n;
-		rnd_attribute_list_t *adst = &placed->Attributes, *asrc = &dst->Attributes;
+		pcb_attribute_list_t *adst = &placed->Attributes, *asrc = &dst->Attributes;
 		for (n = 0; n < asrc->Number; n++)
 			if (strcmp(asrc->List[n].name, "footprint") != 0)
-				rnd_attribute_put(adst, asrc->List[n].name, asrc->List[n].value);
+				pcb_attribute_put(adst, asrc->List[n].name, asrc->List[n].value);
 	}
 
 	flags = dst->Flags.f & fmask;
@@ -2390,6 +2713,15 @@ pcb_subc_t *pcb_subc_replace(pcb_board_t *pcb, pcb_subc_t *dst, pcb_subc_t *src,
 	if (dst_on_bottom != src_on_bottom)
 		pcb_subc_change_side(placed, 2 * oy - PCB->hidlib.size_y);
 
+	if (pcb_subcrepl_apply_thermals_floaters(&repl, placed)) {
+		pcb_opctx_t clip;
+		clip.clip.pcb = pcb;
+		clip.clip.restore = 1; clip.clip.clear = 0;
+		pcb_subc_op(pcb->Data, placed, &ClipFunctions, &clip, PCB_SUBCOP_UNDO_NORMAL);
+		clip.clip.restore = 0; clip.clip.clear = 1;
+		pcb_subc_op(pcb->Data, placed, &ClipFunctions, &clip, PCB_SUBCOP_UNDO_NORMAL);
+	}
+
 	pcb_undo_freeze_add();
 	pcb_subc_select(pcb, placed, (flags & PCB_FLAG_SELECTED) ? PCB_CHGFLG_SET : PCB_CHGFLG_CLEAR, 0);
 	pcb_undo_unfreeze_add();
