@@ -20,7 +20,7 @@
  *
  *  Contact:
  *    Project page: http://repo.hu/projects/pcb-rnd
- *    lead developer: email to pcb-rnd (at) igor2.repo.hu
+ *    lead developer: http://repo.hu/projects/pcb-rnd/contact.html
  *    mailing list: pcb-rnd (at) list.repo.hu (send "subscribe")
  */
 
@@ -50,11 +50,11 @@ extern int pcb_subc_hash_ignore_uid;
 
 /* Calculate a hash value using the content of the subc. The hash value
    represents the actual content of an subc */
-unsigned int pcb_subc_hash(const pcb_subc_t *e);
+unsigned int pcb_subc_hash(pcb_subc_t *e);
 
 /* Compare two subcs and return 1 if they are qeual
    (their uids match and they contain the same objects). */
-int pcb_subc_eq(const pcb_subc_t *sc1, const pcb_subc_t *sc2);
+int pcb_subc_eq(pcb_subc_t *sc1, pcb_subc_t *sc2);
 
 /* Create a new local variable to be used for deduplication */
 #define pcb_subclist_dedup_initializer(state) htscp_t *state = NULL;
@@ -69,7 +69,7 @@ switch(1) { \
 			state = htscp_alloc(pcb_subc_hash, pcb_subc_eq); \
 		if (htscp_has(state, loop_elem)) \
 			continue; \
-		htscp_set(state, loop_elem, 1); \
+		htscp_set(state, loop_elem, loop_elem); \
 	} \
 }
 
