@@ -51,8 +51,6 @@
 #include "obj_subc_parent.h"
 #include "obj_hash.h"
 
-/* TODO: remove this if draw.c is moved here: */
-#include "draw.h"
 #include "obj_line_draw.h"
 #include "obj_text_draw.h"
 #include "conf_core.h"
@@ -106,7 +104,7 @@ void pcb_text_free(pcb_text_t *text)
 {
 	if ((text->parent.layer != NULL) && (text->parent.layer->text_tree != NULL))
 		rnd_r_delete_entry(text->parent.layer->text_tree, (rnd_box_t *)text);
-	rnd_attribute_free(&text->Attributes);
+	pcb_attribute_free(&text->Attributes);
 	pcb_text_unreg(text);
 	free(text->TextString);
 	pcb_obj_common_free((pcb_any_obj_t *)text);
@@ -146,7 +144,8 @@ static int undo_text_geo_swap(void *udata)
 	rnd_swap(rnd_coord_t, g->clearance, g->text->clearance);
 	rnd_swap(double, g->rot, g->text->rot);
 
-	pcb_text_bbox(pcb_font(pcb, g->text->fid, 1), g->text);
+	if (pcb != NULL)
+		pcb_text_bbox(pcb_font(pcb, g->text->fid, 1), g->text);
 	if (layer->text_tree != NULL)
 		rnd_r_insert_entry(layer->text_tree, (rnd_box_t *)g->text);
 	pcb_poly_clear_from_poly(layer->parent.data, PCB_OBJ_TEXT, layer, g->text);
@@ -183,7 +182,7 @@ pcb_text_t *pcb_text_new_(pcb_layer_t *Layer, pcb_font_t *PCBFont, rnd_coord_t X
 	if (mirror & PCB_TXT_MIRROR_Y)
 		Flags.f |= PCB_FLAG_ONSOLDER;
 	if (mirror & PCB_TXT_MIRROR_X)
-		rnd_attribute_put(&text->Attributes, "mirror_x", "1");
+		pcb_attribute_put(&text->Attributes, "mirror_x", "1");
 
 	/* copy values, width and height are set by drawing routine
 	 * because at this point we don't know which symbols are available
@@ -285,7 +284,7 @@ static pcb_text_t *pcb_text_copy_meta(pcb_text_t *dst, pcb_text_t *src)
 {
 	if (dst == NULL)
 		return NULL;
-	rnd_attribute_copy_all(&dst->Attributes, &src->Attributes);
+	pcb_attribute_copy_all(&dst->Attributes, &src->Attributes);
 	return dst;
 }
 
@@ -331,7 +330,7 @@ static int pcb_text_render_str_cb(void *ctx, gds_t *s, const char **input)
 	*input += len+1;
 
 	if ((key[0] == 'a') && (key[1] == '.')) {
-		const rnd_attribute_list_t *attr = &text->Attributes;
+		const pcb_attribute_list_t *attr = &text->Attributes;
 		path = key+2;
 		if ((path[0] == 'p') && (memcmp(path, "parent.", 7) == 0)) {
 			pcb_data_t *par = text->parent.layer->parent.data;
@@ -347,7 +346,7 @@ static int pcb_text_render_str_cb(void *ctx, gds_t *s, const char **input)
 			path+=7;
 		}
 		if (attr != NULL) {
-			attrs = rnd_attribute_get(attr, path);
+			attrs = pcb_attribute_get(attr, path);
 			if (attrs != NULL)
 				gds_append_str(s, attrs);
 		}
@@ -952,6 +951,11 @@ void *pcb_textop_rotate(pcb_opctx_t *ctx, pcb_layer_t *Layer, pcb_text_t *Text)
 		Text->rot += ctx->rotate.angle;
 	pcb_text_bbox(NULL, Text);
 
+	if (Text->rot < 0)
+		Text->rot = fmod(360 - Text->rot, 360);
+	if (Text->rot > 360)
+		Text->rot = fmod(Text->rot - 360, 360);
+
 	if (Layer->text_tree != NULL)
 		rnd_r_insert_entry(Layer->text_tree, (rnd_box_t *) Text);
 	pcb_poly_clear_from_poly(PCB->Data, PCB_OBJ_TEXT, Layer, Text);
@@ -1138,19 +1142,23 @@ void pcb_text_dyn_bbox_update(pcb_data_t *data)
 
 int pcb_text_chg_scale(pcb_text_t *text, double scx, rnd_bool absx, double scy, rnd_bool absy, rnd_bool undoable)
 {
-	int onbrd = (text->parent.layer != NULL) && (!text->parent.layer->is_bound);
+	undo_text_geo_t gtmp, *g = &gtmp;
 
-	TODO("undo: make this undoable");
+	if (undoable) g = pcb_undo_alloc(pcb_data_get_top(text->parent.layer->parent.data), &undo_text_geo, sizeof(undo_text_geo_t));
 
-	if (onbrd)
-		pcb_text_pre(text);
+	g->text = text;
+	g->X = text->X;
+	g->Y = text->Y;
+	g->Scale = text->Scale;
+	g->scale_x = absx ? scx : text->scale_x + scx;
+	g->scale_y = absy ? scy : text->scale_y + scy;
+	g->thickness = text->thickness;
+	g->clearance = text->clearance;
+	g->rot = text->rot;
 
-	text->scale_x = absx ? scx : text->scale_x + scx;
-	text->scale_y = absy ? scy : text->scale_y + scy;
+	undo_text_geo_swap(g);
+	if (undoable) pcb_undo_inc_serial();
 
-	pcb_text_bbox(pcb_font(PCB, text->fid, 1), text);
-	if (onbrd)
-		pcb_text_post(text);
 	return 0;
 }
 
@@ -1463,10 +1471,14 @@ void pcb_text_draw_string(pcb_draw_info_t *info, pcb_font_t *font, const unsigne
 
 void pcb_text_draw_string_simple(pcb_font_t *font, const char *string, rnd_coord_t x0, rnd_coord_t y0, double scx, double scy, double rotdeg, pcb_text_mirror_t mirror, rnd_coord_t thickness, int xordraw, rnd_coord_t xordx, rnd_coord_t xordy)
 {
+	static rnd_xform_t xform = {0};
+	static pcb_draw_info_t info = {0};
+
+	info.xform = &xform;
 	if (font == NULL)
 		font = pcb_font(PCB, 0, 0);
 
-	pcb_text_draw_string_(NULL, font, (const unsigned char *)string, x0, y0, scx, scy, rotdeg, mirror, thickness, 0, xordraw, xordx, xordy, PCB_TXT_TINY_CHEAP, NULL, NULL);
+	pcb_text_draw_string_(&info, font, (const unsigned char *)string, x0, y0, scx, scy, rotdeg, mirror, thickness, 0, xordraw, xordx, xordy, PCB_TXT_TINY_CHEAP, NULL, NULL);
 }
 
 
@@ -1518,12 +1530,12 @@ void pcb_text_name_invalidate_draw(pcb_text_t *text)
 			100.0, is_text_term_vert(text), rnd_true, (pcb_any_obj_t *)text);
 }
 
-void pcb_text_draw_label(pcb_draw_info_t *info, pcb_text_t *text)
+void pcb_text_draw_label(pcb_draw_info_t *info, pcb_text_t *text, rnd_bool vis_side)
 {
-	if (text->term != NULL)
+	if ((text->term != NULL) && vis_side)
 		pcb_term_label_draw(info, (text->BoundingBox.X1 + text->BoundingBox.X2)/2, (text->BoundingBox.Y1 + text->BoundingBox.Y2)/2,
 			conf_core.appearance.term_label_size, is_text_term_vert(text), rnd_true, (pcb_any_obj_t *)text);
-	if (text->noexport)
+	if (text->noexport && vis_side)
 		pcb_obj_noexport_mark(text, (text->BoundingBox.X1 + text->BoundingBox.X2)/2, (text->BoundingBox.Y1 + text->BoundingBox.Y2)/2);
 }
 
@@ -1629,11 +1641,11 @@ void pcb_text_invalidate_draw(pcb_layer_t *Layer, pcb_text_t *Text)
 static pcb_draw_info_t txor_info;
 static rnd_xform_t txor_xform;
 
-void pcb_text_draw_xor(pcb_text_t *text, rnd_coord_t x, rnd_coord_t y)
+void pcb_text_draw_xor(pcb_text_t *text, rnd_coord_t x, rnd_coord_t y, rnd_bool want_box)
 {
 	txor_info.xform = &txor_xform;
 	DrawTextLowLevel_(&txor_info, text, 0, 1, x, y, PCB_TXT_TINY_CHEAP);
-	if ((conf_core.appearance.text_host_bbox) && (text->BoundingBox.X1 != text->BoundingBox.X2)) {
+	if (want_box && (conf_core.appearance.text_host_bbox) && (text->BoundingBox.X1 != text->BoundingBox.X2)) {
 		rnd_render->draw_line(pcb_crosshair.GC, x + text->BoundingBox.X1, y + text->BoundingBox.Y1, x + text->BoundingBox.X1, y + text->BoundingBox.Y2);
 		rnd_render->draw_line(pcb_crosshair.GC, x + text->BoundingBox.X1, y + text->BoundingBox.Y1, x + text->BoundingBox.X2, y + text->BoundingBox.Y1);
 		rnd_render->draw_line(pcb_crosshair.GC, x + text->BoundingBox.X2, y + text->BoundingBox.Y2, x + text->BoundingBox.X1, y + text->BoundingBox.Y2);
