@@ -60,101 +60,6 @@
 #include <librnd/core/actions.h>
 #include "view.h"
 
-static const char pcb_acts_Attributes[] = "Attributes(Layout|Layer|Element|Subc)\n" "Attributes(Layer,layername)";
-static const char pcb_acth_Attributes[] =
-	"Let the user edit the attributes of the layout, current or given\n"
-	"layer, or selected subcircuit.";
-/* DOC: attributes.html */
-static fgw_error_t pcb_act_Attributes(fgw_arg_t *res, int argc, fgw_arg_t *argv)
-{
-	pcb_board_t *pcb = PCB_ACT_BOARD;
-	int id;
-	const char *layername;
-	char *buf;
-
-	RND_ACT_CONVARG(1, FGW_KEYWORD, Attributes, id = fgw_keyword(&argv[1]));
-	RND_ACT_MAY_CONVARG(1, FGW_STR, Attributes, layername = argv[1].val.str);
-	RND_ACT_IRES(0);
-
-	if (!rnd_gui->edit_attributes) {
-		rnd_message(RND_MSG_ERROR, "This GUI doesn't support Attribute Editing\n");
-		return FGW_ERR_UNKNOWN;
-	}
-
-	switch(id) {
-	case F_Layout:
-		{
-			rnd_gui->edit_attributes(rnd_gui, "Layout Attributes", &(pcb->Attributes));
-			return 0;
-		}
-
-	case F_Layer:
-		{
-			pcb_layer_t *layer = PCB_CURRLAYER(pcb);
-			if (layername) {
-				int i;
-				layer = NULL;
-				for (i = 0; i < pcb_max_layer(pcb); i++)
-					if (strcmp(pcb->Data->Layer[i].name, layername) == 0) {
-						layer = &(pcb->Data->Layer[i]);
-						break;
-					}
-				if (layer == NULL) {
-					rnd_message(RND_MSG_ERROR, "No layer named %s\n", layername);
-					return 1;
-				}
-			}
-			pcb_layer_edit_attrib(layer);
-			return 0;
-		}
-
-	case F_Element:
-	case F_Subc:
-		{
-			int n_found = 0;
-			pcb_subc_t *s = NULL;
-			PCB_SUBC_LOOP(pcb->Data);
-			{
-				if (PCB_FLAG_TEST(PCB_FLAG_SELECTED, subc)) {
-					s = subc;
-					n_found++;
-				}
-			}
-			PCB_END_LOOP;
-			if (n_found > 1) {
-				rnd_message(RND_MSG_ERROR, "Too many subcircuits selected\n");
-				return 1;
-			}
-			if (n_found == 0) {
-				rnd_coord_t x, y;
-				void *ptrtmp;
-				rnd_hid_get_coords("Click on a subcircuit", &x, &y, 0);
-				if ((pcb_search_screen(x, y, PCB_OBJ_SUBC, &ptrtmp, &ptrtmp, &ptrtmp)) != PCB_OBJ_VOID)
-					s = (pcb_subc_t *)ptrtmp;
-				else {
-					rnd_message(RND_MSG_ERROR, "No subcircuit found there\n");
-					RND_ACT_IRES(-1);
-					return 0;
-				}
-			}
-
-			if (s->refdes != NULL)
-				buf = rnd_strdup_printf("Subcircuit %s Attributes", s->refdes);
-			else
-				buf = rnd_strdup("Unnamed Subcircuit's Attributes");
-
-			rnd_gui->edit_attributes(rnd_gui, buf, &(s->Attributes));
-			free(buf);
-			break;
-		}
-
-	default:
-		RND_ACT_FAIL(Attributes);
-	}
-
-	return 0;
-}
-
 static const char pcb_acts_DisperseElements[] = "DisperseElements(All|Selected)";
 static const char pcb_acth_DisperseElements[] = "Disperses subcircuits.";
 
@@ -247,7 +152,7 @@ static fgw_error_t pcb_act_DisperseElements(fgw_arg_t *res, int argc, fgw_arg_t
 	pcb_undo_inc_serial();
 
 	rnd_hid_redraw(pcb);
-	pcb_board_set_changed_flag(rnd_true);
+	pcb_board_set_changed_flag(pcb, rnd_true);
 
 	return 0;
 }
@@ -330,7 +235,7 @@ static fgw_error_t pcb_act_MoveObject(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (type == PCB_OBJ_SUBC)
 		rnd_event(RND_ACT_HIDLIB, PCB_EVENT_RUBBER_LOOKUP_RATS, "ippp", type, ptr1, ptr2, ptr3);
 	pcb_move_obj_and_rubberband(type, ptr1, ptr2, ptr3, nx->c[0], ny->c[0]);
-	pcb_board_set_changed_flag(rnd_true);
+	pcb_board_set_changed_flag(PCB_ACT_BOARD, rnd_true);
 
 	RND_ACT_IRES(0);
 	return 0;
@@ -379,7 +284,7 @@ static fgw_error_t pcb_act_MoveToCurrentLayer(fgw_arg_t *res, int argc, fgw_arg_
 					if (((pcb_any_obj_t *)ptr2)->parent_type == PCB_PARENT_LAYER)
 						ly = ((pcb_any_obj_t *)ptr2)->parent.layer; /* might be a bound layer, and ptr1 is a resolved one; we don't want undo to put the object back on the resolved layer instead of the original bound layer */
 					if (pcb_move_obj_to_layer(type, ly, ptr2, ptr3, target, rnd_false))
-						pcb_board_set_changed_flag(rnd_true);
+						pcb_board_set_changed_flag(pcb, rnd_true);
 				}
 				break;
 			}
@@ -387,7 +292,7 @@ static fgw_error_t pcb_act_MoveToCurrentLayer(fgw_arg_t *res, int argc, fgw_arg_
 		case F_SelectedObjects:
 		case F_Selected:
 			if (pcb_move_selected_objs_to_layer(PCB_CURRLAYER(pcb)))
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(pcb, rnd_true);
 			break;
 	}
 	return 0;
@@ -400,7 +305,7 @@ static int number_of_footprints_not_found;
 
 static int parse_layout_attribute_units(pcb_board_t *pcb, const char *name, int def)
 {
-	const char *as = rnd_attrib_get(pcb, name);
+	const char *as = pcb_attrib_get(pcb, name);
 	if (!as)
 		return def;
 	return rnd_get_value(as, NULL, NULL, NULL);
@@ -408,7 +313,7 @@ static int parse_layout_attribute_units(pcb_board_t *pcb, const char *name, int
 
 static int subc_differs(pcb_subc_t *sc, const char *expect_name)
 {
-	const char *got_name = rnd_attribute_get(&sc->Attributes, "footprint");
+	const char *got_name = pcb_attribute_get(&sc->Attributes, "footprint");
 	if ((expect_name != NULL) && (*expect_name == '\0'))
 		expect_name = NULL;
 	if ((got_name != NULL) && (*got_name == '\0'))
@@ -665,7 +570,7 @@ static fgw_error_t pcb_act_ElementList(fgw_arg_t *res, int argc, fgw_arg_t *argv
 		printf("  ... Footprint not on board, need to add it.\n");
 #endif
 		/* Not on board, need to add it. */
-		if (RND_ACT_CALL_C(pcb_act_LoadFootprint, &rs, argc, args) != 0) {
+		if (RND_ACT_CALL_C(RND_ACT_HIDLIB, pcb_act_LoadFootprint, &rs, argc, args) != 0) {
 			number_of_footprints_not_found++;
 			RND_ACT_IRES(1);
 			return 0;
@@ -676,7 +581,7 @@ static fgw_error_t pcb_act_ElementList(fgw_arg_t *res, int argc, fgw_arg_t *argv
 		/* Place components onto center of board. */
 		pcb_crosshair.Y = py; /* flipping side depends on the crosshair unfortunately */
 		if (pcb_buffer_copy_to_layout(pcb, px, py, rnd_false))
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(pcb, rnd_true);
 	}
 	else if (sc && subc_differs(sc, footprint)) {
 #ifdef DEBUG
@@ -687,7 +592,7 @@ static fgw_error_t pcb_act_ElementList(fgw_arg_t *res, int argc, fgw_arg_t *argv
 		double orig_rot;
 
 		/* Different footprint, we need to swap them out.  */
-		if (RND_ACT_CALL_C(pcb_act_LoadFootprint, &rs, argc, args) != 0) {
+		if (RND_ACT_CALL_C(RND_ACT_HIDLIB, pcb_act_LoadFootprint, &rs, argc, args) != 0) {
 			number_of_footprints_not_found++;
 			RND_ACT_IRES(1);
 			return 0;
@@ -737,15 +642,15 @@ static fgw_error_t pcb_act_ElementList(fgw_arg_t *res, int argc, fgw_arg_t *argv
 			if (sc != NULL)
 				pcb_subc_remove(sc);
 			if (pcb_buffer_copy_to_layout(pcb, orig_cx, orig_cy, rnd_false))
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(pcb,rnd_true);
 		}
 	}
 
 	/* Now reload footprint */
 	sc = pcb_subc_by_refdes(pcb->Data, refdes);
 	if (sc != NULL) {
-/*		rnd_attribute_put(&sc->Attributes, "refdes", refdes);*/
-		rnd_attribute_put(&sc->Attributes, "value", value);
+/*		pcb_attribute_put(&sc->Attributes, "refdes", refdes);*/
+		pcb_attribute_put(&sc->Attributes, "value", value);
 		PCB_FLAG_SET(PCB_FLAG_FOUND, sc);
 	}
 
@@ -782,9 +687,9 @@ static fgw_error_t pcb_act_ElementSetAttr(fgw_arg_t *res, int argc, fgw_arg_t *a
 	}
 
 	if (value != NULL)
-		rnd_attribute_put(&sc->Attributes, name, value);
+		pcb_attribute_put(&sc->Attributes, name, value);
 	else
-		rnd_attribute_remove(&sc->Attributes, name);
+		pcb_attribute_remove(&sc->Attributes, name);
 
 	RND_ACT_IRES(0);
 	return 0;
@@ -831,7 +736,7 @@ static fgw_error_t pcb_act_RipUp(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 			if (changed) {
 				pcb_undo_inc_serial();
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(pcb, rnd_true);
 			}
 			break;
 		case F_Selected:
@@ -856,7 +761,7 @@ static fgw_error_t pcb_act_RipUp(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			PCB_END_LOOP;
 			if (changed) {
 				pcb_undo_inc_serial();
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(pcb, rnd_true);
 			}
 			break;
 	}
@@ -1199,7 +1104,6 @@ static fgw_error_t pcb_act_GfxMod(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 }
 
 static rnd_action_t object_action_list[] = {
-	{"Attributes", pcb_act_Attributes, pcb_acth_Attributes, pcb_acts_Attributes},
 	{"DisperseElements", pcb_act_DisperseElements, pcb_acth_DisperseElements, pcb_acts_DisperseElements},
 	{"Flip", pcb_act_Flip, pcb_acth_Flip, pcb_acts_Flip},
 	{"MoveObject", pcb_act_MoveObject, pcb_acth_MoveObject, pcb_acts_MoveObject},
