@@ -29,6 +29,8 @@
 
 #include "config.h"
 
+#include <ctype.h>
+
 #include "plug_footprint.h"
 #include <librnd/core/plugins.h>
 
@@ -51,6 +53,19 @@ FILE *PCB_FP_FOPEN_IN_DST = (FILE *)&PCB_FP_FOPEN_IN_DST_;
 pcb_plug_fp_t *pcb_plug_fp_chain = NULL;
 pcb_fplibrary_t pcb_library;
 
+static pcb_fplibrary_t *pcb_get_library_memory(pcb_fplibrary_t *parent)
+{
+	pcb_fplibrary_t *res;
+	vtp0_t *vt = ((parent) == NULL ? &pcb_library.data.dir.children : &(parent)->data.dir.children);
+
+	res = calloc(sizeof(pcb_fplibrary_t), 1);
+	res->parent = parent;
+	vtp0_append(vt, res);
+
+	return res;
+}
+
+
 int pcb_fp_dupname(const char *name, char **basename, char **params)
 {
 	char *newname, *s;
@@ -65,9 +80,10 @@ int pcb_fp_dupname(const char *name, char **basename, char **params)
 	/* split at '(' */
 	*s = '\0';
 	*params = s + 1;
-	s = *params + strlen(*params) - 1;
 
 	/* strip ')' */
+	s = *params + strlen(*params) - 1;
+	while(isspace(*s) && (s > *params)) s--;
 	if (*s == ')')
 		*s = '\0';
 
@@ -163,7 +179,26 @@ void pcb_fp_fclose(FILE * f, pcb_fp_fopen_ctx_t *fctx)
 	fctx->free_filename = 0;
 }
 
-pcb_fplibrary_t *pcb_fp_append_entry(pcb_fplibrary_t *parent, const char *name, pcb_fptype_t type, void *tags[])
+static void **pcb_fp_dup_tags(void *tags[])
+{
+	long len = 0;
+	void **src, **dst, **res;
+
+	if (tags == NULL)
+		return NULL;
+
+	for(src = tags; *src != NULL; src++) len++;
+
+	res = malloc(sizeof(void *) * (len+1));
+
+	for(src = tags, dst = res; *src != NULL; src++, dst++)
+		*dst = *src; /* these are coming from the central hash, it is safe to keep them */
+
+	*dst = NULL;
+	return res;
+}
+
+pcb_fplibrary_t *pcb_fp_append_entry(pcb_fplibrary_t *parent, const char *name, pcb_fptype_t type, void *tags[], rnd_bool dup_tags)
 {
 	pcb_fplibrary_t *entry;   /* Pointer to individual menu entry */
 
@@ -185,7 +220,7 @@ pcb_fplibrary_t *pcb_fp_append_entry(pcb_fplibrary_t *parent, const char *name,
 
 	entry->type = PCB_LIB_FOOTPRINT;
 	entry->data.fp.type = type;
-	entry->data.fp.tags = tags;
+	entry->data.fp.tags = dup_tags ? pcb_fp_dup_tags(tags) : tags;
 	entry->data.fp.loc_info = NULL;
 	entry->data.fp.backend_data = NULL;
 	return entry;
@@ -193,30 +228,32 @@ pcb_fplibrary_t *pcb_fp_append_entry(pcb_fplibrary_t *parent, const char *name,
 
 pcb_fplibrary_t *fp_lib_search_len(pcb_fplibrary_t *dir, const char *name, int name_len)
 {
-	pcb_fplibrary_t *l;
 	int n;
 
 	if (dir->type != PCB_LIB_DIR)
 		return NULL;
 
-	for(n = 0, l = dir->data.dir.children.array; n < dir->data.dir.children.used; n++, l++)
+	for(n = 0; n < dir->data.dir.children.used; n++) {
+		pcb_fplibrary_t *l = dir->data.dir.children.array[n];
 		if (strncmp(l->name, name, name_len) == 0)
 			return l;
+	}
 
 	return NULL;
 }
 
 pcb_fplibrary_t *pcb_fp_lib_search(pcb_fplibrary_t *dir, const char *name)
 {
-	pcb_fplibrary_t *l;
 	int n;
 
 	if (dir->type != PCB_LIB_DIR)
 		return NULL;
 
-	for(n = 0, l = dir->data.dir.children.array; n < dir->data.dir.children.used; n++, l++)
+	for(n = 0; n < dir->data.dir.children.used; n++) {
+	pcb_fplibrary_t *l = dir->data.dir.children.array[n];
 		if (strcmp(l->name, name) == 0)
 			return l;
+	}
 
 	return NULL;
 }
@@ -230,10 +267,9 @@ pcb_fplibrary_t *pcb_fp_mkdir_len(pcb_fplibrary_t *parent, const char *name, int
 		l->name = rnd_strndup(name, name_len);
 	else
 		l->name = rnd_strdup(name);
-	l->parent = parent;
 	l->type = PCB_LIB_DIR;
 	l->data.dir.backend = NULL;
-	vtlib_init(&l->data.dir.children);
+	vtp0_init(&l->data.dir.children);
 	return l;
 }
 
@@ -286,24 +322,24 @@ pcb_fplibrary_t *pcb_fp_mkdir_p(const char *path)
 
 static int fp_sort_cb(const void *a, const void *b)
 {
-	const pcb_fplibrary_t *fa = a, *fb = b;
-	int res = strcmp(fa->name, fb->name);
+	pcb_fplibrary_t * const *fa = a, * const *fb = b;
+	int res = strcmp((*fa)->name, (*fb)->name);
 	return res == 0 ? 1 : res;
 }
 
 void pcb_fp_sort_children(pcb_fplibrary_t *parent)
 {
-	vtlib_t *v;
+	vtp0_t *v;
 	int n;
 
 	if (parent->type != PCB_LIB_DIR)
 		return;
 
 	v = &parent->data.dir.children;
-	qsort(v->array, vtlib_len(v), sizeof(pcb_fplibrary_t), fp_sort_cb);
+	qsort(v->array, vtp0_len(v), sizeof(pcb_fplibrary_t *), fp_sort_cb);
 
-	for (n = 0; n < vtlib_len(v); n++)
-		pcb_fp_sort_children(&v->array[n]);
+	for (n = 0; n < vtp0_len(v); n++)
+		pcb_fp_sort_children(v->array[n]);
 }
 
 void fp_free_entry(pcb_fplibrary_t *l)
@@ -311,7 +347,7 @@ void fp_free_entry(pcb_fplibrary_t *l)
 	switch(l->type) {
 		case PCB_LIB_DIR:
 			pcb_fp_free_children(l);
-			vtlib_uninit(&(l->data.dir.children));
+			vtp0_uninit(&(l->data.dir.children));
 			break;
 		case PCB_LIB_FOOTPRINT:
 			if (l->data.fp.loc_info != NULL)
@@ -321,24 +357,23 @@ void fp_free_entry(pcb_fplibrary_t *l)
 			break;
 		case PCB_LIB_INVALID: break; /* suppress compiler warning */
 	}
-	if (l->name != NULL) {
+	if (l->name != NULL)
 		free(l->name);
-		l->name = NULL;
-	}
-	l->type = PCB_LIB_INVALID;
+	free(l);
 }
 
 void pcb_fp_free_children(pcb_fplibrary_t *parent)
 {
 	int n;
-	pcb_fplibrary_t *l;
 
 	assert(parent->type == PCB_LIB_DIR);
 
-	for(n = 0, l = parent->data.dir.children.array; n < parent->data.dir.children.used; n++, l++)
+	for(n = 0; n < parent->data.dir.children.used; n++) {
+		pcb_fplibrary_t *l = parent->data.dir.children.array[n];
 		fp_free_entry(l);
+	}
 
-	vtlib_truncate(&(parent->data.dir.children), 0);
+	vtp0_truncate(&(parent->data.dir.children), 0);
 }
 
 
@@ -348,9 +383,10 @@ void pcb_fp_rmdir(pcb_fplibrary_t *dir)
 	int n;
 	fp_free_entry(dir);
 	if (parent != NULL) {
-		for(n = 0, l = parent->data.dir.children.array; n < parent->data.dir.children.used; n++,l++) {
+		for(n = 0; n < parent->data.dir.children.used; n++) {
+			l = parent->data.dir.children.array[n];
 			if (l == dir) {
-				vtlib_remove(&(parent->data.dir.children), n, 1);
+				vtp0_remove(&(parent->data.dir.children), n, 1);
 				break;
 			}
 		}
@@ -360,10 +396,11 @@ void pcb_fp_rmdir(pcb_fplibrary_t *dir)
 /* Debug functions */
 void fp_dump_dir(pcb_fplibrary_t *dir, int level)
 {
-	pcb_fplibrary_t *l;
 	int n, p;
 
-	for(n = 0, l = dir->data.dir.children.array; n < dir->data.dir.children.used; n++, l++) {
+	for(n = 0; n < dir->data.dir.children.used; n++) {
+		pcb_fplibrary_t *l = dir->data.dir.children.array[0];
+
 		for(p = 0; p < level; p++)
 			putchar(' ');
 		if (l->type == PCB_LIB_DIR) {
