@@ -60,6 +60,7 @@
 #include <librnd/core/actions.h>
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/plugins.h>
+#include <librnd/core/hid_menu.h>
 #include "event.h"
 #include <librnd/core/compat_misc.h>
 #include "route_style.h"
@@ -282,6 +283,8 @@ int pcb_parse_footprint(pcb_data_t *Ptr, const char *Filename, const char *fmt)
 			rewind(f);
 			map = available[n].plug->map_footprint(available[n].plug, f, fctx.filename, &head, 0);
 			rewind(f);
+			if (map == NULL)
+				goto skip;
 			fctx.subfpname = pcb_fp_map_choose(&PCB->hidlib, map);
 			if (fctx.subfpname == NULL) /* cancel */
 				goto skip;
@@ -457,6 +460,52 @@ static int pcb_write_buffer(FILE *f, pcb_buffer_t *buff, const char *fmt, rnd_bo
 	return res;
 }
 
+int pcb_write_padstack(FILE *f, pcb_pstk_proto_t *proto, const char *fmt)
+{
+	int res = -1/*, newfmt = 0*/;
+	pcb_plug_io_t *p = pcb_io_find_writer(PCB_IOT_PADSTACK, fmt);
+
+	if ((p != NULL) && (p->write_padstack != NULL)) {
+		res = p->write_padstack(p, f, proto);
+		/*newfmt = 1;*/
+	}
+
+/*	if ((res == 0) && (newfmt))
+		PCB->Data->loader = p;*/
+
+	pcb_plug_io_err(&PCB->hidlib, res, "write padstack", NULL);
+	return res;
+}
+
+int pcb_load_padstack(rnd_hidlib_t *hidlib, pcb_pstk_proto_t *proto, const char *fn, const char *fmt)
+{
+	int res = -1, len, n;
+	pcb_find_io_t available[PCB_IO_MAX_FORMATS];
+	int accepts[PCB_IO_MAX_FORMATS]; /* test-parse output */
+	int accept_total = 0;
+	FILE *ft;
+
+	ft = rnd_fopen(hidlib, fn, "r");
+	len = pcb_test_parse_all(ft, fn, fmt, PCB_IOT_PADSTACK, available, accepts, &accept_total, sizeof(available)/sizeof(available[0]), 0, 0);
+	if (ft != NULL)
+		fclose(ft);
+	if (len < 0)
+		return -1;
+
+	/* try all plugins that said it could handle the file */
+	for(n = 0; n < len; n++) {
+		if ((available[n].plug->parse_padstack == NULL) || (!accepts[n])) /* can't parse or doesn't want to parse this file */
+			continue;
+		res = available[n].plug->parse_padstack(available[n].plug, proto, fn);
+		if (res == 0)
+			break;
+	}
+
+	pcb_plug_io_err(hidlib, res, "load padstack", fn);
+	return res;
+}
+
+
 int pcb_write_footprint_data(FILE *f, pcb_data_t *e, const char *fmt, long subc_idx)
 {
 	int res, newfmt = 0;
@@ -539,6 +588,7 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 	pcb_board_t *newPCB = pcb_board_new_(rnd_false);
 	pcb_board_t *oldPCB;
 	rnd_conf_role_t settings_dest;
+	int pres;
 #ifdef DEBUG
 	double elapsed;
 	clock_t start, end;
@@ -561,8 +611,15 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 		default: abort();
 	}
 
+	pcb_crosshair_move_absolute(PCB, RND_COORD_MAX, RND_COORD_MAX); /* make sure the crosshair is not above any object so ch* plugins release their highlights */
+	rnd_hid_notify_crosshair_change(&PCB->hidlib, rnd_true); /* pcb_crosshair_move_absolute()'s side effect is leaving the crosshair notify in false state, flush that */
+
 	/* new data isn't added to the undo list */
-	if (!pcb_parse_pcb(PCB, new_filename, fmt, settings_dest, how & 0x10)) {
+	rnd_hid_menu_merge_inhibit_inc();
+	pres = pcb_parse_pcb(PCB, new_filename, fmt, settings_dest, how & 0x10);
+	rnd_hid_menu_merge_inhibit_dec();
+
+	if (!pres) {
 		pcb_board_remove(oldPCB);
 
 		pcb_board_new_postproc(PCB, 0);
@@ -590,12 +647,12 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 		PCB->loose_subc = PCB->is_footprint;
 
 		/* clear 'changed flag' */
-		pcb_board_set_changed_flag(rnd_false);
+		pcb_board_set_changed_flag(PCB, rnd_false);
 		PCB->hidlib.filename = new_filename;
 		/* just in case a bad file saved file is loaded */
 
 		/* geda/pcb compatibility: use attribute PCB::grid::unit as unit, if present */
-		unit_suffix = rnd_attrib_get(PCB, "PCB::grid::unit");
+		unit_suffix = pcb_attrib_get(PCB, "PCB::grid::unit");
 		if (unit_suffix && *unit_suffix) {
 			lht_node_t *nat = rnd_conf_lht_get_at(RND_CFR_DESIGN, "editor/grid_unit", 0);
 			if (nat == NULL) {
@@ -612,7 +669,7 @@ static int real_load_pcb(const char *Filename, const char *fmt, rnd_bool revert,
 	{
 		extern fgw_error_t pcb_act_GetStyle(fgw_arg_t *res, int argc, fgw_arg_t *argv);
 		fgw_arg_t res, argv;
-		if (RND_ACT_CALL_C(pcb_act_GetStyle, &res, 1, &argv) < 0)
+		if (RND_ACT_CALL_C(&PCB->hidlib, pcb_act_GetStyle, &res, 1, &argv) < 0)
 			pcb_use_route_style_idx(&PCB->RouteStyle, 0);
 	}
 
@@ -737,7 +794,7 @@ int pcb_save_pcb(const char *file, const char *fmt)
 	if (conf_core.editor.io_incomp_popup) {
 		long int len = pcb_view_list_length(&pcb_io_incompat_lst);
 		if (len > 0) {
-			rnd_message(RND_MSG_ERROR, "There were %ld save incompatibility errors.\nData in memory is not affected, but the file created may be slightly broken.\nSee the popup view listing for detauls.\n", len);
+			rnd_message(RND_MSG_ERROR, "There were %ld save incompatibility errors.\nData in memory is not affected, but the file created may be slightly broken.\nSee the popup view listing for details.\n", len);
 			rnd_actionva(&PCB->hidlib, "IOincompatList", conf_core.editor.io_incomp_style, "auto", NULL);
 		}
 	}
@@ -1102,9 +1159,12 @@ void pcb_io_fp_map_append(pcb_plug_fp_map_t **tail, pcb_plug_fp_map_t *head, con
 
 void pcb_io_fp_map_free_fields(pcb_plug_fp_map_t *m)
 {
+/*
+	Do NOTE free tag values, they are allocated by the central fp hash
 	long n;
 	for(n = 0; n < m->tags.used; n++)
 		free(m->tags.array[n]);
+*/
 	vts0_uninit(&m->tags);
 	free(m->name);
 	m->name = NULL;
