@@ -31,15 +31,16 @@
 #define PCB_PLUG_IO_H
 
 #include "global_typedefs.h"
-#include "vtlibrary.h"
 #include <genvector/vts0.h>
 #include <librnd/core/conf.h>
+#include "plug_footprint.h"
 
 typedef enum { /* I/O type bitmask; each bit is one thing to save or load, not all formats support all things */
 	PCB_IOT_PCB        = 1,
 	PCB_IOT_FOOTPRINT  = 2,
 	PCB_IOT_FONT       = 4,
-	PCB_IOT_BUFFER     = 8
+	PCB_IOT_BUFFER     = 8,
+	PCB_IOT_PADSTACK   = 16
 } pcb_plug_iot_t;
 
 /* Returned by map_footprint() to tell what type of footprint(s) a file contains */
@@ -97,6 +98,12 @@ struct pcb_plug_io_s {
 	/* Attempt to load a complete buffer from a file. Return 0 on success. */
 	int (*parse_buffer)(pcb_plug_io_t *ctx, pcb_buffer_t *buff, const char *filename);
 
+	/* Attempt to load padstack prototype */
+	int (*parse_padstack)(pcb_plug_io_t *ctx, pcb_pstk_proto_t *dst, const char *filename);
+
+
+	/* Write a padstack prototype to a file. Return 0 on success. */
+	int (*write_padstack)(pcb_plug_io_t *ctx, FILE *f, pcb_pstk_proto_t *dst);
 
 	/* Write the buffer to a file. Return 0 on success. */
 	int (*write_buffer)(pcb_plug_io_t *ctx, FILE *f, pcb_buffer_t *buff);
@@ -181,6 +188,8 @@ void pcb_print_quoted_string(FILE *, const char *); /* with wrapping in "" */
 int pcb_write_pcb_file(const char *Filename, rnd_bool thePcb, const char *fmt, rnd_bool emergency, rnd_bool subc_only, long subc_idx, int askovr);
 void pcb_set_design_dir(const char *fn);
 int pcb_load_buffer(rnd_hidlib_t *hidlib, pcb_buffer_t *buff, const char *fn, const char *fmt);
+int pcb_write_padstack(FILE *f, pcb_pstk_proto_t *proto, const char *fmt);
+int pcb_load_padstack(rnd_hidlib_t *hidlib, pcb_pstk_proto_t *proto, const char *fn, const char *fmt);
 
 /* Find the plugin that offers the highest write prio for the format */
 pcb_plug_io_t *pcb_io_find_writer(pcb_plug_iot_t typ, const char *fmt);
