@@ -343,9 +343,16 @@ int pcb_poly_subtract(rnd_polyarea_t *np1, pcb_poly_t *p, rnd_bool fnp)
 	return Subtract(np1, p, fnp);
 }
 
+static rnd_polyarea_t *pcb_poly_from_box_bloated_(rnd_box_t * box, rnd_coord_t bloat, rnd_coord_t enforce_clr, rnd_coord_t obj_clr)
+{
+	if ((enforce_clr != 0) && (enforce_clr*2 > obj_clr)) /* in case of poly-side clearance, the bounding box has to be adjusted: original object side clearance removed, larger poly side clearance added */
+		bloat += obj_clr - enforce_clr/2;
+	return rnd_poly_from_rect(box->X1 - bloat, box->X2 + bloat, box->Y1 - bloat, box->Y2 + bloat);
+}
+
 rnd_polyarea_t *pcb_poly_from_box_bloated(rnd_box_t * box, rnd_coord_t bloat)
 {
-	return rnd_poly_from_rect(box->X1 - bloat, box->X2 + bloat, box->Y1 - bloat, box->Y2 + bloat);
+	return pcb_poly_from_box_bloated_(box, bloat, 0, 0);
 }
 
 /* remove the padstack clearance from the polygon */
@@ -398,11 +405,13 @@ static int SubtractArc(pcb_arc_t * arc, pcb_poly_t * p)
 typedef struct {
 	pcb_poly_t *poly;
 	rnd_coord_t clearance;
-} poly_sub_text_t;
+	unsigned sub:1;
+	rnd_polyarea_t *pa; /* in case of sub==0 the result is accumulated here */
+} poly_poly_text_t;
 
 static void poly_sub_text_cb(void *ctx_, pcb_any_obj_t *obj)
 {
-	poly_sub_text_t *ctx = ctx_;
+	poly_poly_text_t *ctx = ctx_;
 	pcb_line_t *line = (pcb_line_t *)obj;
 	pcb_poly_t *poly = (pcb_poly_t *)obj;
 	pcb_arc_t *arc = (pcb_arc_t *)obj;
@@ -421,8 +430,19 @@ static void poly_sub_text_cb(void *ctx_, pcb_any_obj_t *obj)
 	}
 
 	if (np != NULL) {
-		Subtract(np, ctx->poly, rnd_true);
-		ctx->poly->NoHolesValid = 0;
+		if (ctx->sub) { /* subtract from ctx->poly directly (drawing clearance) */
+			Subtract(np, ctx->poly, rnd_true);
+			ctx->poly->NoHolesValid = 0;
+		}
+		else { /* add to ctx->pa (constructing the clearance polygon for other purposes) */
+			if (ctx->pa != NULL) {
+				rnd_polyarea_t *tmp;
+				rnd_polyarea_boolean_free(ctx->pa, np, &tmp, RND_PBO_UNITE);
+				ctx->pa = tmp;
+			}
+			else
+				ctx->pa = np;
+		}
 	}
 }
 
@@ -431,7 +451,7 @@ static rnd_xform_t tsub_xform;
 
 static int SubtractText(pcb_text_t * text, pcb_poly_t * p)
 {
-	poly_sub_text_t sctx;
+	poly_poly_text_t sctx;
 	int by_bbox = !text->tight_clearance;
 
 	if (!PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, text))
@@ -450,11 +470,39 @@ static int SubtractText(pcb_text_t * text, pcb_poly_t * p)
 	/* new method: detailed clearance */
 	sctx.poly = p;
 	sctx.clearance = text->clearance + RND_MM_TO_COORD(0.5);
+	sctx.sub = 1;
 	tsub_info.xform = &tsub_xform;
 	pcb_text_decompose_text(&tsub_info, text, poly_sub_text_cb, &sctx);
 	return 1;
 }
 
+rnd_polyarea_t *pcb_poly_construct_text_clearance(pcb_text_t *text)
+{
+	poly_poly_text_t sctx;
+	pcb_poly_t dummy = {0};
+	int by_bbox = !text->tight_clearance;
+
+	if (!PCB_FLAG_TEST(PCB_FLAG_CLEARLINE, text))
+		return NULL;
+
+	if (by_bbox) {
+		/* old method: clear by bounding box */
+		const rnd_box_t *b = &text->BoundingBox;
+		rnd_coord_t clr = conf_core.design.bloat;
+		return rnd_poly_from_round_rect(b->X1 + conf_core.design.bloat, b->X2 - conf_core.design.bloat, b->Y1 + conf_core.design.bloat, b->Y2 - conf_core.design.bloat, clr);
+	}
+
+	/* new method: detailed clearance */
+	sctx.poly = &dummy;
+	sctx.pa = NULL;
+	sctx.clearance = text->clearance + RND_MM_TO_COORD(0.5);
+	sctx.sub = 0;
+	tsub_info.xform = &tsub_xform;
+	pcb_text_decompose_text(&tsub_info, text, poly_sub_text_cb, &sctx);
+	return sctx.pa;
+}
+
+
 struct cpInfo {
 	const rnd_box_t *other;
 	pcb_data_t *data;
@@ -588,6 +636,9 @@ void pcb_poly_pa_clearance_construct(rnd_polyarea_t **dst, pcb_poly_it_t *it, rn
 	else
 		rnd_polyarea_copy0(dst, it->pa);
 
+	if (clearance == 0)
+		return;
+
 	clearance *= 2;
 
 	/* care about the outer contours only */
@@ -630,7 +681,8 @@ rnd_polyarea_t *pcb_poly_clearance_construct(pcb_poly_t *subpoly, rnd_coord_t *c
 	else
 		clr = subpoly->Clearance/2;
 
-	clr = RND_MAX(clr, in_poly->enforce_clearance);
+	if (in_poly != NULL)
+		clr = RND_MAX(clr, in_poly->enforce_clearance);
 	/* iterate over all islands of a polygon */
 	for(pa = pcb_poly_island_first(subpoly, &it); pa != NULL; pa = pcb_poly_island_next(&it))
 		pcb_poly_pa_clearance_construct(&ret, &it, clr);
@@ -863,7 +915,7 @@ static int UnsubtractPadstack(pcb_data_t *data, pcb_pstk_t *ps, pcb_layer_t *l,
 	rnd_polyarea_t *np;
 
 	/* overlap a bit to prevent gaps from rounding errors */
-	np = pcb_poly_from_box_bloated(&ps->BoundingBox, UNSUBTRACT_BLOAT * 400000);
+	np = pcb_poly_from_box_bloated_(&ps->BoundingBox, UNSUBTRACT_BLOAT * 400000, p->enforce_clearance, ps->Clearance);
 
 	if (!np)
 		return 0;
@@ -884,7 +936,7 @@ static int UnsubtractArc(pcb_arc_t * arc, pcb_layer_t * l, pcb_poly_t * p)
 		return 0;
 
 	/* overlap a bit to prevent gaps from rounding errors */
-	np = pcb_poly_from_box_bloated(&arc->BoundingBox, UNSUBTRACT_BLOAT);
+	np = pcb_poly_from_box_bloated_(&arc->BoundingBox, UNSUBTRACT_BLOAT, p->enforce_clearance, arc->Clearance);
 
 	if (!np)
 		return 0;
@@ -902,7 +954,7 @@ static int UnsubtractLine(pcb_line_t * line, pcb_layer_t * l, pcb_poly_t * p)
 		return 0;
 
 	/* overlap a bit to prevent notches from rounding errors */
-	np = pcb_poly_from_box_bloated(&line->BoundingBox, UNSUBTRACT_BLOAT);
+	np = pcb_poly_from_box_bloated_(&line->BoundingBox, UNSUBTRACT_BLOAT, p->enforce_clearance, line->Clearance);
 
 	if (!np)
 		return 0;
@@ -920,7 +972,7 @@ static int UnsubtractText(pcb_text_t * text, pcb_layer_t * l, pcb_poly_t * p)
 		return 0;
 
 	/* overlap a bit to prevent notches from rounding errors */
-	np = pcb_poly_from_box_bloated(&text->BoundingBox, UNSUBTRACT_BLOAT);
+	np = pcb_poly_from_box_bloated_(&text->BoundingBox, UNSUBTRACT_BLOAT, p->enforce_clearance, text->clearance);
 
 	if (!np)
 		return -1;
@@ -1046,11 +1098,8 @@ rnd_bool pcb_poly_remove_excess_points(pcb_layer_t *Layer, pcb_poly_t *Polygon)
 	return changed;
 }
 
-/* ---------------------------------------------------------------------------
- * returns the index of the polygon point which is the end
- * point of the segment with the lowest distance to the passed
- * coordinates
- */
+/* returns the index of the polygon point which is the end
+   point of the segment with the lowest distance to the passed coordinates */
 rnd_cardinal_t pcb_poly_get_lowest_distance_point(pcb_poly_t *Polygon, rnd_coord_t X, rnd_coord_t Y)
 {
 	double mindistance = (double) RND_MAX_COORD * RND_MAX_COORD;
@@ -1058,12 +1107,10 @@ rnd_cardinal_t pcb_poly_get_lowest_distance_point(pcb_poly_t *Polygon, rnd_coord
 	rnd_cardinal_t n, result = 0;
 
 	/* we calculate the distance to each segment and choose the
-	 * shortest distance. If the closest approach between the
-	 * given point and the projected line (i.e. the segment extended)
-	 * is not on the segment, then the distance is the distance
-	 * to the segment end point.
-	 */
-
+	   shortest distance. If the closest approach between the
+	   given point and the projected line (i.e. the segment extended)
+	   is not on the segment, then the distance is the distance
+	   to the segment end point.*/
 	for (n = 0; n < Polygon->PointN; n++) {
 		double u, dx, dy;
 		ptr1 = &Polygon->Points[pcb_poly_contour_prev_point(Polygon, n)];
@@ -1093,9 +1140,7 @@ rnd_cardinal_t pcb_poly_get_lowest_distance_point(pcb_poly_t *Polygon, rnd_coord
 	return result;
 }
 
-/* ---------------------------------------------------------------------------
- * go back to the previous point of the polygon (undo)
- */
+/* go back to the previous point of the polygon (undo) */
 void pcb_polygon_go_to_prev_point(void)
 {
 	switch (pcb_crosshair.AttachedPolygon.PointN) {
@@ -1123,9 +1168,7 @@ void pcb_polygon_go_to_prev_point(void)
 	}
 }
 
-/* ---------------------------------------------------------------------------
- * go forward to the next point of the polygon (redo)
- */
+/* go forward to the next point of the polygon (redo) */
 void pcb_polygon_go_to_next_point(void)
 {
 	if ((pcb_crosshair.AttachedPolygon.PointN > 0) && (pcb_crosshair.AttachedPolygon.PointN < pcb_crosshair.AttachedPolygon_pts)) {
@@ -1138,9 +1181,7 @@ void pcb_polygon_go_to_next_point(void)
 	}
 }
 
-/* ---------------------------------------------------------------------------
- * close polygon if possible
- */
+/* close polygon if possible */
 void pcb_polygon_close_poly(void)
 {
 	rnd_cardinal_t n = pcb_crosshair.AttachedPolygon.PointN;
@@ -1148,8 +1189,7 @@ void pcb_polygon_close_poly(void)
 	/* check number of points */
 	if (n >= 3) {
 		/* if 45 degree lines are what we want do a quick check
-		 * if closing the polygon makes sense
-		 */
+		   if closing the polygon makes sense */
 		if (!conf_core.editor.all_direction_lines) {
 			rnd_coord_t dx, dy;
 
@@ -1206,7 +1246,7 @@ void pcb_polygon_copy_attached_to_layer(void)
 
 	pcb_poly_init_clip(PCB->Data, layer, polygon);
 	pcb_poly_invalidate_draw(layer, polygon);
-	pcb_board_set_changed_flag(rnd_true);
+	pcb_board_set_changed_flag(PCB, rnd_true);
 
 	/* reset state of attached line */
 	pcb_crosshair.AttachedLine.State = PCB_CH_STATE_FIRST;
@@ -1722,7 +1762,7 @@ void pcb_poly_to_polygons_on_layer(pcb_data_t * Destination, pcb_layer_t * Layer
 	}
 	while ((pa = pa->f) != Input);
 
-	pcb_board_set_changed_flag(rnd_true);
+	pcb_board_set_changed_flag(PCB, rnd_true);
 }
 
 rnd_bool pcb_pline_is_rectangle(rnd_pline_t *pl)
