@@ -33,7 +33,7 @@
  */
 #include "config.h"
 
-#include "hidlib_conf.h"
+#include <librnd/core/hidlib_conf.h>
 
 #include "board.h"
 #include "data.h"
@@ -44,8 +44,8 @@
 #include "draw.h"
 #include "search.h"
 #include "crosshair.h"
-#include "tool.h"
-#include "actions.h"
+#include <librnd/core/tool.h>
+#include <librnd/core/actions.h>
 
 #include "obj_poly.h"
 
@@ -56,16 +56,16 @@ static fgw_error_t pcb_act_MorphPolygon(fgw_arg_t *res, int argc, fgw_arg_t *arg
 {
 	int op;
 
-	PCB_ACT_CONVARG(1, FGW_KEYWORD, MorphPolygon, op = fgw_keyword(&argv[1]));
+	RND_ACT_CONVARG(1, FGW_KEYWORD, MorphPolygon, op = fgw_keyword(&argv[1]));
 
 	switch(op) {
 		case F_Object:
 			{
-				pcb_coord_t x, y;
+				rnd_coord_t x, y;
 				int type;
 				void *ptr1, *ptr2, *ptr3;
 
-				pcb_hid_get_coords("Select an Object", &x, &y, 0);
+				rnd_hid_get_coords("Select an Object", &x, &y, 0);
 				if ((type = pcb_search_screen(x, y, PCB_OBJ_POLY, &ptr1, &ptr2, &ptr3)) != PCB_OBJ_VOID) {
 					pcb_poly_morph((pcb_layer_t *) ptr1, (pcb_poly_t *) ptr3);
 					pcb_draw();
@@ -85,7 +85,7 @@ static fgw_error_t pcb_act_MorphPolygon(fgw_arg_t *res, int argc, fgw_arg_t *arg
 			pcb_undo_inc_serial();
 			break;
 	}
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -96,10 +96,10 @@ static fgw_error_t pcb_act_Polygon(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	int op;
 	
-	PCB_ACT_CONVARG(1, FGW_KEYWORD, Polygon, op = fgw_keyword(&argv[1]));
+	RND_ACT_CONVARG(1, FGW_KEYWORD, Polygon, op = fgw_keyword(&argv[1]));
 
-	if ((argc > 1) && ((pcbhl_conf.editor.mode == PCB_MODE_POLYGON) || (pcbhl_conf.editor.mode == PCB_MODE_POLYGON_HOLE))) {
-		pcb_notify_crosshair_change(pcb_false);
+	if ((argc > 1) && ((rnd_conf.editor.mode == pcb_crosshair.tool_poly) || (rnd_conf.editor.mode == pcb_crosshair.tool_poly_hole))) {
+		rnd_hid_notify_crosshair_change(RND_ACT_HIDLIB, rnd_false);
 		switch(op) {
 			/* close open polygon if possible */
 		case F_Close:
@@ -116,16 +116,19 @@ static fgw_error_t pcb_act_Polygon(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			pcb_polygon_go_to_prev_point();
 			break;
 		}
-		pcb_notify_crosshair_change(pcb_true);
+		rnd_hid_notify_crosshair_change(RND_ACT_HIDLIB, rnd_true);
 	}
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
 
-pcb_action_t polygon_action_list[] = {
+static rnd_action_t polygon_action_list[] = {
 	{"MorphPolygon", pcb_act_MorphPolygon, pcb_acth_MorphPolygon, pcb_acts_MorphPolygon},
 	{"Polygon", pcb_act_Polygon, pcb_acth_Polygon, pcb_acts_Polygon}
 };
 
-PCB_REGISTER_ACTIONS_FUNC(polygon_action_list, NULL)
+void pcb_poly_act_init2(void)
+{
+	RND_REGISTER_ACTIONS(polygon_action_list, NULL);
+}
