@@ -75,12 +75,12 @@ static fgw_error_t pcb_act_AddRats(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	switch (op) {
 		case F_AllRats:
 			if (pcb_net_add_all_rats(PCB, flgs | PCB_RATACC_INFO) > 0)
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(PCB, rnd_true);
 			break;
 		case F_SelectedRats:
 		case F_Selected:
 			if (pcb_net_add_all_rats(PCB, flgs | PCB_RATACC_INFO | PCB_RATACC_ONLY_SELECTED) > 0)
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(PCB, rnd_true);
 			break;
 		case F_Close:
 			small = RND_SQUARE(RND_MAX_COORD);
@@ -101,7 +101,7 @@ static fgw_error_t pcb_act_AddRats(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 				PCB_FLAG_SET(PCB_FLAG_SELECTED, shorty);
 				pcb_rat_invalidate_draw(shorty);
 				pcb_draw();
-				pcb_center_display((shorty->Point2.X + shorty->Point1.X) / 2, (shorty->Point2.Y + shorty->Point1.Y) / 2);
+				pcb_center_display(PCB, (shorty->Point2.X + shorty->Point1.X) / 2, (shorty->Point2.Y + shorty->Point1.Y) / 2);
 			}
 			break;
 
@@ -186,12 +186,12 @@ static fgw_error_t pcb_act_DeleteRats(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	switch(op) {
 		case F_AllRats:
 			if (pcb_rats_destroy(rnd_false))
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(PCB, rnd_true);
 			break;
 		case F_SelectedRats:
 		case F_Selected:
 			if (pcb_rats_destroy(rnd_true))
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(PCB, rnd_true);
 			break;
 
 		default:
