@@ -53,7 +53,7 @@ struct pcb_ratspatch_line_s {
 
 
 /* Single-word netlist class names */
-const char *pcb_netlist_names[PCB_NUM_NETLISTS];
+extern const char *pcb_netlist_names[PCB_NUM_NETLISTS];
 
 /* Allocate and append a patch line to the patch list */
 void pcb_ratspatch_append(pcb_board_t *pcb, pcb_rats_patch_op_t op, const char *id, const char *a1, const char *a2, int undoable);
@@ -93,6 +93,6 @@ typedef enum {            /* netn is always the net name, unless specified other
 
 /* Call cb() for each item to output; PCB_PTRE_INFO* is calculated/called only
    if need_info_lines is true; the pcb pointer is used for looking up connections */
-int pcb_rats_patch_export(pcb_board_t *pcb, pcb_ratspatch_line_t *pat, pcb_bool need_info_lines, void (*cb)(void *ctx, pcb_rats_patch_export_ev_t ev, const char *netn, const char *key, const char *val), void *ctx);
+int pcb_rats_patch_export(pcb_board_t *pcb, pcb_ratspatch_line_t *pat, rnd_bool need_info_lines, void (*cb)(void *ctx, pcb_rats_patch_export_ev_t ev, const char *netn, const char *key, const char *val), void *ctx);
 
 #endif
