@@ -35,11 +35,14 @@
 #include <librnd/core/conf.h>
 #include <librnd/core/misc_util.h>
 #include "board.h"
+#include "undo.h"
 #include "funchash_core.h"
 #include "conf_core.h"
+#include "event.h"
 
 pcb_route_style_t pcb_custom_route_style;
 
+static const char rst_cookie[] = "core route style";
 
 static rnd_coord_t pcb_get_num(char **s, const char *default_unit)
 {
@@ -69,11 +72,9 @@ char *pcb_route_string_make(vtroutestyle_t *styles)
 	return str.array; /* this is the only allocation made, return this and don't uninit */
 }
 
-/* ----------------------------------------------------------------------
- * parses the routes definition string which is a colon separated list of
- * comma separated Name, Dimension, Dimension, Dimension, Dimension
- * e.g. Signal,20,40,20,10:Power,40,60,28,10:...
- */
+/* parses the routes definition string which is a colon separated list of
+   comma separated Name, Dimension, Dimension, Dimension, Dimension
+   e.g. Signal,20,40,20,10:Power,40,60,28,10:... */
 int pcb_route_string_parse1(char **str, pcb_route_style_t *routeStyle, const char *default_unit)
 {
 	char *s = *str;
@@ -115,7 +116,7 @@ int pcb_route_string_parse1(char **str, pcb_route_style_t *routeStyle, const cha
 		goto error;
 	routeStyle->Hole = pcb_get_num(&s, default_unit);
 	/* for backwards-compatibility, we use a 10-mil default
-	 * for styles which omit the clearance specification. */
+	   for styles which omit the clearance specification. */
 	if (*s != ',')
 		routeStyle->Clearance = RND_MIL_TO_COORD(10);
 	else {
@@ -244,3 +245,156 @@ int pcb_get_style_size(int funcid, rnd_coord_t * out, int type, int size_id)
 	}
 	return 0;
 }
+
+
+
+typedef struct {
+	pcb_board_t *pcb;
+	int idx;
+	pcb_route_style_t rst;
+	enum { RST_SET, RST_NEW, RST_DEL } cmd;
+} undo_rst_t;
+
+static int undo_rst_swap(void *udata)
+{
+	undo_rst_t *g = udata;
+	pcb_route_style_t *rst;
+
+	if (g->cmd != RST_NEW) {
+		rst = vtroutestyle_get(&g->pcb->RouteStyle, g->idx, 0);
+		if (rst == NULL) {
+			rnd_message(RND_MSG_ERROR, "undo_rst_swap(): internal error: route %d does not exist\b", g->idx);
+			return -1;
+		}
+	}
+	else
+		rst = vtroutestyle_alloc_insert(&g->pcb->RouteStyle, g->idx, 1);
+
+	rnd_swap(pcb_route_style_t, *rst, g->rst);
+
+	if (g->cmd == RST_DEL)
+		vtroutestyle_remove(&g->pcb->RouteStyle, g->idx, 1);
+
+	/* invert new/del */
+	if (g->cmd == RST_NEW) g->cmd = RST_DEL;
+	else if (g->cmd == RST_DEL) g->cmd = RST_NEW;
+
+
+	rnd_event(&g->pcb->hidlib, PCB_EVENT_ROUTE_STYLES_CHANGED, NULL);
+	pcb_board_set_changed_flag(g->pcb, 1);
+
+	return 0;
+}
+
+static void undo_rst_print(void *udata, char *dst, size_t dst_len)
+{
+	undo_rst_t *g = udata;
+
+	rnd_snprintf(dst, dst_len, "route style: thick=%.03$mH textt=%.03$mH texts=%.03$mH Clearance=%.03$mH texts=%.03$mH proto=%ld",
+		g->rst.Thick, g->rst.textt, g->rst.texts, g->rst.Clearance, (long)(g->rst.via_proto_set ? g->rst.via_proto : -1));
+}
+
+static const uundo_oper_t undo_rst = {
+	rst_cookie,
+	NULL,
+	undo_rst_swap,
+	undo_rst_swap,
+	undo_rst_print
+};
+
+
+int pcb_route_style_change(pcb_board_t *pcb, int rstidx, rnd_coord_t *thick, rnd_coord_t *textt, int *texts, rnd_coord_t *clearance, rnd_cardinal_t *via_proto, rnd_bool undoable)
+{
+	undo_rst_t gtmp, *g = &gtmp;
+	pcb_route_style_t *rst = vtroutestyle_get(&pcb->RouteStyle, rstidx, 0);
+
+	if (rst == NULL)
+		return -1;
+
+	if (undoable) g = pcb_undo_alloc(pcb, &undo_rst, sizeof(undo_rst_t));
+
+	g->pcb = pcb;
+	g->idx = rstidx;
+	g->rst = *rst;
+	g->cmd = RST_SET;
+	if (thick != NULL)      g->rst.Thick = *thick;
+	if (textt != NULL)      g->rst.textt = *textt;
+	if (texts != NULL)      g->rst.texts = *texts;
+	if (clearance != NULL)  g->rst.Clearance = *clearance;
+	if (via_proto != NULL) {
+		g->rst.via_proto = *via_proto;
+		g->rst.via_proto_set = (*via_proto != -1);
+			
+	}
+
+	undo_rst_swap(g);
+	if (undoable) pcb_undo_inc_serial();
+
+	return 0;
+}
+
+int pcb_route_style_change_name(pcb_board_t *pcb, int rstidx, const char *new_name, rnd_bool undoable)
+{
+	undo_rst_t gtmp, *g = &gtmp;
+	pcb_route_style_t *rst = vtroutestyle_get(&pcb->RouteStyle, rstidx, 0);
+
+	if (rst == NULL)
+		return -1;
+
+	if (undoable) g = pcb_undo_alloc(pcb, &undo_rst, sizeof(undo_rst_t));
+
+	g->pcb = pcb;
+	g->idx = rstidx;
+	g->rst = *rst;
+	g->cmd = RST_SET;
+	strncpy(g->rst.name, new_name, sizeof(g->rst.name));
+	undo_rst_swap(g);
+	if (undoable) pcb_undo_inc_serial();
+
+	return 0;
+}
+
+int pcb_route_style_new(pcb_board_t *pcb, const char *name, rnd_bool undoable)
+{
+
+	undo_rst_t gtmp, *g = &gtmp;
+	if (undoable) g = pcb_undo_alloc(pcb, &undo_rst, sizeof(undo_rst_t));
+
+	g->pcb = pcb;
+	g->idx = vtroutestyle_len(&PCB->RouteStyle);
+	g->cmd = RST_NEW;
+
+	memset(&g->rst, 0, sizeof(g->rst));
+
+	strncpy(g->rst.name, name, sizeof(g->rst.name));
+
+	g->rst.Thick = conf_core.design.line_thickness;
+	g->rst.textt = conf_core.design.text_thickness;
+	g->rst.texts = conf_core.design.text_scale;
+	g->rst.Clearance = conf_core.design.clearance;
+	g->rst.Diameter = conf_core.design.via_thickness*2;
+	g->rst.Hole = conf_core.design.via_drilling_hole;
+
+	undo_rst_swap(g);
+	if (undoable) pcb_undo_inc_serial();
+
+	return g->idx;
+}
+
+int pcb_route_style_del(pcb_board_t *pcb, int idx, rnd_bool undoable)
+{
+	undo_rst_t gtmp, *g = &gtmp;
+	if (undoable) g = pcb_undo_alloc(pcb, &undo_rst, sizeof(undo_rst_t));
+
+	g->pcb = pcb;
+	g->idx = idx;
+	g->cmd = RST_DEL;
+
+	memset(&g->rst, 0, sizeof(g->rst));
+
+	undo_rst_swap(g);
+	if (undoable) pcb_undo_inc_serial();
+
+	return g->idx;
+}
+
