@@ -60,3 +60,18 @@ extern pcb_route_style_t pcb_custom_route_style;
 /* helper: get route style size for a function and selected object type.
    size_id: 0=main size; 1=2nd size (drill); 2=clearance */
 int pcb_get_style_size(int funcid, rnd_coord_t * out, int type, int size_id);
+
+
+/*** Undoable changes to route styles ***/
+
+/* Change a field. Returns 0 on success. */
+int pcb_route_style_change(pcb_board_t *pcb, int rstidx, rnd_coord_t *thick, rnd_coord_t *textt, int *texts, rnd_coord_t *clearance, rnd_cardinal_t *via_proto, rnd_bool undoable);
+
+/* Change the name. Returns 0 on success. */
+int pcb_route_style_change_name(pcb_board_t *pcb, int rstidx, const char *new_name, rnd_bool undoable);
+
+/* Returns the index (counted from 0) or -1 on error */
+int pcb_route_style_new(pcb_board_t *pcb, const char *name, rnd_bool undoable);
+
+/* Returns 0 on success. */
+int pcb_route_style_del(pcb_board_t *pcb, int idx, rnd_bool undoable);
