@@ -214,9 +214,10 @@ do { \
  * if len is non-NULL:
  *  returns a list of object IDs matched the search and loads len with the
  *  length of the list. Returns NULL on no match.
+ * Always limit layer search to layer types matching lyt (and never limit globals)
  */
 TODO("cleanup: should be rewritten with generic ops and rtree")
-static long int *ListBlock_(pcb_board_t *pcb, rnd_box_t *Box, rnd_bool Flag, int *len, void *(cb)(void *ctx, pcb_any_obj_t *obj), void *ctx)
+static long int *ListBlock_(pcb_board_t *pcb, rnd_box_t *Box, rnd_bool Flag, pcb_layer_type_t lyt, int *len, void *(cb)(void *ctx, pcb_any_obj_t *obj), void *ctx)
 {
 	int changed = 0;
 	int used = 0, alloced = 0;
@@ -275,6 +276,9 @@ do { \
 	{
 		unsigned int lflg = pcb_layer_flags(pcb, n);
 
+		if ((lflg &lyt) == 0)
+			continue;
+
 		if ((lflg & PCB_LYT_SILK) && (PCB_LAYERFLG_ON_VISIBLE_SIDE(lflg))) {
 			if (!(pcb_silk_on(pcb) || !Flag))
 				continue;
@@ -292,7 +296,7 @@ do { \
 					&& !PCB_FLAG_TEST(PCB_FLAG_LOCK, line)
 					&& PCB_FLAG_TEST(PCB_FLAG_SELECTED, line) != Flag) {
 				append(PCB_OBJ_LINE, layer, line);
-				if (layer->meta.real.vis)
+				if ((len != NULL) && layer->meta.real.vis)
 					pcb_line_invalidate_draw(layer, line);
 			}
 		}
@@ -303,7 +307,7 @@ do { \
 					&& !PCB_FLAG_TEST(PCB_FLAG_LOCK, arc)
 					&& PCB_FLAG_TEST(PCB_FLAG_SELECTED, arc) != Flag) {
 				append(PCB_OBJ_ARC, layer, arc);
-				if (layer->meta.real.vis)
+				if ((len != NULL) && layer->meta.real.vis)
 					pcb_arc_invalidate_draw(layer, arc);
 			}
 		}
@@ -315,7 +319,7 @@ do { \
 						&& !PCB_FLAG_TEST(PCB_FLAG_LOCK, text)
 						&& PCB_FLAG_TEST(PCB_FLAG_SELECTED, text) != Flag) {
 					append(PCB_OBJ_TEXT, layer, text);
-					if (pcb_text_is_visible(PCB, layer, text))
+					if ((len != NULL) && pcb_text_is_visible(PCB, layer, text))
 						pcb_text_invalidate_draw(layer, text);
 				}
 			}
@@ -327,7 +331,7 @@ do { \
 					&& !PCB_FLAG_TEST(PCB_FLAG_LOCK, polygon)
 					&& PCB_FLAG_TEST(PCB_FLAG_SELECTED, polygon) != Flag) {
 				append(PCB_OBJ_POLY, layer, polygon);
-				if (layer->meta.real.vis)
+				if ((len != NULL) && layer->meta.real.vis)
 					pcb_poly_invalidate_draw(layer, polygon);
 			}
 		}
@@ -338,7 +342,7 @@ do { \
 					&& !PCB_FLAG_TEST(PCB_FLAG_LOCK, gfx)
 					&& PCB_FLAG_TEST(PCB_FLAG_SELECTED, gfx) != Flag) {
 				append(PCB_OBJ_GFX, layer, gfx);
-				if (layer->meta.real.vis)
+				if ((len != NULL) && layer->meta.real.vis)
 					pcb_gfx_invalidate_draw(layer, gfx);
 			}
 		}
@@ -364,8 +368,10 @@ do { \
 					list[used] = subc->ID;
 					used++;
 				}
-				changed = 1;
-				DrawSubc(subc);
+				if (len != NULL) {
+					changed = 1;
+					DrawSubc(subc);
+				}
 			}
 		}
 		PCB_END_LOOP;
@@ -379,14 +385,14 @@ do { \
 					&& !PCB_FLAG_TEST(PCB_FLAG_LOCK, padstack)
 					&& PCB_FLAG_TEST(PCB_FLAG_SELECTED, padstack) != Flag) {
 				append(PCB_OBJ_PSTK, padstack, padstack);
-				if (pcb->pstk_on)
+				if ((len != NULL) && pcb->pstk_on)
 					pcb_pstk_invalidate_draw(padstack);
 			}
 		}
 		PCB_END_LOOP;
 	}
 
-	if (changed) {
+	if ((len != NULL) && changed) {
 		pcb_draw();
 		pcb_undo_inc_serial();
 	}
@@ -476,13 +482,20 @@ rnd_bool pcb_select_block(pcb_board_t *pcb, rnd_box_t *Box, rnd_bool flag, rnd_b
  */
 long int *pcb_list_block(pcb_board_t *pcb, rnd_box_t *Box, int *len)
 {
-	return ListBlock_(pcb, Box, 1, len, NULL, NULL);
+	return ListBlock_(pcb, Box, 1, PCB_LYT_ANYWHERE|PCB_LYT_ANYTHING, len, NULL, NULL);
 }
 
 int pcb_list_block_cb(pcb_board_t *pcb, rnd_box_t *Box, void *(cb)(void *ctx, pcb_any_obj_t *obj), void *ctx)
 {
 	int len = 0;
-	ListBlock_(pcb, Box, -1, &len, cb, ctx);
+	ListBlock_(pcb, Box, -1, PCB_LYT_ANYWHERE|PCB_LYT_ANYTHING, &len, cb, ctx);
+	return len;
+}
+
+int pcb_list_lyt_block_cb(pcb_board_t *pcb, pcb_layer_type_t lyt, rnd_box_t *Box, void *(cb)(void *ctx, pcb_any_obj_t *obj), void *ctx)
+{
+	int len = 0;
+	ListBlock_(pcb, Box, -1, lyt, ((cb == NULL) ? &len : NULL), cb, ctx);
 	return len;
 }
 
