@@ -28,8 +28,9 @@
 #define PCB_THERMAL_H
 
 #include "obj_common.h"
+#include "operation.h"
 #include "layer.h"
-#include "polygon1_gen.h"
+#include <librnd/poly/polygon1_gen.h>
 
 typedef enum pcb_thermal_e {
 	/* bit 0 and 1: shape */
@@ -53,14 +54,23 @@ pcb_thermal_t pcb_thermal_str2bits(const char *str);
    all words. */
 const char *pcb_thermal_bits2str(pcb_thermal_t *bits);
 
+/* Converts all bits of a thermal bitmask to a string that is:
+   - empty if there is no thermal
+   - starts with n, o, x or @ for no-shape, round, sharp or solid
+   - ends in d if diagonal
+*/
+void pcb_thermal_bits2chars(char dst[3], pcb_thermal_t bits);
 
-pcb_polyarea_t *pcb_thermal_area(pcb_board_t *p, pcb_any_obj_t *obj, pcb_layer_id_t lid);
-pcb_polyarea_t *pcb_thermal_area_line(pcb_board_t *pcb, pcb_line_t *line, pcb_layer_id_t lid);
-pcb_polyarea_t *pcb_thermal_area_poly(pcb_board_t *pcb, pcb_poly_t *poly, pcb_layer_id_t lid);
-pcb_polyarea_t *pcb_thermal_area_pstk(pcb_board_t *pcb, pcb_pstk_t *ps, pcb_layer_id_t lid);
 
-unsigned char pcb_themal_style_old2new(pcb_cardinal_t t);
-pcb_cardinal_t pcb_themal_style_new2old(unsigned char t);
+rnd_polyarea_t *pcb_thermal_area(pcb_board_t *p, pcb_any_obj_t *obj, rnd_layer_id_t lid, pcb_poly_t *in_poly);
+rnd_polyarea_t *pcb_thermal_area_line(pcb_board_t *pcb, pcb_line_t *line, rnd_layer_id_t lid, pcb_poly_t *in_poly);
+rnd_polyarea_t *pcb_thermal_area_poly(pcb_board_t *pcb, pcb_poly_t *poly, rnd_layer_id_t lid, pcb_poly_t *in_poly);
+rnd_polyarea_t *pcb_thermal_area_pstk(pcb_board_t *pcb, pcb_pstk_t *ps, rnd_layer_id_t lid, pcb_poly_t *in_poly);
+
+unsigned char pcb_themal_style_old2new(rnd_cardinal_t t);
+rnd_cardinal_t pcb_themal_style_new2old(unsigned char t);
+
+void *pcb_anyop_change_thermal(pcb_opctx_t *ctx, pcb_any_obj_t *ps);
 
 
 #endif
