@@ -1,5 +1,4 @@
-/*#define PCB_PADSTACK_STRUCT_ONLY
-#include "obj_pstk.h"*/
+#include "obj_pstk.h"
 
 #define GVT_DONT_UNDEF
 #include "vtpadstack.h"
