@@ -42,6 +42,7 @@ enum {
 	ST_ATOM, /* unquoted atom */
 	ST_DQ,   /* in double quote */
 	ST_SQ,   /* in single quote */
+	ST_BRC,  /* in brace */
 	ST_DQBS, /* in double quote, previous char was a backslash */
 	ST_SQBS, /* in single quote, previous char was a backslash */
 	ST_QEND, /* quote end - need to be followed by a whitepsace or ) */
@@ -128,6 +129,11 @@ int gsx_parse_char(gsx_parse_t *ctx, int chr)
 				goto append;
 			break;
 
+		case ST_BRC:
+			stbs = ST_BRC;
+			qc = '}';
+			goto quote;
+
 		case ST_QEND:
 			if (isspace(chr)) {
 				if (ctx->depth == 0)
@@ -190,6 +196,14 @@ int gsx_parse_char(gsx_parse_t *ctx, int chr)
 					ctx->pstate = ST_SQ;
 					break;
 
+				case '{':
+					if (ctx->brace_quote) {
+						ctx->pstate = ST_BRC;
+						break;
+					}
+					ctx->pstate = ST_ATOM;
+					goto append;
+
 				case '(':
 					open:;
 					ctx->cb(ctx, GSX_EV_OPEN, "(");
