@@ -30,68 +30,68 @@
 #include "layer.h"
 #include "layer_ui.h"
 /*#include "acompnet_conf.h"*/
-#include "actions.h"
-#include "plugins.h"
+#include <librnd/core/actions.h>
+#include <librnd/core/plugins.h>
 #include "search.h"
 #include "polygon.h"
-#include "conf.h"
+#include <librnd/core/conf.h>
 #include "conf_core.h"
-#include "compat_misc.h"
-#include "error.h"
+#include <librnd/core/compat_misc.h>
+#include <librnd/core/error.h>
 #include "meshgraph.h"
 
 static pcb_layer_t *ly;
 
 typedef struct {
-	pcb_coord_t x, y;
-	pcb_coord_t r;
+	rnd_coord_t x, y;
+	rnd_coord_t r;
 } overlap_t;
 
-static pcb_r_dir_t overlap(const pcb_box_t *box, void *closure)
+static rnd_r_dir_t overlap(const rnd_box_t *box, void *closure)
 {
 	pcb_any_obj_t *obj = (pcb_any_obj_t *)box;
 	overlap_t *ovl = (overlap_t *)closure;
 	switch(obj->type) {
 		case PCB_OBJ_LINE:
 			if (pcb_is_point_in_line(ovl->x, ovl->y, ovl->r, (pcb_any_line_t *)obj))
-				return PCB_R_DIR_CANCEL;
+				return RND_R_DIR_CANCEL;
 			break;
 		case PCB_OBJ_ARC:
 			if (pcb_is_point_on_arc(ovl->x, ovl->y, ovl->r, (pcb_arc_t *)obj))
-				return PCB_R_DIR_CANCEL;
+				return RND_R_DIR_CANCEL;
 			break;
 		case PCB_OBJ_TEXT:
 			if (pcb_is_point_in_box(ovl->x, ovl->y, &obj->bbox_naked, ovl->r))
-				return PCB_R_DIR_CANCEL;
+				return RND_R_DIR_CANCEL;
 			break;
 		case PCB_OBJ_POLY:
 			if (pcb_poly_is_point_in_p(ovl->x, ovl->y, ovl->r, (pcb_poly_t *)obj))
-				return PCB_R_DIR_CANCEL;
+				return RND_R_DIR_CANCEL;
 			break;
 		default: break;
 	}
-	return PCB_R_DIR_NOT_FOUND;
+	return RND_R_DIR_NOT_FOUND;
 }
 
 TODO("move this to search.[ch]")
 /* Search for object(s) on a specific layer */
-static pcb_r_dir_t pcb_search_on_layer(pcb_layer_t *layer, const pcb_box_t *bbox, pcb_r_dir_t (*cb)(const pcb_box_t *box, void *closure), void *closure)
+static rnd_r_dir_t pcb_search_on_layer(pcb_layer_t *layer, const rnd_box_t *bbox, rnd_r_dir_t (*cb)(const rnd_box_t *box, void *closure), void *closure)
 {
-	pcb_r_dir_t res, fin = 0;
+	rnd_r_dir_t res, fin = 0;
 
-	if ((res = pcb_r_search(layer->line_tree, bbox, NULL, cb, closure, NULL)) == PCB_R_DIR_CANCEL)
+	if ((res = rnd_r_search(layer->line_tree, bbox, NULL, cb, closure, NULL)) == RND_R_DIR_CANCEL)
 		return res;
 	fin |= res;
 
-	if ((res = pcb_r_search(layer->arc_tree, bbox, NULL, cb, closure, NULL)) == PCB_R_DIR_CANCEL)
+	if ((res = rnd_r_search(layer->arc_tree, bbox, NULL, cb, closure, NULL)) == RND_R_DIR_CANCEL)
 		return res;
 	fin |= res;
 
-	if ((res = pcb_r_search(layer->polygon_tree, bbox, NULL, cb, closure, NULL)) == PCB_R_DIR_CANCEL)
+	if ((res = rnd_r_search(layer->polygon_tree, bbox, NULL, cb, closure, NULL)) == RND_R_DIR_CANCEL)
 		return res;
 	fin |= res;
 
-	if ((res = pcb_r_search(layer->text_tree, bbox, NULL, cb, closure, NULL)) == PCB_R_DIR_CANCEL)
+	if ((res = rnd_r_search(layer->text_tree, bbox, NULL, cb, closure, NULL)) == RND_R_DIR_CANCEL)
 		return res;
 	fin |= res;
 
@@ -105,20 +105,20 @@ pcb_flag_t flg_mesh_pt;
 static void acompnet_mesh_addpt(pcb_meshgraph_t *gr, pcb_layer_t *layer, double x, double y, int score, double sep)
 {
 	overlap_t ovl;
-	pcb_box_t bbox;
+	rnd_box_t bbox;
 
-	x = pcb_round(x);
-	y = pcb_round(y);
+	x = rnd_round(x);
+	y = rnd_round(y);
 
 	ovl.x = x;
 	ovl.y = y;
-	ovl.r = pcb_round(sep/2-1);
+	ovl.r = rnd_round(sep/2-1);
 	bbox.X1 = x - ovl.r;
 	bbox.X2 = x + ovl.r;
 	bbox.Y1 = y - ovl.r;
 	bbox.Y2 = y + ovl.r;
 
-	if (pcb_search_on_layer(layer, &bbox, overlap, &ovl) == PCB_R_DIR_NOT_FOUND) {
+	if (pcb_search_on_layer(layer, &bbox, overlap, &ovl) == RND_R_DIR_NOT_FOUND) {
 		bbox.X1 = x;
 		bbox.X2 = x+1;
 		bbox.Y1 = y;
@@ -181,12 +181,12 @@ static fgw_error_t pcb_act_acompnet(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	acompnet_mesh(&gr, PCB_CURRLAYER(PCB));
 
 	{ /* temporary hack for testing: fixed, off-mesh start/end */
-		pcb_box_t bbox;
-		bbox.X1 = PCB_MM_TO_COORD(6.35); bbox.X2 = bbox.X1+1;
-		bbox.Y1 = PCB_MM_TO_COORD(21.5); bbox.Y2 = bbox.Y1+1;
+		rnd_box_t bbox;
+		bbox.X1 = RND_MM_TO_COORD(6.35); bbox.X2 = bbox.X1+1;
+		bbox.Y1 = RND_MM_TO_COORD(21.5); bbox.Y2 = bbox.Y1+1;
 		is = pcb_msgr_add_node(&gr, &bbox, 0);
-		bbox.X1 = PCB_MM_TO_COORD(12); bbox.X2 = bbox.X1+1;
-		bbox.Y1 = PCB_MM_TO_COORD(3.8); bbox.Y2 = bbox.Y1+1;
+		bbox.X1 = RND_MM_TO_COORD(12); bbox.X2 = bbox.X1+1;
+		bbox.Y1 = RND_MM_TO_COORD(3.8); bbox.Y2 = bbox.Y1+1;
 		ie = pcb_msgr_add_node(&gr, &bbox, 0);
 	}
 
@@ -205,11 +205,11 @@ static fgw_error_t pcb_act_acompnet(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 TODO("use pcb_drc_lines(), probably during A*, saving mid-point, and draw pairs of lines here");
 		}
 	}
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
-pcb_action_t acompnet_action_list[] = {
+rnd_action_t acompnet_action_list[] = {
 	{"acompnet", pcb_act_acompnet, pcb_acth_acompnet, pcb_acts_acompnet},
 };
 
@@ -219,20 +219,20 @@ int pplg_check_ver_acompnet(int ver_needed) { return 0; }
 
 void pplg_uninit_acompnet(void)
 {
-	pcb_remove_actions_by_cookie(acompnet_cookie);
+	rnd_remove_actions_by_cookie(acompnet_cookie);
 	pcb_uilayer_free_all_cookie(acompnet_cookie);
 }
 
 int pplg_init_acompnet(void)
 {
-	static pcb_color_t clr;
+	static rnd_color_t clr;
 
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
 	if (clr.str[0] != '#')
-		pcb_color_load_str(&clr, "#c09920");
+		rnd_color_load_str(&clr, "#c09920");
 
-	PCB_REGISTER_ACTIONS(acompnet_action_list, acompnet_cookie)
+	RND_REGISTER_ACTIONS(acompnet_action_list, acompnet_cookie)
 	ly = pcb_uilayer_alloc(acompnet_cookie, "autocomp-net", &clr);
 
 	return 0;
