@@ -41,11 +41,13 @@
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/hid_dad.h>
 #include <librnd/core/hid_dad_tree.h>
+#include <librnd/core/hid_menu.h>
 #include "search.h"
 #include "draw.h"
 #include "select.h"
 #include "asm_conf.h"
 #include "../src_plugins/asm/conf_internal.c"
+#include "menu_internal.c"
 
 conf_asm_t conf_asm;
 #define ASM_CONF_FN "asm.conf"
@@ -146,7 +148,7 @@ static char *templ_exec(pcb_subc_t *subc, gdl_list_t *temp)
 			gds_append(&s, ',');
 		switch(t->type) {
 			case TT_ATTR:
-				tmp = rnd_attribute_get(&subc->Attributes, t->key);
+				tmp = pcb_attribute_get(&subc->Attributes, t->key);
 				if (tmp != NULL)
 					gds_append_str(&s, tmp);
 				break;
@@ -362,7 +364,7 @@ static void asm_row_selected(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid
 	box.X2 = RND_MAX_COORD;
 	box.Y2 = RND_MAX_COORD;
 	if (pcb_select_block(PCB, &box, rnd_false, rnd_false, rnd_false))
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(PCB, rnd_true);
 
 	if (row == NULL) {
 		goto skip;
@@ -563,9 +565,9 @@ fgw_error_t pcb_act_asm(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 					if (type == PCB_OBJ_SUBC) {
 						int m;
 						row[1] = (char *)sc->refdes;
-						row[2] = rnd_attribute_get(&sc->Attributes, "footprint");
-						row[3] = rnd_attribute_get(&sc->Attributes, "value");
-						row[4] = rnd_attribute_get(&sc->Attributes, "asm::comment");
+						row[2] = pcb_attribute_get(&sc->Attributes, "footprint");
+						row[3] = pcb_attribute_get(&sc->Attributes, "value");
+						row[4] = pcb_attribute_get(&sc->Attributes, "asm::comment");
 						row[5] = "";
 						for(m = 1; m < 6; m++)
 							if (row[m] == NULL)
@@ -633,6 +635,7 @@ int pplg_check_ver_asm(int ver_needed) { return 0; }
 
 void pplg_uninit_asm(void)
 {
+	rnd_hid_menu_unload(rnd_gui, asm_cookie);
 	rnd_remove_actions_by_cookie(asm_cookie);
 	rnd_conf_unreg_file(ASM_CONF_FN, asm_conf_internal);
 	rnd_conf_unreg_fields("plugins/asm1/");
@@ -648,5 +651,7 @@ int pplg_init_asm(void)
 
 	RND_REGISTER_ACTIONS(asm_action_list, asm_cookie)
 
+	rnd_hid_menu_load(rnd_gui, NULL, asm_cookie, 175, NULL, 0, asm_menu, "plugin: asm");
+
 	return 0;
 }
