@@ -43,7 +43,7 @@ typedef struct {
 			char *arg;
 		} desc;
 		struct {
-			pcb_hid_t *exporter;
+			rnd_hid_t *exporter;
 			int argc;
 			char **argv;
 		} plugin;
@@ -73,9 +73,9 @@ typedef struct {
 #include <genvector/genvector_undef.h>
 
 typedef struct {
-	pcb_hidlib_t *hidlib;
+	rnd_hidlib_t *hidlib;
 	char *prefix;            /* strdup'd file name prefix from the last prefix command */
-	pcb_hid_t *exporter;
+	rnd_hid_t *exporter;
 	unsigned partial:1;      /* when 1, there are objects marked with the EXPORTSEL flag */
 
 	unsigned has_partial:1;  /* the code has partial in it so an initial flag reset is needed */
