@@ -34,17 +34,16 @@
 #include "flag_str.h"
 #include "layer.h"
 #include "diag_conf.h"
-#include "actions.h"
-#include "plugins.h"
-#include "conf.h"
-#include "error.h"
-#include "event.h"
+#include <librnd/core/actions.h>
+#include <librnd/core/plugins.h>
+#include <librnd/core/conf.h>
+#include <librnd/core/error.h>
+#include <librnd/core/event.h>
 #include "integrity.h"
-#include "hid.h"
-#include "hid_attrib.h"
-#include "hid_dad.h"
+#include <librnd/core/hid.h>
+#include <librnd/core/hid_attrib.h>
+#include <librnd/core/hid_dad.h>
 #include "search.h"
-#include "macro.h"
 #include "plug_footprint.h"
 #include "plug_io.h"
 #include "funchash_core.h"
@@ -64,28 +63,28 @@ static fgw_error_t pcb_act_DumpConf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	int op;
 
-	PCB_ACT_CONVARG(1, FGW_KEYWORD, DumpConf, op = fgw_keyword(&argv[1]));
+	RND_ACT_CONVARG(1, FGW_KEYWORD, DumpConf, op = fgw_keyword(&argv[1]));
 
 	switch(op) {
 		case F_Native:
 		{
 			int verbose = 0;
 			const char *prefix = "";
-			PCB_ACT_MAY_CONVARG(2, FGW_INT, DumpConf, verbose = argv[2].val.nat_int);
-			PCB_ACT_MAY_CONVARG(3, FGW_STR, DumpConf, prefix = argv[3].val.str);
+			RND_ACT_MAY_CONVARG(2, FGW_INT, DumpConf, verbose = argv[2].val.nat_int);
+			RND_ACT_MAY_CONVARG(3, FGW_STR, DumpConf, prefix = argv[3].val.str);
 			conf_dump(stdout, prefix, verbose, NULL);
 		}
 		break;
 		case F_Lihata:
 		{
-		conf_role_t role;
+		rnd_conf_role_t role;
 		const char *srole, *prefix = "";
-		PCB_ACT_CONVARG(2, FGW_STR, DumpConf, srole = argv[2].val.str);
-		PCB_ACT_MAY_CONVARG(3, FGW_STR, DumpConf, prefix = argv[3].val.str);
-		role = pcb_conf_role_parse(srole);
-		if (role == CFR_invalid) {
-			pcb_message(PCB_MSG_ERROR, "Invalid role: '%s'\n", argv[1]);
-			PCB_ACT_IRES(1);
+		RND_ACT_CONVARG(2, FGW_STR, DumpConf, srole = argv[2].val.str);
+		RND_ACT_MAY_CONVARG(3, FGW_STR, DumpConf, prefix = argv[3].val.str);
+		role = rnd_conf_role_parse(srole);
+		if (role == RND_CFR_invalid) {
+			rnd_message(RND_MSG_ERROR, "Invalid role: '%s'\n", argv[1]);
+			RND_ACT_IRES(1);
 			return 0;
 		}
 		if (pcb_conf_main_root[role] != NULL) {
@@ -101,11 +100,11 @@ static fgw_error_t pcb_act_DumpConf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		}
 		break;
 		default:
-			PCB_ACT_FAIL(DumpConf);
+			RND_ACT_FAIL(DumpConf);
 			return 1;
 	}
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -117,30 +116,30 @@ static const char pcb_acth_EvalConf[] = "Perform various operations on the confi
 static fgw_error_t pcb_act_EvalConf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	const char *path;
-	conf_native_t *nat;
+	rnd_conf_native_t *nat;
 	int role;
 
-	PCB_ACT_CONVARG(1, FGW_STR, EvalConf, path = argv[1].val.str);
+	RND_ACT_CONVARG(1, FGW_STR, EvalConf, path = argv[1].val.str);
 
-	nat = pcb_conf_get_field(path);
+	nat = rnd_conf_get_field(path);
 	if (nat == NULL) {
-		pcb_message(PCB_MSG_ERROR, "EvalConf: invalid path %s - no such config setting\n", path);
-		PCB_ACT_IRES(-1);
+		rnd_message(RND_MSG_ERROR, "EvalConf: invalid path %s - no such config setting\n", path);
+		RND_ACT_IRES(-1);
 		return 0;
 	}
 
 	printf("Conf node %s\n", path);
-	for(role = 0; role < CFR_max_real; role++) {
+	for(role = 0; role < RND_CFR_max_real; role++) {
 		lht_node_t *n;
-		printf(" Role: %s\n", pcb_conf_role_name(role));
-		n = pcb_conf_lht_get_at(role, path, 0);
+		printf(" Role: %s\n", rnd_conf_role_name(role));
+		n = rnd_conf_lht_get_at(role, path, 0);
 		if (n != NULL) {
-			conf_policy_t pol = -1;
-			long prio = pcb_conf_default_prio[role];
+			rnd_conf_policy_t pol = -1;
+			long prio = rnd_conf_default_prio[role];
 
 
-			if (pcb_conf_get_policy_prio(n, &pol, &prio) == 0)
-				printf("  * policy=%s\n  * prio=%ld\n", pcb_conf_policy_name(pol), prio);
+			if (rnd_conf_get_policy_prio(n, &pol, &prio) == 0)
+				printf("  * policy=%s\n  * prio=%ld\n", rnd_conf_policy_name(pol), prio);
 
 			if (n->file_name != NULL)
 				printf("  * from=%s:%d.%d\n", n->file_name, n->line, n->col);
@@ -154,9 +153,9 @@ static fgw_error_t pcb_act_EvalConf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 
 	printf(" Native:\n");
-	pcb_conf_print_native((conf_pfn)pcb_fprintf, stdout, "  ", 1, nat);
+	rnd_conf_print_native((rnd_conf_pfn)rnd_fprintf, stdout, "  ", 1, nat);
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -167,10 +166,10 @@ extern lht_doc_t *pcb_conf_main_root[];
 static fgw_error_t pcb_act_DumpLayers(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	int op = -2, g, n, used;
-	pcb_layer_id_t arr[128]; /* WARNING: this assumes we won't have more than 128 layers */
-	pcb_layergrp_id_t garr[128]; /* WARNING: this assumes we won't have more than 128 layers */
+	rnd_layer_id_t arr[128]; /* WARNING: this assumes we won't have more than 128 layers */
+	rnd_layergrp_id_t garr[128]; /* WARNING: this assumes we won't have more than 128 layers */
 
-	PCB_ACT_MAY_CONVARG(1, FGW_KEYWORD, DumpLayers, op = fgw_keyword(&argv[1]));
+	RND_ACT_MAY_CONVARG(1, FGW_KEYWORD, DumpLayers, op = fgw_keyword(&argv[1]));
 
 	if (op == F_All) {
 		printf("Per group:\n");
@@ -207,15 +206,15 @@ static fgw_error_t pcb_act_DumpLayers(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			}
 		}
 
-		PCB_ACT_IRES(0);
+		RND_ACT_IRES(0);
 		return 0;
 	}
 
 	printf("Max: theoretical=%d current_board=%d\n", PCB_MAX_LAYER, pcb_max_layer(PCB));
 	used = pcb_layer_list_any(PCB, PCB_LYT_ANYTHING | PCB_LYT_ANYWHERE | PCB_LYT_VIRTUAL, arr, sizeof(arr)/sizeof(arr[0]));
 	for(n = 0; n < used; n++) {
-		pcb_layer_id_t layer_id = arr[n];
-		pcb_layergrp_id_t grp = pcb_layer_get_group(PCB, layer_id);
+		rnd_layer_id_t layer_id = arr[n];
+		rnd_layergrp_id_t grp = pcb_layer_get_group(PCB, layer_id);
 		printf(" [%lx] %04x group=%ld %s\n", layer_id, pcb_layer_flags(PCB, layer_id), grp, pcb_layer_name(PCB->Data, layer_id));
 	}
 
@@ -223,7 +222,7 @@ static fgw_error_t pcb_act_DumpLayers(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	used = pcb_layer_list(PCB, PCB_LYT_COPPER | PCB_LYT_BOTTOM, arr, sizeof(arr)/sizeof(arr[0]));
 	printf("All %d bottom copper layers are:\n", used);
 	for(n = 0; n < used; n++) {
-		pcb_layer_id_t layer_id = arr[n];
+		rnd_layer_id_t layer_id = arr[n];
 		printf(" [%lx] %s \n", layer_id, PCB->Data->Layer[layer_id].name);
 	}
 
@@ -231,15 +230,15 @@ static fgw_error_t pcb_act_DumpLayers(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	used = pcb_layergrp_list(PCB, PCB_LYT_COPPER, garr, sizeof(garr)/sizeof(garr[0]));
 	printf("All %d groups containing copper layers are:\n", used);
 	for(g = 0; g < used; g++) {
-		pcb_layergrp_id_t group_id = garr[g];
+		rnd_layergrp_id_t group_id = garr[g];
 		printf(" group %ld (%d layers)\n", group_id, PCB->LayerGroups.grp[group_id].len);
 		for(n = 0; n < PCB->LayerGroups.grp[group_id].len; n++) {
-			pcb_layer_id_t layer_id = PCB->LayerGroups.grp[group_id].lid[n];
+			rnd_layer_id_t layer_id = PCB->LayerGroups.grp[group_id].lid[n];
 			printf("  [%lx] %s\n", layer_id, PCB->Data->Layer[layer_id].name);
 		}
 	}
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -259,7 +258,7 @@ static void print_font(pcb_font_t *f, const char *prefix)
 	}
 
 	name = f->name == NULL ? "<anon>" : f->name;
-	pcb_printf("%s: %d %s; dim: %$$mm * %$$mm glyphs: %d (letter: %d, digit: %d)\n", prefix, f->id, name, f->MaxWidth, f->MaxHeight, g, gletter, gdigit);
+	rnd_printf("%s: %d %s; dim: %$$mm * %$$mm glyphs: %d (letter: %d, digit: %d)\n", prefix, f->id, name, f->MaxWidth, f->MaxHeight, g, gletter, gdigit);
 }
 
 static const char dump_fonts_syntax[] = "dumpfonts()\n";
@@ -275,7 +274,7 @@ static fgw_error_t pcb_act_DumpFonts(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 	else
 		printf(" <no extra font loaded>\n");
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -287,7 +286,7 @@ static fgw_error_t pcb_act_DumpUndo(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	printf("Undo:\n");
 	undo_dump();
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 #endif
@@ -304,7 +303,7 @@ static void dump_data(pcb_data_t *data, dd_flags what, int ind, const char *pare
 	ind++;
 	for(o = pcb_data_first(&it, data, PCB_OBJ_CLASS_REAL); o != NULL; o = pcb_data_next(&it)) {
 		const char *type = pcb_obj_type_name(o->type);
-		pcb_coord_t cx, cy;
+		rnd_coord_t cx, cy;
 
 		if ((what & DD_COPPER_ONLY) && (o->type == PCB_OBJ_SUBC))
 			goto skip;
@@ -318,7 +317,7 @@ static void dump_data(pcb_data_t *data, dd_flags what, int ind, const char *pare
 		cx = (o->BoundingBox.X1+o->BoundingBox.X2)/2;
 		cy = (o->BoundingBox.Y1+o->BoundingBox.Y2)/2;
 		printf("%*s %s", ind, "", type);
-		pcb_printf(" #%ld %mm;%mm ", o->ID, cx, cy);
+		rnd_printf(" #%ld %mm;%mm ", o->ID, cx, cy);
 
 		if (parent != NULL)
 			printf("%s", parent);
@@ -345,7 +344,7 @@ static fgw_error_t pcb_act_DumpData(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	printf("DumpData:\n");
 	dump_data(PCB->Data, what, 0, NULL);
 	printf("\n");
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -354,7 +353,7 @@ static const char integrity_help[] = "perform integrirty check on the current bo
 static fgw_error_t pcb_act_integrity(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	pcb_check_integrity(PCB);
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -362,10 +361,10 @@ static int dumpflag_cb(void *ctx, gds_t *s, const char **input)
 {
 	pcb_flag_bits_t *flag = (pcb_flag_bits_t *)ctx;
 	switch(**input) {
-		case 'm': (*input)++; pcb_append_printf(s, "%lx", flag->mask); break;
+		case 'm': (*input)++; rnd_append_printf(s, "%lx", flag->mask); break;
 		case 'M': (*input)++; gds_append_str(s, flag->mask_name); break;
 		case 'N': (*input)++; gds_append_str(s, flag->name); break;
-		case 't': (*input)++; pcb_append_printf(s, "%lx", flag->object_types); break;
+		case 't': (*input)++; rnd_append_printf(s, "%lx", flag->object_types); break;
 		case 'H': (*input)++; gds_append_str(s, flag->name); break;
 		default:
 			return -1;
@@ -381,26 +380,26 @@ static fgw_error_t pcb_act_dumpflags(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	const char *default_fmt = "%m (%M %N) for %t:\n  %H\n";
 	const char *fmt = default_fmt;
 
-	PCB_ACT_MAY_CONVARG(1, FGW_STR, dumpflags, fmt = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(1, FGW_STR, dumpflags, fmt = argv[1].val.str);
 
 	for(n = 0; n < pcb_object_flagbits_len; n++) {
 		char *tmp;
-		tmp = pcb_strdup_subst(fmt, dumpflag_cb, &pcb_object_flagbits[n], PCB_SUBST_PERCENT /*| PCB_SUBST_BACKSLASH*/);
+		tmp = rnd_strdup_subst(fmt, dumpflag_cb, &pcb_object_flagbits[n], RND_SUBST_PERCENT /*| RND_SUBST_BACKSLASH*/);
 		printf("%s", tmp);
 		free(tmp);
 	}
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
-static void ev_ui_post(pcb_hidlib_t *hidlib, void *user_data, int argc, pcb_event_arg_t argv[])
+static void ev_ui_post(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
 {
 
 	if (conf_diag.plugins.diag.auto_integrity) {
 		static int cnt = 0;
 		if ((cnt++ % 100) == 0) {
-			pcb_trace("Number of integrity checks so far: %d\n", cnt);
+			rnd_trace("Number of integrity checks so far: %d\n", cnt);
 		}
 		pcb_check_integrity(PCB);
 	}
@@ -410,7 +409,7 @@ static const char pcb_acts_d1[] = "d1()\n";
 static const char pcb_acth_d1[] = "debug action for development";
 static fgw_error_t pcb_act_d1(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -429,7 +428,7 @@ static fgw_error_t pcb_act_DumpIDs(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			printf("%ld: %p %ld %s%s\n", e->key, (void *)o, o->ID, pcb_obj_type_name(o->type), (o->ID == e->key) ? "" : " BROKEN");
 	}
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -452,9 +451,9 @@ static fgw_error_t pcb_act_Find2Perf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 	PCB_END_LOOP;
 
-	pcb_message(PCB_MSG_INFO, "Measuring find.c peformance for %f seconds starting from %ld pins...\n", duration, pins);
+	rnd_message(RND_MSG_INFO, "Measuring find.c peformance for %f seconds starting from %ld pins...\n", duration, pins);
 
-	from = pcb_dtime();
+	from = rnd_dtime();
 	end = from + duration;
 	do {
 		PCB_SUBC_LOOP(PCB->Data) {
@@ -466,10 +465,10 @@ static fgw_error_t pcb_act_Find2Perf(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		}
 		PCB_END_LOOP;
 		its++;
-		now = pcb_dtime();
+		now = rnd_dtime();
 	} while(now < end);
-	pcb_message(PCB_MSG_INFO, "find2.c peformance: %d %f pin find per second\n", its, (double)its * (double)pins / (now-from));
-	PCB_ACT_IRES(0);
+	rnd_message(RND_MSG_INFO, "find2.c peformance: %d %f pin find per second\n", its, (double)its * (double)pins / (now-from));
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -485,13 +484,13 @@ static fgw_error_t pcb_act_DumpLibFootprint(fgw_arg_t *res, int argc, fgw_arg_t
 	pcb_fp_fopen_ctx_t fctx;
 	int n, want_bbox = 0, want_origin = 0;
 
-	PCB_ACT_CONVARG(1, FGW_STR, DumpLibFootprint, fpn = argv[1].val.str);
+	RND_ACT_CONVARG(1, FGW_STR, DumpLibFootprint, fpn = argv[1].val.str);
 
 	for(n = 2; n < argc; n++) {
-		PCB_ACT_CONVARG(n, FGW_STR, DumpLibFootprint, opt = argv[n].val.str);
+		RND_ACT_CONVARG(n, FGW_STR, DumpLibFootprint, opt = argv[n].val.str);
 		if (strcmp(opt, "bbox") == 0) want_bbox = 1;
 		else if (strcmp(opt, "origin") == 0) want_origin = 1;
-		else PCB_ACT_FAIL(DumpLibFootprint);
+		else RND_ACT_FAIL(DumpLibFootprint);
 	}
 
 	f = pcb_fp_fopen(&conf_core.rc.library_search_paths, fpn, &fctx, PCB->Data);
@@ -511,22 +510,23 @@ static fgw_error_t pcb_act_DumpLibFootprint(fgw_arg_t *res, int argc, fgw_arg_t
 		/* print exrtas */
 		if (want_bbox || want_origin) {
 			pcb_buffer_clear(PCB, &SCRATCH);
-			if (!pcb_buffer_load_footprint(&SCRATCH, fpn, NULL)) {
-				PCB_ACT_IRES(1);
+			if (!pcb_buffer_load_footprint(&SCRATCH, fctx.filename, NULL)) {
+				RND_ACT_IRES(1);
 				return 0;
 			}
 		}
 
 		if (want_bbox)
-			pcb_printf(DLF_PREFIX "bbox mm %mm %mm %mm %mm\n", SCRATCH.BoundingBox.X1, SCRATCH.BoundingBox.Y1, SCRATCH.BoundingBox.X2, SCRATCH.BoundingBox.Y2);
+			rnd_printf(DLF_PREFIX "bbox mm %mm %mm %mm %mm\n", SCRATCH.BoundingBox.X1, SCRATCH.BoundingBox.Y1, SCRATCH.BoundingBox.X2, SCRATCH.BoundingBox.Y2);
 		if (want_origin)
-			pcb_printf(DLF_PREFIX "origin mm %mm %mm\n", SCRATCH.X, SCRATCH.Y);
+			rnd_printf(DLF_PREFIX "origin mm %mm %mm\n", SCRATCH.X, SCRATCH.Y);
 
-		PCB_ACT_IRES(0);
+		RND_ACT_IRES(0);
 	}
 	else {
+		pcb_fp_fclose(f, &fctx);
 		printf(DLF_PREFIX "error file not found\n");
-		PCB_ACT_IRES(1);
+		RND_ACT_IRES(1);
 	}
 
 	return 0;
@@ -539,28 +539,27 @@ static const char pcb_acts_forcecolor[] = "forcecolor(#RRGGBB)\n";
 static const char pcb_acth_forcecolor[] = "change selected objects' color to #RRGGBB, reset if does not start with '#'";
 static fgw_error_t pcb_act_forcecolor(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	pcb_coord_t x, y;
+	rnd_coord_t x, y;
 	int type;
 	void *ptr1, *ptr2, *ptr3;
 	const char *new_color;
 
-	pcb_message(PCB_MSG_ERROR, "pcb_acth_forcecolor() is temporarily disabled.\n");
-	return -1;
+	RND_ACT_CONVARG(1, FGW_STR, forcecolor, new_color = argv[1].val.str);
 
-	PCB_ACT_CONVARG(1, FGW_STR, forcecolor, new_color = argv[1].val.str);
+	rnd_hid_get_coords("Click on object to change", &x, &y, 0);
 
-	pcb_hid_get_coords("Click on object to change", &x, &y, 0);
-
-	if ((type = pcb_search_screen(x, y, PCB_FORCECOLOR_TYPES, &ptr1, &ptr2, &ptr3)) != PCB_OBJ_VOID){
-TODO("color: figure where to store this");
-/*		strncpy(((pcb_any_obj_t *)ptr2)->override_color, new_color, sizeof(((pcb_any_obj_t *)ptr2)->override_color)-1);*/
+	if ((type = pcb_search_screen(x, y, PCB_FORCECOLOR_TYPES, &ptr1, &ptr2, &ptr3)) != PCB_OBJ_VOID) {
+		pcb_any_obj_t *o = (pcb_any_obj_t *)ptr2;
+		if (o->override_color == NULL)
+			o->override_color = malloc(sizeof(rnd_color_t));
+		rnd_color_load_str(o->override_color, new_color);
 	}
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
-pcb_action_t diag_action_list[] = {
+rnd_action_t diag_action_list[] = {
 	{"dumpconf", pcb_act_DumpConf, pcb_acth_DumpConf, pcb_acts_DumpConf},
 	{"dumplayers", pcb_act_DumpLayers, pcb_acth_DumpLayers, pcb_acts_DumpLayers},
 	{"dumpfonts", pcb_act_DumpFonts, dump_fonts_help, dump_fonts_syntax},
@@ -584,20 +583,20 @@ int pplg_check_ver_diag(int ver_needed) { return 0; }
 
 void pplg_uninit_diag(void)
 {
-	pcb_remove_actions_by_cookie(diag_cookie);
-	pcb_conf_unreg_fields("plugins/diag/");
-	pcb_event_unbind_allcookie(diag_cookie);
+	rnd_remove_actions_by_cookie(diag_cookie);
+	rnd_conf_unreg_fields("plugins/diag/");
+	rnd_event_unbind_allcookie(diag_cookie);
 }
 
 int pplg_init_diag(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
-	pcb_conf_reg_field(conf_diag, field,isarray,type_name,cpath,cname,desc,flags);
+	rnd_conf_reg_field(conf_diag, field,isarray,type_name,cpath,cname,desc,flags);
 #include "diag_conf_fields.h"
 
-	pcb_event_bind(PCB_EVENT_USER_INPUT_POST, ev_ui_post, NULL, diag_cookie);
-	PCB_REGISTER_ACTIONS(diag_action_list, diag_cookie)
+	rnd_event_bind(RND_EVENT_USER_INPUT_POST, ev_ui_post, NULL, diag_cookie);
+	RND_REGISTER_ACTIONS(diag_action_list, diag_cookie)
 	return 0;
 }
