@@ -34,7 +34,7 @@
 #include <librnd/core/hid_dad.h>
 #include <librnd/core/plugins.h>
 #include "funchash_core.h"
-#include "../src_plugins/lib_hid_common/dialogs_conf.h"
+#include <librnd/plugins/lib_hid_common/dialogs_conf.h>
 
 /* from lib_hid_common */
 extern conf_dialogs_t dialogs_conf;
@@ -63,6 +63,12 @@ extern conf_dialogs_t dialogs_conf;
 #include "dlg_view.h"
 #include "dlg_pref.h"
 
+#include "adialogs_conf.h"
+#include "conf_internal.c"
+
+conf_adialogs_t adialogs_conf;
+#define ADIALOGS_CONF_FN "adialogs.conf"
+
 extern const char pcb_acts_dlg_confval_edit[];
 extern const char pcb_acth_dlg_confval_edit[];
 extern fgw_error_t pcb_act_dlg_confval_edit(fgw_arg_t *res, int argc, fgw_arg_t *argv);
@@ -112,6 +118,8 @@ void pplg_uninit_dialogs(void)
 	rnd_remove_actions_by_cookie(dialogs_cookie);
 	pcb_view_dlg_uninit();
 	pcb_dlg_fontsel_uninit();
+
+	rnd_conf_unreg_file(ADIALOGS_CONF_FN, adialogs_conf_internal);
 	rnd_conf_unreg_fields("plugins/dialogs/");
 }
 
@@ -119,6 +127,12 @@ int pplg_init_dialogs(void)
 {
 	RND_API_CHK_VER;
 
+#define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
+	rnd_conf_reg_field(adialogs_conf, field,isarray,type_name,cpath,cname,desc,flags);
+#include "adialogs_conf_fields.h"
+
+	rnd_conf_reg_file(ADIALOGS_CONF_FN, adialogs_conf_internal);
+
 	RND_REGISTER_ACTIONS(dialogs_action_list, dialogs_cookie)
 	pcb_dlg_pref_init();
 	pcb_dlg_pstklib_init();
