@@ -69,6 +69,10 @@ static void fe_attr_chg(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *a
 
 	/* Note: this function is called upon each change so only one of these will be non-zero: */
 
+	if (set || clr)
+		pcb_undo_add_obj_to_flag(ctx->obj);
+
+
 	if (set != 0)
 		pcb_flag_change(ctx->pcb, PCB_CHGFLG_SET, set, ctx->obj_type, ctx->ptr1, ctx->obj, ctx->obj);
 
@@ -130,7 +134,7 @@ fgw_error_t pcb_act_FlagEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			for(n = 0; n < pcb_object_flagbits_len; n++) {
 				if (pcb_object_flagbits[n].object_types & ctx.obj_type) {
 					RND_DAD_BEGIN_HBOX(dlg);
-						RND_DAD_BOOL(dlg, "");
+						RND_DAD_BOOL(dlg);
 							RND_DAD_HELP(dlg, pcb_object_flagbits[n].help);
 						ctx.wid[ctx.len] = RND_DAD_CURRENT(dlg);
 						ctx.flag_bit[ctx.len] = pcb_object_flagbits[n].mask;
