@@ -34,11 +34,13 @@
 #include <librnd/core/hid_inlines.h>
 #include <librnd/core/hid_dad.h>
 #include <librnd/core/hid_dad_tree.h>
+#include <librnd/core/safe_fs.h>
 #include "obj_pstk.h"
 #include "obj_pstk_inlines.h"
 #include "obj_text_draw.h"
 #include "obj_pstk_draw.h"
 #include "undo_old.h"
+#include "plug_io.h"
 #include "select.h"
 #include "search.h"
 #include "dlg_padstack.h"
@@ -375,6 +377,91 @@ static void pstklib_proto_dup(void *hid_ctx, void *caller_data, rnd_hid_attribut
 	pstklib_proto_new_(hid_ctx, caller_data, attr, 1);
 }
 
+static char *proto_save_fn = NULL, *proto_load_fn = NULL;
+
+static void pstklib_save(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	pstk_lib_ctx_t *ctx = caller_data;
+	pcb_data_t *data = get_data(ctx, ctx->subc_id, NULL);
+	rnd_hid_row_t *row = rnd_dad_tree_get_selected(&ctx->dlg[ctx->wlist]);
+	pcb_pstk_proto_t *proto;
+	FILE *f;
+	char *old_fn;
+
+	if (data == NULL)
+		return;
+
+	if (row == NULL) {
+		rnd_message(RND_MSG_ERROR, "First select a prototype to save\n");
+		return;
+	}
+
+
+	proto = pcb_pstk_get_proto_(data, strtol(row->cell[0], NULL, 10));
+	if (proto == NULL)
+		return;
+
+	if (proto_save_fn == NULL)
+		proto_save_fn = rnd_strdup("padstack.lht");
+	old_fn = proto_save_fn;
+	proto_save_fn = rnd_gui->fileselect(rnd_gui, "Save padstack", "Select a file the padstack prototype is saved to", old_fn, ".lht", NULL, "padstack", 0, NULL);
+	if (proto_save_fn == NULL)
+		return; /* cancel */
+	free(old_fn);
+
+	f = rnd_fopen(&ctx->pcb->hidlib, proto_save_fn, "w");
+	if (f == NULL) {
+		rnd_message(RND_MSG_ERROR, "Failed to open %s for write.\n", proto_save_fn);
+		return;
+	}
+
+	if (pcb_write_padstack(f, proto, "lihata") == 0)
+		rnd_message(RND_MSG_INFO, "Padstack saved to %s.\n", proto_save_fn);
+	else
+		rnd_message(RND_MSG_ERROR, "Padstack not saved to %s.\n", proto_save_fn);
+}
+
+static void pstklib_load(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	pstk_lib_ctx_t *ctx = caller_data;
+	pcb_data_t *data = get_data(ctx, ctx->subc_id, NULL);
+	rnd_hid_row_t *row = rnd_dad_tree_get_selected(&ctx->dlg[ctx->wlist]);
+	pcb_pstk_proto_t *proto;
+	char *old_fn;
+	rnd_hid_attr_val_t hv;
+
+	if (data == NULL)
+		return;
+
+	if (row == NULL) {
+		rnd_message(RND_MSG_ERROR, "First select a prototype to load into\n");
+		return;
+	}
+
+	proto = pcb_pstk_get_proto_(data, strtol(row->cell[0], NULL, 10));
+	if (proto == NULL)
+		return;
+
+	if (proto_load_fn == NULL)
+		proto_load_fn = rnd_strdup("padstack.lht");
+	old_fn = proto_load_fn;
+	proto_load_fn = rnd_gui->fileselect(rnd_gui, "Save padstack", "Select a file the padstack prototype is loaded from", old_fn, ".lht", NULL, "padstack", RND_HID_FSD_READ, NULL);
+	if (proto_load_fn == NULL)
+		return; /* cancel */
+	free(old_fn);
+
+	if (pcb_load_padstack(&ctx->pcb->hidlib, proto, proto_load_fn, NULL) == 0)
+		rnd_message(RND_MSG_INFO, "Padstack loaded from %s.\n", proto_load_fn);
+	else
+		rnd_message(RND_MSG_ERROR, "Padstack failed to load from %s.\n", proto_load_fn);
+
+	proto->parent = data;
+
+	/* redraw */
+	hv.str = NULL;
+	rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wprev, &hv);
+}
+
 static void pstklib_proto_switch(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr_btn)
 {
 	pstk_lib_ctx_t *ctx = caller_data;
@@ -444,7 +531,7 @@ static void pstklib_proto_select(void *hid_ctx, void *caller_data, rnd_hid_attri
 	}
 
 	if (changed) {
-		pcb_board_set_changed_flag(rnd_true);
+		pcb_board_set_changed_flag(PCB, rnd_true);
 		rnd_gui->invalidate_all(rnd_gui);
 	}
 }
@@ -558,18 +645,26 @@ rnd_cardinal_t pcb_dlg_pstklib(pcb_board_t *pcb, long subc_id, rnd_bool modal, c
 						RND_DAD_HELP(ctx->dlg, "Update prototype usage stats and\nremove prototypes that are not\nused by any padstack");
 						RND_DAD_CHANGE_CB(ctx->dlg, pstklib_del_unused);
 				RND_DAD_END(ctx->dlg);
+				RND_DAD_BEGIN_HBOX(ctx->dlg);
+					RND_DAD_BUTTON(ctx->dlg, "Load...");
+						RND_DAD_HELP(ctx->dlg, "Replace the selected padstack with one loaded from a file");
+						RND_DAD_CHANGE_CB(ctx->dlg, pstklib_load);
+					RND_DAD_BUTTON(ctx->dlg, "Save...");
+						RND_DAD_HELP(ctx->dlg, "Save the selected padstack to a file");
+						RND_DAD_CHANGE_CB(ctx->dlg, pstklib_save);
+				RND_DAD_END(ctx->dlg);
 			RND_DAD_END(ctx->dlg);
 
 			/* right */
 			RND_DAD_BEGIN_VBOX(ctx->dlg);
 				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-				RND_DAD_PREVIEW(ctx->dlg, pstklib_expose, NULL, NULL, NULL, 200, 200, ctx);
+				RND_DAD_PREVIEW(ctx->dlg, pstklib_expose, NULL, NULL, NULL, NULL, 200, 200, ctx);
 					RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 					ctx->wprev = RND_DAD_CURRENT(ctx->dlg);
 
 				RND_DAD_BEGIN_TABLE(ctx->dlg, 2);
 					RND_DAD_LABEL(ctx->dlg, "Grid:");
-					RND_DAD_COORD(ctx->dlg, "");
+					RND_DAD_COORD(ctx->dlg);
 						ctx->wgrid = RND_DAD_CURRENT(ctx->dlg);
 						RND_DAD_MINMAX(ctx->dlg, RND_MM_TO_COORD(0.01), RND_MM_TO_COORD(10));
 						RND_DAD_DEFAULT_NUM(ctx->dlg, (rnd_coord_t)RND_MM_TO_COORD(1));
@@ -585,11 +680,11 @@ rnd_cardinal_t pcb_dlg_pstklib(pcb_board_t *pcb, long subc_id, rnd_bool modal, c
 					for(n = 0; n < pcb_proto_num_layers; n++) {
 						RND_DAD_LABEL(ctx->dlg, pcb_proto_layers[n].name);
 						RND_DAD_BEGIN_HBOX(ctx->dlg);
-							RND_DAD_BOOL(ctx->dlg, "");
+							RND_DAD_BOOL(ctx->dlg);
 								RND_DAD_DEFAULT_NUM(ctx->dlg, 1);
 								RND_DAD_CHANGE_CB(ctx->dlg, pstklib_update_prv);
 								ctx->wlayerv[n] = RND_DAD_CURRENT(ctx->dlg);
-							RND_DAD_BOOL(ctx->dlg, "");
+							RND_DAD_BOOL(ctx->dlg);
 								RND_DAD_DEFAULT_NUM(ctx->dlg, (pcb_proto_layers[n].mask == (PCB_LYT_TOP | PCB_LYT_COPPER)));
 								RND_DAD_CHANGE_CB(ctx->dlg, pstklib_update_layerc);
 								ctx->wlayerc[n] = RND_DAD_CURRENT(ctx->dlg);
@@ -666,4 +761,7 @@ void pcb_dlg_pstklib_uninit(void)
 	for(e = htip_first(&pstk_libs); e != NULL; e = htip_next(&pstk_libs, e))
 		pstklib_close_cb(e->value, 0);
 	htip_uninit(&pstk_libs);
+	free(proto_save_fn);
+	free(proto_load_fn);
+	proto_save_fn = proto_load_fn = NULL;
 }
