@@ -51,6 +51,8 @@
 
 #include "dlg_library.h"
 
+#include "adialogs_conf.h"
+
 static const char *library_cookie = "dlg_library";
 
 #define MAX_PARAMS 128
@@ -182,12 +184,16 @@ TODO("Use rich text for this with explicit wrap marks\n");
 
 static void timed_update_preview_(library_ctx_t *ctx, const char *otext)
 {
-	if (pcb_buffer_load_footprint(PCB_PASTEBUFFER, otext, NULL)) {
-		rnd_tool_select_by_name(&PCB->hidlib, "buffer");
-		if (pcb_subclist_length(&PCB_PASTEBUFFER->Data->subc) != 0)
-			library_update_preview(ctx, pcb_subclist_first(&PCB_PASTEBUFFER->Data->subc), NULL);
-		rnd_gui->invalidate_all(rnd_gui);
+	if (otext != NULL) {
+		if (pcb_buffer_load_footprint(PCB_PASTEBUFFER, otext, NULL)) {
+			rnd_tool_select_by_name(&PCB->hidlib, "buffer");
+			if (pcb_subclist_length(&PCB_PASTEBUFFER->Data->subc) != 0)
+				library_update_preview(ctx, pcb_subclist_first(&PCB_PASTEBUFFER->Data->subc), NULL);
+			rnd_gui->invalidate_all(rnd_gui);
+		}
 	}
+	else
+		pcb_buffer_clear(PCB, PCB_PASTEBUFFER);
 	ctx->timer_active = 0;
 	rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->wpend, 1);
 	rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->wnopend, 0);
@@ -212,7 +218,7 @@ static void timed_update_preview(library_ctx_t *ctx, int active)
 	if (active) {
 		rnd_hidval_t user_data;
 		user_data.ptr = ctx;
-		ctx->timer = rnd_gui->add_timer(rnd_gui, timed_update_preview_cb, 500, user_data);
+		ctx->timer = rnd_gui->add_timer(rnd_gui, timed_update_preview_cb, adialogs_conf.plugins.dialogs.library.preview_refresh_timeout, user_data);
 		ctx->timer_active = 1;
 		rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->wpend, 0);
 		rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->wnopend, 1);
@@ -255,11 +261,11 @@ static void library_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
 static void create_lib_tree_model_recurse(rnd_hid_attribute_t *attr, pcb_fplibrary_t *parent_lib, rnd_hid_row_t *parent_row)
 {
 	char *cell[2];
-	pcb_fplibrary_t *l;
 	int n;
 
 	cell[1] = NULL;
-	for(l = parent_lib->data.dir.children.array, n = 0; n < parent_lib->data.dir.children.used; l++, n++) {
+	for(n = 0; n < parent_lib->data.dir.children.used; n++) {
+		pcb_fplibrary_t *l = parent_lib->data.dir.children.array[n];
 		rnd_hid_row_t *row;
 
 		cell[0] = rnd_strdup(l->name);
@@ -613,12 +619,16 @@ static void library_refresh_cb(void *hid_ctx, void *caller_data, rnd_hid_attribu
 	pcb_fplibrary_t *l;
 	char *oname;
 
-	if (r == NULL)
+	if (r == NULL) {
+		rnd_message(RND_MSG_ERROR, "Need to select a subtree for refresh\n");
 		return;
+	}
 
 	l = r->user_data;
-	if ((l == NULL) || (l->parent == NULL))
+	if ((l == NULL) || (l->parent == NULL)) {
+		rnd_message(RND_MSG_ERROR, "Selection can not be refreshed: unknown parent (please select the parent)\n", l);
 		return;
+	}
 
 	while((l->parent != NULL) && (l->parent->parent != NULL)) l = l->parent;
 
@@ -666,7 +676,7 @@ static void pcb_dlg_library(void)
 					library_ctx.wtree = RND_DAD_CURRENT(library_ctx.dlg);
 				RND_DAD_BEGIN_HBOX(library_ctx.dlg);
 					RND_DAD_STRING(library_ctx.dlg);
-						RND_DAD_COMPFLAG(library_ctx.dlg, RND_HATF_EXPFILL);
+						RND_DAD_COMPFLAG(library_ctx.dlg, RND_HATF_EXPFILL | RND_HATF_INIT_FOCUS);
 						RND_DAD_HELP(library_ctx.dlg, "filter: display only footprints matching this text\n(if empty: display all)");
 						RND_DAD_CHANGE_CB(library_ctx.dlg, library_filter_cb);
 						library_ctx.wfilt = RND_DAD_CURRENT(library_ctx.dlg);
@@ -684,7 +694,7 @@ static void pcb_dlg_library(void)
 			RND_DAD_BEGIN_VPANE(library_ctx.dlg);
 				RND_DAD_COMPFLAG(library_ctx.dlg, RND_HATF_EXPFILL | RND_HATF_FRAME);
 				/* right top */
-				RND_DAD_PREVIEW(library_ctx.dlg, library_expose, library_mouse, NULL, NULL, 100, 100, &library_ctx);
+				RND_DAD_PREVIEW(library_ctx.dlg, library_expose, library_mouse, NULL, NULL, NULL, 100, 100, &library_ctx);
 					library_ctx.wpreview = RND_DAD_CURRENT(library_ctx.dlg);
 
 				/* right bottom */
@@ -719,10 +729,7 @@ const char pcb_acts_LibraryDialog[] = "libraryDialog()\n";
 const char pcb_acth_LibraryDialog[] = "Open the library dialog.";
 fgw_error_t pcb_act_LibraryDialog(fgw_arg_t *ores, int oargc, fgw_arg_t *oargv)
 {
-	if (strcmp(rnd_gui->name, "lesstif") == 0)
-		rnd_actionva(oargv[0].val.argv0.user_call_ctx, "DoWindows", "library");
-	else
-		pcb_dlg_library();
+	pcb_dlg_library();
 	return 0;
 }
 
