@@ -36,7 +36,7 @@
 #include "conf_core.h"
 #include <librnd/core/hidlib_conf.h>
 #include "plug_io.h"
-#include "../src_plugins/lib_hid_common/dialogs_conf.h"
+#include <librnd/plugins/lib_hid_common/dialogs_conf.h>
 
 #include "dlg_loadsave.h"
 
@@ -66,7 +66,7 @@ fgw_error_t pcb_act_Load(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	/* Called with both function and file name -> no gui */
 	if (argc > 2)
-		return RND_ACT_CALL_C(pcb_act_LoadFrom, res, argc, argv);
+		return RND_ACT_CALL_C(RND_ACT_HIDLIB, pcb_act_LoadFrom, res, argc, argv);
 
 	RND_ACT_MAY_CONVARG(1, FGW_STR, Load, function = argv[1].val.str);
 
@@ -359,7 +359,7 @@ static void setup_fmt_sub(save_t *save, pcb_plug_iot_t save_type)
 		RND_DAD_BEGIN_HBOX(save->fmtsub->dlg);
 			RND_DAD_LABEL(save->fmtsub->dlg, "Guess format:");
 				RND_DAD_HELP(save->fmtsub->dlg, guess_help);
-			RND_DAD_BOOL(save->fmtsub->dlg, "");
+			RND_DAD_BOOL(save->fmtsub->dlg);
 				save->wguess = RND_DAD_CURRENT(save->fmtsub->dlg);
 				RND_DAD_CHANGE_CB(save->fmtsub->dlg, guess_chg);
 				RND_DAD_DEFAULT_NUM(save->fmtsub->dlg, !!dialogs_conf.plugins.dialogs.file_select_dialog.save_as_format_guess);
@@ -408,7 +408,7 @@ fgw_error_t pcb_act_Save(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	is_dialog = (function != NULL) && (rnd_strncasecmp(function, "Dialog", 6) == 0);
 
 	if ((!is_dialog) && (argc > 2))
-		return RND_ACT_CALL_C(pcb_act_SaveTo, res, argc, argv);
+		return RND_ACT_CALL_C(RND_ACT_HIDLIB, pcb_act_SaveTo, res, argc, argv);
 
 	memset(&save, 0, sizeof(save));
 
