@@ -445,7 +445,7 @@ static void pcb_dlg_netlist(pcb_board_t *pcb)
 					wvpan = RND_DAD_CURRENT(netlist_ctx.dlg);
 					RND_DAD_BEGIN_VBOX(netlist_ctx.dlg); /* right-top */
 						RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL);
-						RND_DAD_PREVIEW(netlist_ctx.dlg, netlist_expose, netlist_mouse, NULL, &netlist_ctx.bb_prv, 100, 100, &netlist_ctx);
+						RND_DAD_PREVIEW(netlist_ctx.dlg, netlist_expose, netlist_mouse, NULL, NULL, &netlist_ctx.bb_prv, 100, 100, &netlist_ctx);
 							RND_DAD_COMPFLAG(netlist_ctx.dlg, RND_HATF_EXPFILL | RND_HATF_PRV_BOARD);
 							netlist_ctx.wprev = RND_DAD_CURRENT(netlist_ctx.dlg);
 					RND_DAD_END(netlist_ctx.dlg);
@@ -604,10 +604,7 @@ static fgw_error_t pcb_act_NetlistDialog(fgw_arg_t *res, int argc, fgw_arg_t *ar
 		return 0;
 	}
 
-	if (strcmp(rnd_gui->name, "lesstif") == 0)
-		rnd_actionva(RND_ACT_HIDLIB, "DoWindows", "netlist");
-	else
-		pcb_dlg_netlist(PCB);
+	pcb_dlg_netlist(PCB);
 	RND_ACT_IRES(0);
 	return 0;
 }
