@@ -89,7 +89,7 @@ static rnd_r_dir_t pinout_mouse_search_cb(void *closure, pcb_any_obj_t *obj, voi
 	if ((obj->term != NULL) && (pcb_obj_parent_subc(obj) == ctx->tempsc) && (obj->term != NULL)) {
 		val.str = obj->term;
 		rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->w_lab_num, &val);
-		val.str = rnd_attribute_get(&obj->Attributes, "name");
+		val.str = pcb_attribute_get(&obj->Attributes, "name");
 		if (val.str != NULL)
 			rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->w_lab_name, &val);
 		if (ctx->pcb != NULL) {
@@ -146,7 +146,7 @@ static void pcb_dlg_pinout(pcb_board_t *pcb, pcb_data_t *data, pcb_subc_t *sc)
 	ctx->subc_id = sc->ID;
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-		RND_DAD_PREVIEW(ctx->dlg, pinout_expose, pinout_mouse, NULL, &sc->BoundingBox, 200, 200, ctx);
+		RND_DAD_PREVIEW(ctx->dlg, pinout_expose, pinout_mouse, NULL, NULL, &sc->BoundingBox, 200, 200, ctx);
 		RND_DAD_BEGIN_HBOX(ctx->dlg);
 			RND_DAD_LABEL(ctx->dlg, "Term ID:");
 			RND_DAD_LABEL(ctx->dlg, "");
