@@ -42,6 +42,13 @@
 
 #include "dlg_pref.h"
 
+#define PREF_TABS 10
+static const char *pref_tabs[PREF_TABS+1] = { "General", "Board meta", "Sizes & DRC",  "Library", "Layers", "Colors", "Window", "Key", "Menu", "Config tree", NULL };
+static const int pref_tab_cfgs[PREF_TABS] = {    1,        0,           1,               1,        0,        1,        1,        0,     0,          0      };
+
+static lht_node_t *pref_dlg2conf_pre(pref_ctx_t *ctx);
+static void pref_dlg2conf_post(pref_ctx_t *ctx);
+
 #include "dlg_pref_sizes.c"
 #include "dlg_pref_board.c"
 #include "dlg_pref_general.c"
@@ -49,6 +56,8 @@
 #include "dlg_pref_layer.c"
 #include "dlg_pref_color.c"
 #include "dlg_pref_win.c"
+#include "dlg_pref_key.c"
+#include "dlg_pref_menu.c"
 #include "dlg_pref_conf.c"
 
 pref_ctx_t pref_ctx;
@@ -58,6 +67,46 @@ rnd_conf_hid_id_t pref_hid;
 static const char *role_names[] =  { "user",   "project",   "design",   "cli", NULL };
 static const rnd_conf_role_t roles[] = { RND_CFR_USER, RND_CFR_PROJECT, RND_CFR_DESIGN, RND_CFR_CLI, 0 };
 
+static lht_node_t *pref_dlg2conf_pre(pref_ctx_t *ctx)
+{
+	lht_node_t *m;
+
+	m = rnd_conf_lht_get_first(ctx->role, 0);
+	if (m == NULL) {
+		if (ctx->role == RND_CFR_PROJECT) {
+			const char *pcb_fn = (PCB == NULL ? NULL : PCB->hidlib.filename);
+			const char *try, *fn = rnd_conf_get_project_conf_name(NULL, pcb_fn, &try);
+			if (fn == NULL) {
+				rnd_message(RND_MSG_ERROR, "Failed to create the project file\n");
+				return NULL;
+			}
+			rnd_conf_reset(ctx->role, fn);
+			rnd_conf_makedirty(ctx->role);
+			rnd_conf_save_file(&PCB->hidlib, fn, pcb_fn, ctx->role, NULL);
+			m = rnd_conf_lht_get_first(ctx->role, 0);
+			if (m == NULL) {
+				rnd_message(RND_MSG_ERROR, "Failed to create the project file %s\n", fn);
+				return NULL;
+			}
+				rnd_message(RND_MSG_INFO, "Created the project file\n");
+		}
+		else {
+			rnd_message(RND_MSG_ERROR, "Failed to create config file for role %s\n", rnd_conf_role_name(ctx->role));
+			return NULL;
+		}
+	}
+
+	return m;
+}
+
+static void pref_dlg2conf_post(pref_ctx_t *ctx)
+{
+	if ((ctx->role == RND_CFR_USER) || (ctx->role == RND_CFR_PROJECT))
+		rnd_conf_save_file(&PCB->hidlib, NULL, (PCB == NULL ? NULL : PCB->hidlib.filename), ctx->role, NULL);
+	else if (ctx->role == RND_CFR_DESIGN)
+		pcb_board_set_changed_flag(PCB, 1);
+}
+
 void pcb_pref_conf2dlg_item(rnd_conf_native_t *cn, pref_confitem_t *item)
 {
 	switch(cn->type) {
@@ -140,7 +189,7 @@ void pcb_pref_create_conf_item(pref_ctx_t *ctx, pref_confitem_t *item, void (*ch
 
 	switch(cn->type) {
 		case RND_CFN_COORD:
-			RND_DAD_COORD(ctx->dlg, "");
+			RND_DAD_COORD(ctx->dlg);
 				item->wid = RND_DAD_CURRENT(ctx->dlg);
 				RND_DAD_MINMAX(ctx->dlg, 0, RND_MAX_COORD);
 				RND_DAD_DEFAULT_NUM(ctx->dlg, cn->val.coord[0]);
@@ -148,14 +197,14 @@ void pcb_pref_create_conf_item(pref_ctx_t *ctx, pref_confitem_t *item, void (*ch
 				RND_DAD_CHANGE_CB(ctx->dlg, change_cb);
 			break;
 		case RND_CFN_BOOLEAN:
-			RND_DAD_BOOL(ctx->dlg, "");
+			RND_DAD_BOOL(ctx->dlg);
 				item->wid = RND_DAD_CURRENT(ctx->dlg);
 				RND_DAD_DEFAULT_NUM(ctx->dlg, cn->val.integer[0]);
 				RND_DAD_HELP(ctx->dlg, cn->description);
 				RND_DAD_CHANGE_CB(ctx->dlg, change_cb);
 			break;
 		case RND_CFN_INTEGER:
-			RND_DAD_INTEGER(ctx->dlg, "");
+			RND_DAD_INTEGER(ctx->dlg);
 				item->wid = RND_DAD_CURRENT(ctx->dlg);
 				RND_DAD_MINMAX(ctx->dlg, 0, INT_MAX);
 				RND_DAD_DEFAULT_NUM(ctx->dlg, cn->val.integer[0]);
@@ -163,7 +212,7 @@ void pcb_pref_create_conf_item(pref_ctx_t *ctx, pref_confitem_t *item, void (*ch
 				RND_DAD_CHANGE_CB(ctx->dlg, change_cb);
 			break;
 		case RND_CFN_REAL:
-			RND_DAD_REAL(ctx->dlg, "");
+			RND_DAD_REAL(ctx->dlg);
 				item->wid = RND_DAD_CURRENT(ctx->dlg);
 				RND_DAD_MINMAX(ctx->dlg, 0, INT_MAX);
 				ctx->dlg[item->wid].val.dbl = cn->val.real[0];
@@ -211,6 +260,17 @@ static void pref_role_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 	ctx->role = roles[attr->val.lng];
 }
 
+static void pref_tab_chosen(pref_ctx_t *ctx, int tab)
+{
+	rnd_trace("tab: %d %d\n", tab, pref_tab_cfgs[tab]);
+	rnd_gui->attr_dlg_widget_hide(ctx->dlg_hid_ctx, ctx->wrolebox, !pref_tab_cfgs[tab]);
+}
+
+static void pref_tab_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	pref_tab_chosen(caller_data, attr->val.lng);
+}
+
 static void pref_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
 {
 	long n;
@@ -222,6 +282,7 @@ static void pref_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
 	pcb_dlg_pref_lib_close(ctx);
 	pcb_dlg_pref_color_close(ctx);
 	pcb_dlg_pref_win_close(ctx);
+	pcb_dlg_pref_menu_close(ctx);
 
 	for(n = 0; n < ctx->auto_free.used; n++)
 		free(ctx->auto_free.array[n]);
@@ -247,7 +308,6 @@ static int pref_strcmp(const char *fixed, const char *inp)
 
 static void pcb_dlg_pref(const char *target_tab_str, const char *tabarg)
 {
-	const char *tabs[] = { "General", "Board meta", "Sizes & DRC",  "Library", "Layers", "Colors", "Window", "Config tree", NULL };
 	rnd_hid_dad_buttons_t clbtn[] = {{"Close", 0}, {NULL, 0}};
 	int target_tab = -1;
 
@@ -255,7 +315,7 @@ static void pcb_dlg_pref(const char *target_tab_str, const char *tabarg)
 		const char **t;
 		int tt;
 
-		for(tt = 0, t = tabs; *t != NULL; t++,tt++) {
+		for(tt = 0, t = pref_tabs; *t != NULL; t++,tt++) {
 			if (pref_strcmp(*t, target_tab_str) == 0) {
 				target_tab = tt;
 				break;
@@ -271,9 +331,11 @@ static void pcb_dlg_pref(const char *target_tab_str, const char *tabarg)
 
 	RND_DAD_BEGIN_VBOX(pref_ctx.dlg);
 		RND_DAD_COMPFLAG(pref_ctx.dlg, RND_HATF_EXPFILL);
-		RND_DAD_BEGIN_TABBED(pref_ctx.dlg, tabs);
+		RND_DAD_BEGIN_TABBED(pref_ctx.dlg, pref_tabs);
 			RND_DAD_COMPFLAG(pref_ctx.dlg, RND_HATF_EXPFILL);
 			pref_ctx.wtab = RND_DAD_CURRENT(pref_ctx.dlg);
+			RND_DAD_CHANGE_CB(pref_ctx.dlg, pref_tab_cb);
+
 			RND_DAD_BEGIN_VBOX(pref_ctx.dlg); /* General */
 				pcb_dlg_pref_general_create(&pref_ctx);
 			RND_DAD_END(pref_ctx.dlg);
@@ -302,18 +364,29 @@ static void pcb_dlg_pref(const char *target_tab_str, const char *tabarg)
 				pcb_dlg_pref_win_create(&pref_ctx);
 			RND_DAD_END(pref_ctx.dlg);
 
+			RND_DAD_BEGIN_VBOX(pref_ctx.dlg); /* Key */
+				pcb_dlg_pref_key_create(&pref_ctx);
+			RND_DAD_END(pref_ctx.dlg);
+
+			RND_DAD_BEGIN_VBOX(pref_ctx.dlg); /* Menu */
+				pcb_dlg_pref_menu_create(&pref_ctx);
+			RND_DAD_END(pref_ctx.dlg);
+
 			RND_DAD_BEGIN_VBOX(pref_ctx.dlg); /* Config tree */
 				pcb_dlg_pref_conf_create(&pref_ctx);
 			RND_DAD_END(pref_ctx.dlg);
 
 		RND_DAD_END(pref_ctx.dlg);
-			RND_DAD_BEGIN_VBOX(pref_ctx.dlg);
+		RND_DAD_BEGIN_VBOX(pref_ctx.dlg);
 			RND_DAD_BEGIN_HBOX(pref_ctx.dlg);
 				RND_DAD_COMPFLAG(pref_ctx.dlg, RND_HATF_EXPFILL);
-				RND_DAD_LABEL(pref_ctx.dlg, "All changes are made to role:");
-				RND_DAD_ENUM(pref_ctx.dlg, role_names);
-					pref_ctx.wrole = RND_DAD_CURRENT(pref_ctx.dlg);
-					RND_DAD_CHANGE_CB(pref_ctx.dlg, pref_role_cb);
+				RND_DAD_BEGIN_HBOX(pref_ctx.dlg);
+					pref_ctx.wrolebox = RND_DAD_CURRENT(pref_ctx.dlg);
+					RND_DAD_LABEL(pref_ctx.dlg, "All changes are made to role:");
+					RND_DAD_ENUM(pref_ctx.dlg, role_names);
+						pref_ctx.wrole = RND_DAD_CURRENT(pref_ctx.dlg);
+						RND_DAD_CHANGE_CB(pref_ctx.dlg, pref_role_cb);
+				RND_DAD_END(pref_ctx.dlg);
 				RND_DAD_BUTTON_CLOSES_NAKED(pref_ctx.dlg, clbtn);
 			RND_DAD_END(pref_ctx.dlg);
 		RND_DAD_END(pref_ctx.dlg);
@@ -330,9 +403,15 @@ static void pcb_dlg_pref(const char *target_tab_str, const char *tabarg)
 	pcb_dlg_pref_lib_open(&pref_ctx);
 	pcb_dlg_pref_color_open(&pref_ctx);
 	pcb_dlg_pref_win_open(&pref_ctx);
-	pcb_dlg_pref_conf_open(&pref_ctx, (target_tab == sizeof(tabs)/sizeof(tabs[0]) - 2) ? tabarg : NULL);
-	if (target_tab >= 0)
+	pcb_dlg_pref_key_open(&pref_ctx);
+	pcb_dlg_pref_menu_open(&pref_ctx);
+	pcb_dlg_pref_conf_open(&pref_ctx, (target_tab == PREF_TABS - 2) ? tabarg : NULL);
+	if ((target_tab >= 0) && (target_tab < PREF_TABS)) {
 		RND_DAD_SET_VALUE(pref_ctx.dlg_hid_ctx, pref_ctx.wtab, lng, target_tab);
+		pref_tab_chosen(&pref_ctx, target_tab);
+	}
+	else
+		pref_tab_chosen(&pref_ctx, 0);
 }
 
 static void pref_ev_board_changed(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
@@ -359,6 +438,14 @@ static void pref_ev_board_meta_changed(rnd_hidlib_t *hidlib, void *user_data, in
 	pref_win_brd2dlg(ctx);
 }
 
+static void pref_ev_menu_changed(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+{
+	pref_ctx_t *ctx = user_data;
+	if (!pref_ctx.active)
+		return;
+	pref_menu_brd2dlg(ctx);
+}
+
 void pref_conf_changed(rnd_conf_native_t *cfg, int arr_idx)
 {
 	pref_confitem_t *i;
@@ -376,6 +463,7 @@ void pcb_dlg_pref_init(void)
 	pref_conf_cb.val_change_post = pref_conf_changed;
 	rnd_event_bind(RND_EVENT_BOARD_CHANGED, pref_ev_board_changed, &pref_ctx, pref_cookie);
 	rnd_event_bind(RND_EVENT_BOARD_META_CHANGED, pref_ev_board_meta_changed, &pref_ctx, pref_cookie);
+	rnd_event_bind(RND_EVENT_MENU_CHANGED, pref_ev_menu_changed, &pref_ctx, pref_cookie);
 	pref_hid = rnd_conf_hid_reg(pref_cookie, &pref_conf_cb);
 	pcb_dlg_pref_sizes_init(&pref_ctx);
 	pcb_dlg_pref_lib_init(&pref_ctx);
