@@ -189,7 +189,7 @@ static void pref_conf_editval_cb(void *hid_ctx, void *caller_data, rnd_hid_attri
 	if ((ctx->role == RND_CFR_USER) || (ctx->role == RND_CFR_PROJECT))
 		rnd_conf_save_file(&PCB->hidlib, NULL, (PCB == NULL ? NULL : PCB->hidlib.filename), ctx->role, NULL);
 	else if (ctx->role == RND_CFR_DESIGN)
-		pcb_board_set_changed_flag(1);
+		pcb_board_set_changed_flag(PCB, 1);
 
 	rnd_gui->invalidate_all(rnd_gui);
 }
@@ -277,12 +277,12 @@ static void pref_conf_edit_dlg(rnd_conf_native_t *nat, long idx, rnd_conf_role_t
 					b[0] = RND_DAD_CURRENT(ctx->dlg);
 				break;
 			case RND_CFN_BOOLEAN:
-				RND_DAD_BOOL(ctx->dlg, "");
+				RND_DAD_BOOL(ctx->dlg);
 					ctx->wnewval = RND_DAD_CURRENT(ctx->dlg);
 					RND_DAD_CHANGE_CB(ctx->dlg, pref_conf_editval_cb);
 				break;
 			case RND_CFN_INTEGER:
-				RND_DAD_INTEGER(ctx->dlg, "");
+				RND_DAD_INTEGER(ctx->dlg);
 					ctx->wnewval = RND_DAD_CURRENT(ctx->dlg);
 					RND_DAD_MINMAX(ctx->dlg, -(1<<30), +(1<<30));
 				RND_DAD_BUTTON(ctx->dlg, "apply");
@@ -290,7 +290,7 @@ static void pref_conf_edit_dlg(rnd_conf_native_t *nat, long idx, rnd_conf_role_t
 					b[0] = RND_DAD_CURRENT(ctx->dlg);
 				break;
 			case RND_CFN_REAL:
-				RND_DAD_REAL(ctx->dlg, "");
+				RND_DAD_REAL(ctx->dlg);
 					ctx->wnewval = RND_DAD_CURRENT(ctx->dlg);
 					RND_DAD_MINMAX(ctx->dlg, -(1<<30), +(1<<30));
 				RND_DAD_BUTTON(ctx->dlg, "apply");
@@ -298,7 +298,7 @@ static void pref_conf_edit_dlg(rnd_conf_native_t *nat, long idx, rnd_conf_role_t
 					b[0] = RND_DAD_CURRENT(ctx->dlg);
 				break;
 			case RND_CFN_COORD:
-				RND_DAD_COORD(ctx->dlg, "");
+				RND_DAD_COORD(ctx->dlg);
 					ctx->wnewval = RND_DAD_CURRENT(ctx->dlg);
 					RND_DAD_MINMAX(ctx->dlg, -RND_MM_TO_COORD(1000), +RND_MM_TO_COORD(1000));
 				RND_DAD_BUTTON(ctx->dlg, "apply");
@@ -423,7 +423,7 @@ const char pcb_acts_dlg_confval_edit[] = "dlg_confval_edit(path, idx, role, [mod
 const char pcb_acth_dlg_confval_edit[] = "Present a dialog box for editing the value of a conf node at path.";
 fgw_error_t pcb_act_dlg_confval_edit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	const char *path, *srole, *smodal;
+	const char *path, *srole, *smodal = NULL;
 	rnd_bool modal;
 	long idx;
 	rnd_conf_native_t *nat;
