@@ -47,9 +47,15 @@ static pref_confitem_t perf_cli[] = {
 static void pref_general_dlg2conf(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	pref_ctx_t *ctx = caller_data;
+
+	if (pref_dlg2conf_pre(ctx) == NULL)
+		return;
+
 	pcb_pref_dlg2conf_table(ctx, perf_topwin, attr);
 	pcb_pref_dlg2conf_table(ctx, perf_backup, attr);
 	pcb_pref_dlg2conf_table(ctx, perf_cli, attr);
+
+	pref_dlg2conf_post(ctx);
 }
 
 void pcb_dlg_pref_general_close(pref_ctx_t *ctx)
