@@ -55,7 +55,7 @@ void pcb_dlg_pref_layer_create(pref_ctx_t *ctx)
 	RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
-		RND_DAD_PREVIEW(ctx->dlg, layersel_expose_cb, layersel_mouse_cb, layersel_free_cb, &vbox, 200, 200, ctx);
+		RND_DAD_PREVIEW(ctx->dlg, layersel_expose_cb, layersel_mouse_cb, NULL, layersel_free_cb, &vbox, 200, 200, ctx);
 			RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_EXPFILL);
 	RND_DAD_END(ctx->dlg);
 }
