@@ -129,24 +129,6 @@ static void pref_lib_conf2dlg_post(rnd_conf_native_t *cfg, int arr_idx)
 	pref_lib_update_buttons();
 }
 
-TODO(": move this to liblihata")
-static void lht_clean_list(lht_node_t * lst)
-{
-	lht_node_t *n;
-	while (lst->data.list.first != NULL) {
-		n = lst->data.list.first;
-		if (n->doc == NULL) {
-			if (lst->data.list.last == n)
-				lst->data.list.last = NULL;
-			lst->data.list.first = n->next;
-		}
-		else
-			lht_tree_unlink(n);
-		lht_dom_node_free(n);
-	}
-	lst->data.list.last = NULL;
-}
-
 /* Dialog box to current libraries in config */
 static void pref_lib_dlg2conf(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
@@ -155,16 +137,20 @@ static void pref_lib_dlg2conf(void *hid_ctx, void *caller_data, rnd_hid_attribut
 	lht_node_t *m, *lst, *nd;
 	rnd_hid_row_t *r;
 
-	ctx->lib.lock++;
 
+	m = pref_dlg2conf_pre(ctx);
+	if (m == NULL)
+		return;
+
+	ctx->lib.lock++;
 	/* get the list and clean it */
-	m = rnd_conf_lht_get_first(ctx->role, 0);
+
 	lst = lht_tree_path_(m->doc, m, "rc/library_search_paths", 1, 0, NULL);
 	if (lst == NULL)
 		rnd_conf_set(ctx->role, "rc/library_search_paths", 0, "", RND_POL_OVERWRITE);
 	lst = lht_tree_path_(m->doc, m, "rc/library_search_paths", 1, 0, NULL);
 	assert(lst != NULL);
-	lht_clean_list(lst);
+	lht_tree_list_clean(lst);
 
 	/* append items from the widget */
 	for(r = gdl_first(&tree->rows); r != NULL; r = gdl_next(&tree->rows, r)) {
@@ -177,8 +163,8 @@ static void pref_lib_dlg2conf(void *hid_ctx, void *caller_data, rnd_hid_attribut
 
 	rnd_conf_update("rc/library_search_paths", -1);
 	rnd_conf_makedirty(ctx->role); /* low level lht_dom_node_alloc() wouldn't make user config to be saved! */
-	if (ctx->role == RND_CFR_DESIGN)
-		pcb_board_set_changed_flag(1);
+
+	pref_dlg2conf_post(ctx);
 
 	ctx->lib.lock--;
 }
