@@ -57,20 +57,23 @@ static void drc_rules_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 	rnd_actionva(&PCB->hidlib, attr->user_data, NULL);
 }
 
-static pref_confitem_t drc_sizes[] = {
+static pref_confitem_t limit_sizes[] = {
 	{"Minimum copper spacing", "design/bloat", 0, NULL},
 	{"Minimum copper width", "design/min_wid", 0, NULL},
-	{"Minimum copper overlap", "design/shrink", 0, NULL},
 	{"Minimum silk width", "design/min_slk", 0, NULL},
-	{"Minimum drill diameter", "design/min_drill", 0, NULL},
-	{"Minimum annular ring", "design/min_ring", 0, NULL},
 	{NULL, NULL, 0}
 };
 
-static void pref_sizes_drc_dlg2conf(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+static void pref_sizes_limit_dlg2conf(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	pref_ctx_t *ctx = caller_data;
-	pcb_pref_dlg2conf_table(ctx, drc_sizes, attr);
+
+	if (pref_dlg2conf_pre(ctx) == NULL)
+		return;
+
+	pcb_pref_dlg2conf_table(ctx, limit_sizes, attr);
+
+	pref_dlg2conf_post(ctx);
 }
 
 static void pref_isle_brd2dlg(rnd_conf_native_t *cfg, int arr_idx)
@@ -92,25 +95,26 @@ static void pref_isle_dlg2brd(void *hid_ctx, void *caller_data, rnd_hid_attribut
 
 void pcb_dlg_pref_sizes_close(pref_ctx_t *ctx)
 {
-	pcb_pref_conflist_remove(ctx, drc_sizes);
+	pcb_pref_conflist_remove(ctx, limit_sizes);
 }
 
 void pcb_dlg_pref_sizes_create(pref_ctx_t *ctx)
 {
 	pcb_drc_impl_t *di;
+	int drcs;
 
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_FRAME);
 		RND_DAD_LABEL(ctx->dlg, "Board size");
 		RND_DAD_BEGIN_HBOX(ctx->dlg);
 			RND_DAD_LABEL(ctx->dlg, "Width=");
-			RND_DAD_COORD(ctx->dlg, "");
+			RND_DAD_COORD(ctx->dlg);
 				ctx->sizes.wwidth = RND_DAD_CURRENT(ctx->dlg);
 				RND_DAD_MINMAX(ctx->dlg, RND_MM_TO_COORD(1), RND_MAX_COORD);
 				RND_DAD_DEFAULT_NUM(ctx->dlg, PCB->hidlib.size_x);
 				RND_DAD_CHANGE_CB(ctx->dlg, pref_sizes_dlg2brd);
 			RND_DAD_LABEL(ctx->dlg, "Height=");
-			RND_DAD_COORD(ctx->dlg, "");
+			RND_DAD_COORD(ctx->dlg);
 				ctx->sizes.wheight = RND_DAD_CURRENT(ctx->dlg);
 				RND_DAD_MINMAX(ctx->dlg, RND_MM_TO_COORD(1), RND_MAX_COORD);
 				RND_DAD_DEFAULT_NUM(ctx->dlg, PCB->hidlib.size_y);
@@ -120,19 +124,27 @@ void pcb_dlg_pref_sizes_create(pref_ctx_t *ctx)
 
 	RND_DAD_BEGIN_VBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_FRAME);
-		RND_DAD_LABEL(ctx->dlg, "*OBSOLETE* DRC; do not use; details:");
-		RND_DAD_STRING(ctx->dlg);
-		RND_DAD_DEFAULT_PTR(ctx->dlg, "http://repo.hu/cgi-bin/pool.cgi?cmd=show&node=deprecation#olddrc");
-		RND_DAD_WIDTH_CHR(ctx->dlg, 64);
+		RND_DAD_LABEL(ctx->dlg, "Limiting sizes (not DRC)");
+		RND_DAD_LABEL(ctx->dlg, "(Used when the code needs to figure the absolute global smallest value)");
 		RND_DAD_BEGIN_TABLE(ctx->dlg, 2);
-			pcb_pref_create_conftable(ctx, drc_sizes, pref_sizes_drc_dlg2conf);
+			pcb_pref_create_conftable(ctx, limit_sizes, pref_sizes_limit_dlg2conf);
 		RND_DAD_END(ctx->dlg);
+
+		RND_DAD_BEGIN_TABLE(ctx->dlg, 2);
+			RND_DAD_LABEL(ctx->dlg, "polygon isle minimum size\n[square um]");
+			RND_DAD_REAL(ctx->dlg);
+				ctx->sizes.wisle = RND_DAD_CURRENT(ctx->dlg);
+				RND_DAD_MINMAX(ctx->dlg, 0, RND_MAX_COORD);
+				ctx->dlg[ctx->sizes.wisle].val.dbl = (conf_core.design.poly_isle_area / 1000000.0);
+				RND_DAD_CHANGE_CB(ctx->dlg, pref_isle_dlg2brd);
+		RND_DAD_END(ctx->dlg);
+
 	RND_DAD_END(ctx->dlg);
 
 	RND_DAD_BEGIN_HBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_FRAME);
 		RND_DAD_LABEL(ctx->dlg, "Configure DRC rules:");
-		for(di = gdl_first(&pcb_drc_impls); di != NULL; di = di->link.next) {
+		for(di = gdl_first(&pcb_drc_impls), drcs = 0; di != NULL; di = di->link.next, drcs++) {
 			char *ra = rnd_strdup(di->list_rules_action); /* need to strdup it just in case the plugin is unloaded while the preferences dialog is open */
 			vtp0_append(&ctx->auto_free, ra);
 			RND_DAD_BUTTON(ctx->dlg, di->name);
@@ -140,19 +152,8 @@ void pcb_dlg_pref_sizes_create(pref_ctx_t *ctx)
 				RND_DAD_SET_ATTR_FIELD(ctx->dlg, user_data, ra);
 				RND_DAD_CHANGE_CB(ctx->dlg, drc_rules_cb);
 		}
-	RND_DAD_END(ctx->dlg);
-
-	RND_DAD_BEGIN_VBOX(ctx->dlg);
-		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_FRAME);
-		RND_DAD_LABEL(ctx->dlg, "misc sizes");
-		RND_DAD_BEGIN_TABLE(ctx->dlg, 2);
-			RND_DAD_LABEL(ctx->dlg, "polygon isle minimum size\n[square um]");
-			RND_DAD_REAL(ctx->dlg, "");
-				ctx->sizes.wisle = RND_DAD_CURRENT(ctx->dlg);
-				RND_DAD_MINMAX(ctx->dlg, 0, RND_MAX_COORD);
-				ctx->dlg[ctx->sizes.wisle].val.dbl = (conf_core.design.poly_isle_area / 1000000.0);
-				RND_DAD_CHANGE_CB(ctx->dlg, pref_isle_dlg2brd);
-		RND_DAD_END(ctx->dlg);
+		if (drcs == 0)
+			RND_DAD_LABEL(ctx->dlg, "ERROR: no DRC plugins available");
 	RND_DAD_END(ctx->dlg);
 }
 
