@@ -30,11 +30,10 @@
 #include <librnd/core/conf.h>
 #include "conf_core.h"
 #include <librnd/core/hidlib_conf.h>
-#include "../src_plugins/lib_hid_common/dialogs_conf.h"
+#include <librnd/plugins/lib_hid_common/dialogs_conf.h>
+#include <librnd/plugins/lib_hid_common/place.h>
 
 extern conf_dialogs_t dialogs_conf;
-extern void pcb_wplc_save_to_role(rnd_conf_role_t role);
-extern int pcb_wplc_save_to_file(const char *fn);
 
 static void pref_win_brd2dlg(pref_ctx_t *ctx)
 {
@@ -70,7 +69,14 @@ static void pref_win_board_cb(void *hid_ctx, void *caller_data, rnd_hid_attribut
 static void pref_win_project_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	pref_ctx_t *ctx = caller_data;
+
+	if (pref_dlg2conf_pre(ctx) == NULL)
+		return;
+
 	rnd_conf_setf(ctx->role, "plugins/dialogs/auto_save_window_geometry/to_project", -1, "%d", attr->val.lng);
+
+	pref_dlg2conf_post(ctx);
+
 	pref_win_brd2dlg(ctx);
 }
 
@@ -84,17 +90,17 @@ static void pref_win_user_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 
 static void pref_win_board_now_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
-	pcb_wplc_save_to_role(RND_CFR_USER);
+	pcb_wplc_save_to_role(rnd_gui->get_dad_hidlib(hid_ctx), RND_CFR_USER);
 }
 
 static void pref_win_project_now_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
-	pcb_wplc_save_to_role(RND_CFR_USER);
+	pcb_wplc_save_to_role(rnd_gui->get_dad_hidlib(hid_ctx), RND_CFR_USER);
 }
 
 static void pref_win_user_now_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
-	pcb_wplc_save_to_role(RND_CFR_USER);
+	pcb_wplc_save_to_role(rnd_gui->get_dad_hidlib(hid_ctx), RND_CFR_USER);
 }
 
 static void pref_win_file_now_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -108,7 +114,7 @@ static void pref_win_file_now_cb(void *hid_ctx, void *caller_data, rnd_hid_attri
 	if (fname == NULL)
 		return;
 
-	if (pcb_wplc_save_to_file(fname) != 0)
+	if (pcb_wplc_save_to_file(rnd_gui->get_dad_hidlib(hid_ctx), fname) != 0)
 		rnd_message(RND_MSG_ERROR, "Error saving window geometry to '%s'\n", fname);
 }
 
@@ -119,7 +125,7 @@ void pcb_dlg_pref_win_create(pref_ctx_t *ctx)
 	RND_DAD_BEGIN_HBOX(ctx->dlg);
 		RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_FRAME);
 		RND_DAD_LABEL(ctx->dlg, "Load window geometry and enable window placement:");
-		RND_DAD_BOOL(ctx->dlg, "");
+		RND_DAD_BOOL(ctx->dlg);
 			RND_DAD_HELP(ctx->dlg, "When enabled, pcb-rnd will load window geometry from config files\nand try to resize and place windows accordingly.\nSizes can be saved once (golden arrangement)\nor at every exit (retrain last setup),\nsee below.");
 			ctx->win.wmaster = RND_DAD_CURRENT(ctx->dlg);
 			RND_DAD_CHANGE_CB(ctx->dlg, pref_win_master_cb);
@@ -139,7 +145,7 @@ void pcb_dlg_pref_win_create(pref_ctx_t *ctx)
 				RND_DAD_BUTTON(ctx->dlg, "now");
 					RND_DAD_CHANGE_CB(ctx->dlg, pref_win_board_now_cb);
 				RND_DAD_LABEL(ctx->dlg, "before close:");
-				RND_DAD_BOOL(ctx->dlg, "");
+				RND_DAD_BOOL(ctx->dlg);
 					ctx->win.wboard = RND_DAD_CURRENT(ctx->dlg);
 					RND_DAD_CHANGE_CB(ctx->dlg, pref_win_board_cb);
 			RND_DAD_END(ctx->dlg);
@@ -154,7 +160,7 @@ void pcb_dlg_pref_win_create(pref_ctx_t *ctx)
 				RND_DAD_BUTTON(ctx->dlg, "now");
 					RND_DAD_CHANGE_CB(ctx->dlg, pref_win_project_now_cb);
 				RND_DAD_LABEL(ctx->dlg, "before close:");
-				RND_DAD_BOOL(ctx->dlg, "");
+				RND_DAD_BOOL(ctx->dlg);
 					ctx->win.wproject = RND_DAD_CURRENT(ctx->dlg);
 					RND_DAD_CHANGE_CB(ctx->dlg, pref_win_project_cb);
 			RND_DAD_END(ctx->dlg);
@@ -169,7 +175,7 @@ void pcb_dlg_pref_win_create(pref_ctx_t *ctx)
 				RND_DAD_BUTTON(ctx->dlg, "now");
 					RND_DAD_CHANGE_CB(ctx->dlg, pref_win_user_now_cb);
 				RND_DAD_LABEL(ctx->dlg, "before close:");
-				RND_DAD_BOOL(ctx->dlg, "");
+				RND_DAD_BOOL(ctx->dlg);
 					ctx->win.wuser = RND_DAD_CURRENT(ctx->dlg);
 					RND_DAD_CHANGE_CB(ctx->dlg, pref_win_user_cb);
 			RND_DAD_END(ctx->dlg);
