@@ -26,15 +26,15 @@
  *    mailing list: pcb-rnd (at) list.repo.hu (send "subscribe")
  */
 
-#include "hid_init.h"
+#include <librnd/core/hid_init.h>
 
-static pcb_hid_attribute_t printer_calibrate_attrs[] = {
+static rnd_hid_attribute_t printer_calibrate_attrs[] = {
 	{"Enter Values here:", "",
-	 PCB_HATT_LABEL, 0, 0, {0, 0, 0}, 0, 0},
+	 RND_HATT_LABEL, 0, 0, {0, 0, 0}, 0, 0},
 	{"x-calibration", "X scale for calibrating your printer",
-	 PCB_HATT_REAL, 0.5, 25, {0, 0, 1.00}, 0, 0},
+	 RND_HATT_REAL, 0.5, 25, {0, 0, 1.00}, 0, 0},
 	{"y-calibration", "Y scale for calibrating your printer",
-	 PCB_HATT_REAL, 0.5, 25, {0, 0, 1.00}, 0, 0}
+	 RND_HATT_REAL, 0.5, 25, {0, 0, 1.00}, 0, 0}
 };
 
 const char pcb_acts_PrintCalibrate[] = "PrintCalibrate()";
@@ -42,18 +42,18 @@ const char pcb_acth_PrintCalibrate[] = "Calibrate the printer.";
 /* DOC: printcalibrate.html */
 fgw_error_t pcb_act_PrintCalibrate(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	pcb_hid_t *printer = pcb_hid_find_printer();
+	rnd_hid_t *printer = rnd_hid_find_printer();
 
 	if (printer == NULL) {
-		pcb_message(PCB_MSG_ERROR, "No printer available\n");
-		PCB_ACT_IRES(1);
+		rnd_message(RND_MSG_ERROR, "No printer available\n");
+		RND_ACT_IRES(1);
 		return 0;
 	}
 	printer->calibrate(printer, 0.0, 0.0);
 
-	if (pcb_attribute_dialog("printer_calibrate", printer_calibrate_attrs, 3, "Printer Calibration Values", NULL))
+	if (rnd_attribute_dialog("printer_calibrate", printer_calibrate_attrs, 3, "Printer Calibration Values", NULL))
 		return 1;
 	printer->calibrate(printer, printer_calibrate_attrs[1].val.dbl, printer_calibrate_attrs[2].val.dbl);
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
