@@ -33,7 +33,7 @@
 
 #include "config.h"
 #include "conf_core.h"
-#include "hidlib_conf.h"
+#include <librnd/core/hidlib_conf.h>
 #include "board.h"
 
 #include <memory.h>
@@ -48,21 +48,20 @@
 #include "flag_str.h"
 #include "find.h"
 #include "layer.h"
-#include "pcb-printf.h"
-#include "compat_misc.h"
-#include "plugins.h"
-#include "actions.h"
+#include <librnd/core/rnd_printf.h>
+#include <librnd/core/compat_misc.h>
+#include <librnd/core/plugins.h>
+#include <librnd/core/actions.h>
 #include "djopt_conf.h"
 #include "obj_line.h"
-#include "event.h"
-#include "macro.h"
+#include <librnd/core/event.h>
 #include "obj_pstk_inlines.h"
 
 conf_djopt_t conf_djopt;
 
 static const char *djopt_cookie = "djopt";
 
-#define dprintf if(0)pcb_printf
+#define dprintf if(0)rnd_printf
 
 #define selected(x) PCB_FLAG_TEST(PCB_FLAG_SELECTED, (x))
 #define autorouted(x) PCB_FLAG_TEST(PCB_FLAG_AUTO, (x))
@@ -153,16 +152,16 @@ static const char *corner_name(corner_s * c)
 	bp = buf[bn] + strlen(buf[bn]);
 
 	if (c->pin)
-		pcb_sprintf(bp, "pin %s:%s at %#mD", element_name_for(c), c->pin->term, c->x, c->y);
+		rnd_sprintf(bp, "pin %s:%s at %#mD", element_name_for(c), c->pin->term, c->x, c->y);
 	else if (c->via)
-		pcb_sprintf(bp, "via at %#mD", c->x, c->y);
+		rnd_sprintf(bp, "via at %#mD", c->x, c->y);
 	else if (c->pad) {
-		pcb_sprintf(bp, "pad %s:%s at %#mD %#mD-%#mD",
+		rnd_sprintf(bp, "pad %s:%s at %#mD %#mD-%#mD",
 								element_name_for(c), c->pad->term, c->x, c->y,
 								c->pad->BoundingBox.X1, c->pad->BoundingBox.Y1, c->pad->BoundingBox.X2, c->pad->BoundingBox.Y2);
 	}
 	else
-		pcb_sprintf(bp, "at %#mD", c->x, c->y);
+		rnd_sprintf(bp, "at %#mD", c->x, c->y);
 	sprintf(bp + strlen(bp), " n%d l%d]\033[0m", c->n_lines, c->layer);
 	return buf[bn];
 }
@@ -223,7 +222,7 @@ static void check2(int srcline, corner_s * c, line_s * l)
 		if (!ll->is_pad
 				&& (ll->s->x != ll->line->Point1.X
 						|| ll->s->y != ll->line->Point1.Y || ll->e->x != ll->line->Point2.X || ll->e->y != ll->line->Point2.Y)) {
-			pcb_printf("line: %#mD to %#mD  pcbline: %#mD to %#mD\n",
+			rnd_printf("line: %#mD to %#mD  pcbline: %#mD to %#mD\n",
 								 ll->s->x, ll->s->y,
 								 ll->e->x, ll->e->y, ll->line->Point1.X, ll->line->Point1.Y, ll->line->Point2.X, ll->line->Point2.Y);
 			dj_abort("check:%d: line doesn't match pcbline\n", srcline);
@@ -237,11 +236,11 @@ static void check2(int srcline, corner_s * c, line_s * l)
 
 #define SWAP(a,b) { a^=b; b^=a; a^=b; }
 
-static int gridsnap(pcb_coord_t n)
+static int gridsnap(rnd_coord_t n)
 {
 	if (n <= 0)
 		return 0;
-	return n - n % (pcbhl_conf.editor.grid);
+	return n - n % (rnd_conf.editor.grid);
 }
 
 /* Avoid commonly used names. */
@@ -271,7 +270,7 @@ static int dist(int x1, int y1, int x2, int y2)
 	dy2 = (double) y2;
 
 	d = sqrt((dx1 - dx2) * (dx1 - dx2) + (dy1 - dy2) * (dy1 - dy2));
-	d = pcb_round(d);
+	d = rnd_round(d);
 
 	return (int) d;
 }
@@ -599,7 +598,7 @@ static void add_corner_to_rect_if(rect_s * rect, corner_s * c, rect_s * e)
 	if (c->x > e->x2 && c->y > e->y2 && dist(c->x, c->y, e->x2, e->y2) > diam)
 		return;
 
-	/*pcb_printf("add point %#mD diam %#mS\n", c->x, c->y, diam); */
+	/*rnd_printf("add point %#mD diam %#mS\n", c->x, c->y, diam); */
 	add_point_to_rect(rect, c->x, c->y, diam);
 }
 
@@ -736,7 +735,7 @@ static void move_corner(corner_s * c, int x, int y)
 				break;
 			}
 		}
-	pcb_hid_progress(0, 0, 0);
+	rnd_hid_progress(0, 0, 0);
 	check(c, 0);
 }
 
@@ -897,7 +896,7 @@ static int canonicalize_line(line_s * l)
 				int th = djmax(p->BoundingBox.X2 - p->BoundingBox.X1, p->BoundingBox.Y2 - p->BoundingBox.Y1);
 				th /= 2;
 				if (dist(l->s->x, l->s->y, c->x, c->y) > th
-						&& dist(l->e->x, l->e->y, c->x, c->y) > th && pcb_isc_pstk_line(p, l->line)) {
+						&& dist(l->e->x, l->e->y, c->x, c->y) > th && pcb_isc_pstk_line(pcb_find0, p, l->line, rnd_false)) {
 					return split_line(l, c);
 				}
 			}
@@ -1358,9 +1357,9 @@ static int orthopull_1(corner_s * c, int fdir, int rdir, int any_sel)
 		len = c->x + max;
 		break;
 	}
-	if (snap && max > pcbhl_conf.editor.grid) {
+	if (snap && max > rnd_conf.editor.grid) {
 		if (pull < 0)
-			len += pcbhl_conf.editor.grid - 1;
+			len += rnd_conf.editor.grid - 1;
 		len = gridsnap(len);
 	}
 	if ((fdir == RIGHT && len == cs[0]->y) || (fdir == DOWN && len == cs[0]->x))
@@ -1407,7 +1406,7 @@ static int orthopull()
 		c = c->next;
 	}
 	if (rv)
-		pcb_printf("orthopull: %ml mils saved\n", rv);
+		rnd_printf("orthopull: %ml mils saved\n", rv);
 	return rv;
 }
 
@@ -1538,7 +1537,7 @@ static int debumpify()
 
 	rv += simple_optimizations();
 	if (rv)
-		pcb_printf("debumpify: %ml mils saved\n", rv / 50);
+		rnd_printf("debumpify: %ml mils saved\n", rv / 50);
 	return rv;
 }
 
@@ -1771,7 +1770,7 @@ static int vianudge()
 	}
 
 	if (rv)
-		pcb_printf("vianudge: %ml mils saved\n", rv);
+		rnd_printf("vianudge: %ml mils saved\n", rv);
 	return rv;
 }
 
@@ -1996,13 +1995,13 @@ static int miter()
 				}
 
 #if 0
-				if (dist < pcbhl_conf.editor.grid) {
+				if (dist < rnd_conf.editor.grid) {
 					c->miter = 0;
 					progress = 1;
 					continue;
 				}
 
-				dist -= dist % pcbhl_conf.editor.grid;
+				dist -= dist % rnd_conf.editor.grid;
 #endif
 				if (dist <= 0) {
 					c->miter = 0;
@@ -2220,7 +2219,7 @@ static void pinsnap()
 			got_one = 0;
 			for (c2 = corners; c2; c2 = c2->next) {
 				int lt;
-				pcb_coord_t thick;
+				rnd_coord_t thick;
 
 				if (DELETED(c2))
 					continue;
@@ -2329,8 +2328,8 @@ static void pinsnap()
 
 static int pstk_orient(pcb_pstk_t *p)
 {
-	pcb_coord_t dx = p->BoundingBox.X2 - p->BoundingBox.X1;
-	pcb_coord_t dy = p->BoundingBox.Y2 - p->BoundingBox.Y1;
+	rnd_coord_t dx = p->BoundingBox.X2 - p->BoundingBox.X1;
+	rnd_coord_t dy = p->BoundingBox.Y2 - p->BoundingBox.Y1;
 	if (dx < dy * 3)
 		return O_VERT;
 	if (dx > dy * 3)
@@ -2440,13 +2439,13 @@ static fgw_error_t pcb_act_DJopt(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	int layn, saved = 0;
 	corner_s *c;
 
-	PCB_ACT_MAY_CONVARG(1, FGW_STR, DJopt, arg = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(1, FGW_STR, DJopt, arg = argv[1].val.str);
 
 #ifdef ENDIF
-	SwitchDrawingWindow(PCB->Zoom, Output.drawing_area->window, conf_core.editor.show_solder_side, pcb_false);
+	SwitchDrawingWindow(PCB->Zoom, Output.drawing_area->window, conf_core.editor.show_solder_side, rnd_false);
 #endif
 
-	pcb_hid_busy(PCB, 1);
+	rnd_hid_busy(PCB, 1);
 
 	lines = 0;
 	corners = 0;
@@ -2481,10 +2480,10 @@ static fgw_error_t pcb_act_DJopt(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	check(0, 0);
 
-	if (PCB_NSTRCMP(arg, "splitlines") == 0) {
+	if (RND_NSTRCMP(arg, "splitlines") == 0) {
 		if (canonicalize_lines())
 			pcb_undo_inc_serial();
-		pcb_hid_busy(PCB, 0);
+		rnd_hid_busy(PCB, 0);
 		return 0;
 	}
 
@@ -2528,25 +2527,25 @@ static fgw_error_t pcb_act_DJopt(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	/*dump_all(); */
 	check(0, 0);
 
-	if (PCB_NSTRCMP(arg, "debumpify") == 0)
+	if (RND_NSTRCMP(arg, "debumpify") == 0)
 		saved += debumpify();
-	else if (PCB_NSTRCMP(arg, "unjaggy") == 0)
+	else if (RND_NSTRCMP(arg, "unjaggy") == 0)
 		saved += unjaggy();
-	else if (PCB_NSTRCMP(arg, "simple") == 0)
+	else if (RND_NSTRCMP(arg, "simple") == 0)
 		saved += simple_optimizations();
-	else if (PCB_NSTRCMP(arg, "vianudge") == 0)
+	else if (RND_NSTRCMP(arg, "vianudge") == 0)
 		saved += vianudge();
-	else if (PCB_NSTRCMP(arg, "viatrim") == 0)
+	else if (RND_NSTRCMP(arg, "viatrim") == 0)
 		saved += viatrim();
-	else if (PCB_NSTRCMP(arg, "orthopull") == 0)
+	else if (RND_NSTRCMP(arg, "orthopull") == 0)
 		saved += orthopull();
-	else if (PCB_NSTRCMP(arg, "auto") == 0)
+	else if (RND_NSTRCMP(arg, "auto") == 0)
 		saved += automagic();
-	else if (PCB_NSTRCMP(arg, "miter") == 0)
+	else if (RND_NSTRCMP(arg, "miter") == 0)
 		saved += miter();
 	else {
 		printf("unknown command: %s\n", arg);
-		pcb_hid_busy(PCB, 0);
+		rnd_hid_busy(PCB, 0);
 		return 1;
 	}
 
@@ -2556,12 +2555,12 @@ static fgw_error_t pcb_act_DJopt(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (saved)
 		pcb_undo_inc_serial();
 
-	pcb_hid_busy(PCB, 0);
-	PCB_ACT_IRES(0);
+	rnd_hid_busy(PCB, 0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
-pcb_action_t djopt_action_list[] = {
+rnd_action_t djopt_action_list[] = {
 	{"djopt", pcb_act_DJopt, pcb_acth_DJopt, pcb_acts_DJopt}
 };
 
@@ -2569,18 +2568,18 @@ int pplg_check_ver_djopt(int ver_needed) { return 0; }
 
 void pplg_uninit_djopt(void)
 {
-	pcb_remove_actions_by_cookie(djopt_cookie);
-	pcb_conf_unreg_fields("plugins/djopt/");
+	rnd_remove_actions_by_cookie(djopt_cookie);
+	rnd_conf_unreg_fields("plugins/djopt/");
 }
 
 int pplg_init_djopt(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
-	pcb_conf_reg_field(conf_djopt, field,isarray,type_name,cpath,cname,desc,flags);
+	rnd_conf_reg_field(conf_djopt, field,isarray,type_name,cpath,cname,desc,flags);
 #include "djopt_conf_fields.h"
 
-	PCB_REGISTER_ACTIONS(djopt_action_list, djopt_cookie)
+	RND_REGISTER_ACTIONS(djopt_action_list, djopt_cookie)
 	return 0;
 }
