@@ -33,18 +33,17 @@
 
 #include "board.h"
 #include "build_run.h"
-#include "compat_misc.h"
+#include <librnd/core/compat_misc.h>
 #include "data.h"
 #include "draw.h"
 #include "../report/drill.h"
-#include "plugins.h"
+#include <librnd/core/plugins.h>
 #include "stub_draw.h"
 #include "draw_fab_conf.h"
 #include "conf_core.h"
-#include "hidlib_conf.h"
-#include "macro.h"
+#include <librnd/core/hidlib_conf.h>
 #include "obj_pstk_inlines.h"
-#include "hid_inlines.h"
+#include <librnd/core/hid_inlines.h>
 #include "funchash_core.h"
 
 #include "obj_text_draw.h"
@@ -56,24 +55,24 @@ conf_draw_fab_t conf_draw_fab;
  * prints a FAB drawing.
  */
 
-#define TEXT_SIZE	PCB_MIL_TO_COORD(150)
-#define TEXT_LINE	PCB_MIL_TO_COORD(150)
-#define DRILL_MARK_SIZE	PCB_MIL_TO_COORD(16)
-#define FAB_LINE_W      PCB_MIL_TO_COORD(8)
+#define TEXT_SIZE	RND_MIL_TO_COORD(150)
+#define TEXT_LINE	RND_MIL_TO_COORD(150)
+#define DRILL_MARK_SIZE	RND_MIL_TO_COORD(16)
+#define FAB_LINE_W      RND_MIL_TO_COORD(8)
 
-static void fab_line(pcb_hid_gc_t gc, int x1, int y1, int x2, int y2)
+static void fab_line(rnd_hid_gc_t gc, int x1, int y1, int x2, int y2)
 {
-	pcb_render->draw_line(gc, x1, y1, x2, y2);
+	rnd_render->draw_line(gc, x1, y1, x2, y2);
 }
 
-static void fab_circle(pcb_hid_gc_t gc, int x, int y, int r)
+static void fab_circle(rnd_hid_gc_t gc, int x, int y, int r)
 {
-	pcb_render->draw_arc(gc, x, y, r, r, 0, 180);
-	pcb_render->draw_arc(gc, x, y, r, r, 180, 180);
+	rnd_render->draw_arc(gc, x, y, r, r, 0, 180);
+	rnd_render->draw_arc(gc, x, y, r, r, 180, 180);
 }
 
 /* align is 0=left, 1=center, 2=right, add 8 for underline */
-static void text_at(pcb_draw_info_t *info, pcb_hid_gc_t gc, int x, int y, int align, const char *fmt, ...)
+static void text_at(pcb_draw_info_t *info, rnd_hid_gc_t gc, int x, int y, int align, const char *fmt, ...)
 {
 	char tmp[512];
 	int w = 0, i;
@@ -85,7 +84,7 @@ static void text_at(pcb_draw_info_t *info, pcb_hid_gc_t gc, int x, int y, int al
 	va_end(a);
 	memset(&t, 0, sizeof(t));
 	t.TextString = tmp;
-	t.Scale = PCB_COORD_TO_MIL(TEXT_SIZE);	/* pcnt of 100mil base height */
+	t.Scale = RND_COORD_TO_MIL(TEXT_SIZE);	/* pcnt of 100mil base height */
 	t.Flags = pcb_no_flags();
 	t.fid = 0; /* use the default font */
 	t.X = x;
@@ -99,12 +98,12 @@ static void text_at(pcb_draw_info_t *info, pcb_hid_gc_t gc, int x, int y, int al
 	pcb_text_draw_(info, &t, 0,0, PCB_TXT_TINY_ACCURATE);
 	if (align & 8)
 		fab_line(gc, t.X,
-						 t.Y + PCB_SCALE_TEXT(font->MaxHeight, t.Scale) + PCB_MIL_TO_COORD(10),
-						 t.X + w, t.Y + PCB_SCALE_TEXT(font->MaxHeight, t.Scale) + PCB_MIL_TO_COORD(10));
+						 t.Y + PCB_SCALE_TEXT(font->MaxHeight, t.Scale) + RND_MIL_TO_COORD(10),
+						 t.X + w, t.Y + PCB_SCALE_TEXT(font->MaxHeight, t.Scale) + RND_MIL_TO_COORD(10));
 }
 
 /* Y, +, X, circle, square */
-static void drill_sym(pcb_hid_gc_t gc, int idx, int x, int y)
+static void drill_sym(rnd_hid_gc_t gc, int idx, int x, int y)
 {
 	int type = idx % 5;
 	int size = idx / 5;
@@ -177,17 +176,17 @@ static int DrawFab_overhang(void)
 	return (ds + 2) * TEXT_LINE;
 }
 
-static void draw_fab_layer(pcb_draw_info_t *info, pcb_hid_gc_t gc, const pcb_hid_expose_ctx_t *e, pcb_layer_t *layer, int found)
+static void draw_fab_layer(pcb_draw_info_t *info, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e, pcb_layer_t *layer, int found)
 {
-	pcb_hid_set_line_width(gc, PCB_MIL_TO_COORD(10));
+	rnd_hid_set_line_width(gc, RND_MIL_TO_COORD(10));
 	PCB_LINE_LOOP(layer);
 	{
-		pcb_render->draw_line(gc, line->Point1.X, line->Point1.Y, line->Point2.X, line->Point2.Y);
+		rnd_render->draw_line(gc, line->Point1.X, line->Point1.Y, line->Point2.X, line->Point2.Y);
 	}
 	PCB_END_LOOP;
 	PCB_ARC_LOOP(layer);
 	{
-		pcb_render->draw_arc(gc, arc->X, arc->Y, arc->Width, arc->Height, arc->StartAngle, arc->Delta);
+		rnd_render->draw_arc(gc, arc->X, arc->Y, arc->Width, arc->Height, arc->StartAngle, arc->Delta);
 	}
 	PCB_END_LOOP;
 	PCB_TEXT_LOOP(layer);
@@ -196,22 +195,22 @@ static void draw_fab_layer(pcb_draw_info_t *info, pcb_hid_gc_t gc, const pcb_hid
 	}
 	PCB_END_LOOP;
 	if (!found) {
-		pcb_hid_set_line_width(gc, FAB_LINE_W);
-		text_at(info, gc, PCB->hidlib.size_x / 2, PCB->hidlib.size_y + PCB_MIL_TO_COORD(20), 1, "Board outline is the centerline of this path");
+		rnd_hid_set_line_width(gc, FAB_LINE_W);
+		text_at(info, gc, PCB->hidlib.size_x / 2, PCB->hidlib.size_y + RND_MIL_TO_COORD(20), 1, "Board outline is the centerline of this path");
 	}
 }
 
-static void DrawFab(pcb_draw_info_t *info, pcb_hid_gc_t gc, const pcb_hid_expose_ctx_t *e)
+static void DrawFab(pcb_draw_info_t *info, rnd_hid_gc_t gc, const rnd_hid_expose_ctx_t *e)
 {
 	pcb_drill_info_t *AllDrills;
 	int i, n, yoff, total_drills = 0, ds = 0, found;
 	char utcTime[64];
 
 	AllDrills = drill_get_info(PCB->Data);
-	if (pcbhl_conf.editor.grid_unit->family == PCB_UNIT_IMPERIAL)
-		drill_round_info(AllDrills, PCB_MIL_TO_COORD(1));
+	if (rnd_conf.editor.grid_unit->family == RND_UNIT_IMPERIAL)
+		drill_round_info(AllDrills, RND_MIL_TO_COORD(1));
 	else
-		drill_round_info(AllDrills, PCB_MM_TO_COORD(0.01));
+		drill_round_info(AllDrills, RND_MM_TO_COORD(0.01));
 	yoff = -TEXT_LINE;
 
 	/* count how many drill description lines will be needed */
@@ -226,8 +225,8 @@ static void DrawFab(pcb_draw_info_t *info, pcb_hid_gc_t gc, const pcb_hid_expose
 		yoff -= (4 - ds) * TEXT_LINE;
 	}
 
-	pcb_hid_set_line_cap(gc, pcb_cap_round);
-	pcb_hid_set_line_width(gc, FAB_LINE_W);
+	rnd_hid_set_line_cap(gc, rnd_cap_round);
+	rnd_hid_set_line_width(gc, FAB_LINE_W);
 
 	for (n = AllDrills->DrillN - 1; n >= 0; n--) {
 		int plated_sym = -1, unplated_sym = -1;
@@ -236,10 +235,10 @@ static void DrawFab(pcb_draw_info_t *info, pcb_hid_gc_t gc, const pcb_hid_expose
 			plated_sym = --ds;
 		if (drill->UnplatedCount)
 			unplated_sym = --ds;
-		pcb_render->set_color(gc, &conf_core.appearance.color.pin);
+		rnd_render->set_color(gc, &conf_core.appearance.color.pin);
 		for (i = 0; i < drill->PinN; i++) {
 			int unplated = 1;
-			pcb_coord_t x, y;
+			rnd_coord_t x, y;
 			assert(drill->hole[i]->type == PCB_OBJ_PSTK);
 			{
 				pcb_pstk_t *ps = (pcb_pstk_t *)drill->hole[i];
@@ -252,48 +251,48 @@ static void DrawFab(pcb_draw_info_t *info, pcb_hid_gc_t gc, const pcb_hid_expose
 		}
 		if (plated_sym != -1) {
 			drill_sym(gc, plated_sym, TEXT_SIZE, yoff + TEXT_SIZE / 4);
-			text_at(info, gc, PCB_MIL_TO_COORD(1350), yoff, PCB_MIL_TO_COORD(2), "YES");
-			text_at(info, gc, PCB_MIL_TO_COORD(980), yoff, PCB_MIL_TO_COORD(2), "%d", drill->PinCount + drill->ViaCount - drill->UnplatedCount);
+			text_at(info, gc, RND_MIL_TO_COORD(1350), yoff, RND_MIL_TO_COORD(2), "YES");
+			text_at(info, gc, RND_MIL_TO_COORD(980), yoff, RND_MIL_TO_COORD(2), "%d", drill->PinCount + drill->ViaCount - drill->UnplatedCount);
 
 			if (unplated_sym != -1)
 				yoff -= TEXT_LINE;
 		}
 		if (unplated_sym != -1) {
 			drill_sym(gc, unplated_sym, TEXT_SIZE, yoff + TEXT_SIZE / 4);
-			text_at(info, gc, PCB_MIL_TO_COORD(1400), yoff, PCB_MIL_TO_COORD(2), "NO");
-			text_at(info, gc, PCB_MIL_TO_COORD(980), yoff, PCB_MIL_TO_COORD(2), "%d", drill->UnplatedCount);
+			text_at(info, gc, RND_MIL_TO_COORD(1400), yoff, RND_MIL_TO_COORD(2), "NO");
+			text_at(info, gc, RND_MIL_TO_COORD(980), yoff, RND_MIL_TO_COORD(2), "%d", drill->UnplatedCount);
 		}
-		pcb_render->set_color(gc, &conf_core.appearance.color.element);
-		if (pcbhl_conf.editor.grid_unit->family == PCB_UNIT_IMPERIAL)
-			text_at(info, gc, PCB_MIL_TO_COORD(450), yoff, PCB_MIL_TO_COORD(2), "%0.3f", PCB_COORD_TO_INCH(drill->DrillSize));
+		rnd_render->set_color(gc, &conf_core.appearance.color.element);
+		if (rnd_conf.editor.grid_unit->family == RND_UNIT_IMPERIAL)
+			text_at(info, gc, RND_MIL_TO_COORD(450), yoff, RND_MIL_TO_COORD(2), "%0.3f", RND_COORD_TO_INCH(drill->DrillSize));
 		else
-			text_at(info, gc, PCB_MIL_TO_COORD(450), yoff, PCB_MIL_TO_COORD(2), "%1.2f", PCB_COORD_TO_MM(drill->DrillSize));
+			text_at(info, gc, RND_MIL_TO_COORD(450), yoff, RND_MIL_TO_COORD(2), "%1.2f", RND_COORD_TO_MM(drill->DrillSize));
 		if (plated_sym != -1 && unplated_sym != -1) {
-			if (pcbhl_conf.editor.grid_unit->family == PCB_UNIT_IMPERIAL)
-				text_at(info, gc, PCB_MIL_TO_COORD(450), yoff + TEXT_LINE, PCB_MIL_TO_COORD(2), "%0.3f", PCB_COORD_TO_INCH(drill->DrillSize));
+			if (rnd_conf.editor.grid_unit->family == RND_UNIT_IMPERIAL)
+				text_at(info, gc, RND_MIL_TO_COORD(450), yoff + TEXT_LINE, RND_MIL_TO_COORD(2), "%0.3f", RND_COORD_TO_INCH(drill->DrillSize));
 			else
-				text_at(info, gc, PCB_MIL_TO_COORD(450), yoff + TEXT_LINE, PCB_MIL_TO_COORD(2), "%1.2f", PCB_COORD_TO_MM(drill->DrillSize));
+				text_at(info, gc, RND_MIL_TO_COORD(450), yoff + TEXT_LINE, RND_MIL_TO_COORD(2), "%1.2f", RND_COORD_TO_MM(drill->DrillSize));
 		}
 		yoff -= TEXT_LINE;
 		total_drills += drill->PinCount;
 		total_drills += drill->ViaCount;
 	}
 
-	pcb_render->set_color(gc, &conf_core.appearance.color.element);
-	text_at(info, gc, 0, yoff, PCB_MIL_TO_COORD(9), "Symbol");
-	if (pcbhl_conf.editor.grid_unit->family == PCB_UNIT_IMPERIAL)
-		text_at(info, gc, PCB_MIL_TO_COORD(410), yoff, PCB_MIL_TO_COORD(9), "Diam. (Inch)");
+	rnd_render->set_color(gc, &conf_core.appearance.color.element);
+	text_at(info, gc, 0, yoff, RND_MIL_TO_COORD(9), "Symbol");
+	if (rnd_conf.editor.grid_unit->family == RND_UNIT_IMPERIAL)
+		text_at(info, gc, RND_MIL_TO_COORD(410), yoff, RND_MIL_TO_COORD(9), "Diam. (Inch)");
 	else
-		text_at(info, gc, PCB_MIL_TO_COORD(410), yoff, PCB_MIL_TO_COORD(9), "Diam. (mm)");
-	text_at(info, gc, PCB_MIL_TO_COORD(950), yoff, PCB_MIL_TO_COORD(9), "Count");
-	text_at(info, gc, PCB_MIL_TO_COORD(1300), yoff, PCB_MIL_TO_COORD(9), "Plated?");
+		text_at(info, gc, RND_MIL_TO_COORD(410), yoff, RND_MIL_TO_COORD(9), "Diam. (mm)");
+	text_at(info, gc, RND_MIL_TO_COORD(950), yoff, RND_MIL_TO_COORD(9), "Count");
+	text_at(info, gc, RND_MIL_TO_COORD(1300), yoff, RND_MIL_TO_COORD(9), "Plated?");
 	yoff -= TEXT_LINE;
 	text_at(info, gc, 0, yoff, 0,
 					"There are %d different drill sizes used in this layout, %d holes total", AllDrills->DrillN, total_drills);
 	/* Create a portable timestamp. */
 
 	if (!conf_draw_fab.plugins.draw_fab.omit_date)
-		pcb_print_utc(utcTime, sizeof(utcTime), 0);
+		rnd_print_utc(utcTime, sizeof(utcTime), 0);
 	else
 		strcpy(utcTime, "<date>");
 
@@ -302,50 +301,50 @@ static void DrawFab(pcb_draw_info_t *info, pcb_hid_gc_t gc, const pcb_hid_expose
 		pcb_layer_t *l = &PCB->Data->Layer[i];
 		pcb_layer_type_t flags = pcb_layer_flags(PCB, i);
 		int purpi = pcb_layer_purpose(PCB, i, NULL);
-		if (PCB_LAYER_IS_ROUTE(flags, purpi) && (!PCB_RTREE_EMPTY(l->line_tree) || !PCB_RTREE_EMPTY(l->arc_tree))) {
+		if (PCB_LAYER_IS_ROUTE(flags, purpi) && (!RND_RTREE_EMPTY(l->line_tree) || !RND_RTREE_EMPTY(l->arc_tree))) {
 			draw_fab_layer(info, gc, e, l, found);
 			found = 1;
 		}
 	}
 	if (!found) {
-		pcb_hid_set_line_width(gc, PCB_MIL_TO_COORD(10));
-		pcb_render->draw_line(gc, 0, 0, PCB->hidlib.size_x, 0);
-		pcb_render->draw_line(gc, 0, 0, 0, PCB->hidlib.size_y);
-		pcb_render->draw_line(gc, PCB->hidlib.size_x, 0, PCB->hidlib.size_x, PCB->hidlib.size_y);
-		pcb_render->draw_line(gc, 0, PCB->hidlib.size_y, PCB->hidlib.size_x, PCB->hidlib.size_y);
+		rnd_hid_set_line_width(gc, RND_MIL_TO_COORD(10));
+		rnd_render->draw_line(gc, 0, 0, PCB->hidlib.size_x, 0);
+		rnd_render->draw_line(gc, 0, 0, 0, PCB->hidlib.size_y);
+		rnd_render->draw_line(gc, PCB->hidlib.size_x, 0, PCB->hidlib.size_x, PCB->hidlib.size_y);
+		rnd_render->draw_line(gc, 0, PCB->hidlib.size_y, PCB->hidlib.size_x, PCB->hidlib.size_y);
 		/*FPrintOutline (); */
-		pcb_hid_set_line_width(gc, FAB_LINE_W);
-		text_at(info, gc, PCB_MIL_TO_COORD(2000), yoff, 0,
-						"Maximum Dimensions: %f mils wide, %f mils high", PCB_COORD_TO_MIL(PCB->hidlib.size_x), PCB_COORD_TO_MIL(PCB->hidlib.size_y));
-		text_at(info, gc, PCB->hidlib.size_x / 2, PCB->hidlib.size_y + PCB_MIL_TO_COORD(20), 1,
+		rnd_hid_set_line_width(gc, FAB_LINE_W);
+		text_at(info, gc, RND_MIL_TO_COORD(2000), yoff, 0,
+						"Maximum Dimensions: %f mils wide, %f mils high", RND_COORD_TO_MIL(PCB->hidlib.size_x), RND_COORD_TO_MIL(PCB->hidlib.size_y));
+		text_at(info, gc, PCB->hidlib.size_x / 2, PCB->hidlib.size_y + RND_MIL_TO_COORD(20), 1,
 						"Board outline is the centerline of this %f mil"
 						" rectangle - 0,0 to %f,%f mils",
-						PCB_COORD_TO_MIL(FAB_LINE_W), PCB_COORD_TO_MIL(PCB->hidlib.size_x), PCB_COORD_TO_MIL(PCB->hidlib.size_y));
+						RND_COORD_TO_MIL(FAB_LINE_W), RND_COORD_TO_MIL(PCB->hidlib.size_x), RND_COORD_TO_MIL(PCB->hidlib.size_y));
 	}
 	yoff -= TEXT_LINE;
 
-	text_at(info, gc, PCB_MIL_TO_COORD(2000), yoff, 0, "Date: %s", utcTime);
+	text_at(info, gc, RND_MIL_TO_COORD(2000), yoff, 0, "Date: %s", utcTime);
 	yoff -= TEXT_LINE;
-	text_at(info, gc, PCB_MIL_TO_COORD(2000), yoff, 0, "Author: %s", pcb_author());
+	text_at(info, gc, RND_MIL_TO_COORD(2000), yoff, 0, "Author: %s", pcb_author());
 	yoff -= TEXT_LINE;
-	text_at(info, gc, PCB_MIL_TO_COORD(2000), yoff, 0, "Title: %s - Fabrication Drawing", PCB_UNKNOWN(PCB->hidlib.name));
+	text_at(info, gc, RND_MIL_TO_COORD(2000), yoff, 0, "Title: %s - Fabrication Drawing", RND_UNKNOWN(PCB->hidlib.name));
 }
 
 int pplg_check_ver_draw_fab(int ver_needed) { return 0; }
 
 void pplg_uninit_draw_fab(void)
 {
-	pcb_conf_unreg_fields("plugins/draw_fab/");
+	rnd_conf_unreg_fields("plugins/draw_fab/");
 }
 
 int pplg_init_draw_fab(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 	pcb_stub_draw_fab = DrawFab;
 	pcb_stub_draw_fab_overhang = DrawFab_overhang;
 
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
-	pcb_conf_reg_field(conf_draw_fab, field,isarray,type_name,cpath,cname,desc,flags);
+	rnd_conf_reg_field(conf_draw_fab, field,isarray,type_name,cpath,cname,desc,flags);
 #include "draw_fab_conf_fields.h"
 
 
