@@ -335,7 +335,7 @@ static int pcb_dlg_rule_edit(rnd_conf_role_t role, const char *rule)
 		RND_DAD_END(ctx->dlg);
 		RND_DAD_BEGIN_HBOX(ctx->dlg);
 			RND_DAD_LABEL(ctx->dlg, "Disable drc rule:");
-			RND_DAD_BOOL(ctx->dlg, "");
+			RND_DAD_BOOL(ctx->dlg);
 			ctx->wdisable = RND_DAD_CURRENT(ctx->dlg);
 		RND_DAD_END(ctx->dlg);
 		RND_DAD_LABEL(ctx->dlg, "DRC violation description:");
@@ -823,6 +823,19 @@ static void dlist_select(rnd_hid_attribute_t *attrib, void *hid_ctx, rnd_hid_row
 	gds_uninit(&tmp);
 }
 
+static void drc_query_refresh_def(void)
+{
+	drc_rlist_ctx_t *ctx = &drc_rlist_ctx;
+	rnd_hid_attribute_t *attr;
+	rnd_hid_row_t *row;
+
+	if (!ctx->active)
+		return;
+
+	attr = &(ctx->dlg[ctx->wdlist]);
+	row = rnd_dad_tree_get_selected(attr);
+	dlist_select(attr, ctx->dlg_hid_ctx, row);
+}
 
 static void pcb_dlg_drc_rlist_rules(int *wpane)
 {
