@@ -60,6 +60,8 @@ static void drc_rlist_pcb2dlg(void);
 
 #include "drc_query_stat.c"
 
+static rnd_conf_hid_id_t cfgid;
+
 static const char *drc_query_cookie = "drc_query";
 
 extern conf_drc_query_t conf_drc_query;
@@ -80,20 +82,37 @@ typedef struct {
 	long hit_cnt;
 } drc_qry_ctx_t;
 
-rnd_coord_t load_obj_const(pcb_obj_qry_const_t *cnst)
+static fgw_arg_t load_obj_const(pcb_obj_qry_const_t *cnst)
 {
+	fgw_arg_t a;
+
 	switch(cnst->val.type) {
-		case PCBQ_VT_COORD: return cnst->val.data.crd;
-		case PCBQ_VT_LONG: return cnst->val.data.lng;
-		case PCBQ_VT_DOUBLE: return cnst->val.data.dbl;
-		
+		case PCBQ_VT_COORD:
+			a.type = FGW_COORD;
+			fgw_coord(&a) = cnst->val.data.crd;
+			return a;
+		case PCBQ_VT_LONG:
+			a.type = FGW_LONG;
+			a.val.nat_long = cnst->val.data.lng;
+			return a;
+		case PCBQ_VT_DOUBLE:
+			a.type = FGW_DOUBLE;
+			a.val.nat_double = cnst->val.data.dbl;
+			return a;
+
+		case PCBQ_VT_STRING:
+			a.type = FGW_STR | FGW_DYN;
+			a.val.str = rnd_strdup(cnst->val.data.str);
+			return a;
+
 		case PCBQ_VT_VOID:
 		case PCBQ_VT_OBJ:
 		case PCBQ_VT_LST:
-		case PCBQ_VT_STRING:
 			break;
 	}
-	return 0;
+
+	a.type = FGW_INVALID;
+	return a;
 }
 
 void drc_qry_exec_cb(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current)
@@ -117,7 +136,7 @@ void drc_qry_exec_cb(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current)
 	violation = pcb_view_new(&qctx->pcb->hidlib, qctx->type, qctx->title, qctx->desc);
 	if (res->type == PCBQ_VT_LST) {
 		int i;
-		rnd_coord_t *expv = NULL, expv_, *mesv = NULL, mesv_;
+		fgw_arg_t *expv = NULL, expv_, *mesv = NULL, mesv_;
 		for(i = 0; i < res->data.lst.used-1; i+=2) {
 			pcb_any_obj_t *cmd = res->data.lst.array[i], *obj = res->data.lst.array[i+1];
 			pcb_qry_drc_ctrl_t ctrl = pcb_qry_drc_ctrl_decode(cmd);
@@ -227,7 +246,7 @@ static void pcb_drc_query(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_e
 	gdl_iterator_t it;
 	rnd_conf_listitem_t *i;
 	long cnt = 0;
-	int bufno = -1;
+	int bufno = -1, *ran;
 	pcb_qry_exec_t ec;
 	drc_query_prog_t prog;
 
@@ -255,6 +274,10 @@ static void pcb_drc_query(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_e
 		if ((dis != NULL) && (*dis != 0))
 			continue;
 
+		assert(argv[1].type == RND_EVARG_PTR);
+		ran = argv[1].d.p;
+		(*ran)++;
+
 		prog.name = i->name;
 		cnt += drc_qry_exec(&ec, pcb, &pcb_drc_lst, i->name,
 			load_str(rule, i, "type"), load_str(rule, i, "title"), load_str(rule, i, "desc"),
@@ -269,6 +292,12 @@ static void pcb_drc_query(rnd_hidlib_t *hidlib, void *user_data, int argc, rnd_e
 	drc_rlist_pcb2dlg(); /* for the run time */
 }
 
+static void drc_query_refresh_def(void);
+static void drc_query_defchg(rnd_conf_native_t *cfg, int v)
+{
+	drc_query_refresh_def();
+}
+
 static vtp0_t free_drc_conf_nodes;
 static rnd_conf_native_t *nat_defs = NULL;
 static rnd_conf_native_t *nat_rules = NULL;
@@ -321,27 +350,28 @@ static void drc_query_newconf(rnd_conf_native_t *cfg, rnd_conf_listitem_t *i)
 		lht_node_t *nd = i->prop.src;
 		char *path = rnd_concat(DRC_CONF_PATH_CONST, nd->name, NULL);
 		rnd_coord_t *c;
+		rnd_conf_native_t *nat = rnd_conf_get_field(path);
 
-		if (rnd_conf_get_field(path) == NULL) {
+		if ((nat == NULL) || (nat->used == 0)) { /* create the definition and set default value (but only once) */
 			union {
 				rnd_coord_t c;
 				double d;
 				void *ptr;
 				char *str;
 			} anyval;
-			rnd_conf_native_t *nat;
 			lht_node_t *ndesc = lht_dom_hash_get(nd, "desc");
 			lht_node_t *ntype = lht_dom_hash_get(nd, "type");
 			lht_node_t *ndefault = lht_dom_hash_get(nd, "default");
 			lht_node_t *nlegacy = lht_dom_hash_get(nd, "legacy");
 			const char *sdesc = "n/a", *stype = NULL, *sdefault = NULL, *slegacy = NULL;
 			rnd_conf_native_type_t type;
+			int pathfree = 1;
+
 			if ((ndesc != NULL) && (ndesc->type == LHT_TEXT)) sdesc = ndesc->data.text.value;
 			if ((ntype != NULL) && (ntype->type == LHT_TEXT)) stype = ntype->data.text.value;
 			if ((ndefault != NULL) && (ndefault->type == LHT_TEXT)) sdefault = ndefault->data.text.value;
 			if ((nlegacy != NULL) && (nlegacy->type == LHT_TEXT)) slegacy = nlegacy->data.text.value;
 
-
 			if (stype == NULL) {
 				if ((ndesc != NULL) || (sdefault != NULL))
 					rnd_message(RND_MSG_ERROR, "drc_query: missing type field for constant %s\n", nd->name);
@@ -354,24 +384,38 @@ static void drc_query_newconf(rnd_conf_native_t *cfg, rnd_conf_listitem_t *i)
 				goto fail;
 			}
 
-			c = calloc(sizeof(anyval), 1);
-			nat = rnd_conf_reg_field_(c, 1, type, path, rnd_strdup(sdesc), 0);
+			/* create the new conf node for the def if it doesn't already exist */
 			if (nat == NULL) {
-				free(c);
-				rnd_message(RND_MSG_ERROR, "drc_query: failed to register conf node '%s'\n", path);
-				goto fail;
+				c = calloc(sizeof(anyval), 1);
+				pathfree = 0;
+				nat = rnd_conf_reg_field_(c, 1, type, path, rnd_strdup(sdesc), 0);
+				if (nat == NULL) {
+					free(c);
+					rnd_message(RND_MSG_ERROR, "drc_query: failed to register conf node '%s'\n", path);
+					goto fail;
+				}
+
+				nat->random_flags.dyn_hash_path = 1;
+				nat->random_flags.dyn_desc = 1;
+				nat->random_flags.dyn_val = 1;
+				vtp0_append(&free_drc_conf_nodes, nat);
 			}
 
-			nat->random_flags.dyn_hash_path = 1;
-			nat->random_flags.dyn_desc = 1;
-			nat->random_flags.dyn_val = 1;
-			vtp0_append(&free_drc_conf_nodes, nat);
-
+			/* set default value */
 			if (slegacy != NULL)
 				pcb_conf_legacy(path, slegacy);
 			else if (sdefault != NULL)
 				rnd_conf_set(RND_CFR_INTERNAL, path, -1, sdefault, RND_POL_OVERWRITE);
-			path = NULL; /* hash key shall not be free'd */
+
+			/* create the chnage binding so the gui can be updated */
+			{
+				static rnd_conf_hid_callbacks_t cbs2;
+				cbs2.val_change_post = drc_query_defchg;
+				rnd_conf_hid_set_cb(rnd_conf_get_field(path), cfgid, &cbs2);
+			}
+
+			if (!pathfree)
+				path = NULL; /* hash key shall not be free'd */
 		}
 		fail:;
 		free(path);
@@ -485,7 +529,7 @@ static int pcb_drc_query_any_by_name(const char *name, int is_rule, lht_node_t *
 		if (nd == NULL) { /* allocate new node */
 			ret = 0;
 			MKDIR_RULE_ROOT(nd, RND_CFR_DESIGN, RND_POL_APPEND, goto skip);
-			if (is_rule) 
+			if (is_rule)
 				MKDIR_RULES(nd, goto skip);
 			else
 				MKDIR_CONSTS(nd, goto skip);
@@ -559,6 +603,8 @@ static int pcb_drc_query_create(rnd_hidlib_t *hidlib, int is_rule, const char *r
 	return 0;
 }
 
+void d2() {}
+
 static int pcb_drc_query_set(rnd_hidlib_t *hidlib, int is_rule, const char *rule, const char *key, const char *val)
 {
 	lht_node_t *nd;
@@ -568,6 +614,20 @@ static int pcb_drc_query_set(rnd_hidlib_t *hidlib, int is_rule, const char *rule
 
 	MKDIR_ND_SET_TEXT(nd, key, val, return -1);
 
+	/* copy default value when set in a separate step, after node creation */
+	if (!is_rule && (nat_defs != NULL)) {
+		char *path = rnd_concat(DRC_CONF_PATH_CONST, nd->name, NULL);
+		rnd_conf_native_t *nat = rnd_conf_get_field(path);
+
+		/* set value only if it's a new node, so existing value is not overwritten */
+		if ((nat == NULL) || (nat->used == 0)) {
+			rnd_conf_listitem_t i = {0};
+			i.prop.src = nd;
+			drc_query_newconf(nat_defs, &i);
+		}
+		free(path);
+	}
+
 	return 0;
 }
 
@@ -589,7 +649,6 @@ static int pcb_drc_query_get_rule_defs(rnd_hidlib_t *hidlib, const char *rule, f
 	htsi_t defs;
 	htsi_entry_t *e;
 	gds_t lst;
-
 	fgw_arg_t tmp;
 	if (pcb_drc_query_get(hidlib, 1, rule, "query", &tmp) != 0)
 		return -1;
@@ -785,7 +844,7 @@ static fgw_error_t pcb_act_DrcQueryImport(fgw_arg_t *res, int argc, fgw_arg_t *a
 	fclose(f);
 
 	if (ires == 0)
-		pcb_board_set_changed_flag(rnd_true);
+		pcb_board_set_changed_flag(PCB_ACT_BOARD, rnd_true);
 
 	free(autofree);
 	RND_ACT_IRES(ires);
@@ -829,6 +888,9 @@ static rnd_conf_hid_callbacks_t cbs;
 
 int pplg_init_drc_query(void)
 {
+	static rnd_conf_hid_callbacks_t cbs2;
+	static rnd_conf_hid_id_t cfgid;
+
 	RND_API_CHK_VER;
 
 	pcb_drcq_stat_init();
@@ -837,13 +899,16 @@ int pplg_init_drc_query(void)
 
 	vtp0_init(&free_drc_conf_nodes);
 	cbs.new_hlist_item_post = drc_query_newconf;
-	rnd_conf_hid_reg(drc_query_cookie, &cbs);
+	cfgid = rnd_conf_hid_reg(drc_query_cookie, &cbs);
 
 	rnd_conf_reg_file(DRC_QUERY_CONF_FN, drc_query_conf_internal);
 #define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
 	rnd_conf_reg_field(conf_drc_query, field,isarray,type_name,cpath,cname,desc,flags);
 #include "drc_query_conf_fields.h"
 
+	cbs2.val_change_post = drc_query_defchg;
+	rnd_conf_hid_set_cb(rnd_conf_get_field("plugins/drc_query/definitions"), cfgid, &cbs2);
+
 	RND_REGISTER_ACTIONS(drc_query_action_list, drc_query_cookie)
 	pcb_drc_impl_reg(&drc_query_impl);
 
