@@ -63,7 +63,8 @@ typedef struct pcb_bom_list_s {
 
 static rnd_export_opt_t *bom_get_export_options(rnd_hid_t *hid, int *n)
 {
-	if ((PCB != NULL) && (bom_options[HA_bomfile].default_val.str == NULL))
+	char **val = bom_options[HA_bomfile].value;
+	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
 		pcb_derive_default_filename(PCB->hidlib.filename, &bom_options[HA_bomfile], ".bom");
 
 	if (n)
@@ -193,7 +194,7 @@ static int bom_print(void)
 		/* insert this component into the bill of materials list */
 		bom = bom_insert((char *) RND_UNKNOWN(subc->refdes),
 			(char *) RND_UNKNOWN(pcb_subc_name(subc, "bom::footprint")),
-			(char *) RND_UNKNOWN(rnd_attribute_get(&subc->Attributes, "value")),
+			(char *) RND_UNKNOWN(pcb_attribute_get(&subc->Attributes, "value")),
 			bom);
 	}
 	PCB_END_LOOP;
@@ -223,13 +224,10 @@ static int bom_print(void)
 
 static void bom_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 {
-	int i;
 	pcb_cam_t cam;
 
 	if (!options) {
 		bom_get_export_options(hid, 0);
-		for (i = 0; i < NUM_OPTIONS; i++)
-			bom_values[i] = bom_options[i].default_val;
 		options = bom_values;
 	}
 
@@ -254,7 +252,7 @@ static int bom_usage(rnd_hid_t *hid, const char *topic)
 
 static int bom_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
-	rnd_export_register_opts(bom_options, sizeof(bom_options) / sizeof(bom_options[0]), bom_cookie, 0);
+	rnd_export_register_opts2(hid, bom_options, sizeof(bom_options) / sizeof(bom_options[0]), bom_cookie, 0);
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
@@ -265,6 +263,7 @@ int pplg_check_ver_export_bom(int ver_needed) { return 0; }
 void pplg_uninit_export_bom(void)
 {
 	rnd_export_remove_opts_by_cookie(bom_cookie);
+	rnd_hid_remove_hid(&bom_hid);
 }
 
 int pplg_init_export_bom(void)
@@ -283,6 +282,7 @@ int pplg_init_export_bom(void)
 	bom_hid.get_export_options = bom_get_export_options;
 	bom_hid.do_export = bom_do_export;
 	bom_hid.parse_arguments = bom_parse_arguments;
+	bom_hid.argument_array = bom_values;
 
 	bom_hid.usage = bom_usage;
 
