@@ -16,7 +16,7 @@ typedef enum aperture_shape_e aperture_shape_t;
 
 typedef struct aperture {
 	int dCode;										/* The RS-274X D code */
-	pcb_coord_t width;									/* Size in pcb units */
+	rnd_coord_t width;									/* Size in pcb units */
 	aperture_shape_t shape;					/* ROUND/SQUARE etc */
 	struct aperture *next;
 } aperture_t;
@@ -31,23 +31,23 @@ void init_aperture_list(aperture_list_t *list);
 void uninit_aperture_list(aperture_list_t *list);
 
 /* Create and add a new aperture to the list */
-aperture_t *add_aperture(aperture_list_t *list, pcb_coord_t width, aperture_shape_t shape);
+aperture_t *add_aperture(aperture_list_t *list, rnd_coord_t width, aperture_shape_t shape);
 
 /* Fetch an aperture from the list with the specified
  *  width/shape, creating a new one if none exists */
-aperture_t *find_aperture(aperture_list_t *list, pcb_coord_t width, aperture_shape_t shape);
+aperture_t *find_aperture(aperture_list_t *list, rnd_coord_t width, aperture_shape_t shape);
 
 /*** drill ***/
 
 typedef struct {
-	pcb_coord_t diam;
-	pcb_coord_t x;
-	pcb_coord_t y;
+	rnd_coord_t diam;
+	rnd_coord_t x;
+	rnd_coord_t y;
 
 	/* for slots */
 	int is_slot;
-	pcb_coord_t x2;
-	pcb_coord_t y2;
+	rnd_coord_t x2;
+	rnd_coord_t y2;
 } pcb_pending_drill_t;
 
 #define GVT(x) vtpdr_ ## x
@@ -70,7 +70,7 @@ typedef struct pcb_drill_ctx_s {
 
 void pcb_drill_init(pcb_drill_ctx_t *ctx, int *aper_cnt);
 void pcb_drill_uninit(pcb_drill_ctx_t *ctx);
-pcb_pending_drill_t *pcb_drill_new_pending(pcb_drill_ctx_t *ctx, pcb_coord_t x1, pcb_coord_t y1, pcb_coord_t x2, pcb_coord_t y2, pcb_coord_t diam);
+pcb_pending_drill_t *pcb_drill_new_pending(pcb_drill_ctx_t *ctx, rnd_coord_t x1, rnd_coord_t y1, rnd_coord_t x2, rnd_coord_t y2, rnd_coord_t diam);
 void pcb_drill_sort(pcb_drill_ctx_t *ctx);
 
 #endif
