@@ -84,8 +84,8 @@ static rnd_hid_attr_val_t fidocadj_values[NUM_OPTIONS];
 static rnd_export_opt_t *fidocadj_get_export_options(rnd_hid_t *hid, int *n)
 {
 	const char *suffix = ".fcd";
-
-	if ((PCB != NULL)  && (fidocadj_attribute_list[HA_fidocadjfile].default_val.str == NULL))
+	char **val = fidocadj_attribute_list[HA_fidocadjfile].value;
+	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
 		pcb_derive_default_filename(PCB->hidlib.filename, &fidocadj_attribute_list[HA_fidocadjfile], suffix);
 
 	if (n)
@@ -164,14 +164,12 @@ static void fidocadj_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 {
 	FILE *f;
 	const char *filename, *libfile;
-	int n, fidoly_next, have_lib;
+	int fidoly_next, have_lib;
 	rnd_layer_id_t lid;
 	htsi_t lib_names; /* hash of names found in the library, if have_lib is 1 */
 
 	if (!options) {
 		fidocadj_get_export_options(hid, 0);
-		for (n = 0; n < NUM_OPTIONS; n++)
-			fidocadj_values[n] = fidocadj_attribute_list[n].default_val;
 		options = fidocadj_values;
 	}
 
@@ -312,7 +310,7 @@ TODO("textrot: can we exprot rotation with %f?")
 	PCB_END_LOOP;
 
 	PCB_SUBC_LOOP(PCB->Data) {
-		const char *fp = rnd_attribute_get(&subc->Attributes, "footprint");
+		const char *fp = pcb_attribute_get(&subc->Attributes, "footprint");
 		if ((fp != NULL) && have_lib && (htsi_get(&lib_names, fp))) {
 			rnd_coord_t x, y;
 			double rot = 0.0;
@@ -348,7 +346,7 @@ TODO(": figure how to store side")
 
 static int fidocadj_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
-	rnd_export_register_opts(fidocadj_attribute_list, sizeof(fidocadj_attribute_list) / sizeof(fidocadj_attribute_list[0]), fidocadj_cookie, 0);
+	rnd_export_register_opts2(hid, fidocadj_attribute_list, sizeof(fidocadj_attribute_list) / sizeof(fidocadj_attribute_list[0]), fidocadj_cookie, 0);
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
@@ -365,6 +363,7 @@ int pplg_check_ver_export_fidocadj(int ver_needed) { return 0; }
 void pplg_uninit_export_fidocadj(void)
 {
 	rnd_export_remove_opts_by_cookie(fidocadj_cookie);
+	rnd_hid_remove_hid(&fidocadj_hid);
 }
 
 int pplg_init_export_fidocadj(void)
@@ -383,6 +382,7 @@ int pplg_init_export_fidocadj(void)
 	fidocadj_hid.get_export_options = fidocadj_get_export_options;
 	fidocadj_hid.do_export = fidocadj_do_export;
 	fidocadj_hid.parse_arguments = fidocadj_parse_arguments;
+	fidocadj_hid.argument_array = fidocadj_values;
 
 	fidocadj_hid.usage = fidocadj_usage;
 
