@@ -39,7 +39,7 @@
 
 #include "../src_plugins/export_excellon/aperture.h"
 
-#include "../src_plugins/lib_hid_common/xpm.h"
+#include <librnd/plugins/lib_hid_common/xpm.h>
 
 
 const char *gerber_cookie = "gerber HID";
@@ -260,7 +260,8 @@ static rnd_hid_attr_val_t gerber_values[NUM_OPTIONS];
 
 static rnd_export_opt_t *gerber_get_export_options(rnd_hid_t *hid, int *n)
 {
-	if ((PCB != NULL)  && (gerber_options[HA_gerberfile].default_val.str == NULL))
+	char **val = gerber_options[HA_gerberfile].value;
+	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
 		pcb_derive_default_filename(PCB->hidlib.filename, &gerber_options[HA_gerberfile], "");
 
 	if (n)
@@ -325,8 +326,6 @@ static void gerber_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	if (!options) {
 		gerber_get_export_options(hid, NULL);
-		for (i = 0; i < NUM_OPTIONS; i++)
-			gerber_values[i] = gerber_options[i].default_val;
 		options = gerber_values;
 	}
 
@@ -421,7 +420,7 @@ static void gerber_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 static int gerber_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
-	rnd_export_register_opts(gerber_options, NUM_OPTIONS, gerber_cookie, 0);
+	rnd_export_register_opts2(hid, gerber_options, NUM_OPTIONS, gerber_cookie, 0);
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
@@ -1067,6 +1066,7 @@ void pplg_uninit_export_gerber(void)
 	rnd_export_remove_opts_by_cookie(gerber_cookie);
 	rnd_conf_unreg_fields("plugins/export_gerber/");
 	rnd_event_unbind_allcookie(gerber_cookie);
+	rnd_hid_remove_hid(&gerber_hid);
 }
 
 int pplg_init_export_gerber(void)
@@ -1109,6 +1109,7 @@ int pplg_init_export_gerber(void)
 	gerber_hid.calibrate = gerber_calibrate;
 	gerber_hid.set_crosshair = gerber_set_crosshair;
 	gerber_hid.usage = gerber_usage;
+	gerber_hid.argument_array = gerber_values;
 
 	rnd_hid_register_hid(&gerber_hid);
 
