@@ -64,11 +64,11 @@ const char *oldconn_cookie = "export_oldconn HID";
 static void print_subc_name(FILE *f, pcb_subc_t *subc)
 {
 	fputc('(', f);
-	pcb_print_quoted_string(f, (char *)RND_EMPTY(rnd_attribute_get(&subc->Attributes, "footprint")));
+	pcb_print_quoted_string(f, (char *)RND_EMPTY(pcb_attribute_get(&subc->Attributes, "footprint")));
 	fputc(' ', f);
 	pcb_print_quoted_string(f, (char *)RND_EMPTY(subc->refdes));
 	fputc(' ', f);
-	pcb_print_quoted_string(f, (char *)RND_EMPTY(rnd_attribute_get(&subc->Attributes, "value")));
+	pcb_print_quoted_string(f, (char *)RND_EMPTY(pcb_attribute_get(&subc->Attributes, "value")));
 	fputs(")\n", f);
 }
 
@@ -283,7 +283,7 @@ fgw_error_t pcb_act_ExportOldConn(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			if (f != NULL) {
 				pcb_lookup_unused_pins(f, 1);
 				fclose(f);
-				pcb_board_set_changed_flag(rnd_true);
+				pcb_board_set_changed_flag(PCB_ACT_BOARD, rnd_true);
 			}
 			return 0;
 
