@@ -170,8 +170,9 @@ static rnd_export_opt_t *openems_get_export_options(rnd_hid_t *hid, int *n)
 {
 	const char *suffix = ".m";
 	pcb_mesh_t *mesh = pcb_mesh_get(MESH_NAME);
+	char **val = openems_attribute_list[HA_openemsfile].value;
 
-	if ((PCB != NULL)  && (openems_attribute_list[HA_openemsfile].default_val.str == NULL))
+	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
 		pcb_derive_default_filename(PCB->hidlib.filename, &openems_attribute_list[HA_openemsfile], suffix);
 
 	if (mesh != NULL) {
@@ -202,7 +203,7 @@ rnd_coord_t ems_layergrp_thickness(pcb_layergrp_t *grp)
 static void find_origin_bump(void *ctx_, pcb_board_t *pcb, pcb_layer_t *layer, pcb_line_t *line)
 {
 	wctx_t *ctx = ctx_;
-	if (rnd_attribute_get(&line->Attributes, "openems-origin") != NULL) {
+	if (pcb_attribute_get(&line->Attributes, "openems-origin") != NULL) {
 		ctx->ox = (line->BoundingBox.X1 + line->BoundingBox.X2) / 2;
 		ctx->oy = (line->BoundingBox.Y1 + line->BoundingBox.Y2) / 2;
 	}
@@ -251,7 +252,7 @@ static void print_lparm(wctx_t *ctx, pcb_layergrp_t *grp, const char *attr, int
 TODO(": this needs layer group attributes in core (planned for lihata v5)")
 #if 0
 TODO(": try openems::attr first - make a new core call for prefixed get, this will be a real common pattern")
-	const char *val = rnd_attribute_get(&grp->Attributes, attr);
+	const char *val = pcb_attribute_get(&grp->Attributes, attr);
 
 	if (val != NULL) {
 		/* specified by a layer group attribute: overrides anything else */
@@ -394,7 +395,7 @@ static void openems_vport_write(wctx_t *ctx, pcb_any_obj_t *o, rnd_coord_t x, rn
 	double resistance = ctx->options[HA_def_port_res].dbl;
 	int act = 1;
 
-	att = rnd_attribute_get(&o->Attributes, "openems::resistance");
+	att = pcb_attribute_get(&o->Attributes, "openems::resistance");
 	if (att != NULL) {
 		double tmp = strtod(att, &end);
 		if (*end == '\0')
@@ -403,7 +404,7 @@ static void openems_vport_write(wctx_t *ctx, pcb_any_obj_t *o, rnd_coord_t x, rn
 			rnd_message(RND_MSG_WARNING, "Ignoring invalid openems::resistance value for port %s: '%s' (must be a number without suffix)\n", port_name, att);
 	}
 
-	att = rnd_attribute_get(&o->Attributes, "openems::active");
+	att = pcb_attribute_get(&o->Attributes, "openems::active");
 	if (att != NULL) {
 		if (rnd_strcasecmp(att, "true") == 0)
 			act = 1;
@@ -487,7 +488,7 @@ static void openems_wr_testpoints(wctx_t *ctx, pcb_data_t *data)
 		if (o->type == PCB_OBJ_SUBC)
 			openems_wr_testpoints(ctx, ((pcb_subc_t *)o)->data);
 
-		port_name = rnd_attribute_get(&o->Attributes, "openems::vport");
+		port_name = pcb_attribute_get(&o->Attributes, "openems::vport");
 		if (port_name == NULL)
 			continue;
 
@@ -519,7 +520,7 @@ static void openems_wr_testpoints(wctx_t *ctx, pcb_data_t *data)
 
 TODO(": check if there is copper object on hid2 at x;y")
 
-					if (rnd_attribute_get(&o->Attributes, "openems::vport-reverse") == NULL)
+					if (pcb_attribute_get(&o->Attributes, "openems::vport-reverse") == NULL)
 						openems_vport_write(ctx, (pcb_any_obj_t *)ps, ps->x, ps->y, gid1, gid2, port_name);
 					else
 						openems_vport_write(ctx, (pcb_any_obj_t *)ps, ps->x, ps->y, gid2, gid1, port_name);
@@ -668,15 +669,13 @@ static void openems_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	const char *filename;
 	char *runfn = NULL, *end;
 	int save_ons[PCB_MAX_LAYER];
-	int i, len, fmt_matlab;
+	int len, fmt_matlab;
 	FILE *fsim;
 
 	openems_ovr = 0;
 
 	if (!options) {
 		openems_get_export_options(hid, 0);
-		for (i = 0; i < NUM_OPTIONS; i++)
-			openems_values[i] = openems_attribute_list[i].default_val;
 		options = openems_values;
 	}
 
@@ -728,7 +727,7 @@ static void openems_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 static int openems_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
-	rnd_export_register_opts(openems_attribute_list, sizeof(openems_attribute_list) / sizeof(openems_attribute_list[0]), openems_cookie, 0);
+	rnd_export_register_opts2(hid, openems_attribute_list, sizeof(openems_attribute_list) / sizeof(openems_attribute_list[0]), openems_cookie, 0);
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
@@ -920,6 +919,7 @@ void pplg_uninit_export_openems(void)
 	pcb_openems_excitation_uninit();
 	rnd_remove_actions_by_cookie(openems_cookie);
 	rnd_export_remove_opts_by_cookie(openems_cookie);
+	rnd_hid_remove_hid(&openems_hid);
 }
 
 int pplg_init_export_openems(void)
@@ -955,6 +955,7 @@ int pplg_init_export_openems(void)
 	openems_hid.fill_rect = openems_fill_rect;
 	openems_hid.calibrate = openems_calibrate;
 	openems_hid.set_crosshair = openems_set_crosshair;
+	openems_hid.argument_array = openems_values;
 
 	openems_hid.usage = openems_usage;
 
