@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2017 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2017,2020 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -82,6 +82,8 @@ static const char *scad_group_color;
 static int scad_layer_cnt;
 static vti0_t scad_comp;
 
+static rnd_hid_attr_val_t *openscad_options;
+
 rnd_export_opt_t openscad_attribute_list[] = {
 	/* other HIDs expect this to be first.  */
 
@@ -132,8 +134,9 @@ static rnd_hid_attr_val_t openscad_values[NUM_OPTIONS];
 static rnd_export_opt_t *openscad_get_export_options(rnd_hid_t *hid, int *n)
 {
 	const char *suffix = ".scad";
+	char **val = openscad_attribute_list[HA_openscadfile].value;
 
-	if ((PCB != NULL)  && (openscad_attribute_list[HA_openscadfile].default_val.str == NULL))
+	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
 		pcb_derive_default_filename(PCB->hidlib.filename, &openscad_attribute_list[HA_openscadfile], suffix);
 
 	if (n)
@@ -157,7 +160,9 @@ void openscad_hid_export_to_file(FILE * the_file, rnd_hid_attr_val_t * options)
 
 	rnd_conf_force_set_bool(conf_core.editor.show_solder_side, 0);
 
+	openscad_options = options;
 	rnd_expose_main(&openscad_hid, &ctx, NULL);
+	openscad_options = NULL;
 
 	rnd_conf_update(NULL, -1); /* restore forced sets */
 }
@@ -295,13 +300,10 @@ static void openscad_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 {
 	const char *filename;
 	int save_ons[PCB_MAX_LAYER];
-	int i;
 	pcb_cam_t cam;
 
 	if (!options) {
 		openscad_get_export_options(hid, 0);
-		for (i = 0; i < NUM_OPTIONS; i++)
-			openscad_values[i] = openscad_attribute_list[i].default_val;
 		options = openscad_values;
 	}
 
@@ -329,16 +331,16 @@ static void openscad_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 	gds_init(&model_calls);
 	vti0_init(&scad_comp);
 
-	if (openscad_attribute_list[HA_models].default_val.lng)
+	if (options[HA_models].lng)
 		scad_insert_models();
 
 	openscad_hid_export_to_file(f, options);
 	scad_close_layer_group();
 
-	if (openscad_attribute_list[HA_drill].default_val.lng)
+	if (options[HA_drill].lng)
 		scad_draw_drills();
 
-	scad_draw_finish();
+	scad_draw_finish(options);
 
 	pcb_hid_restore_layer_ons(save_ons);
 
@@ -353,7 +355,7 @@ static void openscad_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 static int openscad_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
-	rnd_export_register_opts(openscad_attribute_list, sizeof(openscad_attribute_list) / sizeof(openscad_attribute_list[0]), openscad_cookie, 0);
+	rnd_export_register_opts2(hid, openscad_attribute_list, sizeof(openscad_attribute_list) / sizeof(openscad_attribute_list[0]), openscad_cookie, 0);
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
@@ -375,7 +377,7 @@ static int openscad_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, con
 		return 0;
 
 	if (flags & PCB_LYT_MASK) {
-		if (!openscad_attribute_list[HA_mask].default_val.lng)
+		if (!openscad_options[HA_mask].lng)
 			return 0;
 		if (flags & PCB_LYT_TOP) {
 			scad_new_layer_group("top_mask", +2, "0,0.7,0,0.5");
@@ -388,7 +390,7 @@ static int openscad_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, con
 	}
 
 	if (flags & PCB_LYT_SILK) {
-		if (!openscad_attribute_list[HA_silk].default_val.lng)
+		if (!openscad_options[HA_silk].lng)
 			return 0;
 		if (flags & PCB_LYT_TOP) {
 			scad_new_layer_group("top_silk", +3, "0,0,0");
@@ -401,8 +403,10 @@ static int openscad_set_layer_group(rnd_hid_t *hid, rnd_layergrp_id_t group, con
 	}
 
 	if (flags & PCB_LYT_COPPER) {
-		if (!openscad_attribute_list[HA_copper].default_val.lng)
+		if (!openscad_options[HA_copper].lng) {
+			printf("skip copper\n");
 			return 0;
+		}
 		if (flags & PCB_LYT_TOP) {
 			scad_new_layer_group("top_copper", +1, "1,0.4,0.2");
 			return 1;
@@ -524,42 +528,38 @@ static void openscad_draw_rect(rnd_hid_gc_t gc, rnd_coord_t x1, rnd_coord_t y1,
 	openscad_draw_line(gc, x1, y2, x1, y1);
 }
 
+typedef struct {
+	int first;
+	rnd_coord_t lx, ly;
+	rnd_hid_gc_t gc;
+} openscad_draw_arc_t;
+
+static int openscad_draw_arc_cb(void *uctx, rnd_coord_t x, rnd_coord_t y)
+{
+	openscad_draw_arc_t *ctx = uctx;
+
+	if (!ctx->first)
+		openscad_draw_line(ctx->gc, ctx->lx, ctx->ly, x, y);
+
+	ctx->first = 0;
+	ctx->lx = x; ctx->ly = y;
+	return 0;
+}
+
 static void openscad_draw_arc(rnd_hid_gc_t gc, rnd_coord_t cx, rnd_coord_t cy, rnd_coord_t width, rnd_coord_t height, rnd_angle_t start_angle, rnd_angle_t delta_angle)
 {
-	double a, step = delta_angle/10.0, end_angle = start_angle + delta_angle;
-	int first;
-	rnd_coord_t lx, ly, x, y;
+	pcb_arc_t a;
+	openscad_draw_arc_t ctx;
+	rnd_coord_t res = (width+height)/20;
 
-	if (step >= 0) {
-		if (step < 1) step = 1;
-		if (step > 10) step = 10;
-	}
-	else {
-		if (step > -1) step = -1;
-		if (step < -0) step = -10;
-	}
+	a.X = cx; a.Y = cy;
+	a.Width = width; a.Height = height;
+	a.StartAngle = start_angle;
+	a.Delta = delta_angle;
 
-	/* only recent versions support angle for rotate_extrude(), so use line approximation for now */
-	fprintf(f, "			// line-approx arc %f .. %f by %f\n", start_angle, end_angle, step);
-
-	TODO("use the central arc approximation instead");
-	for(first = 1, a = start_angle; step > 0 ? (a < end_angle) : (a > end_angle); a += step) {
-		x = (double)cx + cos((180-a) / RND_RAD_TO_DEG) * (double)width;
-		y = (double)cy + sin((180-a) / RND_RAD_TO_DEG) * (double)height;
-		if (!first) {
-			fprintf(f, "\t");
-			openscad_draw_line(gc, lx, ly, x, y);
-		}
-		lx = x;
-		ly = y;
-		first = 0;
-	}
-	if (!first) {
-		x = (double)cx + cos((180 - end_angle) / RND_RAD_TO_DEG) * (double)width;
-		y = (double)cy + sin((180 - end_angle) / RND_RAD_TO_DEG) * (double)height;
-		fprintf(f, "\t");
-		openscad_draw_line(gc, lx, ly, x, y);
-	}
+	ctx.first = 1;
+	ctx.gc = gc;
+	pcb_arc_approx(&a, -RND_MIN(RND_MM_TO_COORD(2), res), 0, &ctx, openscad_draw_arc_cb);
 }
 
 static void openscad_fill_circle(rnd_hid_gc_t gc, rnd_coord_t cx, rnd_coord_t cy, rnd_coord_t radius)
@@ -663,6 +663,7 @@ void pplg_uninit_export_openscad(void)
 {
 	rnd_export_remove_opts_by_cookie(openscad_cookie);
 	rnd_remove_actions_by_cookie(openscad_cookie);
+	rnd_hid_remove_hid(&openscad_hid);
 }
 
 int pplg_init_export_openscad(void)
@@ -698,6 +699,7 @@ int pplg_init_export_openscad(void)
 	openscad_hid.fill_rect = openscad_fill_rect;
 	openscad_hid.calibrate = openscad_calibrate;
 	openscad_hid.set_crosshair = openscad_set_crosshair;
+	openscad_hid.argument_array = openscad_values;
 
 	openscad_hid.usage = openscad_usage;
 
