@@ -46,10 +46,19 @@ static void scad_insert_model(htsp_t *models, const char *name, rnd_coord_t x0,
 
 			/* replace the module line */
 			while(fgets(buff, sizeof(buff), fin) != NULL) {
-				if (strstr(buff, "module") != NULL) {
-					fprintf(f, "module pcb_part_%s()", safe_name);
-					if (strchr(buff, '{') != NULL)
-						fprintf(f, "{\n");
+				char *mod = strstr(buff, "module"), *par;
+				if (mod != NULL) {
+					mod += 6;
+					*mod = '\0';
+					mod++;
+					fprintf(f, "%s", buff);
+					while(isspace(*mod)) mod++;
+					if (!isalpha(*mod) && (*mod != '_'))
+						rnd_message(RND_MSG_ERROR, "Openscad model '%s': module name must be in the same line as the module keyword\n", full_path);
+					fprintf(f, " pcb_part_%s", safe_name);
+					par = strchr(mod, '(');
+					if (par != NULL)
+						fprintf(f, "%s", par);
 					else
 						fprintf(f, "\n");
 					break;
@@ -79,14 +88,11 @@ static void scad_insert_model(htsp_t *models, const char *name, rnd_coord_t x0,
 		ind++;
 		tab[ind] = '\0';
 
-		if (on_bottom) {
-			rnd_append_printf(&model_calls, "	%smirror([0,0,1])\n", tab);
-			tab[ind] = '\t'; ind++; tab[ind] = '\0';
-		}
-		if (rot != 0) {
-			rnd_append_printf(&model_calls, "	%srotate([0,0,%f])\n", tab, rot);
+		if ((rot != 0) || on_bottom) {
+			rnd_append_printf(&model_calls, "	%srotate([%d,0,%f])\n", tab, (on_bottom ? 180 : 0), rot);
 			tab[ind] = '\t'; ind++; tab[ind] = '\0';
 		}
+
 		if (transf != NULL) {
 			rnd_append_printf(&model_calls, "	%s%s\n", tab, transf);
 			tab[ind] = '\t'; ind++; tab[ind] = '\0';
@@ -109,7 +115,7 @@ static void scad_insert_models(void)
 	htsp_init(&models, strhash, strkeyeq);
 
 	PCB_SUBC_LOOP(PCB->Data); {
-		mod = rnd_attribute_get(&subc->Attributes, "openscad");
+		mod = pcb_attribute_get(&subc->Attributes, "openscad");
 		if (mod != NULL) {
 			rnd_coord_t ox, oy;
 			double rot = 0;
@@ -122,8 +128,8 @@ static void scad_insert_models(void)
 			pcb_subc_get_rotation(subc, &rot);
 			pcb_subc_get_side(subc, &on_bottom);
 
-			transf = rnd_attribute_get(&subc->Attributes, "openscad-transformation");
-			param = rnd_attribute_get(&subc->Attributes, "openscad-param");
+			transf = pcb_attribute_get(&subc->Attributes, "openscad-transformation");
+			param = pcb_attribute_get(&subc->Attributes, "openscad-param");
 			scad_insert_model(&models, mod, TRX_(ox), TRY_(oy), rot, on_bottom, transf, param);
 		}
 	} PCB_END_LOOP;
