@@ -401,8 +401,9 @@ static const char *get_file_suffix(void)
 static rnd_export_opt_t *png_get_export_options(rnd_hid_t *hid, int *n)
 {
 	const char *suffix = get_file_suffix();
+	char **val = png_attribute_list[HA_pngfile].value;
 
-	if ((PCB != NULL)  && (png_attribute_list[HA_pngfile].default_val.str == NULL))
+	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
 		pcb_derive_default_filename(PCB->hidlib.filename, &png_attribute_list[HA_pngfile], suffix);
 
 	if (n)
@@ -599,7 +600,6 @@ static void png_free_cache(void)
 static void png_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 {
 	int save_ons[PCB_MAX_LAYER];
-	int i;
 	rnd_box_t tmp, *bbox;
 	int w, h;
 	int xmax, ymax, dpi;
@@ -609,8 +609,6 @@ static void png_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	if (!options) {
 		png_get_export_options(hid, 0);
-		for (i = 0; i < NUM_OPTIONS; i++)
-			png_values[i] = png_attribute_list[i].default_val;
 		options = png_values;
 	}
 
@@ -793,7 +791,7 @@ static void png_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 static int png_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
-	rnd_export_register_opts(png_attribute_list, sizeof(png_attribute_list) / sizeof(png_attribute_list[0]), png_cookie, 0);
+	rnd_export_register_opts2(hid, png_attribute_list, sizeof(png_attribute_list) / sizeof(png_attribute_list[0]), png_cookie, 0);
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
@@ -1404,6 +1402,9 @@ int pplg_check_ver_export_png(int ver_needed) { return 0; }
 void pplg_uninit_export_png(void)
 {
 	rnd_export_remove_opts_by_cookie(png_cookie);
+#ifdef HAVE_SOME_FORMAT
+	rnd_hid_remove_hid(&png_hid);
+#endif
 }
 
 int pplg_init_export_png(void)
@@ -1439,6 +1440,7 @@ int pplg_init_export_png(void)
 	png_hid.fill_rect = png_fill_rect;
 	png_hid.calibrate = png_calibrate;
 	png_hid.set_crosshair = png_set_crosshair;
+	png_hid.argument_array = png_values;
 
 	png_hid.usage = png_usage;
 
