@@ -101,6 +101,7 @@ static rnd_export_opt_t *xy_get_export_options(rnd_hid_t *hid, int *n)
 {
 	static int last_unit_value = -1;
 	rnd_conf_listitem_t *li;
+	char **val = xy_options[HA_xyfile].value;
 	int idx;
 
 	/* load all formats from the config */
@@ -145,7 +146,8 @@ static rnd_export_opt_t *xy_get_export_options(rnd_hid_t *hid, int *n)
 			xy_options[HA_unit].default_val.lng = rnd_get_unit_struct("mil")->index;
 		last_unit_value = xy_options[HA_unit].default_val.lng;
 	}
-	if ((PCB != NULL)  && (xy_options[HA_xyfile].default_val.str == NULL))
+
+	if ((PCB != NULL) && ((val == NULL) || (*val == NULL) || (**val == '\0')))
 		pcb_derive_default_filename(PCB->hidlib.filename, &xy_options[HA_xyfile], ".xy");
 
 	if (n)
@@ -194,9 +196,9 @@ static void find_origin(subst_ctx_t *ctx, const char *format_name)
 	for(obj = pcb_data_first(&it, PCB->Data, PCB_OBJ_CLASS_REAL); obj != NULL; obj = pcb_data_next(&it)) {
 		int score;
 
-		if (rnd_attribute_get(&obj->Attributes, ctx->origin_tmp) != NULL)
+		if (pcb_attribute_get(&obj->Attributes, ctx->origin_tmp) != NULL)
 			score = 2; /* first look for the format-specific attribute */
-		else if (rnd_attribute_get(&obj->Attributes, "pnp-origin") != NULL)
+		else if (pcb_attribute_get(&obj->Attributes, "pnp-origin") != NULL)
 			score = 1; /* then for the generic pnp-specific attribute */
 		else
 			continue;
@@ -208,6 +210,8 @@ static void find_origin(subst_ctx_t *ctx, const char *format_name)
 	}
 }
 
+/* Calculate the bounding box of the subc as the bounding box of all terminals
+   ("pads", bot heavy and light) */
 static void calc_pad_bbox_(subst_ctx_t *ctx, rnd_coord_t *pw, rnd_coord_t *ph, rnd_coord_t *pcx, rnd_coord_t *pcy)
 {
 	rnd_box_t box;
@@ -282,6 +286,7 @@ TODO("subc: subc-in-subc")
 	}
 }
 
+/* Calculate the bounding box of the subc as the bounding box of all terminals */
 static void calc_pad_bbox(subst_ctx_t *ctx, int prerot, rnd_coord_t *pw, rnd_coord_t *ph, rnd_coord_t *pcx, rnd_coord_t *pcy)
 {
 	if (prerot) {
@@ -430,7 +435,7 @@ static int subst_cb(void *ctx_, gds_t *s, const char **input)
 				else /* only '?' is given, no ':' */
 					nope = "n/a";
 
-				val = rnd_attribute_get(&ctx->subc->Attributes, aname);
+				val = pcb_attribute_get(&ctx->subc->Attributes, aname);
 				if (is_val_true(val))
 					gds_append_str(s, unk_buf);
 				else
@@ -442,7 +447,7 @@ static int subst_cb(void *ctx_, gds_t *s, const char **input)
 				*input = end;
 			(*input)++;
 
-			val = rnd_attribute_get(&ctx->subc->Attributes, aname);
+			val = pcb_attribute_get(&ctx->subc->Attributes, aname);
 			if (val == NULL)
 				val = unk;
 			gds_append_str(s, val);
@@ -693,9 +698,9 @@ static int PrintXY(const template_t *templ, const char *format_name)
 		ctx.pad_w = ctx.pad_h = 0;
 		ctx.theta = ctx.xray_theta = 0.0;
 
-		ctx.name = pcb_bom_clean_str((char *) RND_UNKNOWN(rnd_attribute_get(&subc->Attributes, "refdes")));
+		ctx.name = pcb_bom_clean_str((char *) RND_UNKNOWN(pcb_attribute_get(&subc->Attributes, "refdes")));
 		ctx.descr = pcb_bom_clean_str((char *) RND_UNKNOWN(pcb_subc_name(subc, "export_xy::footprint")));
-		ctx.value = pcb_bom_clean_str((char *) RND_UNKNOWN(rnd_attribute_get(&subc->Attributes, "value")));
+		ctx.value = pcb_bom_clean_str((char *) RND_UNKNOWN(pcb_attribute_get(&subc->Attributes, "value")));
 
 		/* prefer the pnp-origin but if that doesn't exist, pick the subc origin */
 		if (!pcb_subc_find_aux_point(subc, "pnp-origin", &ctx.x, &ctx.y))
@@ -714,7 +719,6 @@ static int PrintXY(const template_t *templ, const char *format_name)
 		ctx.subc = subc;
 		ctx.front = !bott;
 
-TODO("padstack: do not depend on this, just use the normal bbox and rotate that back")
 		calc_pad_bbox(&ctx, 0, &ctx.pad_w, &ctx.pad_h, &ctx.pad_cx, &ctx.pad_cy);
 		calc_pad_bbox(&ctx, 1, &ctx.prpad_w, &ctx.prpad_h, &ctx.prpad_cx, &ctx.prpad_cy);
 		xy_translate(&ctx, &ctx.pad_cx, &ctx.pad_cy);
@@ -789,7 +793,6 @@ static const char *get_templ(const char *tid, const char *type)
 
 static void xy_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 {
-	int i;
 	template_t templ;
 	char **tid;
 	pcb_cam_t cam;
@@ -801,8 +804,6 @@ static void xy_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
 
 	if (!options) {
 		xy_get_export_options(hid, 0);
-		for (i = 0; i < NUM_OPTIONS; i++)
-			xy_values[i] = xy_options[i].default_val;
 		options = xy_values;
 	}
 
@@ -840,7 +841,7 @@ static int xy_usage(rnd_hid_t *hid, const char *topic)
 
 static int xy_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
-	rnd_export_register_opts(xy_options, sizeof(xy_options) / sizeof(xy_options[0]), xy_cookie, 0);
+	rnd_export_register_opts2(hid, xy_options, sizeof(xy_options) / sizeof(xy_options[0]), xy_cookie, 0);
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
@@ -856,6 +857,7 @@ void pplg_uninit_export_xy(void)
 	free_fmts();
 	vts0_uninit(&fmt_names);
 	vts0_uninit(&fmt_ids);
+	rnd_hid_remove_hid(&xy_hid);
 }
 
 
@@ -881,6 +883,7 @@ int pplg_init_export_xy(void)
 	xy_hid.get_export_options = xy_get_export_options;
 	xy_hid.do_export = xy_do_export;
 	xy_hid.parse_arguments = xy_parse_arguments;
+	xy_hid.argument_array = xy_values;
 
 	xy_hid.usage = xy_usage;
 
