@@ -47,13 +47,13 @@
 #include "layer.h"
 #include "move.h"
 #include "remove.h"
-#include "rtree.h"
+#include <librnd/poly/rtree.h>
 #include "flag_str.h"
 #include "undo.h"
-#include "pcb-printf.h"
-#include "plugins.h"
-#include "actions.h"
-#include "compat_misc.h"
+#include <librnd/core/rnd_printf.h>
+#include <librnd/core/plugins.h>
+#include <librnd/core/actions.h>
+#include <librnd/core/compat_misc.h>
 #include "event.h"
 #include "polygon.h"
 #include "obj_poly_draw.h"
@@ -64,25 +64,25 @@
    should search the grid for the gridlines and use them to figure out
    where the symbols are. */
 
-#define CELL_SIZE   ((pcb_coord_t)(PCB_MIL_TO_COORD (100)))
+#define CELL_SIZE   ((rnd_coord_t)(RND_MIL_TO_COORD (100)))
 
 #define XYtoSym(x,y) (((x) / CELL_SIZE - 1)  +  (16 * ((y) / CELL_SIZE - 1)))
 
 static const char pcb_acts_fontedit[] = "FontEdit()";
 static const char pcb_acth_fontedit[] = "Convert the current font to a PCB for editing.";
-static pcb_layer_t *make_layer(pcb_layergrp_id_t grp, const char *lname)
+static pcb_layer_t *make_layer(rnd_layergrp_id_t grp, const char *lname)
 {
-	pcb_layer_id_t lid;
+	rnd_layer_id_t lid;
 
 	assert(grp >= 0);
-	lid = pcb_layer_create(PCB, grp, lname);
+	lid = pcb_layer_create(PCB, grp, lname, 0);
 	assert(lid >= 0);
 	PCB->Data->Layer[lid].meta.real.vis = 1;
 	PCB->Data->Layer[lid].meta.real.color = *pcb_layer_default_color(lid, 0);
 	return &PCB->Data->Layer[lid];
 }
 
-static void add_poly(pcb_layer_t *layer, pcb_poly_t *poly, pcb_coord_t ox, pcb_coord_t oy)
+static void add_poly(pcb_layer_t *layer, pcb_poly_t *poly, rnd_coord_t ox, rnd_coord_t oy)
 {
 	pcb_poly_t *np;
 	
@@ -101,29 +101,29 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	pcb_font_t *font;
 	pcb_symbol_t *symbol;
 	pcb_layer_t *lfont, *lorig, *lwidth, *lgrid, *lsilk;
-	pcb_layergrp_id_t grp[4];
+	rnd_layergrp_id_t grp[4];
 	pcb_poly_t *poly;
 	pcb_arc_t *arc, *newarc;
 	int s, l;
 
 	font = pcb_font_unlink(PCB, conf_core.design.text_font_id);
 	if (font == NULL) {
-		pcb_message(PCB_MSG_ERROR, "Can't fetch font id %d\n", conf_core.design.text_font_id);
+		rnd_message(RND_MSG_ERROR, "Can't fetch font id %d\n", conf_core.design.text_font_id);
 		return 1;
 	}
 
-	if (pcb_actionva(PCB_ACT_HIDLIB, "New", "Font", 0))
+	if (rnd_actionva(RND_ACT_HIDLIB, "New", "Font", 0))
 		return 1;
 
-	pcb_conf_set(CFR_DESIGN, "editor/grid_unit", -1, "mil", POL_OVERWRITE);
-	conf_set_design("design/min_wid", "%s", "1");
-	conf_set_design("design/min_slk", "%s", "1");
-	conf_set_design("design/text_font_id", "%s", "0");
+	rnd_conf_set(RND_CFR_DESIGN, "editor/grid_unit", -1, "mil", RND_POL_OVERWRITE);
+	rnd_conf_set_design("design/min_wid", "%s", "1");
+	rnd_conf_set_design("design/min_slk", "%s", "1");
+	rnd_conf_set_design("design/text_font_id", "%s", "0");
 
 
 	PCB->hidlib.size_x = CELL_SIZE * 18;
 	PCB->hidlib.size_y = CELL_SIZE * ((PCB_MAX_FONTPOSITION + 15) / 16 + 2);
-	PCB->hidlib.grid = PCB_MIL_TO_COORD(5);
+	PCB->hidlib.grid = RND_MIL_TO_COORD(5);
 
 	/* create the layer stack and logical layers */
 	pcb_layergrp_inhibit_inc();
@@ -145,18 +145,18 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	pcb_layergrp_inhibit_dec();
 
 	/* Inform the rest about the board change (layer stack, size) */
-	pcb_event(&PCB->hidlib, PCB_EVENT_BOARD_CHANGED, NULL);
-	pcb_event(&PCB->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
+	rnd_event(&PCB->hidlib, RND_EVENT_BOARD_CHANGED, NULL);
+	rnd_event(&PCB->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
 
 	for (s = 0; s <= PCB_MAX_FONTPOSITION; s++) {
 		char txt[32];
-		pcb_coord_t ox = (s % 16 + 1) * CELL_SIZE;
-		pcb_coord_t oy = (s / 16 + 1) * CELL_SIZE;
-		pcb_coord_t w, miny, maxy, maxx = 0;
+		rnd_coord_t ox = (s % 16 + 1) * CELL_SIZE;
+		rnd_coord_t oy = (s / 16 + 1) * CELL_SIZE;
+		rnd_coord_t w, miny, maxy, maxx = 0;
 
 		symbol = &font->Symbol[s];
 
-		miny = PCB_MIL_TO_COORD(5);
+		miny = RND_MIL_TO_COORD(5);
 		maxy = font->MaxHeight;
 
 		if ((s > 32) && (s < 127)) {
@@ -184,8 +184,8 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 
 		for(arc = arclist_first(&symbol->arcs); arc != NULL; arc = arclist_next(arc)) {
-			pcb_arc_new(lfont, arc->X + ox, arc->Y + oy, arc->Width, arc->Height, arc->StartAngle, arc->Delta, arc->Thickness, 0, pcb_no_flags(), pcb_true);
-			newarc = pcb_arc_new(lorig, arc->X + ox, arc->Y + oy, arc->Width, arc->Height, arc->StartAngle, arc->Delta, arc->Thickness, 0, pcb_no_flags(), pcb_true);
+			pcb_arc_new(lfont, arc->X + ox, arc->Y + oy, arc->Width, arc->Height, arc->StartAngle, arc->Delta, arc->Thickness, 0, pcb_no_flags(), rnd_true);
+			newarc = pcb_arc_new(lorig, arc->X + ox, arc->Y + oy, arc->Width, arc->Height, arc->StartAngle, arc->Delta, arc->Thickness, 0, pcb_no_flags(), rnd_true);
 			if (newarc != NULL) {
 				if (maxx < newarc->BoundingBox.X2 - ox)
 					maxx = newarc->BoundingBox.X2 - ox;
@@ -196,7 +196,7 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 		for(poly = polylist_first(&symbol->polys); poly != NULL; poly = polylist_next(poly)) {
 			int n;
-			pcb_point_t *pnt;
+			rnd_point_t *pnt;
 
 			add_poly(lfont, poly, ox, oy);
 			add_poly(lorig, poly, ox, oy);
@@ -210,18 +210,18 @@ static fgw_error_t pcb_act_FontEdit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		}
 
 		w = maxx + symbol->Delta + ox;
-		pcb_line_new_merge(lwidth, w, miny + oy, w, maxy + oy, PCB_MIL_TO_COORD(1), PCB_MIL_TO_COORD(1), pcb_no_flags());
+		pcb_line_new_merge(lwidth, w, miny + oy, w, maxy + oy, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
 	}
 
 	for (l = 0; l < 16; l++) {
 		int x = (l + 1) * CELL_SIZE;
-		pcb_line_new_merge(lgrid, x, 0, x, PCB->hidlib.size_y, PCB_MIL_TO_COORD(1), PCB_MIL_TO_COORD(1), pcb_no_flags());
+		pcb_line_new_merge(lgrid, x, 0, x, PCB->hidlib.size_y, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
 	}
 	for (l = 0; l <= PCB_MAX_FONTPOSITION / 16 + 1; l++) {
 		int y = (l + 1) * CELL_SIZE;
-		pcb_line_new_merge(lgrid, 0, y, PCB->hidlib.size_x, y, PCB_MIL_TO_COORD(1), PCB_MIL_TO_COORD(1), pcb_no_flags());
+		pcb_line_new_merge(lgrid, 0, y, PCB->hidlib.size_x, y, RND_MIL_TO_COORD(1), RND_MIL_TO_COORD(1), pcb_no_flags());
 	}
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
@@ -302,9 +302,9 @@ static fgw_error_t pcb_act_FontSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	/* pack polygons */
 	polylist_foreach(&lfont->Polygon, &it, p) {
-		pcb_coord_t x1 = p->Points[0].X;
-		pcb_coord_t y1 = p->Points[0].Y;
-		pcb_coord_t s, ox, oy;
+		rnd_coord_t x1 = p->Points[0].X;
+		rnd_coord_t y1 = p->Points[0].Y;
+		rnd_coord_t s, ox, oy;
 		int n;
 
 		s = XYtoSym(x1, y1);
@@ -324,9 +324,9 @@ static fgw_error_t pcb_act_FontSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	/* recalc delta */
 	linelist_foreach(&lwidth->Line, &it, l) {
-		pcb_coord_t x1 = l->Point1.X;
-		pcb_coord_t y1 = l->Point1.Y;
-		pcb_coord_t ox, s;
+		rnd_coord_t x1 = l->Point1.X;
+		rnd_coord_t y1 = l->Point1.Y;
+		rnd_coord_t ox, s;
 
 		s = XYtoSym(x1, y1);
 		ox = (s % 16 + 1) * CELL_SIZE;
@@ -338,13 +338,13 @@ static fgw_error_t pcb_act_FontSave(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	}
 
 	pcb_font_set_info(font);
-	pcb_actionva(PCB_ACT_HIDLIB, "SaveFontTo", NULL);
+	rnd_actionva(RND_ACT_HIDLIB, "SaveFontTo", NULL);
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
-pcb_action_t fontmode_action_list[] = {
+rnd_action_t fontmode_action_list[] = {
 	{"FontEdit", pcb_act_FontEdit, pcb_acth_fontedit, pcb_acts_fontedit},
 	{"FontSave", pcb_act_FontSave, pcb_acth_fontsave, pcb_acts_fontsave}
 };
@@ -355,12 +355,12 @@ int pplg_check_ver_fontmode(int ver_needed) { return 0; }
 
 void pplg_uninit_fontmode(void)
 {
-	pcb_remove_actions_by_cookie(fontmode_cookie);
+	rnd_remove_actions_by_cookie(fontmode_cookie);
 }
 
 int pplg_init_fontmode(void)
 {
-	PCB_API_CHK_VER;
-	PCB_REGISTER_ACTIONS(fontmode_action_list, fontmode_cookie)
+	RND_API_CHK_VER;
+	RND_REGISTER_ACTIONS(fontmode_action_list, fontmode_cookie)
 	return 0;
 }
