@@ -42,17 +42,28 @@
 #include "data.h"
 #include <librnd/core/paths.h>
 #include <librnd/core/plugins.h>
+#include <genregex/regex_sei.h>
 #include "plug_footprint.h"
 #include "plug_io.h"
 #include <librnd/core/compat_fs.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/error.h>
 #include <librnd/core/conf.h>
+#include <librnd/core/conf_hid.h>
 #include "conf_core.h"
 #include <librnd/core/hid_init.h>
 #include <librnd/core/safe_fs.h>
 #include <librnd/core/safe_fs_dir.h>
 
+#include "fp_fs_conf.h"
+
+#define FP_FS_CONF_FN "ar_extern.conf"
+static conf_fp_fs_t conf_fp_fs;
+static const char fp_fs_cookie[] = "fp_fs plugin";
+
+static vtp0_t remove_regex;
+
+#include "conf_internal.c"
 
 /*** low level map cache ***/
 
@@ -136,7 +147,7 @@ static int list_cb(void *cookie, const char *subdir, const char *name, pcb_fptyp
 	}
 
 	l->children++;
-	e = pcb_fp_append_entry(l->menu, name, type, tags);
+	e = pcb_fp_append_entry(l->menu, name, type, tags, 1);
 
 /* Avoid using rnd_concat() - would be a new dependency for gsch2pcb-rnd */
 	{
@@ -160,18 +171,31 @@ static int list_cb(void *cookie, const char *subdir, const char *name, pcb_fptyp
 }
 
 /* returns whether file should be ignored by file name */
-TODO("fp: make this a configurable list")
 static int fp_fs_ignore_fn(const char *fn, int len)
 {
-	if (fn[0] == '.') return 1;
-	if (RND_NSTRCMP(fn, "CVS") == 0) return 1;
-	if (RND_NSTRCMP(fn, "Makefile") == 0) return 1;
-	if (RND_NSTRCMP(fn, "Makefile.am") == 0) return 1;
-	if (RND_NSTRCMP(fn, "Makefile.in") == 0) return 1;
-	
-	if ((len >= 4) && (RND_NSTRCMP(fn + (len - 4), ".png") == 0)) return 1;
-	if ((len >= 4) && (RND_NSTRCMP(fn + (len - 4), ".pcb") == 0)) return 1;
-	if ((len >= 5) && (RND_NSTRCMP(fn + (len - 5), ".html") == 0)) return 1;
+	int n;
+	rnd_conf_listitem_t *ci;
+	const char *p;
+
+	if (fn == NULL) return 1;
+
+	if (fn[0] == '.') { /* do not depend on config in avoiding infinite recursion on . and .. */
+		if (fn[1] == '\0') return 1;
+		if ((fn[1] == '.') && (fn[2] == '\0')) return 1;
+	}
+
+	rnd_conf_loop_list_str(&conf_fp_fs.plugins.fp_fs.ignore_prefix, ci, p, n) {
+		const char *s1, *s2;
+		for(s1 = fn, s2 = p; *s1 == *s2; s1++, s2++) {
+			if (*s2 == '\0') return 1;
+			if (*s1 == '\0') break;
+		}
+	}
+
+	rnd_conf_loop_list_str(&conf_fp_fs.plugins.fp_fs.ignore_suffix, ci, p, n) {
+		long slen = strlen(p);
+		if ((len >= slen) && (strcmp(fn + (len - slen), p) == 0)) return 1;
+	}
 
 	return 0;
 }
@@ -240,7 +264,8 @@ static int fp_fs_list(pcb_fplibrary_t *pl, const char *subdir, int recurse,
 		   may exist in a library tree to provide an html browsable
 		   index of the library. */
 		l = strlen(subdirentry->d_name);
-		if (fp_fs_ignore_fn(subdirentry->d_name, l)) continue;
+		if (fp_fs_ignore_fn(subdirentry->d_name, l))
+			continue;
 		if (stat(subdirentry->d_name, &buffer) == 0) {
 			strcpy(fn_end, subdirentry->d_name);
 			if ((S_ISREG(buffer.st_mode)) || (RND_WRAP_S_ISLNK(buffer.st_mode))) {
@@ -358,8 +383,23 @@ static int fp_search_cb(void *cookie, const char *subdir, const char *name, pcb_
 	fp_search_t *ctx = (fp_search_t *) cookie;
 	if ((strncmp(ctx->target, name, ctx->target_len) == 0) && ((! !ctx->parametric) == (type == PCB_FP_PARAMETRIC))) {
 		const char *suffix = name + ctx->target_len;
-		/* ugly heuristics: footprint names may end in .fp or .ele or .subc.lht or .lht */
-		if ((*suffix == '\0') || (rnd_strcasecmp(suffix, ".fp") == 0) || (rnd_strcasecmp(suffix, ".ele") == 0) || (rnd_strcasecmp(suffix, ".subc.lht") == 0) || (rnd_strcasecmp(suffix, ".lht") == 0)) {
+		int n, found = 0;
+		if (*suffix != '\0') { /* footprint names may end in .fp or .ele or .subc.lht or .lht */
+			for(n = 0; n < remove_regex.used; n++) {
+				if (re_sei_exec(remove_regex.array[n], name)) {
+					char *dst;
+					/* remove by the regex, the remaining part must match the original request */
+					re_sei_subst(remove_regex.array[n], &dst, name, "", 0);
+					found = (strcmp(dst, ctx->target) == 0);
+					if (found)
+						break;
+				}
+			}
+		}
+		else
+			found = 1;
+
+		if (found) {
 			ctx->path = rnd_strdup(subdir);
 			ctx->real_name = rnd_strdup(name);
 			return 1;
@@ -492,8 +532,34 @@ static void fp_fs_fclose(pcb_plug_fp_t *ctx, FILE * f, pcb_fp_fopen_ctx_t *fctx)
 		rnd_tempfile_unlink((char *)fctx->field[F_TMPNAME].p);
 }
 
+static void fp_fs_free_remove_regex(void)
+{
+	long n;
+	for(n = 0; n < remove_regex.used; n++)
+		re_sei_free(remove_regex.array[n]);
+	vtp0_uninit(&remove_regex);
+}
+
+static void fp_fs_cfg_cb(rnd_conf_native_t *cfg, int arr_idx)
+{
+	int n;
+	rnd_conf_listitem_t *ci;
+	const char *p;
+
+	fp_fs_free_remove_regex();
+	vtp0_init(&remove_regex);
+	rnd_conf_loop_list_str(&conf_fp_fs.plugins.fp_fs.remove_regex, ci, p, n) {
+		re_sei_t *regex = re_sei_comp(p);
+		if (regex != NULL)
+			vtp0_append(&remove_regex, regex);
+		else
+			rnd_message(RND_MSG_ERROR, "fp_fs: failed to compile remove_regex: '%s'\n", p);
+	}
+}
+
 
 static pcb_plug_fp_t fp_fs;
+static rnd_conf_hid_id_t cfgid;
 
 int pplg_check_ver_fp_fs(int ver_needed) { return 0; }
 
@@ -501,11 +567,19 @@ void pplg_uninit_fp_fs(void)
 {
 	RND_HOOK_UNREGISTER(pcb_plug_fp_t, pcb_plug_fp_chain, &fp_fs);
 
+	rnd_conf_hid_unreg(fp_fs_cookie);
+
+	rnd_conf_unreg_file(FP_FS_CONF_FN, fp_fs_conf_internal);
+
 	fp_fs_cache_uninit(&fp_fs_cache);
+	rnd_conf_unreg_fields("plugins/fp_fs/");
+	fp_fs_free_remove_regex();
 }
 
 int pplg_init_fp_fs(void)
 {
+	static rnd_conf_hid_callbacks_t cbs;
+
 	RND_API_CHK_VER;
 	fp_fs.plugin_data = NULL;
 	fp_fs.load_dir = fp_fs_load_dir;
@@ -513,5 +587,16 @@ int pplg_init_fp_fs(void)
 	fp_fs.fp_fclose = fp_fs_fclose;
 	RND_HOOK_REGISTER(pcb_plug_fp_t, pcb_plug_fp_chain, &fp_fs);
 	htsp_init(&fp_fs_cache, strhash, strkeyeq);
+
+	rnd_conf_reg_file(FP_FS_CONF_FN, fp_fs_conf_internal);
+
+#define conf_reg(field,isarray,type_name,cpath,cname,desc,flags) \
+	rnd_conf_reg_field(conf_fp_fs, field,isarray,type_name,cpath,cname,desc,flags);
+#include "fp_fs_conf_fields.h"
+
+	cfgid = rnd_conf_hid_reg(fp_fs_cookie, NULL);
+	cbs.val_change_post = fp_fs_cfg_cb;
+	rnd_conf_hid_set_cb(rnd_conf_get_field("plugins/fp_fs/remove_regex"), cfgid, &cbs);
+
 	return 0;
 }
