@@ -34,12 +34,13 @@
 
 #include "board.h"
 #include "data.h"
+#include "undo.h"
 #include "plug_import.h"
 #include <librnd/core/error.h>
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
-
+#include <librnd/core/hid_menu.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/plugins.h>
 #include <librnd/core/hid.h>
@@ -47,6 +48,8 @@
 #define NETEXT ".net"
 #define CMPEXT ".cmp"
 
+#include "menu_internal.c"
+
 static const char *calay_cookie = "calay importer";
 
 /* remove leading whitespace */
@@ -184,7 +187,10 @@ static int calay_load(const char *fname_net, const char *fname_cmp)
 	if (f == NULL)
 		rnd_message(RND_MSG_ERROR, "can't open calay component file '%s' for read\n(non-fatal, but footprints will not be placed)\n", fname_cmp);
 
+	pcb_undo_freeze_serial();
 	ret = calay_parse_comp(f);
+	pcb_undo_unfreeze_serial();
+	pcb_undo_inc_serial();
 
 	fclose(f);
 	return ret;
@@ -269,6 +275,7 @@ void pplg_uninit_import_calay(void)
 {
 	rnd_remove_actions_by_cookie(calay_cookie);
 	RND_HOOK_UNREGISTER(pcb_plug_import_t, pcb_plug_import_chain, &import_calay);
+	rnd_hid_menu_unload(rnd_gui, calay_cookie);
 }
 
 int pplg_init_import_calay(void)
@@ -291,5 +298,6 @@ int pplg_init_import_calay(void)
 
 
 	RND_REGISTER_ACTIONS(calay_action_list, calay_cookie)
+	rnd_hid_menu_load(rnd_gui, NULL, calay_cookie, 170, NULL, 0, calay_menu, "plugin: import calay");
 	return 0;
 }
