@@ -33,6 +33,7 @@
 
 #include "board.h"
 #include "data.h"
+#include "undo.h"
 #include <librnd/core/safe_fs.h>
 
 #include "conf_core.h"
@@ -41,18 +42,21 @@
 #include <librnd/core/actions.h>
 #include <librnd/core/plugins.h>
 #include <librnd/poly/rtree.h>
+#include <librnd/core/hid_menu.h>
 
 #include "../src_plugins/lib_compat_help/pstk_help.h"
 
 #include "plug_import.h"
 
+#include "menu_internal.c"
+
 static const char *ipcd356_cookie = "ipcd356 importer";
 
-static void set_src(rnd_attribute_list_t *a, const char *fn, long lineno)
+static void set_src(pcb_attribute_list_t *a, const char *fn, long lineno)
 {
 	char src[8192];
 	rnd_snprintf(src, sizeof(src), "ipcd356::%s:%ld", fn, lineno);
-	rnd_attribute_put(a, "source", src);
+	pcb_attribute_put(a, "source", src);
 }
 
 static int netname_valid(const char *netname)
@@ -277,11 +281,11 @@ static void create_feature(pcb_board_t *pcb, pcb_data_t *data, test_feature_t *t
 	ps = pcb_pstk_new_from_shape(data, tf->cx, y, tf->hole, tf->is_plated, conf_core.design.bloat, sh);
 
 	if (tf->is_middle)
-		rnd_attribute_put(&ps->Attributes, "ipcd356::mid", "yes");
+		pcb_attribute_put(&ps->Attributes, "ipcd356::mid", "yes");
 	if (tf->is_tooling)
-		rnd_attribute_put(&ps->Attributes, "ipcd356::tooling", "yes");
+		pcb_attribute_put(&ps->Attributes, "ipcd356::tooling", "yes");
 	if (term)
-		rnd_attribute_put(&ps->Attributes, "term", term);
+		pcb_attribute_put(&ps->Attributes, "term", term);
 }
 
 static int ipc356_parse(pcb_board_t *pcb, FILE *f, const char *fn, htsp_t *subcs, int want_net, int want_pads)
@@ -323,9 +327,9 @@ static int ipc356_parse(pcb_board_t *pcb, FILE *f, const char *fn, htsp_t *subcs
 					if (sc == NULL) {
 						const char *nr;
 						sc = pcb_subc_alloc();
-						rnd_attribute_put(&sc->Attributes, "refdes", refdes);
+						pcb_attribute_put(&sc->Attributes, "refdes", refdes);
 						set_src(&sc->Attributes, fn, lineno);
-						nr = rnd_attribute_get(&sc->Attributes, "refdes");
+						nr = pcb_attribute_get(&sc->Attributes, "refdes");
 						htsp_set(subcs, (char *)nr, sc);
 						pcb_subc_reg(pcb->Data, sc);
 						pcb_subc_bind_globals(pcb, sc);
@@ -404,6 +408,8 @@ fgw_error_t pcb_act_LoadIpc356From(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		scs = &subcs;
 	}
 
+	pcb_undo_freeze_serial();
+
 	if (want_net) {
 		rnd_actionva(RND_ACT_HIDLIB, "Netlist", "Freeze", NULL);
 		rnd_actionva(RND_ACT_HIDLIB, "Netlist", "Clear", NULL);
@@ -431,6 +437,9 @@ fgw_error_t pcb_act_LoadIpc356From(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		htsp_uninit(&subcs);
 	}
 
+	pcb_undo_unfreeze_serial();
+	pcb_undo_inc_serial();
+
 	RND_ACT_IRES(rs);
 	return 0;
 }
@@ -491,6 +500,7 @@ void pplg_uninit_import_ipcd356(void)
 {
 	rnd_remove_actions_by_cookie(ipcd356_cookie);
 	RND_HOOK_UNREGISTER(pcb_plug_import_t, pcb_plug_import_chain, &import_ipcd356);
+	rnd_hid_menu_unload(rnd_gui, ipcd356_cookie);
 }
 
 int pplg_init_import_ipcd356(void)
@@ -513,5 +523,6 @@ int pplg_init_import_ipcd356(void)
 
 
 	RND_REGISTER_ACTIONS(import_ipcd356_action_list, ipcd356_cookie);
+	rnd_hid_menu_load(rnd_gui, NULL, ipcd356_cookie, 180, NULL, 0, ipcd356_menu, "ipcd356 import");
 	return 0;
 }
