@@ -36,17 +36,20 @@
 
 #include "board.h"
 #include "data.h"
+#include "undo.h"
 #include "plug_import.h"
 #include <librnd/core/error.h>
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
 #include <librnd/core/compat_fs.h>
-
+#include <librnd/core/hid_menu.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/plugins.h>
 #include <librnd/core/hid.h>
 
+#include "menu_internal.c"
+
 static const char *ltspice_cookie = "ltspice importer";
 
 static int ltspice_hdr_asc(FILE *f)
@@ -310,7 +313,10 @@ fgw_error_t pcb_act_LoadLtspiceFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	gen_filenames(fname, &fname_net, &fname_asc);
 
+	pcb_undo_freeze_serial();
 	rs = ltspice_load(fname_net, fname_asc);
+	pcb_undo_unfreeze_serial();
+	pcb_undo_inc_serial();
 
 	free(fname_asc);
 	free(fname_net);
@@ -384,6 +390,7 @@ void pplg_uninit_import_ltspice(void)
 {
 	rnd_remove_actions_by_cookie(ltspice_cookie);
 	RND_HOOK_UNREGISTER(pcb_plug_import_t, pcb_plug_import_chain, &import_ltspice);
+	rnd_hid_menu_unload(rnd_gui, ltspice_cookie);
 }
 
 int pplg_init_import_ltspice(void)
@@ -405,5 +412,6 @@ int pplg_init_import_ltspice(void)
 	RND_HOOK_REGISTER(pcb_plug_import_t, pcb_plug_import_chain, &import_ltspice);
 
 	RND_REGISTER_ACTIONS(ltspice_action_list, ltspice_cookie)
+	rnd_hid_menu_load(rnd_gui, NULL, ltspice_cookie, 165, NULL, 0, ltspice_menu, "plugin: ltspice netlist import");
 	return 0;
 }
