@@ -34,12 +34,13 @@
 
 #include "board.h"
 #include "data.h"
+#include "undo.h"
 #include "plug_import.h"
 #include <librnd/core/error.h>
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/compat_misc.h>
 #include <gensexpr/gsxl.h>
-
+#include <librnd/core/hid_menu.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/plugins.h>
 #include <librnd/core/hid.h>
@@ -49,6 +50,8 @@
 
 #include "netlist_helper.h"
 
+#include "menu_internal.c"
+
 conf_mentor_sch_t conf_mentor;
 
 
@@ -177,6 +180,8 @@ static int mentor_parse_tree(gsxl_dom_t *dom)
 		return -1;
 	}
 
+	pcb_undo_freeze_serial();
+
 	rnd_actionva(&PCB->hidlib, "Netlist", "Freeze", NULL);
 	rnd_actionva(&PCB->hidlib, "Netlist", "Clear", NULL);
 	rnd_actionva(&PCB->hidlib, "ElementList", "start", NULL);
@@ -203,6 +208,9 @@ static int mentor_parse_tree(gsxl_dom_t *dom)
 	rnd_actionva(&PCB->hidlib, "Netlist", "Sort", NULL);
 	rnd_actionva(&PCB->hidlib, "Netlist", "Thaw", NULL);
 
+	pcb_undo_unfreeze_serial();
+	pcb_undo_inc_serial();
+
 /*	for(n = library->children; n != NULL; n = n->next) {
 		printf("n=%s\n", n->str);
 		if (strcmp(n->str, "cell") == 0) { 
@@ -311,6 +319,7 @@ void pplg_uninit_import_mentor_sch(void)
 	rnd_remove_actions_by_cookie(mentor_sch_cookie);
 	rnd_conf_unreg_fields("plugins/import_mentor_sch/");
 	RND_HOOK_UNREGISTER(pcb_plug_import_t, pcb_plug_import_chain, &import_mentor_sch);
+	rnd_hid_menu_unload(rnd_gui, mentor_sch_cookie);
 }
 
 int pplg_init_import_mentor_sch(void)
@@ -336,5 +345,6 @@ int pplg_init_import_mentor_sch(void)
 	RND_HOOK_REGISTER(pcb_plug_import_t, pcb_plug_import_chain, &import_mentor_sch);
 
 	RND_REGISTER_ACTIONS(mentor_sch_action_list, mentor_sch_cookie)
+	rnd_hid_menu_load(rnd_gui, NULL, mentor_sch_cookie, 185, NULL, 0, mentor_menu, "plugin: mentor_sch");
 	return 0;
 }
