@@ -34,11 +34,11 @@
 #include <genht/hash.h>
 
 #include "netlist_helper.h"
-#include "compat_misc.h"
-#include "pcb-printf.h"
-#include "error.h"
-#include "actions.h"
-#include "safe_fs.h"
+#include <librnd/core/compat_misc.h>
+#include <librnd/core/rnd_printf.h>
+#include <librnd/core/error.h>
+#include <librnd/core/actions.h>
+#include <librnd/core/safe_fs.h>
 
 
 nethlp_ctx_t *nethlp_new(nethlp_ctx_t *prealloc)
@@ -121,13 +121,13 @@ static int part_map_parse(nethlp_ctx_t *nhctx, int argc, char *argv[], const cha
 	int prio;
 
 	if (argc != 5) {
-		pcb_message(PCB_MSG_ERROR, "Loading part map: wrong number of fields %d in %s:%d - expected 5 - ignoring this rule\n", argc, fn, lineno);
+		rnd_message(RND_MSG_ERROR, "Loading part map: wrong number of fields %d in %s:%d - expected 5 - ignoring this rule\n", argc, fn, lineno);
 		return -1;
 	}
 	if (*argv[0] != '*') {
 		prio = strtol(argv[0], &end, 10);
 		if (*end != '\0') {
-			pcb_message(PCB_MSG_ERROR, "Loading part map: invaid priority '%s' in %s:%d - ignoring this rule\n", argv[0], fn, lineno);
+			rnd_message(RND_MSG_ERROR, "Loading part map: invaid priority '%s' in %s:%d - ignoring this rule\n", argv[0], fn, lineno);
 			return -1;
 		}
 	}
@@ -135,13 +135,13 @@ static int part_map_parse(nethlp_ctx_t *nhctx, int argc, char *argv[], const cha
 		prio = nethlp_prio_always;
 	kr = re_se_comp(argv[1]);
 	if (kr == NULL) {
-		pcb_message(PCB_MSG_ERROR, "Loading part map: can't compile attribute name regex in %s:%d - ignoring this rule\n", fn, lineno);
+		rnd_message(RND_MSG_ERROR, "Loading part map: can't compile attribute name regex in %s:%d - ignoring this rule\n", fn, lineno);
 		return -1;
 	}
 	vr = re_se_comp(argv[2]);
 	if (vr == NULL) {
 		re_se_free(kr);
-		pcb_message(PCB_MSG_ERROR, "Loading part map: can't compile attribute value regex in %s:%d - ignoring this rule\n", fn, lineno);
+		rnd_message(RND_MSG_ERROR, "Loading part map: can't compile attribute value regex in %s:%d - ignoring this rule\n", fn, lineno);
 		return -1;
 	}
 
@@ -149,8 +149,8 @@ static int part_map_parse(nethlp_ctx_t *nhctx, int argc, char *argv[], const cha
 	r->prio = prio;
 	r->key = kr;
 	r->val = vr;
-	r->new_key = pcb_strdup(argv[3]);
-	r->new_val = pcb_strdup(argv[4]);
+	r->new_key = rnd_strdup(argv[3]);
+	r->new_val = rnd_strdup(argv[4]);
 	r->next = nhctx->part_rules;
 	nhctx->part_rules = r;
 
@@ -163,7 +163,7 @@ int nethlp_load_part_map(nethlp_ctx_t *nhctx, const char *fn)
 	int cnt, argc, lineno;
 	char line[1024], *argv[8];
 
-	f = pcb_fopen(NULL, fn, "r");
+	f = rnd_fopen(NULL, fn, "r");
 	if (f == NULL)
 		return -1;
 
@@ -191,19 +191,19 @@ nethlp_elem_ctx_t *nethlp_elem_new(nethlp_ctx_t *nhctx, nethlp_elem_ctx_t *preal
 	else
 		prealloc->alloced = 0;
 	prealloc->nhctx = nhctx;
-	prealloc->id = pcb_strdup(id);
+	prealloc->id = rnd_strdup(id);
 	htsp_init(&prealloc->attr, strhash, strkeyeq);
 	return prealloc;
 }
 
 void nethlp_elem_refdes(nethlp_elem_ctx_t *ectx, const char *refdes)
 {
-	htsp_set(&ectx->nhctx->id2refdes, pcb_strdup(ectx->id), pcb_strdup(refdes));
+	htsp_set(&ectx->nhctx->id2refdes, rnd_strdup(ectx->id), rnd_strdup(refdes));
 }
 
 void nethlp_elem_attr(nethlp_elem_ctx_t *ectx, const char *key, const char *val)
 {
-	htsp_set(&ectx->attr, pcb_strdup(key), pcb_strdup(val));
+	htsp_set(&ectx->attr, rnd_strdup(key), rnd_strdup(val));
 }
 
 static void elem_map_apply(nethlp_elem_ctx_t *ectx, nethlp_rule_t *r)
@@ -211,10 +211,10 @@ static void elem_map_apply(nethlp_elem_ctx_t *ectx, nethlp_rule_t *r)
 	char *dst;
 	re_se_backref(r->val, &dst, r->new_val);
 /*	printf("Map add: '%s' -> '%s'\n", r->new_key, dst);*/
-	htsp_set(&ectx->attr, pcb_strdup(r->new_key), pcb_strdup(dst));
+	htsp_set(&ectx->attr, rnd_strdup(r->new_key), rnd_strdup(dst));
 }
 
-void nethlp_elem_done(pcb_hidlib_t *hl, nethlp_elem_ctx_t *ectx)
+void nethlp_elem_done(rnd_hidlib_t *hl, nethlp_elem_ctx_t *ectx)
 {
 	htsp_entry_t *e;
 	char *refdes, *footprint, *value;
@@ -256,11 +256,11 @@ void nethlp_elem_done(pcb_hidlib_t *hl, nethlp_elem_ctx_t *ectx)
 		if (value == NULL) value = "";
 
 		/* create elemet */
-		pcb_actionva(hl, "ElementList", "Need", refdes, footprint, value, NULL);
+		rnd_actionva(hl, "ElementList", "Need", refdes, footprint, value, NULL);
 /*		printf("Elem '%s' -> %s:%s:%s\n", ectx->id, refdes, footprint, value);*/
 	}
 	else
-		pcb_message(PCB_MSG_ERROR, "Ignoring part %s: no refdes\n", ectx->id);
+		rnd_message(RND_MSG_ERROR, "Ignoring part %s: no refdes\n", ectx->id);
 
 	/* free */
 	for (e = htsp_first(&ectx->attr); e; e = htsp_next(&ectx->attr, e)) {
@@ -284,19 +284,19 @@ nethlp_net_ctx_t *nethlp_net_new(nethlp_ctx_t *nhctx, nethlp_net_ctx_t *prealloc
 		prealloc->alloced = 0;
 	prealloc->nhctx = nhctx;
 
-	prealloc->netname = pcb_strdup(netname);
+	prealloc->netname = rnd_strdup(netname);
 	return prealloc;
 }
 
-void nethlp_net_add_term(pcb_hidlib_t *hl, nethlp_net_ctx_t *nctx, const char *part, const char *pin)
+void nethlp_net_add_term(rnd_hidlib_t *hl, nethlp_net_ctx_t *nctx, const char *part, const char *pin)
 {
 	char *refdes = htsp_get(&nctx->nhctx->id2refdes, part);
 	char term[256];
 	if (refdes == NULL) {
-		pcb_message(PCB_MSG_ERROR, "nethelper: can't resolve refdes of part %s\n", part);
+		rnd_message(RND_MSG_ERROR, "nethelper: can't resolve refdes of part %s\n", part);
 	}
-	pcb_snprintf(term, sizeof(term), "%s-%s", refdes, pin);
-	pcb_actionva(hl, "Netlist", "Add",  nctx->netname, term, NULL);
+	rnd_snprintf(term, sizeof(term), "%s-%s", refdes, pin);
+	rnd_actionva(hl, "Netlist", "Add",  nctx->netname, term, NULL);
 }
 
 void nethlp_net_destroy(nethlp_net_ctx_t *nctx)
