@@ -36,6 +36,7 @@
 #include "globalconst.h"
 
 #include "board.h"
+#include "undo.h"
 #include "plug_import.h"
 #include "import_sch_conf.h"
 
@@ -50,8 +51,8 @@ static const char *import_sch_cookie = "import_sch2 plugin";
 
 static int convert_attribs(void)
 {
-	const char *mode = rnd_attrib_get(PCB, "import::mode");
-	const char *src0 = rnd_attrib_get(PCB, "import::src0");
+	const char *mode = pcb_attrib_get(PCB, "import::mode");
+	const char *src0 = pcb_attrib_get(PCB, "import::src0");
 	char tmp[32];
 	int n, idx;
 
@@ -62,7 +63,7 @@ static int convert_attribs(void)
 		const char *src;
 		
 		sprintf(tmp, "import::src%d", n);
-		src = rnd_attrib_get(PCB, tmp);
+		src = pcb_attrib_get(PCB, tmp);
 		if (src != NULL) {
 			rnd_conf_grow("plugins/import_sch/args", idx+1);
 			rnd_conf_set(RND_CFR_DESIGN, "plugins/import_sch/args", idx, src, RND_POL_OVERWRITE);
@@ -78,9 +79,9 @@ static int convert_attribs(void)
 
 
 	if (strcmp(mode, "cmd") == 0) {
-		const char *outfile = rnd_attrib_get(PCB, "import::outfile");
-		const char *makefile = rnd_attrib_get(PCB, "import::makefile");
-		const char *target = rnd_attrib_get(PCB, "import::target");
+		const char *outfile = pcb_attrib_get(PCB, "import::outfile");
+		const char *makefile = pcb_attrib_get(PCB, "import::makefile");
+		const char *target = pcb_attrib_get(PCB, "import::target");
 		gds_t cmdline;
 
 		if (outfile == NULL) outfile = "-";
@@ -142,7 +143,10 @@ static int do_import(void)
 	for(n = 0, ci = rnd_conflist_first((rnd_conflist_t *)&conf_import_sch.plugins.import_sch.args); ci != NULL; ci = rnd_conflist_next(ci), n++)
 		a[n] = ci->val.string[0];
 	rnd_message(RND_MSG_DEBUG, "import_sch2: reimport with %s -> %p\n", imp_name, p);
+	pcb_undo_freeze_serial();
 	res = p->import(p, IMPORT_ASPECT_NETLIST, a, len);
+	pcb_undo_unfreeze_serial();
+	pcb_undo_inc_serial();
 	free(a);
 	return res;
 }
