@@ -35,10 +35,10 @@
 #include "read.h"
 #include "write.h"
 
-#include "hid.h"
-#include "compat_misc.h"
+#include <librnd/core/hid.h>
+#include <librnd/core/compat_misc.h>
 #include "plug_io.h"
-#include "plugins.h"
+#include <librnd/core/plugins.h>
 
 
 static const char *dsn_cookie = "dsn IO";
@@ -52,7 +52,7 @@ int io_dsn_fmt(pcb_plug_io_t *ctx, pcb_plug_iot_t typ, int wr, const char *fmt)
 	if (strcmp(ctx->description, fmt) == 0)
 		return 200;
 
-	if ((pcb_strcasecmp(fmt, "dsn") != 0) ||
+	if ((rnd_strcasecmp(fmt, "dsn") != 0) ||
 		((typ & (~(PCB_IOT_PCB))) != 0))
 		return 0;
 
@@ -63,12 +63,12 @@ int pplg_check_ver_io_dsn(int ver_needed) { return 0; }
 
 void pplg_uninit_io_dsn(void)
 {
-	PCB_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_dsn);
+	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_dsn);
 }
 
 int pplg_init_io_dsn(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
 	/* register the IO hook */
 	io_dsn.plugin_data = NULL;
@@ -76,6 +76,7 @@ int pplg_init_io_dsn(void)
 	io_dsn.test_parse = io_dsn_test_parse;
 	io_dsn.parse_pcb = io_dsn_parse_pcb;
 	io_dsn.parse_footprint = NULL;
+	io_dsn.map_footprint = NULL;
 	io_dsn.parse_font = NULL;
 	io_dsn.write_buffer = NULL;
 	io_dsn.write_pcb = io_dsn_write_pcb;
@@ -86,7 +87,7 @@ int pplg_init_io_dsn(void)
 	io_dsn.fp_extension = NULL;
 	io_dsn.mime_type = "application/dsn";
 
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_dsn);
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_dsn);
 
 	return 0;
 }
