@@ -28,12 +28,12 @@
  */
 
 #include "config.h"
-#include "plugins.h"
-#include "hid.h"
+#include <librnd/core/plugins.h>
+#include <librnd/core/hid.h>
 #include "plug_io.h"
 #include "read.h"
 #include "read_dru.h"
-#include "actions.h"
+#include <librnd/core/actions.h>
 
 static pcb_plug_io_t io_eagle_xml, io_eagle_bin, io_eagle_dru;
 static const char *eagle_cookie = "eagle plugin";
@@ -58,15 +58,15 @@ int pplg_check_ver_io_eagle(int ver_needed) { return 0; }
 void pplg_uninit_io_eagle(void)
 {
 	/* Runs once when the plugin is unloaded. TODO: free plugin-globals here. */
-	pcb_remove_actions_by_cookie(eagle_cookie);
-	PCB_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_xml);
-	PCB_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_bin);
-	PCB_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_dru);
+	rnd_remove_actions_by_cookie(eagle_cookie);
+	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_xml);
+	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_bin);
+	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_dru);
 }
 
 int pplg_init_io_eagle(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
 	/* register the IO hook */
 	io_eagle_xml.plugin_data = NULL;
@@ -74,6 +74,7 @@ int pplg_init_io_eagle(void)
 	io_eagle_xml.test_parse = io_eagle_test_parse_xml;
 	io_eagle_xml.parse_pcb = io_eagle_read_pcb_xml;
 /*	io_eagle_xml.parse_footprint = NULL;
+	io_eagle_xml.map_footprint = NULL;
 	io_eagle_xml.parse_font = NULL;
 	io_eagle_xml.write_buffer = io_eagle_write_buffer;
 	io_eagle_xml.write_pcb = io_eagle_write_pcb;*/
@@ -84,7 +85,7 @@ int pplg_init_io_eagle(void)
 	io_eagle_xml.fp_extension = ".eagle_mod";
 	io_eagle_xml.mime_type = "application/x-eagle-pcb";
 
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_xml);
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_xml);
 
 	/* register the IO hook */
 	io_eagle_bin.plugin_data = NULL;
@@ -92,6 +93,7 @@ int pplg_init_io_eagle(void)
 	io_eagle_bin.test_parse = io_eagle_test_parse_bin;
 	io_eagle_bin.parse_pcb = io_eagle_read_pcb_bin;
 /*	io_eagle_bin.parse_footprint = NULL;
+	io_eagle_bin.map_footprint = NULL;
 	io_eagle_bin.parse_font = NULL;
 	io_eagle_bin.write_buffer = io_eagle_write_buffer;
 	io_eagle_bin.write_pcb = io_eagle_write_pcb;*/
@@ -102,7 +104,7 @@ int pplg_init_io_eagle(void)
 	io_eagle_bin.fp_extension = ".???";
 	io_eagle_bin.mime_type = "application/x-eagle-pcb";
 
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_bin);
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_bin);
 
 	/* register the IO hook */
 	io_eagle_dru.plugin_data = NULL;
@@ -110,6 +112,7 @@ int pplg_init_io_eagle(void)
 	io_eagle_dru.test_parse = io_eagle_test_parse_dru;
 	io_eagle_dru.parse_pcb = io_eagle_read_pcb_dru;
 	io_eagle_dru.parse_footprint = NULL;
+	io_eagle_dru.map_footprint = NULL;
 	io_eagle_dru.parse_font = NULL;
 	io_eagle_dru.write_buffer = NULL;
 	io_eagle_dru.write_pcb = /*io_eagle_write_pcb_dru*/ NULL;
@@ -120,7 +123,7 @@ int pplg_init_io_eagle(void)
 	io_eagle_dru.fp_extension = ".dru";
 	io_eagle_dru.mime_type = "application/x-eagle-dru";
 
-	PCB_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_dru);
+	RND_HOOK_REGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_eagle_dru);
 
 	return 0;
 }
