@@ -98,6 +98,7 @@ typedef struct read_state_s {
 
 	const char *default_unit; /* assumed unit for unitless coord values */
 	unsigned elem_by_name:1; /* whether elements are addressed by name (or by index in the lib) */
+	unsigned warned_poly_side_clr:1; /* whether polygon-side clearance is already warned about */
 } read_state_t;
 
 typedef struct {
@@ -369,13 +370,10 @@ static int eagle_read_layers(read_state_t *st, trnode_t *subtree, void *obj, int
 	return 0;
 }
 
+#include "layertab.c"
+
 static pcb_layer_t *eagle_layer_get(read_state_t *st, eagle_layerid_t id, eagle_loc_t loc, void *obj)
 {
-	/* tDocu & bDocu are used for info used when designing, but not necessarily for
-	   exporting to Gerber i.e. package outlines that cross pads, or instructions.
-	   These layers within the silk groups will be needed when subc replaces elements
-	   since most Eagle packages use tDocu, bDocu for some of their artwork */
-
 	eagle_layer_t *ly = htip_get(&st->layers, id);
 	rnd_layer_id_t lid;
 	pcb_subc_t *subc = obj;
@@ -384,28 +382,29 @@ static pcb_layer_t *eagle_layer_get(read_state_t *st, eagle_layerid_t id, eagle_
 
 	/* if more than 51 or 52 are considered useful, we could relax the test here: */
 	if ((ly == NULL) || (ly->lid < 0)) {
-		TODO("move this out to a separate function")
-		if (id == 51 || id == 52) {
-				/* create docu on the first reference */
-			pcb_layer_type_t typ;
-			rnd_layergrp_id_t gid;
-			switch (id) {
-				case 51: /* = tDocu */
-					typ        = PCB_LYT_SILK | PCB_LYT_TOP;
-					ly->name   = "tDocu";
-					ly->color  = 14;
-					break;
-				default: /* i.e. 52 = bDocu: */
-					typ        = PCB_LYT_SILK | PCB_LYT_BOTTOM;
-					ly->name   = "bDocu";
-					ly->color  = 7;
-					break;
-			}
+		const eagle_layertab_t *t;
 
+		for(t = eagle_layertab; t->id != 0; t++)
+			if (t->id == id)
+				break;
+
+		if (t->id == id) {
+				/* create docu on the first reference */
+			pcb_layer_type_t typ = t->lyt;
+			rnd_layergrp_id_t gid;
+			ly->name    = t->name;
+			ly->color   = t->color;
 			ly->fill    = 1;
 			ly->visible = 0;
 			ly->active  = 1;
-			pcb_layergrp_list(st->pcb, typ, &gid, 1);
+			if (pcb_layergrp_listp(st->pcb, typ, &gid, 1, -1, t->purp) != 1) {
+				pcb_layergrp_t *grp = pcb_get_grp_new_misc(st->pcb);
+				grp->name = rnd_strdup(ly->name);
+				grp->ltype = typ;
+				if (t->purp != NULL)
+					pcb_layergrp_set_purpose(grp, t->purp, 0);
+				gid = grp - st->pcb->LayerGroups.grp;
+			}
 			ly->lid = pcb_layer_create(st->pcb, gid, ly->name, 0);
 		}
 		else
@@ -1012,7 +1011,7 @@ TODO("{clearance} this should be coming from the eagle file")
 		rnd_message(RND_MSG_ERROR, "Failed to load smd pad\n");
 
 	if (name != NULL)
-		rnd_attribute_put(&ps->Attributes, "term", name);
+		pcb_attribute_put(&ps->Attributes, "term", name);
 
 	return 0;
 }
@@ -1078,7 +1077,7 @@ TODO("variable mask is ignored");
 	ps = eagle_create_pstk(st, data, x, y, sh, diax, diay, clr, drill, roundness, rot, onbottom, plated);
 
 	if (name != NULL)
-		rnd_attribute_put(&ps->Attributes, "term", name);
+		pcb_attribute_put(&ps->Attributes, "term", name);
 
 	switch(loc) {
 		case IN_SUBC: break;
@@ -1117,6 +1116,8 @@ static int eagle_read_pkg_txt(read_state_t *st, trnode_t *subtree, void *obj, in
 	rnd_coord_t x, y;
 	int dir = 0, scale;
 	eagle_layerid_t layer;
+	eagle_layer_t *ely;
+	pcb_layer_type_t lyt;
 	const char *pattern;
 
 	for(n = CHILDREN(subtree); n != NULL; n = NEXT(n))
@@ -1141,7 +1142,14 @@ static int eagle_read_pkg_txt(read_state_t *st, trnode_t *subtree, void *obj, in
 	y += size; /* different text object origin in eagle */
 	scale = (int)(((double)size/(double)EAGLE_TEXT_SIZE_100) * 100.0);
 
-	pcb_subc_add_dyntex((pcb_subc_t *)obj, x, y, dir, scale, (layer == 27), pattern);
+	/* figure if target layer is on top or bottom */
+	ely = htip_get(&st->layers, layer);
+	if (ely != NULL)
+		lyt = pcb_layer_flags(st->pcb, ely->lid);
+	else
+		lyt = 0; /* unknown - at least not bottom */
+
+	pcb_subc_add_dyntex((pcb_subc_t *)obj, x, y, dir, scale, (lyt & PCB_LYT_BOTTOM), pattern);
 
 	return 0;
 }
@@ -1167,6 +1175,7 @@ static int eagle_read_poly(read_state_t *st, trnode_t *subtree, void *obj, int t
 	pcb_layer_t *ly;
 	eagle_layerid_t ln = eagle_get_attrl(st, subtree, "layer", -1);
 	const char *pour = GET_PROP(subtree, "pour");
+	const char *isolate = GET_PROP(subtree, "isolate");
 	pcb_poly_t *poly;
 	trnode_t *n;
 	int is_cutout;
@@ -1202,6 +1211,19 @@ TODO("bin: can remove the following if dealt with in post processor for binary t
 		}
 	}
 
+	/* the isolate field, when present, is poly-side clearance value;
+	   load only when centrally enabled, else warn so the user knows how to enable */
+	if (isolate != 0) {
+		if (!conf_core.import.alien_format.poly_side_clearance) {
+			if (!st->warned_poly_side_clr) {
+				rnd_message(RND_MSG_ERROR, "This eagle board has polygon side clearances that are IGNORED.\nTo enable loading them, change config node\nimport.alien_format.poly_side_clearance to true\n");
+				st->warned_poly_side_clr = 1;
+			}
+		}
+		else
+			poly->enforce_clearance = eagle_get_attrc(st, subtree, "isolate", 0);
+	}
+
 	pcb_add_poly_on_layer(ly, poly);
 	pcb_poly_init_clip(st->pcb->Data, ly, poly);
 
@@ -1240,7 +1262,7 @@ static int eagle_read_library_file_pkgs(read_state_t *st, trnode_t *subtree, voi
 			pcb_subc_t *subc;
 
 			subc = pcb_subc_alloc();
-			rnd_attribute_put(&subc->Attributes, "refdes", "K1");
+			pcb_attribute_put(&subc->Attributes, "refdes", "K1");
 			pcb_subc_reg(st->pcb->Data, subc);
 			pcb_subc_bind_globals(st->pcb, subc);
 			eagle_read_pkg(st, n, subc);
@@ -1250,9 +1272,9 @@ static int eagle_read_library_file_pkgs(read_state_t *st, trnode_t *subtree, voi
 				continue;
 			}
 
-			rnd_attribute_put(&subc->Attributes, "refdes", eagle_get_attrs(st, n, "name", NULL));
-			rnd_attribute_put(&subc->Attributes, "value", eagle_get_attrs(st, n, "value", NULL));
-			rnd_attribute_put(&subc->Attributes, "footprint", eagle_get_attrs(st, n, "package", NULL));
+			pcb_attribute_put(&subc->Attributes, "refdes", eagle_get_attrs(st, n, "name", NULL));
+			pcb_attribute_put(&subc->Attributes, "value", eagle_get_attrs(st, n, "value", NULL));
+			pcb_attribute_put(&subc->Attributes, "footprint", eagle_get_attrs(st, n, "package", NULL));
 
 			pcb_subc_bbox(subc);
 TODO("subc: revise this: are we loading an instance here? do we need to place it? do not even bump if not!")
@@ -1425,7 +1447,7 @@ static int eagle_read_signals(read_state_t *st, trnode_t *subtree, void *obj, in
 
 static void eagle_read_subc_attrs(read_state_t *st, trnode_t *nd, pcb_subc_t *subc, rnd_coord_t x, rnd_coord_t y, const char *attname, const char *subc_attr, const char *str, rnd_bool add_text)
 {
-	rnd_attribute_put(&subc->Attributes, subc_attr, str);
+	pcb_attribute_put(&subc->Attributes, subc_attr, str);
 	if (!add_text)
 		return;
 
@@ -1451,6 +1473,8 @@ TODO("{libtext} some text objects should be already created in the library; we s
 static int eagle_read_elements(read_state_t *st, trnode_t *subtree, void *obj, int type)
 {
 	trnode_t *n, *nlib;
+	double ang;
+
 	if (st->elem_by_name)
 		nlib = NULL;
 	else
@@ -1525,9 +1549,11 @@ static int eagle_read_elements(read_state_t *st, trnode_t *subtree, void *obj, i
 			pcb_subc_bbox(new_subc);
 			pcb_subc_rebind(st->pcb, new_subc);
 
+			pcb_subc_create_aux(new_subc, x, y, 0, 0);
+
 			if (rot != NULL) {
 				char *end;
-				double ang = strtod(rot+1, &end);
+				ang = strtod(rot+1, &end);
 				if (*end == '\0') {
 					if (fmod(ang, 90) == 0) { /* use lossles rotation without any sin() */
 						int steps = eagle_rot2steps(rot);
@@ -1541,6 +1567,8 @@ static int eagle_read_elements(read_state_t *st, trnode_t *subtree, void *obj, i
 					else {
 						double sina, cosa;
 						ang = -ang;
+						if (back)
+							ang -= 180;
 						sina = sin(ang / RND_RAD_TO_DEG);
 						cosa = cos(ang / RND_RAD_TO_DEG);
 						pcb_subc_rotate(new_subc, x, y, cosa, sina, ang);
@@ -1549,6 +1577,8 @@ static int eagle_read_elements(read_state_t *st, trnode_t *subtree, void *obj, i
 				else
 					rnd_message(RND_MSG_ERROR, "syntax error in element rotation '%s': %s/%s/%s\n", rot, name, pkg, lib);
 			}
+			else
+				ang = 0;
 
 			if (back)
 				pcb_subc_change_side(new_subc, 2 * y - st->pcb->hidlib.size_y);
