@@ -2,7 +2,7 @@
  *				COPYRIGHT
  *
  *	pcb-rnd, interactive printed circuit board design
- *	Copyright (C) 2017 Tibor 'Igor2' Palinkas
+ *	Copyright (C) 2017,2020 Tibor 'Igor2' Palinkas
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -36,19 +36,20 @@
 
 #include "board.h"
 #include "data.h"
-#include "error.h"
-#include "pcb-printf.h"
-#include "compat_misc.h"
-#include "safe_fs.h"
+#include "plug_import.h"
+#include <librnd/core/error.h>
+#include <librnd/core/rnd_printf.h>
+#include <librnd/core/compat_misc.h>
+#include <librnd/core/safe_fs.h>
 
-#include "actions.h"
-#include "plugins.h"
-#include "hid.h"
+#include <librnd/core/actions.h>
+#include <librnd/core/plugins.h>
+#include <librnd/core/hid.h>
 
 #define if_strval(node, name) \
 	if (strcmp(node->str, #name) == 0) { \
 		if (name != NULL) { \
-			pcb_message(PCB_MSG_ERROR, "Invalid eeschema: multiple %s subtrees\n", #name); \
+			rnd_message(RND_MSG_ERROR, "Invalid eeschema: multiple %s subtrees\n", #name); \
 			return -1; \
 		} \
 		if (node->children != NULL) \
@@ -58,7 +59,7 @@
 #define if_subtree(node, name) \
 	if (strcmp(node->str, #name) == 0) { \
 		if (name != NULL) { \
-			pcb_message(PCB_MSG_ERROR, "Invalid eeschema: multiple %s subtrees\n", #name); \
+			rnd_message(RND_MSG_ERROR, "Invalid eeschema: multiple %s subtrees\n", #name); \
 			return -1; \
 		} \
 		name = node; \
@@ -66,7 +67,7 @@
 
 #define req_subtree(name) \
 	if (name == NULL) { \
-		pcb_message(PCB_MSG_ERROR, "Invalid eeschema: missing %s subtree\n", #name); \
+		rnd_message(RND_MSG_ERROR, "Invalid eeschema: missing %s subtree\n", #name); \
 		return -1; \
 	} \
 
@@ -77,7 +78,7 @@ static int eeschema_parse_net(gsxl_dom_t *dom)
 
 	/* check the header */
 	if (strcmp(dom->root->str, "export") != 0) {
-		pcb_message(PCB_MSG_ERROR, "Invalid eeschema netlist header: not an export\n");
+		rnd_message(RND_MSG_ERROR, "Invalid eeschema netlist header: not an export\n");
 		return -1;
 	}
 
@@ -92,12 +93,12 @@ static int eeschema_parse_net(gsxl_dom_t *dom)
 	req_subtree(nets);
 
 	if ((version->children == NULL) || (strcmp(version->children->str, "D") != 0)) {
-		pcb_message(PCB_MSG_ERROR, "Invalid eeschema version: expected 'D', got '%s'\n", version->children->str);
+		rnd_message(RND_MSG_ERROR, "Invalid eeschema version: expected 'D', got '%s'\n", version->children->str);
 		return -1;
 	}
 
 	/* Load the elements */
-	pcb_actionva(&PCB->hidlib, "ElementList", "start", NULL);
+	rnd_actionva(&PCB->hidlib, "ElementList", "start", NULL);
 
 	for(c = components->children; c != NULL; c = c->next) {
 		const char *ref = NULL, *value = NULL, *footprint = NULL;
@@ -109,22 +110,22 @@ static int eeschema_parse_net(gsxl_dom_t *dom)
 			else if_strval(n, footprint)
 		}
 		if (ref == NULL) {
-			pcb_message(PCB_MSG_WARNING, "eeschema: ignoring component with no refdes\n");
+			rnd_message(RND_MSG_WARNING, "eeschema: ignoring component with no refdes\n");
 			continue;
 		}
 		if (footprint == NULL) {
-			pcb_message(PCB_MSG_WARNING, "eeschema: ignoring component %s with no footprint\n", ref);
+			rnd_message(RND_MSG_WARNING, "eeschema: ignoring component %s with no footprint\n", ref);
 			continue;
 		}
-		pcb_actionva(&PCB->hidlib, "ElementList", "Need", ref, footprint, value == NULL ? "" : value, NULL);
+		rnd_actionva(&PCB->hidlib, "ElementList", "Need", ref, footprint, value == NULL ? "" : value, NULL);
 	}
 
-	pcb_actionva(&PCB->hidlib, "ElementList", "Done", NULL);
+	rnd_actionva(&PCB->hidlib, "ElementList", "Done", NULL);
 
 	/* Load the netlist */
 
-	pcb_actionva(&PCB->hidlib, "Netlist", "Freeze", NULL);
-	pcb_actionva(&PCB->hidlib, "Netlist", "Clear", NULL);
+	rnd_actionva(&PCB->hidlib, "Netlist", "Freeze", NULL);
+	rnd_actionva(&PCB->hidlib, "Netlist", "Clear", NULL);
 
 	for(net = nets->children; net != NULL; net = net->next) {
 		const char *netname = NULL, *code = NULL, *name = NULL;
@@ -153,23 +154,23 @@ static int eeschema_parse_net(gsxl_dom_t *dom)
 						netname = code;
 				}
 				if (netname == NULL) {
-					pcb_message(PCB_MSG_WARNING, "eeschema: ignoring pins of incomplete net\n");
+					rnd_message(RND_MSG_WARNING, "eeschema: ignoring pins of incomplete net\n");
 					continue;
 				}
 
 				/* do the binding */
 				if ((ref == NULL) || (pin == NULL)) {
-					pcb_message(PCB_MSG_WARNING, "eeschema: ignoring incomplete connection to net %s: refdes=%s pin=%s \n", netname, ref, pin);
+					rnd_message(RND_MSG_WARNING, "eeschema: ignoring incomplete connection to net %s: refdes=%s pin=%s \n", netname, ref, pin);
 					continue;
 				}
-				pcb_snprintf(refpin, sizeof(refpin), "%s-%s", ref, pin);
-				pcb_actionva(&PCB->hidlib, "Netlist", "Add",  netname, refpin, NULL);
+				rnd_snprintf(refpin, sizeof(refpin), "%s-%s", ref, pin);
+				rnd_actionva(&PCB->hidlib, "Netlist", "Add",  netname, refpin, NULL);
 			}
 		}
 	}
 
-	pcb_actionva(&PCB->hidlib, "Netlist", "Sort", NULL);
-	pcb_actionva(&PCB->hidlib, "Netlist", "Thaw", NULL);
+	rnd_actionva(&PCB->hidlib, "Netlist", "Sort", NULL);
+	rnd_actionva(&PCB->hidlib, "Netlist", "Thaw", NULL);
 
 	return 0;
 }
@@ -183,9 +184,9 @@ static int eeschema_load(const char *fname_net)
 	int c, ret = 0;
 	gsx_parse_res_t res;
 
-	fn = pcb_fopen(&PCB->hidlib, fname_net, "r");
+	fn = rnd_fopen(&PCB->hidlib, fname_net, "r");
 	if (fn == NULL) {
-		pcb_message(PCB_MSG_ERROR, "can't open file '%s' for read\n", fname_net);
+		rnd_message(RND_MSG_ERROR, "can't open file '%s' for read\n", fname_net);
 		return -1;
 	}
 
@@ -220,12 +221,12 @@ fgw_error_t pcb_act_LoadeeschemaFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	const char *fname = NULL;
 	static char *default_file = NULL;
 
-	PCB_ACT_MAY_CONVARG(1, FGW_STR, LoadeeschemaFrom, fname = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(1, FGW_STR, LoadeeschemaFrom, fname = argv[1].val.str);
 
 	if (!fname || !*fname) {
-		fname = pcb_gui->fileselect(pcb_gui, "Load eeschema netlist file...",
+		fname = rnd_gui->fileselect(rnd_gui, "Load eeschema netlist file...",
 					"Picks a eeschema netlist file to load.\n",
-					default_file, ".net", NULL, "eeschema", PCB_HID_FSD_READ, NULL);
+					default_file, ".net", NULL, "eeschema", RND_HID_FSD_READ, NULL);
 		if (fname == NULL)
 			return 1;
 		if (default_file != NULL) {
@@ -234,7 +235,73 @@ fgw_error_t pcb_act_LoadeeschemaFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		}
 	}
 
-	PCB_ACT_IRES(eeschema_load(fname));
+	RND_ACT_IRES(eeschema_load(fname));
 	return 0;
 }
 
+
+static int eeschema_support_prio(pcb_plug_import_t *ctx, unsigned int aspects, const char **args, int numargs)
+{
+	unsigned int n, good = 0;
+	FILE *f;
+
+	if ((aspects != IMPORT_ASPECT_NETLIST) && (numargs == 1))
+		return 0; /* only pure netlist import is supported with a single input file */
+
+	f = rnd_fopen(&PCB->hidlib, args[0], "r");
+	if (f == NULL)
+		return 0;
+
+	for(n = 0; n < 32; n++) {
+		char *s, line[1024];
+		s = fgets(line, sizeof(line), f);
+		if (s == NULL)
+			break;
+		while(isspace(*s)) s++;
+		if (strstr(s, "(design") != NULL)
+			good |= 1;
+		else if (strstr(s, "(export") != NULL)
+			good |= 2;
+		if (good == (1|2)) {
+			fclose(f);
+			return 100;
+		}
+	}
+
+	fclose(f);
+	return 0;
+}
+
+
+static int eeschema_import(pcb_plug_import_t *ctx, unsigned int aspects, const char **fns, int numfns)
+{
+	if (numfns != 1) {
+		rnd_message(RND_MSG_ERROR, "import_eeschema: requires exactly 1 input file name\n");
+		return -1;
+	}
+	return eeschema_load(fns[0]);
+}
+
+static pcb_plug_import_t import_eeschema;
+
+void pcb_eeschema_uninit(void)
+{
+	RND_HOOK_UNREGISTER(pcb_plug_import_t, pcb_plug_import_chain, &import_eeschema);
+}
+
+void pcb_eeschema_init(void)
+{
+	/* register the IO hook */
+	import_eeschema.plugin_data = NULL;
+
+	import_eeschema.fmt_support_prio = eeschema_support_prio;
+	import_eeschema.import           = eeschema_import;
+	import_eeschema.name             = "eeschema";
+	import_eeschema.desc             = "schamtics from KiCad's eeschema";
+	import_eeschema.ui_prio          = 50;
+	import_eeschema.single_arg       = 1;
+	import_eeschema.all_filenames    = 1;
+	import_eeschema.ext_exec         = 0;
+
+	RND_HOOK_REGISTER(pcb_plug_import_t, pcb_plug_import_chain, &import_eeschema);
+}
