@@ -202,7 +202,7 @@ static lht_node_t *build_board_meta(pcb_board_t *pcb)
 	return meta;
 }
 
-static lht_node_t *build_attributes(rnd_attribute_list_t *lst)
+static lht_node_t *build_attributes(pcb_attribute_list_t *lst)
 {
 	int n;
 	lht_node_t *ln;
@@ -290,13 +290,13 @@ static void obj_attr_flag_warn(pcb_any_obj_t *obj)
 	int warned = 0;
 
 	if (wrver < 5) {
-		if (rnd_attribute_get(&obj->Attributes, "intnoconn") != NULL) {
+		if (pcb_attribute_get(&obj->Attributes, "intnoconn") != NULL) {
 			warned = 1;
 			rnd_message(RND_MSG_WARNING, "pcb-rnd versions only reading file older than lihata v5 may ignore the intnoconn flag\n");
 		}
 	}
 	if (wrver < 3) {
-		if (rnd_attribute_get(&obj->Attributes, "intconn") != NULL) {
+		if (pcb_attribute_get(&obj->Attributes, "intconn") != NULL) {
 			warned = 1;
 			rnd_message(RND_MSG_WARNING, "pcb-rnd versions only reading file older than lihata v3 may ignore the intconn flag\n");
 		}
@@ -609,7 +609,7 @@ static lht_node_t *build_pstk_pinvia(pcb_data_t *data, pcb_pstk_t *ps, rnd_bool
 	pcb_pstk_compshape_t cshape;
 	rnd_bool plated;
 	pcb_flag_t flg;
-	char *name = rnd_attribute_get(&ps->Attributes, "name");
+	char *name = pcb_attribute_get(&ps->Attributes, "name");
 
 
 	if (!pcb_pstk_export_compat_via(ps, &x, &y, &drill_dia, &pad_dia, &clearance, &mask, &cshape, &plated)) {
@@ -644,7 +644,7 @@ static lht_node_t *build_pstk_pad(pcb_data_t *data, pcb_pstk_t *ps, rnd_coord_t
 	lht_node_t *obj;
 	rnd_coord_t x1, y1, x2, y2, thickness, clearance, mask;
 	rnd_bool square, nopaste;
-	char *name = rnd_attribute_get(&ps->Attributes, "name");
+	char *name = pcb_attribute_get(&ps->Attributes, "name");
 	pcb_flag_t flg;
 
 	if (!pcb_pstk_export_compat_pad(ps, &x1, &y1, &x2, &y2, &thickness, &clearance, &mask, &square, &nopaste)) {
@@ -795,11 +795,11 @@ static lht_node_t *build_pcb_text(const char *role, pcb_text_t *text)
 	if (role != NULL)
 		lht_dom_hash_put(obj, build_text("role", role));
 
-	if ((wrver < 7) && ((av = rnd_attribute_get(&text->Attributes, "tight_clearance")) != NULL))
+	if ((wrver < 7) && ((av = pcb_attribute_get(&text->Attributes, "tight_clearance")) != NULL))
 		if (rnd_istrue(av))
 			pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text_tight_clearance", "lihata boards before version v7 did not support text tight_clearance\n", "Either save in lihata v7+ or remove the tight_clearance attribute");
 
-	if ((wrver < 7) && ((av = rnd_attribute_get(&text->Attributes, "mirror_x")) != NULL))
+	if ((wrver < 7) && ((av = pcb_attribute_get(&text->Attributes, "mirror_x")) != NULL))
 		if (rnd_istrue(av))
 			pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text_mirror_x", "lihata boards before version v7 did not support text mirror_x\n", "Either save in lihata v7+ or remove the mirror_x attribute");
 
@@ -859,11 +859,11 @@ static lht_node_t *build_subc_element(pcb_subc_t *subc)
 					if (!seen_refdes) {
 						pcb_text_t tmp;
 						memcpy(&tmp, text, sizeof(tmp));
-						tmp.TextString = rnd_attribute_get(&subc->Attributes, "footprint");
+						tmp.TextString = pcb_attribute_get(&subc->Attributes, "footprint");
 						lht_dom_list_append(lst, build_pcb_text("desc", &tmp));
-						tmp.TextString = rnd_attribute_get(&subc->Attributes, "refdes");
+						tmp.TextString = pcb_attribute_get(&subc->Attributes, "refdes");
 						lht_dom_list_append(lst, build_pcb_text("name", &tmp));
-						tmp.TextString = rnd_attribute_get(&subc->Attributes, "value");
+						tmp.TextString = pcb_attribute_get(&subc->Attributes, "value");
 						lht_dom_list_append(lst, build_pcb_text("value", &tmp));
 						seen_refdes = 1;
 					}
@@ -944,10 +944,10 @@ static void build_data_layer_comb(void *ctx, pcb_layer_combining_t bit, const ch
 }
 
 
-static lht_node_t *build_pstk_protos(pcb_data_t *data, pcb_vtpadstack_proto_t *pp)
+static lht_node_t *build_pstk_proto(pcb_data_t *data, pcb_pstk_proto_t *proto, long pid)
 {
-	lht_node_t *lst, *nproto, *nmask, *nshape, *nshapelst, *ncomb, *nshapeo;
-	rnd_cardinal_t n, sn, pn;
+	lht_node_t *nproto, *nmask, *nshape, *nshapelst, *ncomb, *nshapeo;
+	rnd_cardinal_t sn, pn;
 	pcb_pstk_tshape_t *ts;
 	char tmp[64];
 	pcb_layer_type_t lyt_permit = PCB_LYT_ANYWHERE | PCB_LYT_COPPER | PCB_LYT_SILK | PCB_LYT_MASK | PCB_LYT_PASTE;
@@ -955,97 +955,105 @@ static lht_node_t *build_pstk_protos(pcb_data_t *data, pcb_vtpadstack_proto_t *p
 	if (wrver >= 6)
 		lyt_permit |= PCB_LYT_MECH;
 
+	if (wrver < 6)
+		sprintf(tmp, "ps_proto_v4.%ld", pid);
+	else
+		sprintf(tmp, "ps_proto_v6.%ld", pid);
+
+	nproto = lht_dom_node_alloc(LHT_HASH, tmp);
+
+	lht_dom_hash_put(nproto, build_textf("hdia", CFMT, proto->hdia));
+	lht_dom_hash_put(nproto, build_textf("htop", "%d", proto->htop));
+	lht_dom_hash_put(nproto, build_textf("hbottom", "%d", proto->hbottom));
+	lht_dom_hash_put(nproto, build_textf("hplated", "%d", proto->hplated));
+	if (proto->name != NULL) {
+		if (wrver >= 5)
+			lht_dom_hash_put(nproto, build_text("name", proto->name));
+		else
+			pcb_io_incompat_save(NULL, NULL, "padstack-name", "versions below lihata board v5 do not support padstack prototype names\n", "Be aware that padstack proto names are lost in save or use lihata board v5 or higher");
+	}
+	else
+		lht_dom_hash_put(nproto, dummy_node("name"));
+
+	/* save each shape */
+	lht_dom_hash_put(nproto, nshapelst = lht_dom_node_alloc(LHT_LIST, "shape"));
+	ts = &proto->tr.array[0]; /* save the canonical shape only, the transformation cache is generated runtime */
+	if (ts != NULL)
+	for(sn = 0; sn < ts->len; sn++) {
+		pcb_pstk_shape_t *shape = ts->shape + sn;
+		pcb_layer_type_t save_mask;
+
+		save_mask = shape->layer_mask & lyt_permit;
+		if (save_mask != shape->layer_mask) {
+			pcb_io_incompat_save(data, NULL, "padstack-layer", "Can not save padstack prototype properly because it uses a layer type not supported by this version of lihata padstack.", "Either save in the latest lihata - or accept that some shapes are omitted");
+			continue;
+		}
+
+		lht_dom_list_append(nshapelst, nshape = lht_dom_node_alloc(LHT_HASH, "ps_shape_v4"));
+
+		lht_dom_hash_put(nshape, nmask = lht_dom_node_alloc(LHT_HASH, "layer_mask"));
+		pcb_layer_type_map(save_mask, nmask, build_layer_stack_flag);
+
+		lht_dom_hash_put(nshape, ncomb = lht_dom_node_alloc(LHT_HASH, "combining"));
+		pcb_layer_comb_map(shape->comb, ncomb, build_data_layer_comb);
+
+		lht_dom_hash_put(nshape, build_textf("clearance", CFMT, shape->clearance));
+
+		switch(shape->shape) {
+			case PCB_PSSH_POLY:
+				nshapeo = lht_dom_node_alloc(LHT_LIST, "ps_poly");
+				for(pn = 0; pn < shape->data.poly.len; pn++) {
+					lht_dom_list_append(nshapeo, build_textf(NULL, CFMT, shape->data.poly.x[pn]));
+					lht_dom_list_append(nshapeo, build_textf(NULL, CFMT, shape->data.poly.y[pn]));
+				}
+				break;
+			case PCB_PSSH_LINE:
+				nshapeo = lht_dom_node_alloc(LHT_HASH, "ps_line");
+				lht_dom_hash_put(nshapeo, build_textf("x1", CFMT, shape->data.line.x1));
+				lht_dom_hash_put(nshapeo, build_textf("y1", CFMT, shape->data.line.y1));
+				lht_dom_hash_put(nshapeo, build_textf("x2", CFMT, shape->data.line.x2));
+				lht_dom_hash_put(nshapeo, build_textf("y2", CFMT, shape->data.line.y2));
+				lht_dom_hash_put(nshapeo, build_textf("thickness", CFMT, shape->data.line.thickness));
+				lht_dom_hash_put(nshapeo, build_textf("square", "%d", shape->data.line.square));
+				break;
+			case PCB_PSSH_CIRC:
+				nshapeo = lht_dom_node_alloc(LHT_HASH, "ps_circ");
+				lht_dom_hash_put(nshapeo, build_textf("x", CFMT, shape->data.circ.x));
+				lht_dom_hash_put(nshapeo, build_textf("y", CFMT, shape->data.circ.y));
+				lht_dom_hash_put(nshapeo, build_textf("dia", CFMT, shape->data.circ.dia));
+				break;
+			case PCB_PSSH_HSHADOW:
+				if (wrver < 6) {
+					pcb_io_incompat_save(data, NULL, "padstack-shape", "Can not save padstack prototype shape \"hshadow\" in lihata formats below version 6.", "Either save in lihata v6 - or accept that the padstack will connect more layers than it should.");
+					nshapeo = lht_dom_node_alloc(LHT_HASH, "ps_circ");
+					lht_dom_hash_put(nshapeo, build_textf("dia", CFMT, 1));
+				}
+				else
+					nshapeo = build_text("ps_hshadow", "");
+				break;
+			default:
+				rnd_message(RND_MSG_ERROR, "Internal error: unimplemented pad stack shape %d\n", shape->shape);
+				abort();
+		}
+		lht_dom_hash_put(nshape, nshapeo);
+	}
+
+	return nproto;
+}
+
+static lht_node_t *build_pstk_protos(pcb_data_t *data, pcb_vtpadstack_proto_t *pp)
+{
+	lht_node_t *lst;
+	rnd_cardinal_t n;
+
 	lst = lht_dom_node_alloc(LHT_LIST, "padstack_prototypes");
 	for(n = 0; n < pcb_vtpadstack_proto_len(pp); n++) {
 		pcb_pstk_proto_t *proto = pp->array+n;
 
-		if (!proto->in_use) {
+		if (proto->in_use)
+			lht_dom_list_append(lst, build_pstk_proto(data, proto, n));
+		else
 			lht_dom_list_append(lst, build_text("unused", "1"));
-			continue;
-		}
-
-		if (wrver < 6)
-			sprintf(tmp, "ps_proto_v4.%ld", (long)n);
-		else
-			sprintf(tmp, "ps_proto_v6.%ld", (long)n);
-
-		lht_dom_list_append(lst, nproto = lht_dom_node_alloc(LHT_HASH, tmp));
-
-		lht_dom_hash_put(nproto, build_textf("hdia", CFMT, proto->hdia));
-		lht_dom_hash_put(nproto, build_textf("htop", "%d", proto->htop));
-		lht_dom_hash_put(nproto, build_textf("hbottom", "%d", proto->hbottom));
-		lht_dom_hash_put(nproto, build_textf("hplated", "%d", proto->hplated));
-		if (proto->name != NULL) {
-			if (wrver >= 5)
-				lht_dom_hash_put(nproto, build_text("name", proto->name));
-			else
-				pcb_io_incompat_save(NULL, NULL, "padstack-name", "versions below lihata board v5 do not support padstack prototype names\n", "Be aware that padstack proto names are lost in save or use lihata board v5 or higher");
-		}
-		else
-			lht_dom_hash_put(nproto, dummy_node("name"));
-
-		/* save each shape */
-		lht_dom_hash_put(nproto, nshapelst = lht_dom_node_alloc(LHT_LIST, "shape"));
-		ts = &proto->tr.array[0]; /* save the canonical shape only, the transformation cache is generated runtime */
-		if (ts != NULL)
-		for(sn = 0; sn < ts->len; sn++) {
-			pcb_pstk_shape_t *shape = ts->shape + sn;
-			pcb_layer_type_t save_mask;
-
-			save_mask = shape->layer_mask & lyt_permit;
-			if (save_mask != shape->layer_mask) {
-				pcb_io_incompat_save(data, NULL, "padstack-layer", "Can not save padstack prototype properly because it uses a layer type not supported by this version of lihata padstack.", "Either save in the latest lihata - or accept that some shapes are omitted");
-				continue;
-			}
-
-			lht_dom_list_append(nshapelst, nshape = lht_dom_node_alloc(LHT_HASH, "ps_shape_v4"));
-
-			lht_dom_hash_put(nshape, nmask = lht_dom_node_alloc(LHT_HASH, "layer_mask"));
-			pcb_layer_type_map(save_mask, nmask, build_layer_stack_flag);
-
-			lht_dom_hash_put(nshape, ncomb = lht_dom_node_alloc(LHT_HASH, "combining"));
-			pcb_layer_comb_map(shape->comb, ncomb, build_data_layer_comb);
-
-			lht_dom_hash_put(nshape, build_textf("clearance", CFMT, shape->clearance));
-
-			switch(shape->shape) {
-				case PCB_PSSH_POLY:
-					nshapeo = lht_dom_node_alloc(LHT_LIST, "ps_poly");
-					for(pn = 0; pn < shape->data.poly.len; pn++) {
-						lht_dom_list_append(nshapeo, build_textf(NULL, CFMT, shape->data.poly.x[pn]));
-						lht_dom_list_append(nshapeo, build_textf(NULL, CFMT, shape->data.poly.y[pn]));
-					}
-					break;
-				case PCB_PSSH_LINE:
-					nshapeo = lht_dom_node_alloc(LHT_HASH, "ps_line");
-					lht_dom_hash_put(nshapeo, build_textf("x1", CFMT, shape->data.line.x1));
-					lht_dom_hash_put(nshapeo, build_textf("y1", CFMT, shape->data.line.y1));
-					lht_dom_hash_put(nshapeo, build_textf("x2", CFMT, shape->data.line.x2));
-					lht_dom_hash_put(nshapeo, build_textf("y2", CFMT, shape->data.line.y2));
-					lht_dom_hash_put(nshapeo, build_textf("thickness", CFMT, shape->data.line.thickness));
-					lht_dom_hash_put(nshapeo, build_textf("square", "%d", shape->data.line.square));
-					break;
-				case PCB_PSSH_CIRC:
-					nshapeo = lht_dom_node_alloc(LHT_HASH, "ps_circ");
-					lht_dom_hash_put(nshapeo, build_textf("x", CFMT, shape->data.circ.x));
-					lht_dom_hash_put(nshapeo, build_textf("y", CFMT, shape->data.circ.y));
-					lht_dom_hash_put(nshapeo, build_textf("dia", CFMT, shape->data.circ.dia));
-					break;
-				case PCB_PSSH_HSHADOW:
-					if (wrver < 6) {
-						pcb_io_incompat_save(data, NULL, "padstack-shape", "Can not save padstack prototype shape \"hshadow\" in lihata formats below version 6.", "Either save in lihata v6 - or accept that the padstack will connect more layers than it should.");
-						nshapeo = lht_dom_node_alloc(LHT_HASH, "ps_circ");
-						lht_dom_hash_put(nshapeo, build_textf("dia", CFMT, 1));
-					}
-					else
-						nshapeo = build_text("ps_hshadow", "");
-					break;
-				default:
-					rnd_message(RND_MSG_ERROR, "Internal error: unimplemented pad stack shape %d\n", shape->shape);
-					abort();
-			}
-			lht_dom_hash_put(nshape, nshapeo);
-		}
 	}
 
 	return lst;
@@ -1524,7 +1532,7 @@ static lht_node_t *build_netlist(pcb_netlist_t *netlist, const char *name, int *
 			pcb_net_t *net = e->value;
 			pcb_net_term_t *t;
 			const char *netname = net->name;
-			const char *style = rnd_attribute_get(&net->Attributes, "style");
+			const char *style = pcb_attribute_get(&net->Attributes, "style");
 
 			/* create the net hash */
 			nnet = lht_dom_node_alloc(LHT_HASH, netname);
@@ -2011,6 +2019,29 @@ int io_lihata_write_buffer(pcb_plug_io_t *ctx, FILE *f, pcb_buffer_t *buff)
 
 }
 
+int io_lihata_write_padstack(pcb_plug_io_t *ctx, FILE *f, pcb_pstk_proto_t *proto)
+{
+	int res;
+	lht_doc_t *doc;
+
+	wrver = plug2ver(ctx);
+	if (wrver < 6)
+		wrver = 6;
+
+	io_lihata_full_tree = 1;
+	doc = lht_dom_init();
+	doc->root =lht_dom_node_alloc(LHT_HASH, "pcb-rnd-padstack-v6");
+	lht_dom_hash_put(doc->root, build_pstk_proto(NULL, proto, 0));
+
+	clean_invalid(doc->root); /* remove invalid nodes placed for persistency */
+	res = lht_dom_export(doc->root, f, "");
+
+	lht_dom_uninit(doc);
+	io_lihata_full_tree = 0;
+	return res;
+
+}
+
 typedef struct {
 	int womit_font, womit_config, womit_styles;
 	int ver;
@@ -2024,21 +2055,21 @@ void *io_lihata_save_as_subd_init(const pcb_plug_io_t *ctx, rnd_hid_dad_subdialo
 		RND_DAD_BEGIN_HBOX(sub->dlg);
 			RND_DAD_LABEL(sub->dlg, "Omit font");
 				RND_DAD_HELP(sub->dlg, "Do not save the font subtree\nWARNING: this will make the board depend on\nthe default font available on systems\nwhere it is loaded; if multiple fonts\nare used, all will be displayed using the default");
-			RND_DAD_BOOL(sub->dlg, "");
+			RND_DAD_BOOL(sub->dlg);
 				RND_DAD_DEFAULT_NUM(sub->dlg, !!conf_io_lihata.plugins.io_lihata.omit_font);
 				save->womit_font = RND_DAD_CURRENT(sub->dlg);
 		RND_DAD_END(sub->dlg);
 		RND_DAD_BEGIN_HBOX(sub->dlg);
 			RND_DAD_LABEL(sub->dlg, "Omit config");
 				RND_DAD_HELP(sub->dlg, "Do not save the config subtree\nWARNING: this will lose all DESIGN role\nconfig setting in the resulting file");
-			RND_DAD_BOOL(sub->dlg, "");
+			RND_DAD_BOOL(sub->dlg);
 				RND_DAD_DEFAULT_NUM(sub->dlg, !!conf_io_lihata.plugins.io_lihata.omit_config);
 				save->womit_config = RND_DAD_CURRENT(sub->dlg);
 		RND_DAD_END(sub->dlg);
 		RND_DAD_BEGIN_HBOX(sub->dlg);
 			RND_DAD_LABEL(sub->dlg, "Omit styles");
 				RND_DAD_HELP(sub->dlg, "Do not save the routing style subtree\nThe resulting file will have no\nrouting styles");
-			RND_DAD_BOOL(sub->dlg, "");
+			RND_DAD_BOOL(sub->dlg);
 				RND_DAD_DEFAULT_NUM(sub->dlg, !!conf_io_lihata.plugins.io_lihata.omit_styles);
 				save->womit_styles = RND_DAD_CURRENT(sub->dlg);
 		RND_DAD_END(sub->dlg);
