@@ -210,7 +210,7 @@ TODO("layer: revise this loop to save only what the original code saved")
 }
 
 
-static void WriteAttributeList(FILE * FP, rnd_attribute_list_t *list, const char *prefix, const char **inhibit)
+static void WriteAttributeList(FILE * FP, pcb_attribute_list_t *list, const char *prefix, const char **inhibit)
 {
 	int i;
 	const char **ih;
@@ -352,7 +352,7 @@ static void WriteViaData(FILE * FP, pcb_data_t *Data)
 		rnd_coord_t x, y, drill_dia, pad_dia, clearance, mask;
 		pcb_pstk_compshape_t cshape;
 		rnd_bool plated;
-		char *name = rnd_attribute_get(&ps->Attributes, "name");
+		char *name = pcb_attribute_get(&ps->Attributes, "name");
 
 		if (!pcb_pstk_export_compat_via(ps, &x, &y, &drill_dia, &pad_dia, &clearance, &mask, &cshape, &plated)) {
 			pcb_io_incompat_save(Data, (pcb_any_obj_t *)ps, "via", "Failed to convert to old-style via", "Old via format is very much restricted; try to use a simpler, uniform shape padstack");
@@ -396,7 +396,7 @@ static void WritePCBNetlistData(FILE *FP)
 		fprintf(FP, "\tNet(");
 		pcb_print_quoted_string(FP, net->name);
 		fprintf(FP, " ");
-		pcb_print_quoted_string(FP, (char *) RND_UNKNOWN(rnd_attribute_get(&net->Attributes, "style")));
+		pcb_print_quoted_string(FP, (char *) RND_UNKNOWN(pcb_attribute_get(&net->Attributes, "style")));
 		fprintf(FP, ")\n\t(\n");
 		for(t = pcb_termlist_first(&net->conns); t != NULL; t = pcb_termlist_next(t)) {
 			fprintf(FP, "\t\tConnect(\"");
@@ -446,23 +446,22 @@ static void io_pcb_print_subc(pcb_plug_io_t *ctx, FILE *FP, pcb_subc_t *sc)
 
 			rx = trefdes->X - ox;
 			ry = trefdes->Y - oy;
-			if (!pcb_text_old_direction(&rdir, trefdes->rot)) {
-TODO("textrot: incompatibility warning")
-			}
+			if (!pcb_text_old_direction(&rdir, trefdes->rot))
+				pcb_io_incompat_save(NULL, (pcb_any_obj_t *)trefdes, "text rotation", "text rotation angle rounded", "the gEDA/PCB file format does not support text rotation other than multiple of 90 degree");
 			rscale = scale;
 		}
 		else {
 			const char *tmp;
-			tmp = rnd_attribute_get(&sc->Attributes, "io_pcb::hidename_x");
+			tmp = pcb_attribute_get(&sc->Attributes, "io_pcb::hidename_x");
 			if (tmp != NULL)
 				rx = rnd_get_value(tmp, NULL, NULL, NULL) - ox;
-			tmp = rnd_attribute_get(&sc->Attributes, "io_pcb::hidename_y");
+			tmp = pcb_attribute_get(&sc->Attributes, "io_pcb::hidename_y");
 			if (tmp != NULL)
 				ry = rnd_get_value(tmp, NULL, NULL, NULL) - oy;
-			tmp = rnd_attribute_get(&sc->Attributes, "io_pcb::hidename_direction");
+			tmp = pcb_attribute_get(&sc->Attributes, "io_pcb::hidename_direction");
 			if (tmp != NULL)
 				rdir = atoi(tmp);
-			tmp = rnd_attribute_get(&sc->Attributes, "io_pcb::hidename_scale");
+			tmp = pcb_attribute_get(&sc->Attributes, "io_pcb::hidename_scale");
 			if (tmp != NULL)
 				rscale = atoi(tmp);
 		}
@@ -474,11 +473,11 @@ TODO("textrot: incompatibility warning")
 		if (on_bot)
 			fobj.Flags.f |= PCB_FLAG_ONSOLDER;
 		fprintf(FP, "\nElement[%s ", F2S(&fobj, PCB_OBJ_ELEMENT));
-		pcb_print_quoted_string(FP, (char *) RND_EMPTY(rnd_attribute_get(&sc->Attributes, "footprint")));
+		pcb_print_quoted_string(FP, (char *) RND_EMPTY(pcb_attribute_get(&sc->Attributes, "footprint")));
 		fputc(' ', FP);
-		pcb_print_quoted_string(FP, (char *) RND_EMPTY(rnd_attribute_get(&sc->Attributes, "refdes")));
+		pcb_print_quoted_string(FP, (char *) RND_EMPTY(pcb_attribute_get(&sc->Attributes, "refdes")));
 		fputc(' ', FP);
-		pcb_print_quoted_string(FP, (char *) RND_EMPTY(rnd_attribute_get(&sc->Attributes, "value")));
+		pcb_print_quoted_string(FP, (char *) RND_EMPTY(pcb_attribute_get(&sc->Attributes, "value")));
 		rnd_fprintf(FP, " %[0] %[0] %[0] %[0] %d %d %s]\n(\n", ox, oy, rx, ry, rdir, rscale, trefdes != NULL ? F2S(trefdes, PCB_OBJ_ELEMENT_NAME) : "\"\"");
 		WriteAttributeList(FP, &sc->Attributes, "\t", attr_inhibit);
 
@@ -489,18 +488,18 @@ TODO("textrot: incompatibility warning")
 			unsigned char ic = ps->intconn;
 			if (pcb_pstk_export_compat_via(ps, &x, &y, &drill_dia, &pad_dia, &clearance, &mask, &cshape, &plated)) {
 				rnd_fprintf(FP, "\tPin[%[0] %[0] %[0] %[0] %[0] %[0] ", x - ox, y - oy, pad_dia, clearance*2, mask, drill_dia);
-				pcb_print_quoted_string(FP, (char *)RND_EMPTY(rnd_attribute_get(&ps->Attributes, "name")));
+				pcb_print_quoted_string(FP, (char *)RND_EMPTY(pcb_attribute_get(&ps->Attributes, "name")));
 				fprintf(FP, " ");
-				pcb_print_quoted_string(FP, (char *) RND_EMPTY(rnd_attribute_get(&ps->Attributes, "term")));
+				pcb_print_quoted_string(FP, (char *) RND_EMPTY(pcb_attribute_get(&ps->Attributes, "term")));
 				fprintf(FP, " %s]\n", pcb_strflg_f2s(pcb_pstk_compat_pinvia_flag(ps, cshape, PCB_PSTKCOMP_OLD_OCTAGON), PCB_OBJ_PIN, &ic, 1));
 			}
 			else if (pcb_pstk_export_compat_pad(ps, &x1, &y1, &x2, &y2, &thickness, &clearance, &mask, &square, &nopaste)) {
 				unsigned long fl = (square ? PCB_FLAG_SQUARE : 0) | (nopaste ? PCB_FLAG_NOPASTE : 0) | (on_bot ? PCB_FLAG_ONSOLDER : 0);
 				rnd_fprintf(FP, "\tPad[%[0] %[0] %[0] %[0] %[0] %[0] %[0] ",
 					x1 - ox, y1 - oy, x2 - ox, y2 - oy, thickness, clearance, mask);
-					pcb_print_quoted_string(FP, (char *)RND_EMPTY(rnd_attribute_get(&ps->Attributes, "name")));
+					pcb_print_quoted_string(FP, (char *)RND_EMPTY(pcb_attribute_get(&ps->Attributes, "name")));
 					fprintf(FP, " ");
-					pcb_print_quoted_string(FP, (char *) RND_EMPTY(rnd_attribute_get(&ps->Attributes, "term")));
+					pcb_print_quoted_string(FP, (char *) RND_EMPTY(pcb_attribute_get(&ps->Attributes, "term")));
 					fprintf(FP, " %s]\n", pcb_strflg_f2s(pcb_flag_make(fl), PCB_OBJ_PAD, &ic, 1));
 			}
 			else
@@ -645,9 +644,8 @@ static void WriteLayerData(FILE * FP, rnd_cardinal_t Number, pcb_layer_t *layer)
 				pcb_io_incompat_save(PCB->Data, (pcb_any_obj_t *)text, "text-scale", "file format does not support different x and y direction text scale - using average scale", "Use the scale field, set scale_x and scale_y to 0");
 			if (text->mirror_x)
 				pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text-mirror-x", "file format does not support different mirroring text in the x direction", "do not mirror, or mirror in the y direction (with the ONSOLDER flag)");
-			if (!pcb_text_old_direction(&dir, text->rot)) {
-TODO("textrot: incompatibility warning")
-			}
+			if (!pcb_text_old_direction(&dir, text->rot))
+				pcb_io_incompat_save(NULL, (pcb_any_obj_t *)text, "text rotation", "text rotation angle rounded", "the gEDA/PCB file format does not support text rotation other than multiple of 90 degree");
 			rnd_fprintf(FP, "\tText[%[0] %[0] %d %d ", text->X, text->Y, dir, scale);
 			pcb_print_quoted_string(FP, (char *) RND_EMPTY(text->TextString));
 			fprintf(FP, " %s]\n", F2S(text, PCB_OBJ_TEXT));
@@ -729,8 +727,10 @@ static void LayersFixup(void)
 		chg = 1;
 	}
 
-	if (chg)
+	if (chg) {
+		rnd_message(RND_MSG_ERROR, "The geda/pcb file format requires top and bottom silk be the last layers in the list.\nI had to swap layers in your board _before_ the save.\nAt the moment this is not undoable!\n");
 		rnd_event(&PCB->hidlib, PCB_EVENT_LAYERS_CHANGED, NULL);
+	}
 }
 
 static void WriteLayers(FILE *FP, pcb_data_t *data)
@@ -753,7 +753,7 @@ static void WriteLayers(FILE *FP, pcb_data_t *data)
 
 int io_pcb_WritePCB(pcb_plug_io_t *ctx, FILE * FP, const char *old_filename, const char *new_filename, rnd_bool emergency)
 {
-	rnd_attribute_put(&PCB->Attributes, "PCB::loader", ctx->description);
+	pcb_attribute_put(&PCB->Attributes, "PCB::loader", ctx->description);
 
 	LayersFixup();
 
@@ -1060,11 +1060,11 @@ pcb_subc_t *io_pcb_element_new(pcb_data_t *Data, pcb_subc_t *subc,
 	PCB_FLAG_SET(Flags.f, sc);
 
 	if (Description != NULL)
-		rnd_attribute_put(&sc->Attributes, "footprint", Description);
+		pcb_attribute_put(&sc->Attributes, "footprint", Description);
 	if (NameOnPCB != NULL)
-		rnd_attribute_put(&sc->Attributes, "refdes", NameOnPCB);
+		pcb_attribute_put(&sc->Attributes, "refdes", NameOnPCB);
 	if (Value != NULL)
-		rnd_attribute_put(&sc->Attributes, "value", Value);
+		pcb_attribute_put(&sc->Attributes, "value", Value);
 
 TODO("subc: TextFlags")
 	if (!(Flags.f & PCB_FLAG_HIDENAME))
@@ -1073,13 +1073,13 @@ TODO("subc: TextFlags")
 	if (Flags.f & PCB_FLAG_HIDENAME) {
 		char tmp[128];
 		rnd_sprintf(tmp, "%$mm", TextX);
-		rnd_attribute_put(&sc->Attributes, "io_pcb::hidename_x", tmp);
+		pcb_attribute_put(&sc->Attributes, "io_pcb::hidename_x", tmp);
 		rnd_sprintf(tmp, "%$mm", TextY);
-		rnd_attribute_put(&sc->Attributes, "io_pcb::hidename_y", tmp);
+		pcb_attribute_put(&sc->Attributes, "io_pcb::hidename_y", tmp);
 		sprintf(tmp, "%d", Direction);
-		rnd_attribute_put(&sc->Attributes, "io_pcb::hidename_direction", tmp);
+		pcb_attribute_put(&sc->Attributes, "io_pcb::hidename_direction", tmp);
 		sprintf(tmp, "%d", TextScale);
-		rnd_attribute_put(&sc->Attributes, "io_pcb::hidename_scale", tmp);
+		pcb_attribute_put(&sc->Attributes, "io_pcb::hidename_scale", tmp);
 	}
 
 	return sc;
@@ -1122,9 +1122,9 @@ pcb_pstk_t *io_pcb_element_pin_new(pcb_subc_t *subc, rnd_coord_t X, rnd_coord_t
 	pcb_pstk_t *p;
 	p = pcb_old_via_new(subc->data, -1, X, Y, Thickness, Clearance, Mask, DrillingHole, Name, Flags);
 	if (Number != NULL)
-		rnd_attribute_put(&p->Attributes, "term", Number);
+		pcb_attribute_put(&p->Attributes, "term", Number);
 	if (Name != NULL)
-		rnd_attribute_put(&p->Attributes, "name", Name);
+		pcb_attribute_put(&p->Attributes, "name", Name);
 
 	if (yysubc_bottom)
 		pcb_pstk_mirror(p, PCB_PSTK_DONT_MIRROR_COORDS, 1, 0, 0);
@@ -1137,9 +1137,9 @@ pcb_pstk_t *io_pcb_element_pad_new(pcb_subc_t *subc, rnd_coord_t X1, rnd_coord_t
 
 	p = pcb_pstk_new_compat_pad(subc->data, -1, X1, Y1, X2, Y2, Thickness, Clearance, Mask, Flags.f & PCB_FLAG_SQUARE, Flags.f & PCB_FLAG_NOPASTE, (!!(Flags.f & PCB_FLAG_ONSOLDER)) != yysubc_bottom);
 	if (Number != NULL)
-		rnd_attribute_put(&p->Attributes, "term", Number);
+		pcb_attribute_put(&p->Attributes, "term", Number);
 	if (Name != NULL)
-		rnd_attribute_put(&p->Attributes, "name", Name);
+		pcb_attribute_put(&p->Attributes, "name", Name);
 
 	if (yysubc_bottom) {
 		pcb_data_t *old_hack = pcb_pstk_data_hack;
@@ -1304,3 +1304,124 @@ out:;
 	gds_uninit(&tag);
 	return head;
 }
+
+/* old outline rules from geda/pcb */
+#define LAYER_IS_OUTLINE(idx) ((pcb->Data->Layer[idx].name != NULL) && ((strcmp(pcb->Data->Layer[idx].name, "route") == 0 || rnd_strcasecmp(pcb->Data->Layer[(idx)].name, "outline") == 0)))
+
+static int flush_item(const char *s, const char *start, rnd_layer_id_t *lids, int *lids_len, pcb_layer_type_t *loc)
+{
+	char *end;
+	rnd_layer_id_t lid;
+	switch (*start) {
+		case 'c': case 'C': case 't': case 'T': *loc = PCB_LYT_TOP; break;
+		case 's': case 'S': case 'b': case 'B': *loc = PCB_LYT_BOTTOM; break;
+		default:
+			lid = strtol(start, &end, 10)-1;
+			if (end != s)
+				return -1;
+			if ((*lids_len) >= PCB_MAX_LAYER)
+				return -1;
+			lids[*lids_len] = lid;
+			(*lids_len)++;
+	}
+	return 0;
+}
+
+int pcb_layer_parse_group_string(pcb_board_t *pcb, const char *grp_str, int LayerN, int oldfmt)
+{
+	const char *s, *start;
+	rnd_layer_id_t lids[PCB_MAX_LAYER];
+	int lids_len = 0;
+	pcb_layer_type_t loc = PCB_LYT_INTERN;
+	pcb_layergrp_t *g;
+	int n;
+	pcb_layer_stack_t *LayerGroup = &pcb->LayerGroups;
+
+	pcb_layergrp_inhibit_inc();
+
+	/* clear struct */
+	pcb_layer_group_setup_default(pcb);
+
+	for(start = s = grp_str; ; s++) {
+		switch(*s) {
+			case ',':
+				if (flush_item(s, start, lids, &lids_len, &loc) != 0)
+					goto error;
+				start = s+1;
+				break;
+			case '\0':
+			case ':':
+				if (flush_item(s, start, lids, &lids_len, &loc) != 0)
+					goto error;
+				/* finalize group */
+				if (loc & PCB_LYT_INTERN) {
+					g = pcb_get_grp_new_intern(pcb, -1);
+					if (g == NULL) {
+						rnd_message(RND_MSG_ERROR, "pcb_layer_parse_group_string(): unable to insert layer groups for copper\n");
+						goto error;
+					}
+				}
+				else {
+					g = pcb_get_grp(LayerGroup, loc, PCB_LYT_COPPER);
+					if (g == NULL) {
+						rnd_message(RND_MSG_ERROR, "pcb_layer_parse_group_string(): unable to insert layer groups for copper\n");
+						goto error;
+					}
+				}
+
+				for(n = 0; n < lids_len; n++) {
+					if (lids[n] < 0)
+						continue;
+					if (LAYER_IS_OUTLINE(lids[n])) {
+						if (g->ltype & PCB_LYT_INTERN) {
+							pcb_layergrp_fix_turn_to_outline(g);
+							pcb->Data->Layer[lids[n]].comb |= PCB_LYC_AUTO;
+						}
+						else
+							rnd_message(RND_MSG_ERROR, "outline layer can not be on the solder or component side - converting it into a copper layer\n");
+					}
+					if (g == NULL) {
+						rnd_message(RND_MSG_ERROR, "pcb_layer_parse_group_string(): unable to find copper group for creating the copper layer\n");
+						goto error;
+					}
+					pcb_layer_add_in_group_(pcb, g, g - LayerGroup->grp, lids[n]);
+				}
+
+				lids_len = 0;
+
+				/* prepare for next iteration */
+				loc = PCB_LYT_INTERN;
+				start = s+1;
+				break;
+		}
+		if (*s == '\0')
+			break;
+	}
+
+	pcb_layergrp_fix_old_outline(pcb);
+
+	/* set the two silks */
+	g = pcb_get_grp(LayerGroup, PCB_LYT_BOTTOM, PCB_LYT_SILK);
+	if (g == NULL) {
+		rnd_message(RND_MSG_ERROR, "pcb_layer_parse_group_string(): unable to find bottom silk layer group\n");
+		goto error;
+	}
+	pcb_layer_add_in_group_(pcb, g, g - LayerGroup->grp, LayerN-2);
+
+
+	g = pcb_get_grp(LayerGroup, PCB_LYT_TOP, PCB_LYT_SILK);
+	if (g == NULL) {
+		rnd_message(RND_MSG_ERROR, "pcb_layer_parse_group_string(): unable to find top silk layer group\n");
+		goto error;
+	}
+	pcb_layer_add_in_group_(pcb, g, g - LayerGroup->grp, LayerN-1);
+
+	pcb_layergrp_inhibit_dec();
+	return 0;
+
+	/* reset structure on error */
+error:
+	pcb_layergrp_inhibit_dec();
+	memset(LayerGroup, 0, sizeof(pcb_layer_stack_t));
+	return 1;
+}
