@@ -42,14 +42,19 @@
 #include <librnd/core/actions.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
+#include <librnd/core/hid_menu.h>
 #include "plug_io.h"
 #include "stackup.h"
 #include "tlayer.h"
 #include "tboard.h"
+#include "trouter.h"
 #include "tdrc.h"
 #include "tdrc_query.h"
 #include "tetest.h"
 #include "tnetlist.h"
+#include "trouter.h"
+
+#include "menu_internal.c"
 
 static const char *tedax_cookie = "tEDAx IO";
 static pcb_plug_io_t io_tedax;
@@ -69,7 +74,8 @@ int io_tedax_fmt(pcb_plug_io_t *ctx, pcb_plug_iot_t typ, int wr, const char *fmt
 
 static const char pcb_acts_Savetedax[] = 
 	"SaveTedax(netlist|board-footprints|stackup|layer|board|drc|etest, filename)\n"
-	"SaveTedax(drc_query, filename, [rule_name])";
+	"SaveTedax(drc_query, filename, [rule_name])"
+	"SaveTedax(route_req, filename, [confkey=value, confkey=value, ...])";
 static const char pcb_acth_Savetedax[] = "Saves the specific type of data in a tEDAx file.";
 static fgw_error_t pcb_act_Savetedax(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
@@ -119,6 +125,11 @@ static fgw_error_t pcb_act_Savetedax(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		return 0;
 	}
 
+	if (rnd_strcasecmp(type, "route_req") == 0) {
+		RND_ACT_IRES(tedax_route_req_save(PCB, fname, argc-3, argv+3));
+		return 0;
+	}
+
 	RND_ACT_FAIL(Savetedax);
 	RND_ACT_IRES(1);
 	return 0;
@@ -140,7 +151,7 @@ do { \
 	} \
 } while(0)
 
-static const char pcb_acts_LoadtedaxFrom[] = "LoadTedaxFrom(netlist|board|footprint|stackup|layer|drc|drc_query, filename, [block_id, [silent, [src]]])";
+static const char pcb_acts_LoadtedaxFrom[] = "LoadTedaxFrom(netlist|board|footprint|stackup|layer|drc|drc_query|route_res, filename, [block_id, [silent, [src]]])";
 static const char pcb_acth_LoadtedaxFrom[] = "Loads the specified block from a tedax file.";
 static fgw_error_t pcb_act_LoadtedaxFrom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
@@ -163,6 +174,17 @@ static fgw_error_t pcb_act_LoadtedaxFrom(fgw_arg_t *res, int argc, fgw_arg_t *ar
 		RND_ACT_IRES(tedax_net_load(fname, 1, id, silent));
 		return 0;
 	}
+	if (rnd_strcasecmp(type, "route_res") == 0) {
+		gen_load(route_res, fname);
+		RND_ACT_IRES(tedax_route_res_load(fname, id, silent));
+		return 0;
+	}
+	if (rnd_strcasecmp(type, "route_conf_keys") == 0) { /* intentionally undocumented - for internal use, returns a pointer */
+		gen_load(route_conf_keys, fname);
+		res->type = FGW_PTR;
+		res->val.ptr_void = tedax_route_conf_keys_load(fname, id, silent);
+		return 0;
+	}
 	if (rnd_strcasecmp(type, "board") == 0) {
 		gen_load(board, fname);
 		RND_ACT_IRES(tedax_board_load(PCB, fname, id, silent));
@@ -170,7 +192,7 @@ static fgw_error_t pcb_act_LoadtedaxFrom(fgw_arg_t *res, int argc, fgw_arg_t *ar
 	}
 	if (rnd_strcasecmp(type, "footprint") == 0) {
 		gen_load(footprint, fname);
-		RND_ACT_IRES(tedax_fp_load(PCB_PASTEBUFFER->Data, fname, 0, id, silent));
+		RND_ACT_IRES(tedax_fp_load(PCB_PASTEBUFFER->Data, fname, 0, id, silent, 0));
 		return 0;
 	}
 	if (rnd_strcasecmp(type, "stackup") == 0) {
@@ -231,7 +253,7 @@ rnd_action_t tedax_action_list[] = {
 
 static int io_tedax_parse_footprint(pcb_plug_io_t *ctx, pcb_data_t *Ptr, const char *name, const char *subfpname)
 {
-	return tedax_fp_load(Ptr, name, 0, NULL, 0);
+	return tedax_fp_load(Ptr, name, 0, NULL, 0, 1);
 }
 
 int io_tedax_fp_write_subcs_head(pcb_plug_io_t *ctx, void **udata, FILE *f, int lib, long num_subcs)
@@ -277,7 +299,7 @@ int io_tedax_parse_pcb(pcb_plug_io_t *ctx, pcb_board_t *Ptr, const char *Filenam
 
 	Ptr->is_footprint = 1;
 
-	res = tedax_fp_load(Ptr->Data, Filename, 0, NULL, 0);
+	res = tedax_fp_load(Ptr->Data, Filename, 0, NULL, 0, 0);
 	if (res == 0) {
 		pcb_subc_t *sc = Ptr->Data->subc.lst.first;
 
@@ -298,6 +320,7 @@ void pplg_uninit_io_tedax(void)
 	tedax_etest_uninit();
 	RND_HOOK_UNREGISTER(pcb_plug_io_t, pcb_plug_io_chain, &io_tedax);
 	pcb_tedax_net_uninit();
+	rnd_hid_menu_unload(rnd_gui, tedax_cookie);
 }
 
 int pplg_init_io_tedax(void)
@@ -330,6 +353,6 @@ int pplg_init_io_tedax(void)
 
 	RND_REGISTER_ACTIONS(tedax_action_list, tedax_cookie)
 	pcb_tedax_net_init();
-
+	rnd_hid_menu_load(rnd_gui, NULL, tedax_cookie, 195, NULL, 0, tedax_menu, "plugin: io_tedax");
 	return 0;
 }
