@@ -147,8 +147,6 @@ int tedax_etest_fsave(pcb_board_t *pcb, const char *etestid, FILE *f)
 			continue;
 		tedax_etest_fsave_pstk(f, ps, t->parent.net->name, sc->refdes, ps->term);
 	}
-	rnd_r_end(&it);
-
 
 	fprintf(f, "end etest\n");
 	return 0;
@@ -237,7 +235,7 @@ static int tedax_etest_usage(rnd_hid_t *hid, const char *topic)
 static const char *tedax_etest_cookie = "tEDAx etest";
 static int tedax_etest_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
 {
-	rnd_export_register_opts(tedax_etest_options, sizeof(tedax_etest_options) / sizeof(tedax_etest_options[0]), tedax_etest_cookie, 0);
+	rnd_export_register_opts2(hid, tedax_etest_options, sizeof(tedax_etest_options) / sizeof(tedax_etest_options[0]), tedax_etest_cookie, 0);
 	return rnd_hid_parse_command_line(argc, argv);
 }
 
@@ -246,6 +244,7 @@ static rnd_hid_t exp_tedax_etest;
 void tedax_etest_uninit(void)
 {
 	rnd_export_remove_opts_by_cookie(tedax_etest_cookie);
+	rnd_hid_remove_hid(&exp_tedax_etest);
 }
 
 void tedax_etest_init(void)
