@@ -33,25 +33,15 @@ typedef struct{
 	int active; /* already open - allow only one instance */
 	int curr;
 	int wname, wlineth, wclr, wtxtscale, wtxtth, wviahole, wviaring, wattr;
+
+	rnd_hidval_t name_timer;
+
+	char name[PCB_RST_NAME_LEN];
+	unsigned name_pending:1;
 } rstdlg_ctx_t;
 
 rstdlg_ctx_t rstdlg_ctx;
 
-static void rstdlg_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
-{
-	rstdlg_ctx_t *ctx = caller_data;
-
-	{ /* can be safely removed when route style switches over to padstacks */
-		pcb_route_style_t *rst = vtroutestyle_get(&PCB->RouteStyle, ctx->curr, 0);
-		if (rst->Diameter <= rst->Hole) {
-			rnd_message(RND_MSG_ERROR, "had to increase the via ring diameter - can not be smaller than the hole");
-			rst->Diameter = rst->Hole+RND_MIL_TO_COORD(1);
-		}
-	}
-
-	RND_DAD_FREE(ctx->dlg);
-	memset(ctx, 0, sizeof(rstdlg_ctx_t)); /* reset all states to the initial - includes ctx->active = 0; */
-}
 
 static void rstdlg_pcb2dlg(int rst_idx)
 {
@@ -60,7 +50,7 @@ static void rstdlg_pcb2dlg(int rst_idx)
 	pcb_route_style_t *rst;
 	rnd_hid_attribute_t *attr;
 	rnd_hid_tree_t *tree;
-	rnd_attribute_t *a;
+	pcb_attribute_t *a;
 
 	if (!rstdlg_ctx.active)
 		return;
@@ -71,6 +61,13 @@ static void rstdlg_pcb2dlg(int rst_idx)
 	if (rst_idx < 0)
 		rst_idx = rstdlg_ctx.curr;
 
+	if ((rst_idx < 0) || (rst_idx >= vtroutestyle_len(&PCB->RouteStyle))) {
+		hv.str = "<invalid>";
+		rnd_gui->attr_dlg_set_value(rstdlg_ctx.dlg_hid_ctx, rstdlg_ctx.wname, &hv);
+		return;
+	}
+
+
 	rst = vtroutestyle_get(&PCB->RouteStyle, rst_idx, 0);
 
 	hv.str = rst->name;
@@ -82,7 +79,7 @@ static void rstdlg_pcb2dlg(int rst_idx)
 	hv.crd = rst->textt;
 	rnd_gui->attr_dlg_set_value(rstdlg_ctx.dlg_hid_ctx, rstdlg_ctx.wtxtth, &hv);
 
-	hv.crd = rst->texts;
+	hv.lng = rst->texts;
 	rnd_gui->attr_dlg_set_value(rstdlg_ctx.dlg_hid_ctx, rstdlg_ctx.wtxtscale, &hv);
 
 	hv.crd = rst->Clearance;
@@ -111,7 +108,34 @@ static void rst_updated(pcb_route_style_t *rst)
 	if (rst != NULL)
 		pcb_use_route_style(rst);
 	rnd_event(&PCB->hidlib, PCB_EVENT_ROUTE_STYLES_CHANGED, NULL);
-	pcb_board_set_changed_flag(1);
+	pcb_board_set_changed_flag(PCB, 1);
+}
+
+/* if the change is silent, do not use the new route style */
+static void name_chg_cb_silent(int silent)
+{
+	if (rstdlg_ctx.name_pending) {
+		pcb_route_style_t *rst = vtroutestyle_get(&PCB->RouteStyle, rstdlg_ctx.curr, 0);
+		pcb_route_style_change_name(PCB, rstdlg_ctx.curr, rstdlg_ctx.name, 1);
+		rstdlg_ctx.name_pending = 0;
+		rst_updated(silent ? NULL : rst);
+	}
+}
+
+/* delayed name change */
+static void name_chg_cb(rnd_hidval_t data)
+{
+	name_chg_cb_silent(0);
+}
+
+/* call this if idx changes */
+static void idx_changed(void)
+{
+	if (rstdlg_ctx.name_pending) { /* make sure pending name update is executed on the old style */
+		if (rnd_gui->stop_timer != NULL)
+			rnd_gui->stop_timer(rnd_gui, rstdlg_ctx.name_timer);
+		name_chg_cb_silent(1);
+	}
 }
 
 static void rst_change_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
@@ -125,21 +149,32 @@ static void rst_change_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t
 		return;
 	}
 
-TODO("This change is not undoable");
-
 	if (idx == rstdlg_ctx.wname) {
 		const char *s = attr->val.str;
 		while(isspace(*s)) s++;
-		strncpy(rst->name, s, sizeof(rst->name));
+		strncpy(rstdlg_ctx.name, s, sizeof(rst->name));
+
+		/* If we already have a timer going, then cancel it out */
+		if (rstdlg_ctx.name_pending && (rnd_gui->stop_timer != NULL))
+			rnd_gui->stop_timer(rnd_gui, rstdlg_ctx.name_timer);
+
+		/* Start up a new timer */
+		rstdlg_ctx.name_pending = 1;
+		if (rnd_gui->add_timer != NULL)
+			rstdlg_ctx.name_timer = rnd_gui->add_timer(rnd_gui, name_chg_cb, 1000 * 2, rstdlg_ctx.name_timer);
+		else
+			name_chg_cb(rstdlg_ctx.name_timer);
 	}
 	else if (idx == rstdlg_ctx.wlineth)
-		rst->Thick = attr->val.crd;
+		pcb_route_style_change(PCB, rstdlg_ctx.curr, &attr->val.crd, NULL, NULL, NULL, NULL, 1);
 	else if (idx == rstdlg_ctx.wtxtth)
-		rst->textt = attr->val.crd;
-	else if (idx == rstdlg_ctx.wtxtscale)
-		rst->texts = attr->val.crd;
+		pcb_route_style_change(PCB, rstdlg_ctx.curr, NULL, &attr->val.crd, NULL, NULL, NULL, 1);
+	else if (idx == rstdlg_ctx.wtxtscale) {
+		int tmp = attr->val.lng;
+		pcb_route_style_change(PCB, rstdlg_ctx.curr, NULL, NULL, &tmp, NULL, NULL, 1);
+	}
 	else if (idx == rstdlg_ctx.wclr)
-		rst->Clearance = attr->val.crd;
+		pcb_route_style_change(PCB, rstdlg_ctx.curr, NULL, NULL, NULL, &attr->val.crd, NULL, 1);
 	else if (idx == rstdlg_ctx.wviahole) {
 		rst->Hole = attr->val.crd;
 		if (rst->Hole * 1.1 >= rstdlg_ctx.dlg[rstdlg_ctx.wviaring].val.crd) {
@@ -147,6 +182,7 @@ TODO("This change is not undoable");
 			rnd_gui->attr_dlg_set_value(rstdlg_ctx.dlg_hid_ctx, rstdlg_ctx.wviaring, &hv);
 			rst->Diameter = hv.crd;
 		}
+		rst_updated(rst);
 	}
 	else if (idx == rstdlg_ctx.wviaring) {
 		rst->Diameter = attr->val.crd;
@@ -155,14 +191,12 @@ TODO("This change is not undoable");
 			rnd_gui->attr_dlg_set_value(rstdlg_ctx.dlg_hid_ctx, rstdlg_ctx.wviahole, &hv);
 			rst->Hole = hv.crd;
 		}
-
+		rst_updated(rst);
 	}
 	else {
 		rnd_message(RND_MSG_ERROR, "Internal error: route style field does not exist");
 		return;
 	}
-
-	rst_updated(rst);
 }
 
 static int rst_edit_attr(char **key, char **val)
@@ -203,7 +237,7 @@ static void rst_add_attr_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 	char *key = NULL, *val = NULL;
 
 	if (rst_edit_attr(&key, &val) == 0) {
-		rnd_attribute_put(&rst->attr, key, val);
+		pcb_attribute_put(&rst->attr, key, val);
 		rst_updated(rst);
 	}
 }
@@ -222,8 +256,8 @@ static void rst_edit_attr_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 	val = row->cell[1];
 
 	if (rst_edit_attr(&key, &val) == 0) {
-		rnd_attribute_remove(&rst->attr, row->cell[0]);
-		rnd_attribute_put(&rst->attr, key, val);
+		pcb_attribute_remove(&rst->attr, row->cell[0]);
+		pcb_attribute_put(&rst->attr, key, val);
 		rst_updated(rst);
 	}
 }
@@ -237,10 +271,27 @@ static void rst_del_attr_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 	if (row == NULL)
 		return;
 
-	rnd_attribute_remove(&rst->attr, row->cell[0]);
+	pcb_attribute_remove(&rst->attr, row->cell[0]);
 	rst_updated(rst);
 }
 
+static void rstdlg_close_cb(void *caller_data, rnd_hid_attr_ev_t ev)
+{
+	rstdlg_ctx_t *ctx = caller_data;
+
+	idx_changed(); /* flush pending timed changes */
+
+	{ /* can be safely removed when route style switches over to padstacks */
+		pcb_route_style_t *rst = vtroutestyle_get(&PCB->RouteStyle, ctx->curr, 0);
+		if (rst->Diameter <= rst->Hole) {
+			rnd_message(RND_MSG_ERROR, "had to increase the via ring diameter - can not be smaller than the hole");
+			rst->Diameter = rst->Hole+RND_MIL_TO_COORD(1);
+		}
+	}
+
+	RND_DAD_FREE(ctx->dlg);
+	memset(ctx, 0, sizeof(rstdlg_ctx_t)); /* reset all states to the initial - includes ctx->active = 0; */
+}
 
 static int pcb_dlg_rstdlg(int rst_idx)
 {
@@ -248,6 +299,7 @@ static int pcb_dlg_rstdlg(int rst_idx)
 	static const char *attr_hdr[] = {"attribute key", "attribute value", NULL};
 
 	if (rstdlg_ctx.active) { /* do not open another, just refresh data to target */
+		idx_changed();
 		rstdlg_pcb2dlg(rst_idx);
 		return 0;
 	}
@@ -263,42 +315,42 @@ static int pcb_dlg_rstdlg(int rst_idx)
 				RND_DAD_CHANGE_CB(rstdlg_ctx.dlg, rst_change_cb);
 
 			RND_DAD_LABEL(rstdlg_ctx.dlg, "Line thick.:");
-			RND_DAD_COORD(rstdlg_ctx.dlg, "");
+			RND_DAD_COORD(rstdlg_ctx.dlg);
 				rstdlg_ctx.wlineth = RND_DAD_CURRENT(rstdlg_ctx.dlg);
 				RND_DAD_HELP(rstdlg_ctx.dlg, "Thickness of line/arc objects");
 				RND_DAD_MINMAX(rstdlg_ctx.dlg, 1, RND_MAX_COORD);
 				RND_DAD_CHANGE_CB(rstdlg_ctx.dlg, rst_change_cb);
 
 			RND_DAD_LABEL(rstdlg_ctx.dlg, "Text scale:");
-			RND_DAD_COORD(rstdlg_ctx.dlg, "");
+			RND_DAD_INTEGER(rstdlg_ctx.dlg);
 				rstdlg_ctx.wtxtscale = RND_DAD_CURRENT(rstdlg_ctx.dlg);
 				RND_DAD_HELP(rstdlg_ctx.dlg, "Text size scale in %; 100 means normal size");
-				RND_DAD_MINMAX(rstdlg_ctx.dlg, 1, RND_MAX_COORD);
+				RND_DAD_MINMAX(rstdlg_ctx.dlg, 1, 100000);
 				RND_DAD_CHANGE_CB(rstdlg_ctx.dlg, rst_change_cb);
 
 			RND_DAD_LABEL(rstdlg_ctx.dlg, "Clearance:");
-			RND_DAD_COORD(rstdlg_ctx.dlg, "");
+			RND_DAD_COORD(rstdlg_ctx.dlg);
 				rstdlg_ctx.wclr = RND_DAD_CURRENT(rstdlg_ctx.dlg);
 				RND_DAD_HELP(rstdlg_ctx.dlg, "Object clearance: any object placed with this style\nwill clear this much from sorrunding clearing-enabled polygons\n(unless the object is joined to the polygon)");
 				RND_DAD_MINMAX(rstdlg_ctx.dlg, 1, RND_MAX_COORD);
 				RND_DAD_CHANGE_CB(rstdlg_ctx.dlg, rst_change_cb);
 
 			RND_DAD_LABEL(rstdlg_ctx.dlg, "Text thick.:");
-			RND_DAD_COORD(rstdlg_ctx.dlg, "");
+			RND_DAD_COORD(rstdlg_ctx.dlg);
 				rstdlg_ctx.wtxtth = RND_DAD_CURRENT(rstdlg_ctx.dlg);
 				RND_DAD_HELP(rstdlg_ctx.dlg, "Text stroke thickness;\nif 0 use the default heuristics that\ncalculates it from text scale");
 				RND_DAD_MINMAX(rstdlg_ctx.dlg, 1, RND_MAX_COORD);
 				RND_DAD_CHANGE_CB(rstdlg_ctx.dlg, rst_change_cb);
 
 			RND_DAD_LABEL(rstdlg_ctx.dlg, "*Via hole:");
-			RND_DAD_COORD(rstdlg_ctx.dlg, "");
+			RND_DAD_COORD(rstdlg_ctx.dlg);
 				rstdlg_ctx.wviahole = RND_DAD_CURRENT(rstdlg_ctx.dlg);
 				RND_DAD_HELP(rstdlg_ctx.dlg, "Via hole diameter\nwarning: will be replaced with the padstack selector");
 				RND_DAD_MINMAX(rstdlg_ctx.dlg, 1, RND_MAX_COORD);
 				RND_DAD_CHANGE_CB(rstdlg_ctx.dlg, rst_change_cb);
 
 			RND_DAD_LABEL(rstdlg_ctx.dlg, "*Via ring:");
-			RND_DAD_COORD(rstdlg_ctx.dlg, "");
+			RND_DAD_COORD(rstdlg_ctx.dlg);
 				rstdlg_ctx.wviaring = RND_DAD_CURRENT(rstdlg_ctx.dlg);
 				RND_DAD_HELP(rstdlg_ctx.dlg, "Via ring diameter\nwarning: will be replaced with the padstack selector");
 				RND_DAD_MINMAX(rstdlg_ctx.dlg, 1, RND_MAX_COORD);
