@@ -91,10 +91,11 @@ static void build_st_line1(void)
 static void build_st_line2(void)
 {
 	rnd_append_printf(&status.buf,
-		"via=%mS (%mS)  "
+		"%svia=%mS (%mS)  "
 		"clr=%mS  "
 		"text=%d%% %$mS "
 		"buff=#%d",
+		conf_core.appearance.compact ? "" : " ", /* "line" separator for single-line print */
 		conf_core.design.via_thickness, conf_core.design.via_drilling_hole,
 		conf_core.design.clearance,
 		conf_core.design.text_scale,
@@ -498,7 +499,7 @@ fgw_error_t pcb_act_DescribeLocation(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	gds_append_str(&desc, "Subc. refdes:\t"); gds_append_str(&desc, subc->refdes == NULL ? "--" : subc->refdes);
 	gds_append_str(&desc, "\nTerminal:  \t"); gds_append_str(&desc, obj->term == NULL ? "--" : obj->term);
 	if (obj->term != NULL) { /* print terminal name if not empty and not the same as term */
-		const char *name = rnd_attribute_get(&obj->Attributes, "name");
+		const char *name = pcb_attribute_get(&obj->Attributes, "name");
 		if ((name != NULL) && (strcmp(name, obj->term) != 0)) {
 			gds_append_str(&desc, " (");
 			gds_append_str(&desc, name);
