@@ -48,7 +48,7 @@ void pcb_placement_build(pcb_placement_t *ctx, pcb_data_t *data)
 		if (!htscp_has(&ctx->subcs, subc)) {
 			pcb_host_trans_t tr;
 			pcb_data_t *oldhack;
-			pcb_subc_t *proto = pcb_subc_dup_at(ctx->pcb, &ctx->data, subc, 0, 0, 0); /* do not keep IDs because that fools pstk parent logic */
+			pcb_subc_t *proto = pcb_subc_dup_at(ctx->pcb, &ctx->data, subc, 0, 0, 0, rnd_true); /* do not keep IDs because that fools pstk parent logic */
 			pcb_subc_get_host_trans(subc, &tr, 1);
 
 			oldhack = pcb_pstk_data_hack;
@@ -56,12 +56,12 @@ void pcb_placement_build(pcb_placement_t *ctx, pcb_data_t *data)
 
 			pcb_subc_move(proto, tr.ox, tr.oy, 1);
 			if (tr.rot != 0) {
-				double rr = tr.rot / PCB_RAD_TO_DEG;
+				double rr = tr.rot / RND_RAD_TO_DEG;
 				pcb_subc_rotate(proto, 0, 0, cos(rr), sin(rr), tr.rot);
 			}
 			if (tr.on_bottom) {
 				int n;
-				pcb_data_mirror(proto->data, 0, PCB_TXM_SIDE, 1);
+				pcb_data_mirror(proto->data, 0, PCB_TXM_SIDE, 1, 0);
 				for(n = 0; n < proto->data->LayerN; n++) {
 					pcb_layer_t *ly = proto->data->Layer + n;
 					ly->meta.bound.type = pcb_layer_mirror_type(ly->meta.bound.type);
