@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2017 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2017,2020 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,6 +38,8 @@
 #include "obj_line.h"
 #include "obj_poly.h"
 #include "obj_poly_draw.h"
+#include "obj_pstk_inlines.h"
+#include "find.h"
 #include "polygon.h"
 #include "search.h"
 #include <librnd/core/hid.h>
@@ -169,14 +171,10 @@ static pcb_any_obj_t *next_conn(vtp0_t *list, vti0_t *endlist, pcb_any_obj_t *cu
 	return NULL; /* nothing found */
 }
 
-static int map_contour(pcb_data_t *data, vtp0_t *list, vti0_t *endlist, pcb_any_obj_t *start)
+static int map_contour_with(pcb_data_t *data, vtp0_t *list, vti0_t *endlist, pcb_any_obj_t *start, pcb_dynf_t df)
 {
 	long i;
 	pcb_any_obj_t *n;
-	pcb_dynf_t df;
-
-	df = pcb_dynflag_alloc("topoly_map_contour");
-	pcb_data_dynflag_clear(data, df);
 
 /*rnd_trace("loop start: %d\n", start->ID);*/
 	vtp0_append(list, start);
@@ -190,10 +188,22 @@ static int map_contour(pcb_data_t *data, vtp0_t *list, vti0_t *endlist, pcb_any_
 			PCB_DFLAG_CLR(&start->Flags, df); /* allow finding the start object again for proper closing */
 	}
 
-	pcb_dynflag_free(df);
 	return 0;
 }
 
+static int map_contour(pcb_data_t *data, vtp0_t *list, vti0_t *endlist, pcb_any_obj_t *start)
+{
+	int res;
+	pcb_dynf_t df;
+	df = pcb_dynflag_alloc("topoly_map_contour");
+	pcb_data_dynflag_clear(data, df);
+
+	res = map_contour_with(data, list, endlist, start, df);
+
+	pcb_dynflag_free(df);
+	return res;
+}
+
 static int contour2poly_cb(void *uctx, rnd_coord_t x, rnd_coord_t y)
 {
 	pcb_poly_t *poly = uctx;
@@ -238,14 +248,13 @@ pcb_poly_t *contour2poly(pcb_board_t *pcb, vtp0_t *objs, vti0_t *ends, pcb_topol
 		pcb_add_poly_on_layer(layer, poly);
 		pcb_poly_init_clip(pcb->Data, layer, poly);
 		pcb_poly_invalidate_draw(layer, poly);
-TODO(": use pcb_board_set_changed_flag(), but decouple that from PCB")
-		pcb->Changed = rnd_true;
+		pcb_board_set_changed_flag(pcb, rnd_true);
 	}
 
 	return poly;
 }
 
-pcb_poly_t *pcb_topoly_conn(pcb_board_t *pcb, pcb_any_obj_t *start, pcb_topoly_t how)
+pcb_poly_t *pcb_topoly_conn_with(pcb_board_t *pcb, pcb_any_obj_t *start, pcb_topoly_t how, pcb_dynf_t df)
 {
 	vtp0_t objs;
 	vti0_t ends;
@@ -259,7 +268,10 @@ pcb_poly_t *pcb_topoly_conn(pcb_board_t *pcb, pcb_any_obj_t *start, pcb_topoly_t
 
 	vtp0_init(&objs);
 	vti0_init(&ends);
-	res = map_contour(pcb->Data, &objs, &ends, start);
+	if (df < 0)
+		res = map_contour(pcb->Data, &objs, &ends, start);
+	else
+		res = map_contour_with(pcb->Data, &objs, &ends, start, df);
 	if (res != 0) {
 		rnd_message(RND_MSG_ERROR, "pcb_topoly_conn(): failed to find a closed loop of lines and arcs\n");
 		vtp0_uninit(&objs);
@@ -274,6 +286,62 @@ pcb_poly_t *pcb_topoly_conn(pcb_board_t *pcb, pcb_any_obj_t *start, pcb_topoly_t
 	return poly;
 }
 
+pcb_poly_t *pcb_topoly_conn(pcb_board_t *pcb, pcb_any_obj_t *start, pcb_topoly_t how)
+{
+	return pcb_topoly_conn_with(pcb, start, how, -1);
+}
+
+typedef struct {
+	pcb_board_t *pcb;
+	pcb_poly_t *poly;
+	pcb_dynf_t df;
+	vtp0_t pstks;  /* a list of (pcb_pstk_t *) of padstacks having mech shape crossing the poly border */
+
+	/* temporary, per pline callback fields */
+	pcb_pstk_t *ps;
+	pcb_pstk_shape_t *shape;
+} pstk_on_outline_t;
+
+/* rtree callback on pline segment crossing padstack bbox */
+static rnd_r_dir_t pcb_topoly_check_pstk_on_pline_cb(const rnd_box_t *box, void *cl)
+{
+	pstk_on_outline_t *ctx = cl;
+	pcb_find_t fctx = {0};
+	pcb_line_t line = {0};
+	rnd_vnode_t *vn = rnd_pline_seg2vnode((void *)box);
+
+	line.Point1.X = vn->point[0]; line.Point1.Y = vn->point[1];
+	line.Point2.X = vn->next->point[0]; line.Point2.Y = vn->next->point[1];
+	if (pcb_isc_pstk_line_shp(&fctx, ctx->ps, &line, ctx->shape)) {
+		if (ctx->df != -1)
+			PCB_DFLAG_SET(&ctx->ps->Flags, ctx->df);
+		vtp0_append(&ctx->pstks, ctx->ps);
+	}
+
+	return RND_R_DIR_NOT_FOUND;
+}
+
+/* rtree callback on generated polygon overlapping padstack */
+static rnd_r_dir_t pcb_topoly_check_pstk_on_outline_cb(const rnd_box_t *box, void *cl)
+{
+	pstk_on_outline_t *ctx = cl;
+	pcb_pstk_t *ps = (pcb_pstk_t *)box;
+	pcb_pstk_shape_t holetmp;
+	pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
+	pcb_pstk_shape_t *shape = pcb_pstk_shape_mech_or_hole_(ps, proto, &holetmp);
+
+	if (shape == NULL)
+		return RND_R_DIR_NOT_FOUND;
+
+	ctx->ps = ps;
+	ctx->shape = shape;
+	rnd_r_search(ctx->poly->Clipped->contours->tree, &ps->bbox_naked, NULL, pcb_topoly_check_pstk_on_pline_cb, ctx, NULL);
+	ctx->ps = NULL;
+	ctx->shape = NULL;
+
+	return RND_R_DIR_NOT_FOUND;
+}
+
 #define check(x, y, obj) \
 do { \
 	double dist = (double)x*(double)x + (double)y*(double)y; \
@@ -317,10 +385,13 @@ pcb_any_obj_t *pcb_topoly_find_1st_outline(pcb_board_t *pcb)
 }
 #undef check
 
-pcb_poly_t *pcb_topoly_1st_outline(pcb_board_t *pcb, pcb_topoly_t how)
+pcb_poly_t *pcb_topoly_1st_outline_with(pcb_board_t *pcb, pcb_topoly_t how, pcb_dynf_t df)
 {
 	pcb_poly_t *poly;
 	pcb_any_obj_t *start = pcb_topoly_find_1st_outline(pcb);
+	pstk_on_outline_t pctx;
+	int need_full;
+	long n;
 
 	if (start == NULL) {
 		poly = pcb_poly_alloc(pcb->Data->Layer);
@@ -330,11 +401,47 @@ pcb_poly_t *pcb_topoly_1st_outline(pcb_board_t *pcb, pcb_topoly_t how)
 		pcb_poly_point_new(poly, 0, pcb->hidlib.size_y);
 	}
 	else
-		poly = pcb_topoly_conn(pcb, start, how);
+		poly = pcb_topoly_conn_with(pcb, start, how, df);
 
+	if (poly == NULL)
+		return NULL;
+
+	pcb_poly_bbox(poly);
+	poly->Clipped = pcb_poly_to_polyarea(poly, &need_full);
+
+	if (need_full)
+		rnd_message(RND_MSG_ERROR, "pcb_topoly_1st_outline_with: internal error: need full poly\nPlease report this bug with an example file!\n");
+
+	/* padstacks crossing polygon boundary need to be subtracted from the poly as
+	   they modify the contour */
+	pctx.pcb = pcb;
+	pctx.poly = poly;
+	pctx.df = df;
+	vtp0_init(&pctx.pstks);
+
+	/* map: first search (and mark) all offending padstacks */
+	rnd_r_search(pcb->Data->padstack_tree, &poly->bbox_naked, NULL, pcb_topoly_check_pstk_on_outline_cb, &pctx, NULL);
+
+	/* apply: subtract all padstacks found while mapping */
+	for(n = 0; n < pctx.pstks.used; n++) {
+		pcb_pstk_t *ps = pctx.pstks.array[n];
+		pcb_pstk_shape_t holetmp;
+		pcb_pstk_proto_t *proto = pcb_pstk_get_proto(ps);
+		pcb_pstk_shape_t *shape = pcb_pstk_shape_mech_or_hole_(ps, proto, &holetmp);
+		rnd_polyarea_t *mpa = pcb_pstk_shape2polyarea(ps, shape);
+		if (mpa != NULL)
+			pcb_poly_subtract(mpa, poly, 1);
+	}
+
+	vtp0_uninit(&pctx.pstks);
 	return poly;
 }
 
+pcb_poly_t *pcb_topoly_1st_outline(pcb_board_t *pcb, pcb_topoly_t how)
+{
+	return pcb_topoly_1st_outline_with(pcb, how, -1);
+}
+
 const char pcb_acts_topoly[] = "ToPoly()\nToPoly(outline)\n";
 const char pcb_acth_topoly[] = "convert a closed loop of lines and arcs into a polygon";
 fgw_error_t pcb_act_topoly(fgw_arg_t *res, int argc, fgw_arg_t *argv)
