@@ -28,13 +28,13 @@
 #define PCB_ORDER_H
 
 #include <genvector/vtp0.h>
-#include "hid_dad.h"
+#include <librnd/core/hid_dad.h>
 #include "../src_plugins/order/order_conf.h"
 
 extern conf_order_t conf_order;
 
 typedef struct{
-	PCB_DAD_DECL_NOINIT(dlg)
+	RND_DAD_DECL_NOINIT(dlg)
 	int active; /* already open - allow only one instance */
 	vtp0_t names;
 	void *odata;                                   /* implementation-specific data of the current order */
@@ -63,8 +63,8 @@ typedef enum pcb_order_autoload_e {
 } pcb_order_autoload_t;
 
 typedef struct pcb_order_field_s {
-	pcb_hid_attr_type_t type;
-	pcb_hid_attr_val_t val;
+	rnd_hid_attr_type_t type;
+	rnd_hid_attr_val_t val;
 	char **enum_vals;
 	char *help;
 	pcb_order_autoload_t autoload;
