@@ -16,33 +16,32 @@
 #include "config.h"
 #include "board.h"
 #include "data.h"
-#include "macro.h"
 #include "remove.h"
-#include "hid.h"
-#include "error.h"
-#include "rtree.h"
+#include <librnd/core/hid.h>
+#include <librnd/core/error.h>
+#include <librnd/poly/rtree.h>
 #include "polygon.h"
-#include "polyarea.h"
+#include <librnd/poly/polyarea.h>
 #include "assert.h"
 #include "flag_str.h"
 #include "find.h"
 #include "draw.h"
 #include "undo.h"
-#include "plugins.h"
-#include "actions.h"
+#include <librnd/core/plugins.h>
+#include <librnd/core/actions.h>
 #include "obj_poly.h"
 
-static pcb_polyarea_t *original_poly(pcb_poly_t *p, pcb_bool *forward)
+static rnd_polyarea_t *original_poly(pcb_poly_t *p, rnd_bool *forward)
 {
-	pcb_pline_t *contour = NULL;
-	pcb_polyarea_t *np = NULL;
-	pcb_cardinal_t n;
-	pcb_vector_t v;
+	rnd_pline_t *contour = NULL;
+	rnd_polyarea_t *np = NULL;
+	rnd_cardinal_t n;
+	rnd_vector_t v;
 	int hole = 0;
 
-	*forward = pcb_true;
+	*forward = rnd_true;
 
-	if ((np = pcb_polyarea_create()) == NULL)
+	if ((np = rnd_polyarea_create()) == NULL)
 		return NULL;
 
 	/* first make initial polygon contour */
@@ -53,29 +52,29 @@ static pcb_polyarea_t *original_poly(pcb_poly_t *p, pcb_bool *forward)
 		v[0] = p->Points[n].X;
 		v[1] = p->Points[n].Y;
 		if (contour == NULL) {
-			if ((contour = pcb_poly_contour_new(v)) == NULL)
+			if ((contour = rnd_poly_contour_new(v)) == NULL)
 				return NULL;
 		}
 		else {
-			pcb_poly_vertex_include(contour->head->prev, pcb_poly_node_create(v));
+			rnd_poly_vertex_include(contour->head->prev, rnd_poly_node_create(v));
 		}
 
 		/* Is current point last in contour? If so process it. */
 		if (n == p->PointN - 1 || (hole < p->HoleIndexN && n == p->HoleIndex[hole] - 1)) {
-			pcb_poly_contour_pre(contour, pcb_true);
+			rnd_poly_contour_pre(contour, rnd_true);
 
 			/* Log the direction in which the outer contour was specified */
 			if (hole == 0)
-				*forward = (contour->Flags.orient == PCB_PLF_DIR);
+				*forward = (contour->Flags.orient == RND_PLF_DIR);
 
 			/* make sure it is a positive contour (outer) or negative (hole) */
-			if (contour->Flags.orient != (hole ? PCB_PLF_INV : PCB_PLF_DIR))
-				pcb_poly_contour_inv(contour);
-			assert(contour->Flags.orient == (hole ? PCB_PLF_INV : PCB_PLF_DIR));
+			if (contour->Flags.orient != (hole ? RND_PLF_INV : RND_PLF_DIR))
+				rnd_poly_contour_inv(contour);
+			assert(contour->Flags.orient == (hole ? RND_PLF_INV : RND_PLF_DIR));
 
-			pcb_polyarea_contour_include(np, contour);
+			rnd_polyarea_contour_include(np, contour);
 			contour = NULL;
-			assert(pcb_poly_valid(np));
+			assert(rnd_poly_valid(np));
 
 			hole++;
 		}
@@ -87,8 +86,8 @@ typedef struct poly_tree poly_tree;
 
 struct poly_tree {
 	pcb_poly_t *polygon;
-	pcb_bool forward;
-	pcb_polyarea_t *polyarea;
+	rnd_bool forward;
+	rnd_polyarea_t *polyarea;
 	poly_tree *parent;
 	poly_tree *child;
 	poly_tree *prev;
@@ -119,15 +118,15 @@ struct poly_tree {
  * contours can be assumed not to overlap, we can drill down in this
  * order: P1, P2, P3, P4, P5, P6.
  */
-static pcb_bool PolygonContainsPolygon(pcb_polyarea_t *outer, pcb_polyarea_t *inner)
+static rnd_bool PolygonContainsPolygon(rnd_polyarea_t *outer, rnd_polyarea_t *inner)
 {
 /*  int contours_isect;*/
 	/* Should check outer contours don't intersect? */
-/*  contours_isect = pcb_polyarea_touching(outer, inner);*/
+/*  contours_isect = rnd_polyarea_touching(outer, inner);*/
 	/* Cheat and assume simple single contour polygons for now */
 /*  return contours_isect ?
-           0 : pcb_poly_contour_in_contour(outer->contours, inner->contours);*/
-	return pcb_poly_contour_in_contour(outer->contours, inner->contours);
+           0 : rnd_poly_contour_in_contour(outer->contours, inner->contours);*/
+	return rnd_poly_contour_in_contour(outer->contours, inner->contours);
 }
 
 
@@ -135,9 +134,9 @@ static poly_tree *insert_node_recursive(poly_tree * start_point, poly_tree * to_
 {
 	poly_tree *cur_node, *next = NULL;
 /*  bool to_insert_isects_cur_node;    Intersection */
-	pcb_bool to_insert_contains_cur_node;	/* Containment */
-	pcb_bool cur_node_contains_to_insert;	/* Containment */
-	pcb_bool placed_to_insert = pcb_false;
+	rnd_bool to_insert_contains_cur_node;	/* Containment */
+	rnd_bool cur_node_contains_to_insert;	/* Containment */
+	rnd_bool placed_to_insert = rnd_false;
 
 	poly_tree *return_root = start_point;
 
@@ -180,7 +179,7 @@ static poly_tree *insert_node_recursive(poly_tree * start_point, poly_tree * to_
 					to_insert->prev->next = to_insert;
 				if (to_insert->next)
 					to_insert->next->prev = to_insert;
-				placed_to_insert = pcb_true;
+				placed_to_insert = rnd_true;
 
 				if (cur_node == start_point)
 					return_root = to_insert;
@@ -241,14 +240,14 @@ static poly_tree *insert_node_recursive(poly_tree * start_point, poly_tree * to_
 	return to_insert;
 }
 
-static pcb_polyarea_t *compute_polygon_recursive(poly_tree * root, pcb_polyarea_t * accumulate)
+static rnd_polyarea_t *compute_polygon_recursive(poly_tree * root, rnd_polyarea_t * accumulate)
 {
-	pcb_polyarea_t *res;
+	rnd_polyarea_t *res;
 	poly_tree *cur_node;
 	for (cur_node = root; cur_node != NULL; cur_node = cur_node->next) {
 		/* Process this element */
 /*      printf ("Processing node %ld %s\n", cur_node->polygon->ID, cur_node->forward ? "FWD" : "BWD");*/
-		pcb_polyarea_boolean_free(accumulate, cur_node->polyarea, &res, cur_node->forward ? PCB_PBO_UNITE : PCB_PBO_SUB);
+		rnd_polyarea_boolean_free(accumulate, cur_node->polyarea, &res, cur_node->forward ? RND_PBO_UNITE : RND_PBO_SUB);
 		accumulate = res;
 
 		/* And its children if it has them */
@@ -263,13 +262,13 @@ static pcb_polyarea_t *compute_polygon_recursive(poly_tree * root, pcb_polyarea_
 /* DOC: polycombine.html */
 static fgw_error_t pcb_act_polycombine(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	pcb_polyarea_t *rs;
-	pcb_bool forward;
-	pcb_polyarea_t *np;
+	rnd_polyarea_t *rs;
+	rnd_bool forward;
+	rnd_polyarea_t *np;
 /*  bool outer;
-    pcb_polyarea_t *pa;
-    pcb_pline_t *pline;
-    pcb_vnode_t *node;
+    rnd_polyarea_t *pa;
+    rnd_pline_t *pline;
+    rnd_vnode_t *node;
     pcb_poly_t *Polygon;*/
 	pcb_layer_t *Layer = NULL;
 	poly_tree *root = NULL;
@@ -329,11 +328,11 @@ static fgw_error_t pcb_act_polycombine(fgw_arg_t *res, int argc, fgw_arg_t *argv
 	pcb_undo_inc_serial();
 	pcb_draw();
 
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
-static pcb_action_t polycombine_action_list[] = {
+static rnd_action_t polycombine_action_list[] = {
 	{"PolyCombine", pcb_act_polycombine, NULL, NULL}
 };
 
@@ -343,12 +342,12 @@ int pplg_check_ver_polycombine(int ver_needed) { return 0; }
 
 void pplg_uninit_polycombine(void)
 {
-	pcb_remove_actions_by_cookie(polycombine_cookie);
+	rnd_remove_actions_by_cookie(polycombine_cookie);
 }
 
 int pplg_init_polycombine(void)
 {
-	PCB_API_CHK_VER;
-	PCB_REGISTER_ACTIONS(polycombine_action_list, polycombine_cookie);
+	RND_API_CHK_VER;
+	RND_REGISTER_ACTIONS(polycombine_action_list, polycombine_cookie);
 	return 0;
 }
