@@ -18,20 +18,19 @@
 #include "config.h"
 #include "board.h"
 #include "data.h"
-#include "macro.h"
 #include "remove.h"
-#include "hid.h"
-#include "error.h"
-#include "rtree.h"
+#include <librnd/core/hid.h>
+#include <librnd/core/error.h>
+#include <librnd/poly/rtree.h>
 #include "draw.h"
 #include "polygon.h"
-#include "plugins.h"
-#include "actions.h"
+#include <librnd/core/plugins.h>
+#include <librnd/core/actions.h>
 #include "obj_poly.h"
 #include "obj_poly_draw.h"
 
 /* Given the X,Y, find the inmost (closest) polygon */
-static pcb_poly_t *find_crosshair_poly(pcb_coord_t x, pcb_coord_t y)
+static pcb_poly_t *find_crosshair_poly(rnd_coord_t x, rnd_coord_t y)
 {
 	double best = 0, dist;
 	pcb_poly_t *res = NULL;
@@ -42,8 +41,8 @@ static pcb_poly_t *find_crosshair_poly(pcb_coord_t x, pcb_coord_t y)
 		PCB_POLY_POINT_LOOP(polygon);
 		{
 			/* point */
-			pcb_coord_t dx = x - point->X;
-			pcb_coord_t dy = y - point->Y;
+			rnd_coord_t dx = x - point->X;
+			rnd_coord_t dy = y - point->Y;
 			dist = (double)dx * dx + (double)dy * dy;
 			if ((dist < best) || (res == NULL)) {
 				res = polygon;
@@ -55,7 +54,7 @@ static pcb_poly_t *find_crosshair_poly(pcb_coord_t x, pcb_coord_t y)
 	PCB_ENDALL_LOOP;
 
 	if (res == NULL)
-		pcb_message(PCB_MSG_ERROR, "Cannot find any polygons");
+		rnd_message(RND_MSG_ERROR, "Cannot find any polygons");
 
 	return res;
 }
@@ -77,23 +76,23 @@ static pcb_poly_t *find_enclosing_poly(pcb_poly_t *inner_poly)
 	}
 	PCB_END_LOOP;
 
-	pcb_message(PCB_MSG_ERROR, "Cannot find a polygon enclosing the one you selected");
+	rnd_message(RND_MSG_ERROR, "Cannot find a polygon enclosing the one you selected");
 	return NULL;
 }
 
 
 static fgw_error_t pcb_act_polystitch(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	pcb_coord_t x, y;
+	rnd_coord_t x, y;
 	pcb_poly_t *inner_poly, *outer_poly;
 
-	pcb_hid_get_coords("Select a corner on the inner polygon", &x, &y, 0);
+	rnd_hid_get_coords("Select a corner on the inner polygon", &x, &y, 0);
 	inner_poly = find_crosshair_poly(x, y);
 
 	if (inner_poly) {
 		outer_poly = find_enclosing_poly(inner_poly);
 		if (outer_poly) {
-			pcb_cardinal_t n, end;
+			rnd_cardinal_t n, end;
 
 			/* figure how many contour points the inner poly has (holes are going to be ignored) */
 			if (inner_poly->HoleIndexN > 0)
@@ -111,11 +110,11 @@ static fgw_error_t pcb_act_polystitch(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			pcb_poly_remove(inner_poly->parent.layer, inner_poly);
 		}
 	}
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
-static pcb_action_t polystitch_action_list[] = {
+static rnd_action_t polystitch_action_list[] = {
 	{"PolyStitch", pcb_act_polystitch, NULL, NULL}
 };
 
@@ -125,12 +124,12 @@ int pplg_check_ver_polystitch(int ver_needed) { return 0; }
 
 void pplg_uninit_polystitch(void)
 {
-	pcb_remove_actions_by_cookie(polystitch_cookie);
+	rnd_remove_actions_by_cookie(polystitch_cookie);
 }
 
 int pplg_init_polystitch(void)
 {
-	PCB_API_CHK_VER;
-	PCB_REGISTER_ACTIONS(polystitch_action_list, polystitch_cookie);
+	RND_API_CHK_VER;
+	RND_REGISTER_ACTIONS(polystitch_action_list, polystitch_cookie);
 	return 0;
 }
