@@ -27,22 +27,22 @@
 #include <stdlib.h>
 #include "board.h"
 #include "data.h"
-#include "plugins.h"
+#include <librnd/core/plugins.h>
 #include "config.h"
 #include "props.h"
 #include "propsel.h"
 #include "propdlg.h"
-#include "actions.h"
-#include "pcb-printf.h"
-#include "error.h"
+#include <librnd/core/actions.h>
+#include <librnd/core/rnd_printf.h>
+#include <librnd/core/error.h>
 #include "layer.h"
 #include "layer_addr.h"
 #include "layer_grp.h"
 #include "search.h"
 #include "crosshair.h"
-#include "compat_misc.h"
+#include <librnd/core/compat_misc.h>
 
-extern pcb_layergrp_id_t pcb_actd_EditGroup_gid;
+extern rnd_layergrp_id_t pcb_actd_EditGroup_gid;
 
 int prop_scope_add(pcb_propedit_t *pe, const char *cmd, int quiet)
 {
@@ -56,7 +56,7 @@ int prop_scope_add(pcb_propedit_t *pe, const char *cmd, int quiet)
 		pcb_objtype_t type = pcb_search_obj_by_location(PCB_OBJ_SUBC, &o1, &o2, &o3, pcb_crosshair.X, pcb_crosshair.Y, PCB_SLOP);
 		if (type == 0) {
 			if (!quiet)
-				pcb_message(PCB_MSG_ERROR, "No object under the cursor\n");
+				rnd_message(RND_MSG_ERROR, "No object under the cursor\n");
 			return FGW_ERR_ARG_CONV;
 		}
 		goto object_scope;
@@ -66,7 +66,7 @@ int prop_scope_add(pcb_propedit_t *pe, const char *cmd, int quiet)
 			idp = pcb_str2idpath(pe->pcb, cmd+7);
 			if (idp == NULL) {
 				if (!quiet)
-					pcb_message(PCB_MSG_ERROR, "Failed to convert object ID: '%s'\n", cmd+7);
+					rnd_message(RND_MSG_ERROR, "Failed to convert object ID: '%s'\n", cmd+7);
 				return FGW_ERR_ARG_CONV;
 			}
 			pcb_idpath_list_append(&pe->objs, idp);
@@ -77,17 +77,17 @@ int prop_scope_add(pcb_propedit_t *pe, const char *cmd, int quiet)
 
 			type = pcb_search_obj_by_location(PCB_OBJ_PSTK | PCB_OBJ_SUBC_PART, &o1, &o2, &o3, pcb_crosshair.X, pcb_crosshair.Y, PCB_SLOP);
 			if (type == 0)
-				type = pcb_search_obj_by_location(PCB_OBJ_CLASS_REAL, &o1, &o2, &o3, pcb_crosshair.X, pcb_crosshair.Y, PCB_SLOP);
+				type = pcb_search_obj_by_location(PCB_OBJ_CLASS_REAL | PCB_LOOSE_SUBC(pe->pcb), &o1, &o2, &o3, pcb_crosshair.X, pcb_crosshair.Y, PCB_SLOP);
 			if (type == 0) {
 				if (!quiet)
-					pcb_message(PCB_MSG_ERROR, "No object under the cursor\n");
+					rnd_message(RND_MSG_ERROR, "No object under the cursor\n");
 				return FGW_ERR_ARG_CONV;
 			}
 			object_scope:;
 			idp = pcb_obj2idpath(o2);
 			if (idp == NULL) {
 				if (!quiet)
-					pcb_message(PCB_MSG_ERROR, "Object under the cursor has no idpath\n");
+					rnd_message(RND_MSG_ERROR, "Object under the cursor has no idpath\n");
 				return FGW_ERR_ARG_CONV;
 			}
 			pcb_idpath_list_append(&pe->objs, idp);
@@ -99,7 +99,7 @@ int prop_scope_add(pcb_propedit_t *pe, const char *cmd, int quiet)
 				id = pcb_layergrp_str2id(pe->pcb, cmd+9);
 				if (id < 0) {
 					if (!quiet)
-						pcb_message(PCB_MSG_ERROR, "Invalid layergrp ID '%s'\n", cmd+9);
+						rnd_message(RND_MSG_ERROR, "Invalid layergrp ID '%s'\n", cmd+9);
 					return FGW_ERR_ARG_CONV;
 				}
 			}
@@ -116,7 +116,7 @@ int prop_scope_add(pcb_propedit_t *pe, const char *cmd, int quiet)
 			id = pcb_layer_str2id(pe->data, cmd+6);
 			if (id < 0) {
 				if (!quiet)
-					pcb_message(PCB_MSG_ERROR, "Invalid layer ID '%s'\n", cmd+6);
+					rnd_message(RND_MSG_ERROR, "Invalid layer ID '%s'\n", cmd+6);
 				return FGW_ERR_ARG_CONV;
 			}
 			vtl0_append(&pe->layers, id);
@@ -126,7 +126,7 @@ int prop_scope_add(pcb_propedit_t *pe, const char *cmd, int quiet)
 		}
 	}
 	else if (strncmp(cmd, "net:", 4) == 0) {
-		char *name = pcb_strdup(cmd+4);
+		char *name = rnd_strdup(cmd+4);
 		if (!pe->nets_inited) {
 			htsp_init(&pe->nets, strhash, strkeyeq);
 			pe->nets_inited = 1;
@@ -142,12 +142,12 @@ int prop_scope_add(pcb_propedit_t *pe, const char *cmd, int quiet)
 	else {
 		char *end;
 		pcb_idpath_t *idp = (void *)strtol(cmd, &end, 0);
-		if ((*end == '\0') && (idp != NULL) && (htpp_get(&pcb_fgw.ptr_tbl, idp) == PCB_PTR_DOMAIN_IDPATH)) {
+		if ((*end == '\0') && (idp != NULL) && (htpp_get(&rnd_fgw.ptr_tbl, idp) == RND_PTR_DOMAIN_IDPATH)) {
 			pcb_idpath_list_append(&pe->objs, idp);
 			return 0;
 		}
 		if (!quiet)
-			pcb_message(PCB_MSG_ERROR, "Invalid scope: %s\n", cmd);
+			rnd_message(RND_MSG_ERROR, "Invalid scope: %s\n", cmd);
 		return FGW_ERR_ARG_CONV;
 	}
 	return 0;
@@ -172,7 +172,7 @@ static void prop_scope_finish(pcb_propedit_t *pe)
 	}
 }
 
-extern pcb_layergrp_id_t pcb_actd_EditGroup_gid;
+extern rnd_layergrp_id_t pcb_actd_EditGroup_gid;
 
 static const char pcb_acts_propset[] = "propset([scope], name, value)";
 static const char pcb_acth_propset[] = "Change the named property of scope or all selected objects to/by value. Scope is documented at PropEdit().";
@@ -183,25 +183,52 @@ fgw_error_t pcb_act_propset(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	pcb_props_init(&ctx, PCB);
 
-	PCB_ACT_CONVARG(1, FGW_STR, propset, first = argv[1].val.str);
+	RND_ACT_CONVARG(1, FGW_STR, propset, first = argv[1].val.str);
 	if (prop_scope_add(&ctx, first, 1) == 0) {
-		PCB_ACT_CONVARG(2, FGW_STR, propset, name = argv[2].val.str);
-		PCB_ACT_CONVARG(3, FGW_STR, propset, val = argv[3].val.str);
+		RND_ACT_CONVARG(2, FGW_STR, propset, name = argv[2].val.str);
+		RND_ACT_CONVARG(3, FGW_STR, propset, val = argv[3].val.str);
 	}
 	else {
 		name = first;
 		ctx.selection = 1;
-		PCB_ACT_CONVARG(2, FGW_STR, propset, val = argv[2].val.str);
+		RND_ACT_CONVARG(2, FGW_STR, propset, val = argv[2].val.str);
 	}
 
-	PCB_ACT_IRES(pcb_propsel_set_str(&ctx, name, val));
+	RND_ACT_IRES(pcb_propsel_set_str(&ctx, name, val));
 
 	prop_scope_finish(&ctx);
 	pcb_props_uninit(&ctx);
 	return 0;
 }
 
-static const char pcb_acts_propget[] = "propset([scope], name, [stattype])";
+static const char pcb_acts_proptoggle[] = "proptoggle([scope], name, [create])";
+static const char pcb_acth_proptoggle[] = "Toggle the named property of scope or all selected objects, assuming the property is boolean. Scope is documented at PropEdit(). If create is true, non-existing attributes are created as true.";
+fgw_error_t pcb_act_proptoggle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	const char *first, *name, *create = NULL;
+	pcb_propedit_t ctx;
+
+	pcb_props_init(&ctx, PCB);
+
+	RND_ACT_CONVARG(1, FGW_STR, proptoggle, first = argv[1].val.str);
+	if (prop_scope_add(&ctx, first, 1) == 0) {
+		RND_ACT_CONVARG(2, FGW_STR, proptoggle, name = argv[2].val.str);
+		RND_ACT_MAY_CONVARG(3, FGW_STR, proptoggle, create = argv[3].val.str);
+	}
+	else {
+		name = first;
+		RND_ACT_MAY_CONVARG(2, FGW_STR, proptoggle, create = argv[2].val.str);
+		ctx.selection = 1;
+	}
+
+	RND_ACT_IRES(pcb_propsel_toggle(&ctx, name, rnd_istrue(create)));
+
+	prop_scope_finish(&ctx);
+	pcb_props_uninit(&ctx);
+	return 0;
+}
+
+static const char pcb_acts_propget[] = "propget([scope], name, [stattype])";
 static const char pcb_acth_propget[] = "Return the named property of scope or all selected objects to/by value. Scope is documented at PropEdit().";
 fgw_error_t pcb_act_propget(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
@@ -214,15 +241,15 @@ fgw_error_t pcb_act_propget(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	pcb_props_init(&ctx, PCB);
 
-	PCB_ACT_CONVARG(1, FGW_STR, propget, first = argv[1].val.str);
+	RND_ACT_CONVARG(1, FGW_STR, propget, first = argv[1].val.str);
 	if (prop_scope_add(&ctx, first, 1) == 0) {
-		PCB_ACT_CONVARG(2, FGW_STR, propget, name = argv[2].val.str);
-		PCB_ACT_MAY_CONVARG(3, FGW_STR, propget, stty = argv[3].val.str);
+		RND_ACT_CONVARG(2, FGW_STR, propget, name = argv[2].val.str);
+		RND_ACT_MAY_CONVARG(3, FGW_STR, propget, stty = argv[3].val.str);
 	}
 	else {
 		name = first;
 		ctx.selection = 1;
-		PCB_ACT_CONVARG(2, FGW_STR, propget, stty = argv[2].val.str);
+		RND_ACT_CONVARG(2, FGW_STR, propget, stty = argv[2].val.str);
 	}
 
 	ctx.geo = 1;
@@ -255,13 +282,14 @@ fgw_error_t pcb_act_propget(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 			e = htprop_first(&p->values);
 			most_common = e->key;
 			res->type = FGW_STR | FGW_DYN;
-			res->val.str = pcb_strdup(out->string == NULL ? "" : out->string);
+			res->val.str = rnd_strdup(out->string == NULL ? "" : out->string);
 			break;
 		case PCB_PROPT_COORD: res->type = FGW_COORD; fgw_coord(res) = out->coord; break;
 		case PCB_PROPT_ANGLE: res->type = FGW_DOUBLE; res->val.nat_double = out->angle; break;
+		case PCB_PROPT_DOUBLE: res->type = FGW_DOUBLE; res->val.nat_double = out->d; break;
 		case PCB_PROPT_BOOL:
 		case PCB_PROPT_INT:   res->type = FGW_INT; res->val.nat_int = out->i; break;
-		case PCB_PROPT_COLOR: res->type = FGW_STR | FGW_DYN; res->val.str = pcb_strdup(out->clr.str); break;
+		case PCB_PROPT_COLOR: res->type = FGW_STR | FGW_DYN; res->val.str = rnd_strdup(out->clr.str); break;
 		case PCB_PROPT_invalid:
 		case PCB_PROPT_max: goto error;
 	}
@@ -285,7 +313,7 @@ fgw_error_t pcb_act_propprint(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	pcb_props_init(&ctx, PCB);
 
-	PCB_ACT_MAY_CONVARG(1, FGW_STR, propset, scope = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(1, FGW_STR, propprint, scope = argv[1].val.str);
 	if (scope != NULL) {
 		if (prop_scope_add(&ctx, scope, 0) != 0)
 			return FGW_ERR_ARG_CONV;
@@ -307,17 +335,21 @@ fgw_error_t pcb_act_propprint(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		switch(p->type) {
 			case PCB_PROPT_STRING: printf("	common='%s'\n", com.string); break;
 			case PCB_PROPT_COORD:
-				pcb_printf("	common='%$$mm'\n", com.coord);
-				pcb_printf("	min/avg/max=%$$mm/%$$mm/%$$mm\n", min.coord, avg.coord, max.coord);
+				rnd_printf("	common='%$$mm'\n", com.coord);
+				rnd_printf("	min/avg/max=%$$mm/%$$mm/%$$mm\n", min.coord, avg.coord, max.coord);
 				break;
 			case PCB_PROPT_ANGLE:
-				pcb_printf("	common='%f'\n", com.angle);
-				pcb_printf("	min/avg/max=%f/%f/%f\n", min.angle, avg.angle, max.angle);
+				rnd_printf("	common='%f'\n", com.angle);
+				rnd_printf("	min/avg/max=%f/%f/%f\n", min.angle, avg.angle, max.angle);
+				break;
+			case PCB_PROPT_DOUBLE:
+				rnd_printf("	common='%f'\n", com.d);
+				rnd_printf("	min/avg/max=%f/%f/%f\n", min.d, avg.d, max.d);
 				break;
 			case PCB_PROPT_INT:
 			case PCB_PROPT_BOOL:
-				pcb_printf("	common='%d'\n", com.i);
-				pcb_printf("	min/avg/max=%d/%d/%d\n", min.i, avg.i, max.i);
+				rnd_printf("	common='%d'\n", com.i);
+				rnd_printf("	min/avg/max=%d/%d/%d\n", min.i, avg.i, max.i);
 				break;
 			case PCB_PROPT_COLOR: printf("	common=#%02d%02d%02d\n", com.clr.r, com.clr.g, com.clr.b); break;
 			case PCB_PROPT_invalid:
@@ -329,16 +361,17 @@ fgw_error_t pcb_act_propprint(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 	prop_scope_finish(&ctx);
 	pcb_props_uninit(&ctx);
-	PCB_ACT_IRES(0);
+	RND_ACT_IRES(0);
 	return 0;
 }
 
 static const char *propedit_cookie = "propedit";
 
-pcb_action_t propedit_action_list[] = {
+rnd_action_t propedit_action_list[] = {
 	{"propedit", pcb_act_propedit, pcb_acth_propedit, pcb_acts_propedit},
 	{"propprint", pcb_act_propprint, pcb_acth_propprint, pcb_acts_propprint},
 	{"propset", pcb_act_propset, pcb_acth_propset, pcb_acts_propset},
+	{"proptoggle", pcb_act_proptoggle, pcb_acth_proptoggle, pcb_acts_proptoggle},
 	{"propget", pcb_act_propget, pcb_acth_propget, pcb_acts_propget}
 };
 
@@ -347,24 +380,24 @@ int pplg_check_ver_propedit(int ver_needed) { return 0; }
 void pplg_uninit_propedit(void)
 {
 	pcb_propdlg_uninit();
-	pcb_remove_actions_by_cookie(propedit_cookie);
+	rnd_remove_actions_by_cookie(propedit_cookie);
 }
 
 int pplg_init_propedit(void)
 {
-	PCB_API_CHK_VER;
+	RND_API_CHK_VER;
 
-	if (sizeof(long) < sizeof(pcb_layer_id_t)) {
-		pcb_message(PCB_MSG_ERROR, "can't load propedig: layer id type wider than long\n");
+	if (sizeof(long) < sizeof(rnd_layer_id_t)) {
+		rnd_message(RND_MSG_ERROR, "can't load propedig: layer id type wider than long\n");
 		return -1;
 	}
 
-	if (sizeof(long) < sizeof(pcb_layergrp_id_t)) {
-		pcb_message(PCB_MSG_ERROR, "can't load propedig: layergrp id type wider than long\n");
+	if (sizeof(long) < sizeof(rnd_layergrp_id_t)) {
+		rnd_message(RND_MSG_ERROR, "can't load propedig: layergrp id type wider than long\n");
 		return -1;
 	}
 
-	PCB_REGISTER_ACTIONS(propedit_action_list, propedit_cookie)
+	RND_REGISTER_ACTIONS(propedit_action_list, propedit_cookie)
 	pcb_propdlg_init();
 	return 0;
 }
