@@ -26,10 +26,10 @@
 #include "config.h"
 #include "props.h"
 #include "propsel.h"
-#include "compat_misc.h"
+#include <librnd/core/compat_misc.h>
 #include "board.h"
-#include "pcb-printf.h"
-#include "hid.h"
+#include <librnd/core/rnd_printf.h>
+#include <librnd/core/hid.h>
 #include <genht/hash.h>
 /*#define HT_INVALID_VALUE ((pcb_propval_t){PCB_PROPT_invalid, {0}})*/
 #define HT(x) htprop_ ## x
@@ -37,11 +37,12 @@
 #undef HT
 
 /* Type names in text */
-static const char *type_names[] = { "invalid", "string", "coord", "angle", "int" };
+static const char *type_names[] = { "invalid", "string", "coord", "angle", "double", "int" };
 
 /* A hash function for each known type */
 static unsigned int prophash_coord(pcb_propval_t key)  { return longhash(key.coord); }
 static unsigned int prophash_angle(pcb_propval_t key)  { return longhash(key.angle); }
+static unsigned int prophash_double(pcb_propval_t key) { return longhash(key.d); }
 static unsigned int prophash_int(pcb_propval_t key)    { return longhash(key.i); }
 static unsigned int prophash_bool(pcb_propval_t key)   { return longhash(key.i); }
 static unsigned int prophash_color(pcb_propval_t key)  { return longhash(key.clr.packed); }
@@ -49,12 +50,13 @@ static unsigned int prophash_string(pcb_propval_t key) { return key.string == NU
 
 typedef unsigned int (*prophash_ft)(pcb_propval_t key);
 static prophash_ft prophash[PCB_PROPT_max] = {
-	NULL, prophash_string, prophash_coord, prophash_angle, prophash_int, prophash_bool, prophash_color
+	NULL, prophash_string, prophash_coord, prophash_angle, prophash_double, prophash_int, prophash_bool, prophash_color
 };
 
 /* A keyeq function for each known type */
 static int propkeyeq_coord(pcb_propval_t a, pcb_propval_t b)  { return a.coord == b.coord; }
 static int propkeyeq_angle(pcb_propval_t a, pcb_propval_t b)  { return a.angle == b.angle; }
+static int propkeyeq_double(pcb_propval_t a, pcb_propval_t b) { return a.d == b.d; }
 static int propkeyeq_int(pcb_propval_t a, pcb_propval_t b)    { return a.i == b.i; }
 static int propkeyeq_bool(pcb_propval_t a, pcb_propval_t b)   { return a.i == b.i; }
 static int propkeyeq_color(pcb_propval_t a, pcb_propval_t b)  { return a.clr.packed == b.clr.packed; }
@@ -70,7 +72,7 @@ static int propkeyeq_string(pcb_propval_t a, pcb_propval_t b)
 
 typedef int (*propkeyeq_ft)(pcb_propval_t a, pcb_propval_t b);
 static propkeyeq_ft propkeyeq[PCB_PROPT_max] = {
-	NULL, propkeyeq_string, propkeyeq_coord, propkeyeq_angle, propkeyeq_int, propkeyeq_bool, propkeyeq_color
+	NULL, propkeyeq_string, propkeyeq_coord, propkeyeq_angle, propkeyeq_double, propkeyeq_int, propkeyeq_bool, propkeyeq_color
 };
 
 
@@ -136,7 +138,7 @@ pcb_props_t *pcb_props_add(pcb_propedit_t *ctx, const char *propname, pcb_prop_t
 		p = malloc(sizeof(pcb_props_t));
 		p->type = type;
 		htprop_init(&p->values, prophash[type], propkeyeq[type]);
-		htsp_set(&ctx->props, pcb_strdup(propname), p);
+		htsp_set(&ctx->props, rnd_strdup(propname), p);
 	}
 	else {
 		if (type != p->type)
@@ -193,8 +195,9 @@ int pcb_props_stat(pcb_propedit_t *ctx, pcb_props_t *p, pcb_propval_t *most_comm
 		case PCB_PROPT_invalid: break;
 		case PCB_PROPT_max: break;
 		case PCB_PROPT_STRING: break;
-		case PCB_PROPT_COORD:  minp.coord = COORD_MAX; maxp.coord = -minp.coord;  break;
+		case PCB_PROPT_COORD:  minp.coord = RND_COORD_MAX; maxp.coord = -minp.coord;  break;
 		case PCB_PROPT_ANGLE:  minp.angle = 100000;    maxp.angle = -minp.angle; break;
+		case PCB_PROPT_DOUBLE: minp.d     = 100000;    maxp.d = -minp.d; break;
 		case PCB_PROPT_INT:    minp.i     = INT_MAX;   maxp.i = -minp.i; break;
 		case PCB_PROPT_BOOL:   minp.i     = 1;         maxp.i = 0; break;
 		case PCB_PROPT_COLOR:  break;
@@ -213,6 +216,7 @@ int pcb_props_stat(pcb_propedit_t *ctx, pcb_props_t *p, pcb_propval_t *most_comm
 			case PCB_PROPT_STRING: break;
 			case PCB_PROPT_COORD:  STAT(e->key, coord, e->value); break;
 			case PCB_PROPT_ANGLE:  STAT(e->key, angle, e->value); break;
+			case PCB_PROPT_DOUBLE: STAT(e->key, d,     e->value); break;
 			case PCB_PROPT_INT:    STAT(e->key, i,     e->value); break;
 			case PCB_PROPT_BOOL:   STAT(e->key, i,     e->value); break;
 			case PCB_PROPT_COLOR:  break;
@@ -227,6 +231,7 @@ int pcb_props_stat(pcb_propedit_t *ctx, pcb_props_t *p, pcb_propval_t *most_comm
 			case PCB_PROPT_STRING: break;
 			case PCB_PROPT_COORD:  avgp.coord = avgp.coord/num_vals;  break;
 			case PCB_PROPT_ANGLE:  avgp.angle = avgp.angle/num_vals;  break;
+			case PCB_PROPT_DOUBLE: avgp.angle = avgp.d/num_vals;  break;
 			case PCB_PROPT_INT:    avgp.i     = avgp.i/num_vals;  break;
 			case PCB_PROPT_BOOL:   avgp.i     = avgp.i * 100/num_vals;  break;
 			case PCB_PROPT_COLOR:  break;
