@@ -73,7 +73,7 @@ do { \
 	pcb_props_add(ctx, name, type2TYPE_ ## type, v); \
 } while(0)
 
-static void map_attr(void *ctx, const rnd_attribute_list_t *list)
+static void map_attr(void *ctx, const pcb_attribute_list_t *list)
 {
 	int i, bl = 0;
 	char small[256];
@@ -138,8 +138,8 @@ static void map_layer(pcb_propedit_t *ctx, pcb_layer_t *layer)
 	if (layer == NULL)
 		return;
 	map_add_prop(ctx, "p/layer/name", String, layer->name);
-	map_add_prop(ctx, "p/layer/comb/negative", int, !!(layer->comb & PCB_LYC_SUB));
-	map_add_prop(ctx, "p/layer/comb/auto", int, !!(layer->comb & PCB_LYC_AUTO));
+	map_add_prop(ctx, "p/layer/comb/negative", bool, !!(layer->comb & PCB_LYC_SUB));
+	map_add_prop(ctx, "p/layer/comb/auto", bool, !!(layer->comb & PCB_LYC_AUTO));
 	if (!layer->is_bound)
 		map_add_prop(ctx, "p/layer/color", color, layer->meta.real.color);
 	map_attr(ctx, &layer->Attributes);
@@ -362,10 +362,10 @@ static int attr_key_has_side_effect(const char *key)
 	return 0;
 }
 
-static void toggle_attr(pcb_propset_ctx_t *st, rnd_attribute_list_t *list, int undoable, pcb_any_obj_t *obj)
+static void toggle_attr(pcb_propset_ctx_t *st, pcb_attribute_list_t *list, int undoable, pcb_any_obj_t *obj)
 {
 	const char *key = st->name+2, *newval = NULL;
-	const char *orig = rnd_attribute_get(list, key);
+	const char *orig = pcb_attribute_get(list, key);
 	int side_effect = 0;
 
 	if (orig == NULL) {
@@ -393,7 +393,7 @@ static void toggle_attr(pcb_propset_ctx_t *st, rnd_attribute_list_t *list, int u
 	if (undoable)
 		pcb_uchg_attr(st->pcb, obj, key, newval);
 	else
-		rnd_attribute_put(list, key, newval);
+		pcb_attribute_put(list, key, newval);
 	if ((obj != NULL) && side_effect) {
 		pcb_obj_update_bbox(st->pcb, obj);
 		pcb_obj_post(obj);
@@ -402,7 +402,7 @@ static void toggle_attr(pcb_propset_ctx_t *st, rnd_attribute_list_t *list, int u
 	st->set_cnt++;
 }
 
-static void set_attr_raw(pcb_propset_ctx_t *st, rnd_attribute_list_t *list)
+static void set_attr_raw(pcb_propset_ctx_t *st, pcb_attribute_list_t *list)
 {
 	const char *key = st->name+2;
 	const char *orig;
@@ -412,11 +412,11 @@ static void set_attr_raw(pcb_propset_ctx_t *st, rnd_attribute_list_t *list)
 		return;
 	}
 
-	orig = rnd_attribute_get(list, key);
+	orig = pcb_attribute_get(list, key);
 	if ((orig != NULL) && (strcmp(orig, st->s) == 0))
 		return;
 
-	rnd_attribute_put(list, key, st->s);
+	pcb_attribute_put(list, key, st->s);
 	st->set_cnt++;
 }
 
@@ -460,6 +460,8 @@ static int set_common(pcb_propset_ctx_t *st, pcb_any_obj_t *obj)
 		if (i->mask & PCB_FLAG_CLEARLINE)
 			pcb_obj_pre(obj);
 
+		pcb_undo_add_obj_to_flag(obj);
+
 		if (st->toggle)
 			pcb_flag_change(st->pcb, PCB_CHGFLG_TOGGLE, i->mask, obj->type, obj->parent.any, obj, obj);
 		else
@@ -516,6 +518,13 @@ static int layer_recolor(pcb_layer_t *layer, const char *clr)
 	return pcb_layer_recolor_(layer, &c, 1);
 }
 
+static int layer_recomb(pcb_layer_t *layer, int val, pcb_layer_combining_t bit)
+{
+	if (val)
+		return pcb_layer_recomb(layer, layer->comb | bit, 1);
+	return pcb_layer_recomb(layer, layer->comb & ~bit, 1);
+}
+
 static int set_layer(pcb_propset_ctx_t *st, pcb_layer_t *layer)
 {
 	const char *pn = st->name + 8;
@@ -534,6 +543,12 @@ static int set_layer(pcb_propset_ctx_t *st, pcb_layer_t *layer)
 
 		if ((strcmp(pn, "color") == 0) &&
 		    (layer_recolor(layer, st->color.str) == 0)) DONE0;
+
+		if ((strcmp(pn, "comb/negative") == 0) &&
+		    (layer_recomb(layer, st->c, PCB_LYC_SUB) == 0)) DONE0;
+
+		if ((strcmp(pn, "comb/auto") == 0) &&
+		    (layer_recomb(layer, st->c, PCB_LYC_AUTO) == 0)) DONE0;
 	}
 
 	return 0;
@@ -572,7 +587,7 @@ static void set_net(pcb_propset_ctx_t *st, const char *netname)
 
 	if (st->is_attr) {
 		const char *key = st->name+2;
-		const char *orig = rnd_attribute_get(&net->Attributes, key);
+		const char *orig = pcb_attribute_get(&net->Attributes, key);
 
 		if ((orig != NULL) && (strcmp(orig, st->s) == 0))
 			return;
@@ -998,7 +1013,7 @@ int pcb_propsel_set(pcb_propedit_t *ctx, const char *prop, pcb_propset_ctx_t *sc
 	if (ctx->board)
 		set_board(sctx, ctx->pcb);
 
-	pcb_board_set_changed_flag(rnd_true);
+	pcb_board_set_changed_flag(ctx->pcb, rnd_true);
 	pcb_undo_inc_serial();
 	return sctx->set_cnt;
 }
@@ -1011,10 +1026,10 @@ int pcb_propsel_set_str(pcb_propedit_t *ctx, const char *prop, const char *value
 	const char *start;
 
 	/* sanity checks for invalid props */
-	if (prop[1] != '/')
-		return 0;
-	if ((prop[0] != 'a') && (prop[0] != 'p'))
+	if ((prop[1] != '/') || ((prop[0] != 'a') && (prop[0] != 'p'))) {
+		rnd_message(RND_MSG_ERROR, "Invalid property path: '%s':\n must start with p/ for property or a/ for attribute\n", prop);
 		return 0;
+	}
 
 	memset(&sctx, 0, sizeof(sctx));
 
@@ -1059,9 +1074,9 @@ int pcb_propsel_toggle(pcb_propedit_t *ctx, const char *prop, rnd_bool create)
 
 /*******************/
 
-static long del_attr(void *ctx, rnd_attribute_list_t *list, const char *key)
+static long del_attr(void *ctx, pcb_attribute_list_t *list, const char *key)
 {
-	if (rnd_attribute_remove(list, key))
+	if (pcb_attribute_remove(list, key))
 		return 1;
 	return 0;
 }
@@ -1079,7 +1094,7 @@ static long del_layergrp(void *ctx, pcb_layergrp_t *grp, const char *key)
 static long del_net(pcb_propedit_t *ctx, const char *netname, const char *key)
 {
 	pcb_net_t *net = pcb_net_get(ctx->pcb, &ctx->pcb->netlist[PCB_NETLIST_EDITED], netname, 0);
-	if ((net == NULL) || (rnd_attribute_get(&net->Attributes, key) == NULL))
+	if ((net == NULL) || (pcb_attribute_get(&net->Attributes, key) == NULL))
 		return 0;
 
 	pcb_ratspatch_append_optimize(ctx->pcb, RATP_CHANGE_ATTRIB, netname, key, NULL);
@@ -1137,7 +1152,7 @@ int pcb_propsel_del(pcb_propedit_t *ctx, const char *key)
 	if (ctx->board)
 		del_cnt += del_board(&ctx, ctx->pcb, key);
 
-	pcb_board_set_changed_flag(rnd_true);
+	pcb_board_set_changed_flag(ctx->pcb, rnd_true);
 	return del_cnt;
 }
 
