@@ -1400,6 +1400,7 @@ static rnd_r_dir_t gp_pstk_cb(const rnd_box_t *b, void *cb)
 	pcb_pstk_t *ps = (pcb_pstk_t *)b; /* have to drop const because we may update the cache in ps */
 	pcb_layer_t *layer = PCB_CURRLAYER(PCB);
 	pcb_pstk_shape_t *shape = pcb_pstk_shape_at(PCB, ps, layer), tmpshp;
+	int n;
 
 	if (ps == start_pinpad || ps == end_pinpad)
 		return RND_R_DIR_NOT_FOUND;
@@ -1416,12 +1417,20 @@ static rnd_r_dir_t gp_pstk_cb(const rnd_box_t *b, void *cb)
 			gp_point(ps->x + shape->data.circ.x, ps->y + shape->data.circ.y, shape->data.circ.dia/2, 0);
 			break;
 		case PCB_PSSH_POLY:
-TODO(": we lump poly padstacks in with square; safe, but not optimal; rather use the real shape")
+			for(n = 0; n < shape->data.poly.len; n++)
+				gp_point(ps->x + shape->data.poly.x[n], ps->y + shape->data.poly.y[n], 0, 0);
+			break;
 		case PCB_PSSH_LINE:
-			gp_point(ps->BoundingBox.X1, ps->BoundingBox.Y1, 0, 0);
-			gp_point(ps->BoundingBox.X1, ps->BoundingBox.Y2, 0, 0);
-			gp_point(ps->BoundingBox.X2, ps->BoundingBox.Y1, 0, 0);
-			gp_point(ps->BoundingBox.X2, ps->BoundingBox.Y2, 0, 0);
+			if (shape->data.line.square) {
+				gp_point(ps->bbox_naked.X1, ps->bbox_naked.Y1, 0, 0);
+				gp_point(ps->bbox_naked.X1, ps->bbox_naked.Y2, 0, 0);
+				gp_point(ps->bbox_naked.X2, ps->bbox_naked.Y1, 0, 0);
+				gp_point(ps->bbox_naked.X2, ps->bbox_naked.Y2, 0, 0);
+			}
+			else {
+				gp_point(ps->x + shape->data.line.x1, ps->y + shape->data.line.y1, shape->data.line.thickness/2, 0);
+				gp_point(ps->x + shape->data.line.x2, ps->y + shape->data.line.y2, shape->data.line.thickness/2, 0);
+			}
 			break;
 	}
 	return RND_R_DIR_NOT_FOUND;
