@@ -287,7 +287,7 @@ do { \
 		fld2str_req(s2, fld, 1); \
 		if (!PCB_OBJ_IS_CLASS(obj->type, PCB_OBJ_CLASS_OBJ)) \
 			PCB_QRY_RET_INV(res); \
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&obj->Attributes, s2)); \
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&obj->Attributes, s2)); \
 	} \
  \
 	if (fh1 == query_fields_ID) { \
@@ -329,6 +329,8 @@ do { \
  \
 } while(0)
 
+static int field_net(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fld, pcb_qry_val_t *res);
+
 #define NETNAME_FIELDS(ec) \
 do { \
 	if (fh1 == query_fields_netname) { \
@@ -345,6 +347,26 @@ do { \
 		else \
 			PCB_QRY_RET_INV(res); \
 	} \
+	if (fh1 == query_fields_net) { \
+		if (ec != NULL) { \
+			pcb_any_obj_t *term = pcb_qry_parent_net_term(ec, obj); \
+			pcb_net_t *net; \
+			if ((term == NULL) || (term->type != PCB_OBJ_NET_TERM)) \
+				PCB_QRY_RET_INV(res); \
+			net = term->parent.net; \
+			if ((net == NULL) || (net->type != PCB_OBJ_NET)) \
+				PCB_QRY_RET_INV(res); \
+			if (fld->next == NULL) \
+				PCB_QRY_RET_OBJ(res, (pcb_any_obj_t *)net); \
+			else { \
+				pcb_qry_node_t *__fn__ = (fld)->next; \
+				return field_net(ec, (pcb_any_obj_t *)net, __fn__, res); \
+			} \
+			PCB_QRY_RET_INV(res); \
+		} \
+		else \
+			PCB_QRY_RET_INV(res); \
+	} \
 	if (fh1 == query_fields_netseg) { \
 		if (ec != NULL) { \
 			pcb_any_obj_t *term = pcb_qry_parent_net_term(ec, obj); \
@@ -381,7 +403,7 @@ static int field_layer(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *f
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&l->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&l->Attributes, s2));
 	}
 
 	if (fld->next != NULL)
@@ -402,11 +424,66 @@ static int field_layer(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *f
 	PCB_QRY_RET_INV(res);
 }
 
+static int field_layergrp(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fld, pcb_qry_val_t *res)
+{
+	pcb_layergrp_t *g = (pcb_layergrp_t *)obj;
+	query_fields_keys_t fh1;
+
+	fld2hash_req(fh1, fld, 0);
+
+	/* in some cases .type will do the wrong thing at the caller; the escape is .layer.type; drop the redundant .layer */
+	if (fh1 == query_fields_layergroup) {
+		fld = fld->next;
+		fld2hash_req(fh1, fld, 0);
+	}
+
+	if (fh1 == query_fields_a) {
+		const char *s2;
+		fld2str_req(s2, fld, 1);
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&g->Attributes, s2));
+	}
+
+	if (fld->next != NULL)
+		PCB_QRY_RET_INV(res);
+
+	switch(fh1) {
+		case query_fields_IID:      PCB_QRY_RET_INT(res, pcb_obj_iid((pcb_any_obj_t *)g));
+		case query_fields_name:     PCB_QRY_RET_STR(res, g->name);
+		case query_fields_visible:  PCB_QRY_RET_INT(res, g - ec->pcb->LayerGroups.grp);
+		case query_fields_position: PCB_QRY_RET_INT(res, g->ltype & PCB_LYT_ANYWHERE);
+		case query_fields_type:     PCB_QRY_RET_INT(res, g->ltype & PCB_LYT_ANYTHING);
+		case query_fields_purpose:  PCB_QRY_RET_STR(res, g->purpose);
+		default:;
+	}
+
+	PCB_QRY_RET_INV(res);
+}
+
 static int field_layer_from_ptr(pcb_qry_exec_t *ec, pcb_layer_t *l, pcb_qry_node_t *fld, pcb_qry_val_t *res)
 {
 	return field_layer(ec, (pcb_any_obj_t *)l, fld, res);
 }
 
+static int field_layergrp_from_ptr(pcb_qry_exec_t *ec, pcb_layergrp_t *l, pcb_qry_node_t *fld, pcb_qry_val_t *res)
+{
+	return field_layergrp(ec, (pcb_any_obj_t *)l, fld, res);
+}
+
+static int field_layergrp_from_layer_ptr(pcb_qry_exec_t *ec, pcb_layer_t *l, pcb_qry_node_t *fld, pcb_qry_val_t *res)
+{
+	pcb_layergrp_t *grp;
+
+	l = pcb_layer_get_real(l);
+	if (l == NULL)
+		PCB_QRY_RET_INV(res);
+
+	grp = pcb_get_layergrp(ec->pcb, l->meta.real.grp);
+	if (grp == NULL)
+		PCB_QRY_RET_INV(res);
+
+	return field_layergrp(ec, (pcb_any_obj_t *)grp, fld, res);
+}
+
 /* process from .layer */
 static int layer_of_obj(pcb_qry_exec_t *ec, pcb_qry_node_t *fld, pcb_qry_val_t *res, pcb_layer_type_t mask)
 {
@@ -428,6 +505,27 @@ static int layer_of_obj(pcb_qry_exec_t *ec, pcb_qry_node_t *fld, pcb_qry_val_t *
 	return field_layer_from_ptr(ec, PCB->Data->Layer+id, fld, res);
 }
 
+/* process from .layergroup */
+static int layergrp_of_obj(pcb_qry_exec_t *ec, pcb_qry_node_t *fld, pcb_qry_val_t *res, pcb_layer_type_t mask)
+{
+	rnd_layergrp_id_t id;
+	const char *s1;
+
+	if (pcb_layergrp_list(PCB, mask, &id, 1) != 1)
+		PCB_QRY_RET_INV(res);
+
+	fld2str_req(s1, fld, 0);
+
+	if (s1 == NULL) {
+		res->source = NULL;
+		res->type = PCBQ_VT_OBJ;
+		res->data.obj = (pcb_any_obj_t *)&(PCB->LayerGroups.grp[id]);
+		return 0;
+	}
+
+	return field_layergrp_from_ptr(ec, PCB->LayerGroups.grp+id, fld, res);
+}
+
 static double pcb_line_len2(pcb_line_t *l)
 {
 	double x = l->Point1.X - l->Point2.X;
@@ -445,7 +543,7 @@ static int field_line(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fl
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&l->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&l->Attributes, s2));
 	}
 
 	if (fh1 == query_fields_layer) {
@@ -454,6 +552,12 @@ static int field_line(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fl
 		else
 			PCB_QRY_RET_INV(res);
 	}
+	else if (fh1 == query_fields_layergroup) {
+		if (obj->parent_type == PCB_PARENT_LAYER)
+			return field_layergrp_from_layer_ptr(ec, obj->parent.layer, fld->next, res);
+		else
+			PCB_QRY_RET_INV(res);
+	}
 
 	NETNAME_FIELDS(ec);
 
@@ -506,7 +610,7 @@ static int field_arc(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fld
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&a->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&a->Attributes, s2));
 	}
 
 	if (fh1 == query_fields_angle) {
@@ -525,6 +629,12 @@ static int field_arc(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fld
 		else
 			PCB_QRY_RET_INV(res);
 	}
+	else if (fh1 == query_fields_layergroup) {
+		if (obj->parent_type == PCB_PARENT_LAYER)
+			return field_layergrp_from_layer_ptr(ec, obj->parent.layer, fld->next, res);
+		else
+			PCB_QRY_RET_INV(res);
+	}
 
 	NETNAME_FIELDS(ec);
 
@@ -572,7 +682,7 @@ static int field_gfx(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fld
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&g->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&g->Attributes, s2));
 	}
 
 	if (fh1 == query_fields_layer) {
@@ -581,6 +691,12 @@ static int field_gfx(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fld
 		else
 			PCB_QRY_RET_INV(res);
 	}
+	else if (fh1 == query_fields_layergroup) {
+		if (obj->parent_type == PCB_PARENT_LAYER)
+			return field_layergrp_from_layer_ptr(ec, obj->parent.layer, fld->next, res);
+		else
+			PCB_QRY_RET_INV(res);
+	}
 
 	if (fld->next != NULL)
 		PCB_QRY_RET_INV(res);
@@ -607,7 +723,7 @@ static int field_text(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fl
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&t->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&t->Attributes, s2));
 	}
 
 	if (fh1 == query_fields_layer) {
@@ -616,6 +732,12 @@ static int field_text(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fl
 		else
 			PCB_QRY_RET_INV(res);
 	}
+	else if (fh1 == query_fields_layergroup) {
+		if (obj->parent_type == PCB_PARENT_LAYER)
+			return field_layergrp_from_layer_ptr(ec, obj->parent.layer, fld->next, res);
+		else
+			PCB_QRY_RET_INV(res);
+	}
 
 	NETNAME_FIELDS(ec);
 
@@ -649,7 +771,7 @@ static int field_polygon(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&p->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&p->Attributes, s2));
 	}
 
 	if (fh1 == query_fields_layer) {
@@ -658,6 +780,12 @@ static int field_polygon(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t
 		else
 			PCB_QRY_RET_INV(res);
 	}
+	else if (fh1 == query_fields_layergroup) {
+		if (obj->parent_type == PCB_PARENT_LAYER)
+			return field_layergrp_from_layer_ptr(ec, obj->parent.layer, fld->next, res);
+		else
+			PCB_QRY_RET_INV(res);
+	}
 
 	NETNAME_FIELDS(ec);
 
@@ -708,7 +836,7 @@ static int field_pstk(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fl
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&p->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&p->Attributes, s2));
 	}
 
 	if (fh1 == query_fields_shape) {
@@ -764,7 +892,7 @@ static int field_net(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fld
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&net->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&net->Attributes, s2));
 	}
 
 	if (fld->next != NULL)
@@ -791,12 +919,15 @@ static int field_subc(pcb_qry_exec_t *ec, pcb_any_obj_t *obj, pcb_qry_node_t *fl
 	if (fh1 == query_fields_a) {
 		const char *s2;
 		fld2str_req(s2, fld, 1);
-		PCB_QRY_RET_STR(res, rnd_attribute_get(&p->Attributes, s2));
+		PCB_QRY_RET_STR(res, pcb_attribute_get(&p->Attributes, s2));
 	}
 
 	if (fh1 == query_fields_layer)
 		return layer_of_obj(ec, fld->next, res, PCB_LYT_SILK | (PCB_FLAG_TEST(PCB_FLAG_ONSOLDER, p) ? PCB_LYT_BOTTOM : PCB_LYT_TOP));
 
+	if (fh1 == query_fields_layergroup)
+		return layergrp_of_obj(ec, fld->next, res, PCB_LYT_SILK | (PCB_FLAG_TEST(PCB_FLAG_ONSOLDER, p) ? PCB_LYT_BOTTOM : PCB_LYT_TOP));
+
 	if (fld->next != NULL)
 		PCB_QRY_RET_INV(res);
 
@@ -892,8 +1023,7 @@ int pcb_qry_obj_field(pcb_qry_exec_t *ec, pcb_qry_val_t *objval, pcb_qry_node_t
 
 		case PCB_OBJ_NET:      return field_net(ec, obj, fld, res);
 		case PCB_OBJ_LAYER:    return field_layer(ec, obj, fld, res);
-TODO("layer TODO")
-		case PCB_OBJ_LAYERGRP:
+		case PCB_OBJ_LAYERGRP: return field_layergrp(ec, obj, fld, res);
 		default:;
 	}
 
