@@ -222,7 +222,7 @@ static void pcb_qry_extract_defs_(htsi_t *dst, pcb_qry_node_t *nd, int *total)
 {
 	if (nd->type == PCBQ_FCALL) {
 		pcb_qry_node_t *fname = nd->data.children;
-		if ((fname->type == PCBQ_FNAME) && (fname->data.fnc == pcb_qry_fnc_getconf) && (fname->next->type == PCBQ_DATA_STRING)) {
+		if ((fname->type == PCBQ_FNAME) && (fname->precomp.fnc.bui == pcb_qry_fnc_getconf) && (fname->next->type == PCBQ_DATA_STRING)) {
 			const char *name = fname->next->data.str;
 			htsi_entry_t *e;
 			if (strncmp(name, "design/drc/", 11) == 0) {
@@ -340,7 +340,7 @@ static fgw_error_t pcb_act_query(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		if (pcb_qry_run_script(NULL, PCB_ACT_BOARD, arg, scope, flagop_cb, &sel) < 0)
 			printf("Failed to run the query\n");
 		if (sel.cnt > 0) {
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(PCB_ACT_BOARD, rnd_true);
 			if (RND_HAVE_GUI_ATTR_DLG)
 				rnd_hid_redraw(PCB);
 		}
@@ -368,7 +368,7 @@ static fgw_error_t pcb_act_query(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		if (pcb_qry_run_script(NULL, PCB_ACT_BOARD, arg, scope, flagop_cb, &sel) < 0)
 			printf("Failed to run the query\n");
 		if (sel.cnt > 0) {
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(PCB_ACT_BOARD, rnd_true);
 			if (RND_HAVE_GUI_ATTR_DLG)
 				rnd_hid_redraw(PCB);
 		}
