@@ -74,6 +74,8 @@ void pcb_qry_autofree(pcb_qry_exec_t *ctx)
 	ctx->iter = NULL; /* no need to free the iterator: ctx->root free handled that as it was allocated in one of the nodes */
 }
 
+extern void pcb_qry_uninit_layer_setup(pcb_qry_exec_t *ectx);
+
 void pcb_qry_uninit(pcb_qry_exec_t *ctx)
 {
 	pcb_qry_autofree(ctx);
@@ -96,6 +98,10 @@ void pcb_qry_uninit(pcb_qry_exec_t *ctx)
 	}
 
 	vtp0_uninit(&ctx->tmplst);
+	pcb_qry_uninit_layer_setup(ctx);
+
+	ctx->obj2netterm_inited = ctx->obj2lenseg_inited = \
+	ctx->layer_setup_inited = ctx->warned_missing_thickness = 0;
 }
 
 static void val_free_fields(pcb_qry_val_t *val)
@@ -116,32 +122,39 @@ static void val_free_fields(pcb_qry_val_t *val)
 	}
 }
 
-static int pcb_qry_run_(pcb_qry_exec_t *ec, pcb_qry_node_t *prg, int it_reset, int eval_list, void (*cb)(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current), void *user_ctx)
+static int pcb_qry_run_(pcb_qry_exec_t *ec, pcb_qry_node_t *prg, pcb_qry_val_t *res, int it_reset, int eval_list, void (*cb)(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current), void *user_ctx)
 {
-	pcb_qry_val_t res;
-	int errs = 0;
+	pcb_qry_val_t restmp;
+	int errs = 0, keep_res = 1;
 
 	if (it_reset && (pcb_qry_it_reset(ec, prg) != 0))
 		return -1;
 
+	if (res == NULL) {
+		res = &restmp;
+		keep_res = 0;
+	}
+	res->type = PCBQ_VT_VOID;
+
 	do {
-		if (pcb_qry_eval(ec, prg, &res) == 0) {
-			if ((eval_list) && (res.type == PCBQ_VT_LST)) {
+		val_free_fields(res);
+		if ((pcb_qry_eval(ec, prg, res, cb, user_ctx) == 0) && (cb != NULL)) {
+			if ((eval_list) && (res->type == PCBQ_VT_LST)) {
 				long n;
 
 				/* special case: result is a list, need to return each object so 'let' gets it */
-				for(n = 0; n < res.data.lst.used; n++)
-					cb(user_ctx, &res, res.data.lst.array[n]);
+				for(n = 0; n < res->data.lst.used; n++)
+					cb(user_ctx, res, res->data.lst.array[n]);
 			}
 			else if (ec->iter->last_obj != NULL) {
-				cb(user_ctx, &res, ec->iter->last_obj);
+				cb(user_ctx, res, ec->iter->last_obj);
 			}
-
-			val_free_fields(&res);
 		}
 		else
 			errs++;
 	} while(pcb_qry_it_next(ec));
+	if (!keep_res)
+		val_free_fields(res);
 	return errs;
 }
 
@@ -179,7 +192,7 @@ static void pcb_qry_let(pcb_qry_exec_t *ctx, pcb_qry_node_t *node)
 	/* evaluate 'let' the expression, filling up the list */
 	pcb_qry_it_reset_(lctx.ctx);
 	ctx->iter->it_active = node->precomp.it_active;
-	pcb_qry_run_(lctx.ctx, expr, 0, 1,let_cb, &lctx);
+	pcb_qry_run_(lctx.ctx, expr, NULL, 0, 1,let_cb, &lctx);
 	ctx->iter->it_active = NULL;
 
 	/* initialize the iterator */
@@ -187,9 +200,84 @@ static void pcb_qry_let(pcb_qry_exec_t *ctx, pcb_qry_node_t *node)
 	ctx->iter->idx[vi] = 0;
 }
 
+/* Run one node; increment ret by the number of hits and return that, or -1 on error.
+   If res is not NULL the value of PCBQ_RETURN is loaded in it.
+   Call cb/user_ctx when assert is true. */
+static int pcb_qry_run_one(pcb_qry_exec_t *ec, pcb_qry_node_t *prg, int ret, pcb_qry_val_t *res, void (*cb)(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current), void *user_ctx)
+{
+	int r;
+	pcb_qry_node_t *start;
+	int is_ret = 0;
+
+	if (res != NULL)
+		res->type = PCBQ_VT_VOID;
+
+	if (prg->type == PCBQ_FUNCTION) {
+		if (ec->trace)
+			rnd_message(RND_MSG_INFO, "query: entering user function %s\n", prg->data.children->next->data.str);
+		start = prg->data.children->next->next;
+		while(start->type == PCBQ_ARG)
+			start = start->next;
+		goto run_all;
+	}
+	else if (prg->type == PCBQ_RULE) {
+		pcb_qry_node_t *n;
+		start = prg->data.children->next->next;
+
+		/* execute 'let' statements first */
+		run_all:;
+		for(n = start; n != NULL; n = n->next) {
+			if (n->type == PCBQ_LET)
+				pcb_qry_let(ec, n);
+			if (n->type == PCBQ_RETURN)
+				break;
+		}
+
+		for(n = start; n != NULL; n = n->next) {
+			if (ec->trace)
+				rnd_message(RND_MSG_INFO, "query: %p %s\n", n, pcb_qry_nodetype_name(n->type));
+			switch(n->type) {
+				case PCBQ_LET: break;
+				case PCBQ_RETURN:
+					is_ret = 1;
+				case PCBQ_ASSERT:
+					ec->root = n;
+					if (ec->iter != NULL)
+						ec->iter->it_active = n->precomp.it_active;
+					r = pcb_qry_run_(ec, n->data.children, (is_ret ? res : NULL), 1, 0, (n->type == PCBQ_RETURN ? NULL : cb), user_ctx);
+					if (ec->iter != NULL)
+						ec->iter->it_active = NULL;
+					if (r < 0)
+						ret = r;
+					else if (ret >= 0)
+						ret += r;
+					ec->root = NULL;
+					break;
+				default:;
+			}
+			if (is_ret)
+				break;
+		}
+	}
+	else
+		return -1;
+
+	return ret;
+}
+
+static int pcb_qry_run_all(pcb_qry_exec_t *ec, pcb_qry_node_t *prg, int ret, void (*cb)(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current), void *user_ctx)
+{
+	while(prg != NULL) { /* execute a list of rules */
+		if (prg->type != PCBQ_FUNCTION)
+			ret = pcb_qry_run_one(ec, prg, ret, NULL, cb, user_ctx);
+		prg = prg->next;
+	}
+	return ret;
+}
+
 int pcb_qry_run(pcb_qry_exec_t *ec, pcb_board_t *pcb, pcb_qry_node_t *prg, int bufno, void (*cb)(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current), void *user_ctx)
 {
-	int ret = 0, r, ec_uninit = 0;
+	int ret = 0, ec_uninit = 0;
 	pcb_qry_exec_t ec_local;
 
 	if (ec == NULL) {
@@ -203,43 +291,10 @@ int pcb_qry_run(pcb_qry_exec_t *ec, pcb_board_t *pcb, pcb_qry_node_t *prg, int b
 		pcb_qry_setup(ec, pcb, prg);
 	}
 
-	if (prg->type == PCBQ_EXPR_PROG) {
-		ret = pcb_qry_run_(ec, prg, 1, 0, cb, user_ctx);
-	}
-	else if (prg->type == PCBQ_RULE) {
-		while(prg != NULL) { /* execute a list of rules */
-			pcb_qry_node_t *n;
-
-			/* execute 'let' statements first */
-			for(n = prg->data.children->next->next; n != NULL; n = n->next) {
-				if (n->type == PCBQ_LET)
-					pcb_qry_let(ec, n);
-			}
-
-			for(n = prg->data.children->next->next; n != NULL; n = n->next) {
-				switch(n->type) {
-					case PCBQ_LET: break;
-					case PCBQ_ASSERT:
-						ec->root = n;
-						if (ec->iter != NULL)
-							ec->iter->it_active = n->precomp.it_active;
-						r = pcb_qry_run_(ec, n->data.children, 1, 0, cb, user_ctx);
-						if (ec->iter != NULL)
-							ec->iter->it_active = NULL;
-						if (r < 0)
-							ret = r;
-						else if (ret >= 0)
-							ret += r;
-						ec->root = NULL;
-						break;
-					default:;
-				}
-			}
-			prg = prg->next;
-		}
-	}
+	if (prg->type == PCBQ_EXPR_PROG)
+		ret = pcb_qry_run_(ec, prg, NULL, 1, 0, cb, user_ctx);
 	else
-		ret = -1;
+		ret = pcb_qry_run_all(ec, prg, ret, cb, user_ctx);
 
 	if (ec_uninit)
 		pcb_qry_uninit(&ec_local);
@@ -248,12 +303,74 @@ int pcb_qry_run(pcb_qry_exec_t *ec, pcb_board_t *pcb, pcb_qry_node_t *prg, int b
 	return ret;
 }
 
+static int qry_exec_user_func(pcb_qry_exec_t *ectx, pcb_qry_node_t *fdef, int argc, pcb_qry_val_t *argv, pcb_qry_val_t *res, void (*cb)(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current), void *user_ctx)
+{
+	pcb_qry_exec_t fctx;
+	int n, ret, alloced[PCB_QRY_MAX_FUNC_ARGS];
+	pcb_qry_node_t *fname;
+
+	if (argc > PCB_QRY_MAX_FUNC_ARGS)
+		return -1;
+
+	if (fdef == NULL) {
+		rnd_message(RND_MSG_ERROR, "call to unknown/undefined function\n");
+		return -1;
+	}
+
+	fctx = *ectx;
+
+	assert(fdef->type == PCBQ_FUNCTION);
+	fname = fdef->data.children;
+	assert(fname->type == PCBQ_ITER_CTX);
+	fctx.iter = fname->data.iter_ctx;
+	fname = fname->next; /* skip iter */
+
+	pcb_qry_iter_init(fctx.iter);
+
+	/* accept only objects and lists as argument */
+	for(n = 0; n < argc; n++) {
+		if ((argv[n].type != PCBQ_VT_OBJ) && (argv[n].type != PCBQ_VT_LST))
+			return -1;
+	}
+
+	for(n = 0; n < argc; n++) {
+		if (argv[n].type == PCBQ_VT_OBJ) {
+			fctx.iter->lst[n].type = PCBQ_VT_LST;
+			vtp0_init(&fctx.iter->lst[n].data.lst);
+			vtp0_append(&fctx.iter->lst[n].data.lst, argv[n].data.obj);
+			alloced[n] = 1;
+		}
+		else {
+			fctx.iter->lst[n] = argv[n];
+			alloced[n] = 0;
+		}
+		fctx.iter->vects[n] = &fctx.iter->lst[n].data.lst;
+		fctx.iter->idx[n] = 0;
+	}
+
+	/* reset lists from the previous calls */
+	for(; n < fctx.iter->num_vars; n++) {
+		vtp0_t *v = fctx.iter->vects[n];
+		if (v != NULL)
+			v->used = 0;
+	}
+
+	ret = pcb_qry_run_one(&fctx, fdef, 0, res, cb, user_ctx);
+
+	for(n = 0; n < argc; n++) {
+		if (alloced[n])
+			vtp0_uninit(&fctx.iter->lst[n].data.lst);
+	}
+
+	return ret;
+}
+
 /* load unary operand to o1 */
 #define UNOP() \
 do { \
 	if ((node->data.children == NULL) || (node->data.children->next != NULL)) \
 		return -1; \
-	if (pcb_qry_eval(ctx, node->data.children, &o1) < 0) \
+	if (pcb_qry_eval(ctx, node->data.children, &o1, cb, user_ctx) < 0) \
 		return -1; \
 } while(0)
 
@@ -262,14 +379,14 @@ do { \
 do { \
 	if ((node->data.children == NULL) || (node->data.children->next == NULL) || (node->data.children->next->next != NULL)) \
 		return -1; \
-	if (pcb_qry_eval(ctx, node->data.children, &o1) < 0) \
+	if (pcb_qry_eval(ctx, node->data.children, &o1, cb, user_ctx) < 0) \
 		return -1; \
 } while(0)
 
 /* load 2nd binary operand to o2 */
 #define BINOPS2() \
 do { \
-	if (pcb_qry_eval(ctx, node->data.children->next, &o2) < 0) \
+	if (pcb_qry_eval(ctx, node->data.children->next, &o2, cb, user_ctx) < 0) \
 		return -1; \
 } while(0)
 
@@ -297,7 +414,7 @@ static int promote(pcb_qry_val_t *a, pcb_qry_val_t *b)
 			return -1;
 		case PCBQ_VT_LONG:
 			if (b->type == PCBQ_VT_DOUBLE)  PCB_QRY_RET_DBL(a, a->data.lng);
-			if (b->type == PCBQ_VT_COORD)   PCB_QRY_RET_DBL(a, a->data.lng);
+			if (b->type == PCBQ_VT_COORD)   PCB_QRY_RET_COORD(a, a->data.lng);
 			return -1;
 		case PCBQ_VT_DOUBLE:
 			if (b->type == PCBQ_VT_COORD)  PCB_QRY_RET_DBL(b, b->data.crd);
@@ -449,7 +566,7 @@ do { \
 	if (s2 == NULL) s2 = pcb_qry_empty; \
 } while(0)
 
-int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res)
+int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res, void (*cb)(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current), void *user_ctx)
 {
 	pcb_qry_val_t o1, o2;
 	pcb_any_obj_t **tmp;
@@ -457,7 +574,7 @@ int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res)
 
 	switch(node->type) {
 		case PCBQ_EXPR:
-			return pcb_qry_eval(ctx, node->data.children, res);
+			return pcb_qry_eval(ctx, node->data.children, res, cb, user_ctx);
 
 		case PCBQ_EXPR_PROG: {
 			pcb_qry_node_t *itn, *exprn;
@@ -471,7 +588,7 @@ int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res)
 				return -1;
 			if (ctx->iter != itn->data.iter_ctx)
 				return -1;
-			return pcb_qry_eval(ctx, exprn, res);
+			return pcb_qry_eval(ctx, exprn, res, cb, user_ctx);
 		}
 
 
@@ -679,7 +796,7 @@ int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res)
 		case PCBQ_FIELD_OF:
 			if ((node->data.children == NULL) || (node->data.children->next == NULL))
 				return -1;
-			if (pcb_qry_eval(ctx, node->data.children, &o1) < 0)
+			if (pcb_qry_eval(ctx, node->data.children, &o1, cb, user_ctx) < 0)
 				return -1;
 			return pcb_qry_obj_field(ctx, &o1, node->data.children->next, res);
 
@@ -731,18 +848,21 @@ int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res)
 			if (fname == NULL)
 				return -1;
 			farg = fname->next;
-			if ((fname->type !=  PCBQ_FNAME) || (fname->data.fnc == NULL))
+			if (fname->type !=  PCBQ_FNAME)
 				return -1;
 			memset(args, 0, sizeof(args));
 			for(n = 0; (n < PCB_QRY_MAX_FUNC_ARGS) && (farg != NULL); n++, farg = farg->next)
-				if (pcb_qry_eval(ctx, farg, &args[n]) < 0)
+				if (pcb_qry_eval(ctx, farg, &args[n], cb, user_ctx) < 0)
 					return -1;
 
 			if (farg != NULL) {
 				rnd_message(RND_MSG_ERROR, "too many function arguments\n");
 				return -1;
 			}
-			return fname->data.fnc(ctx, n, args, res);
+			if (fname->precomp.fnc.bui != NULL)
+				return fname->precomp.fnc.bui(ctx, n, args, res);
+			else
+				return qry_exec_user_func(ctx, fname->precomp.fnc.uf, n, args, res, cb, user_ctx);
 		}
 
 		case PCBQ_DATA_COORD:       PCB_QRY_RET_INT_SRC(res, node->data.crd, node);
@@ -763,6 +883,9 @@ int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res)
 		case PCBQ_RNAME:
 		case PCBQ_DATA_LYTC:
 		case PCBQ_ITER_CTX:
+		case PCBQ_FUNCTION:
+		case PCBQ_RETURN:
+		case PCBQ_ARG:
 			return -1;
 	}
 	return -1;
