@@ -52,11 +52,16 @@ struct pcb_qry_exec_s {
 	htpi_t obj2lenseg_cc; /* (pcb_any_obj_t *) object -> connection-counter (how many different objects are connected) */
 	vtp0_t obj2lenseg_free; /* delayed free of obj2lenseg_cc objects */
 	vtp0_t tmplst;        /* may be reused in a function call to save on allocation; always clear it at the end of the fnc */
+	htpp_t layer_setup_precomp;  /* fnc layer_setup(): cache precompiled conditions */
+	vtp0_t layer_setup_netobjs;  /* fnc layer_setup(): tmp allocation cache for object listing */
+	void *layer_setup_res_cache; /* fnc layer_setup(): cached results for each condition evaluated - requests tend to repeat */
 	time_t last_prog_cb;
 
 	unsigned obj2netterm_inited:1;
 	unsigned obj2lenseg_inited:1;
+	unsigned layer_setup_inited:1;
 	unsigned warned_missing_thickness:1;
+	unsigned trace:1;
 };
 
 /* if bufno is -1, scope is the board, else scope is the buffer addressed by bufno */
@@ -75,7 +80,7 @@ int pcb_qry_run(pcb_qry_exec_t *ec, pcb_board_t *pcb, pcb_qry_node_t *prg, int b
 
 int pcb_qry_is_true(pcb_qry_val_t *val);
 
-int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res);
+int pcb_qry_eval(pcb_qry_exec_t *ctx, pcb_qry_node_t *node, pcb_qry_val_t *res, void (*cb)(void *user_ctx, pcb_qry_val_t *res, pcb_any_obj_t *current), void *user_ctx);
 
 int pcb_qry_it_reset(pcb_qry_exec_t *ctx, pcb_qry_node_t *node);
 
