@@ -107,14 +107,20 @@ static void notify_line(rnd_hidlib_t *hl)
 			pcb_crosshair_set_local_ref(pcb_crosshair.X, pcb_crosshair.Y, rnd_true);
 	switch (pcb_crosshair.AttachedLine.State) {
 	case PCB_CH_STATE_FIRST:						/* first point */
-TODO("subc: this should work on heavy terminals too!")
-		if (pcb->RatDraw && pcb_search_screen(pcb_crosshair.X, pcb_crosshair.Y, PCB_OBJ_PSTK | PCB_OBJ_SUBC_PART, &ptr1, &ptr1, &ptr1) == PCB_OBJ_VOID) {
-			rnd_gui->beep(rnd_gui);
-			break;
+		if (pcb->RatDraw) {
+			/* prefer light terminal but also check for heavy terminals */
+			if ((type = pcb_search_screen(pcb_crosshair.X, pcb_crosshair.Y, PCB_OBJ_PSTK | PCB_OBJ_SUBC_PART, &ptr1, &ptr2, &ptr3)) == PCB_OBJ_VOID)
+				type = pcb_search_screen(pcb_crosshair.X, pcb_crosshair.Y, PCB_OBJ_LINE | PCB_OBJ_ARC | PCB_OBJ_POLY | PCB_OBJ_SUBC_PART, &ptr1, &ptr2, &ptr3);
+			/* but make sure it is a terminal, not a via or plain object */
+			if ((type == PCB_OBJ_VOID) || (((pcb_any_obj_t *)ptr2)->term == NULL)) {
+				rnd_gui->beep(rnd_gui);
+				break;
+			}
 		}
 		if (conf_core.editor.auto_drc) {
 			pcb_find_t fctx;
-			type = pcb_search_screen(pcb_crosshair.X, pcb_crosshair.Y, PCB_OBJ_PSTK | PCB_OBJ_SUBC_PART, &ptr1, &ptr2, &ptr3);
+			if (type == PCB_OBJ_VOID)
+				type = pcb_search_screen(pcb_crosshair.X, pcb_crosshair.Y, PCB_OBJ_PSTK | PCB_OBJ_SUBC_PART, &ptr1, &ptr2, &ptr3);
 			memset(&fctx, 0, sizeof(fctx));
 			fctx.flag_set = PCB_FLAG_FOUND;
 			fctx.flag_chg_undoable = 1;
@@ -383,7 +389,7 @@ void pcb_tool_line_draw_attached(rnd_hidlib_t *hl)
 			pcb_draw_wireframe_line(pcb_crosshair.GC,
 				pcb_crosshair.X, pcb_crosshair.Y,
 				pcb_crosshair.X, pcb_crosshair.Y, 
-				conf_core.design.line_thickness + (2 * conf_core.design.bloat), 0);
+				conf_core.design.line_thickness + (2 * conf_core.design.clearance), 0);
 			rnd_render->set_color(pcb_crosshair.GC, &conf_core.appearance.color.attached);
 		}
 	}
@@ -416,7 +422,7 @@ rnd_bool pcb_tool_line_undo_act(rnd_hidlib_t *hl)
 		pcb_crosshair.AttachedLine.Point2.X = ptr2->Point1.X;
 		pcb_crosshair.AttachedLine.Point2.Y = ptr2->Point1.Y;
 		if ((type = pcb_undo(rnd_true)) == 0)
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(pcb, rnd_true);
 		/* check that the undo was of the right type */
 		if ((type & PCB_UNDO_CREATE) == 0) {
 			/* wrong undo type, restore anchor points */
@@ -440,7 +446,7 @@ rnd_bool pcb_tool_line_undo_act(rnd_hidlib_t *hl)
 			pcb_crosshair.AttachedLine.Point1.X = pcb_crosshair.AttachedLine.Point2.X = ptr2->Point2.X;
 			pcb_crosshair.AttachedLine.Point1.Y = pcb_crosshair.AttachedLine.Point2.Y = ptr2->Point2.Y;
 		}
-		pcb_crosshair_grid_fit(pcb_crosshair.X, pcb_crosshair.Y);
+		pcb_crosshair_grid_fit(pcb, pcb_crosshair.X, pcb_crosshair.Y);
 		rnd_tool_adjust_attached(hl);
 		if (--pcb_added_lines == 0) {
 			pcb_crosshair.AttachedLine.State = PCB_CH_STATE_SECOND;
@@ -464,7 +470,7 @@ rnd_bool pcb_tool_line_redo_act(rnd_hidlib_t *hl)
 	if (pcb_crosshair.AttachedLine.State == PCB_CH_STATE_SECOND)
 		return rnd_false;
 	if (pcb_redo(rnd_true)) {
-		pcb_board_set_changed_flag(rnd_true);
+		pcb_board_set_changed_flag(pcb, rnd_true);
 		if (pcb_crosshair.AttachedLine.State != PCB_CH_STATE_FIRST) {
 			pcb_line_t *line = linelist_last(&PCB_CURRLAYER(pcb)->Line);
 			pcb_crosshair.AttachedLine.Point1.X = pcb_crosshair.AttachedLine.Point2.X = line->Point2.X;
