@@ -46,6 +46,7 @@
 #include <librnd/core/plugins.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/hid_cfg.h>
+#include <librnd/core/hid_menu.h>
 #include "vendor_conf.h"
 #include <librnd/core/compat_misc.h>
 #include "obj_pstk_inlines.h"
@@ -53,6 +54,8 @@
 #include <liblihata/lihata.h>
 #include <liblihata/tree.h>
 
+#include "menu_internal.c"
+
 conf_vendor_t conf_vendor;
 
 static void add_to_drills(char *);
@@ -371,7 +374,7 @@ static void apply_vendor_map(void)
 		 * file, redraw things, and make sure we can undo.
 		 */
 		if (changed) {
-			pcb_board_set_changed_flag(rnd_true);
+			pcb_board_set_changed_flag(PCB, rnd_true);
 			rnd_hid_redraw(PCB);
 			pcb_undo_inc_serial();
 		}
@@ -549,7 +552,7 @@ TODO(": these 3 loops should be wrapped in a single loop that iterates over attr
 		}
 	}
 	if (noskip) {
-		const char *vl = rnd_attribute_get(&subc->Attributes, "value");
+		const char *vl = pcb_attribute_get(&subc->Attributes, "value");
 		for (i = 0; i < n_value; i++) {
 			if ((RND_NSTRCMP(RND_UNKNOWN(vl), ignore_value[i]) == 0)
 					|| rematch(ignore_value[i], RND_UNKNOWN(vl))) {
@@ -560,7 +563,7 @@ TODO(": these 3 loops should be wrapped in a single loop that iterates over attr
 	}
 
 	if (noskip) {
-		const char *fp = rnd_attribute_get(&subc->Attributes, "footprint");
+		const char *fp = pcb_attribute_get(&subc->Attributes, "footprint");
 		for (i = 0; i < n_descr; i++) {
 			if ((RND_NSTRCMP(RND_UNKNOWN(fp), ignore_descr[i]) == 0)
 					|| rematch(ignore_descr[i], RND_UNKNOWN(fp))) {
@@ -660,6 +663,7 @@ void pplg_uninit_vendordrill(void)
 	rnd_remove_actions_by_cookie(vendor_cookie);
 	vendor_free_all();
 	rnd_conf_unreg_fields("plugins/vendor/");
+	rnd_hid_menu_unload(rnd_gui, vendor_cookie);
 }
 
 int pplg_init_vendordrill(void)
@@ -671,5 +675,6 @@ int pplg_init_vendordrill(void)
 
 	rnd_event_bind(PCB_EVENT_NEW_PSTK, vendor_new_pstk, NULL, vendor_cookie);
 	RND_REGISTER_ACTIONS(vendor_action_list, vendor_cookie)
+	rnd_hid_menu_load(rnd_gui, NULL, vendor_cookie, 110, NULL, 0, vendor_menu, "plugin: vendor drill mapping");
 	return 0;
 }
