@@ -1,28 +1,29 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <ctype.h>
-#include "hid.h"
-#include "conf.h"
-#include "conf_hid.h"
+#include "config.h"
+#include <librnd/core/hid.h>
+#include <librnd/core/conf.h>
+#include <librnd/core/conf_hid.h>
+#include <librnd/core/hidlib_conf.h>
+#include <librnd/core/compat_misc.h>
 #include "conf_core.h"
-#include "hidlib_conf.h"
-#include "compat_misc.h"
 #include "src_plugins/diag/diag_conf.h"
 
 int lineno = 0;
 int global_notify = 0;
-conf_hid_id_t hid_id;
+rnd_conf_hid_id_t hid_id;
 const char *hid_cookie = "conftest cookie";
-pcb_hid_t *pcb_gui = NULL;
-const char *pcb_hidlib_default_embedded_menu = "";
-const char *pcbhl_menu_file_paths[] = { "./", "~/.pcb-rnd/", PCBSHAREDIR "/", NULL };
-const char *pcbhl_menu_name_fmt = "pcb-menu-%s.lht";
+rnd_hid_t *rnd_gui = NULL;
+const char *rnd_hidlib_default_embedded_menu = "";
+const char *rnd_menu_file_paths[] = { "./", "~/.pcb-rnd/", PCBSHAREDIR "/", NULL };
+const char *rnd_menu_name_fmt = "pcb-menu-%s.lht";
 
 #define CONF_USER_DIR "~/" DOT_PCB_RND
-const char *pcbhl_conf_userdir_path = CONF_USER_DIR;
-const char *pcphl_conf_user_path = CONF_USER_DIR "/pcb-conf.lht";
-const char *pcbhl_conf_sysdir_path = PCBSHAREDIR;
-const char *pcbhl_conf_sys_path = PCBSHAREDIR "/pcb-conf.lht";
+const char *rnd_conf_userdir_path = CONF_USER_DIR;
+const char *rnd_pcphl_conf_user_path = CONF_USER_DIR "/pcb-conf.lht";
+const char *rnd_conf_sysdir_path = PCBSHAREDIR;
+const char *rnd_conf_sys_path = PCBSHAREDIR "/pcb-conf.lht";
 
 void pcbhl_conf_postproc(void)
 {
@@ -38,48 +39,48 @@ const char *pcb_board_get_name(void)
 	return "dummy_brd";
 }
 
-int pcb_file_loaded_set_at(const char *catname, const char *name, const char *path, const char *desc)
+int rnd_file_loaded_set_at(const char *catname, const char *name, const char *path, const char *desc)
 {
 	return 0;
 }
 
-int pcb_file_loaded_del_at(const char *catname, const char *name)
+int rnd_file_loaded_del_at(const char *catname, const char *name)
 {
 	return 0;
 }
 
 
-void watch_pre(conf_native_t *cfg, int idx)
+void watch_pre(rnd_conf_native_t *cfg, int idx)
 {
 	printf("watch_pre:  '%s' old value\n", cfg->hash_path);
 }
 
-void watch_post(conf_native_t *cfg, int idx)
+void watch_post(rnd_conf_native_t *cfg, int idx)
 {
 	printf("watch_post: '%s' new value\n", cfg->hash_path);
 }
 
-void notify_pre(conf_native_t *cfg, int idx)
+void notify_pre(rnd_conf_native_t *cfg, int idx)
 {
 	if (global_notify)
 		printf("notify_pre:  '%s' old value\n", cfg->hash_path);
 }
 
-void notify_post(conf_native_t *cfg, int idx)
+void notify_post(rnd_conf_native_t *cfg, int idx)
 {
 	if (global_notify)
 		printf("notify_post: '%s' new value\n", cfg->hash_path);
 }
 
-conf_hid_callbacks_t watch_cbs = {watch_pre, watch_post, NULL, NULL};
-conf_hid_callbacks_t global_cbs = {notify_pre, notify_post, NULL, NULL};
+rnd_conf_hid_callbacks_t watch_cbs = {watch_pre, watch_post, NULL, NULL};
+rnd_conf_hid_callbacks_t global_cbs = {notify_pre, notify_post, NULL, NULL};
 
 
 extern lht_doc_t *pcb_conf_main_root[];
 void cmd_dump(char *arg)
 {
 	if (arg == NULL) {
-		pcb_message(PCB_MSG_ERROR, "Need an arg: native or lihata");
+		rnd_message(RND_MSG_ERROR, "Need an arg: native or lihata");
 		return;
 	}
 	if (strncmp(arg, "native", 6) == 0) {
@@ -88,12 +89,12 @@ void cmd_dump(char *arg)
 		conf_dump(stdout, "", 1, arg);
 	}
 	else if (strncmp(arg, "lihata", 6) == 0) {
-		conf_role_t role;
+		rnd_conf_role_t role;
 		arg+=7;
 		while(isspace(*arg)) arg++;
-		role = pcb_conf_role_parse(arg);
-		if (role == CFR_invalid) {
-			pcb_message(PCB_MSG_ERROR, "Invalid role: '%s'", arg);
+		role = rnd_conf_role_parse(arg);
+		if (role == RND_CFR_invalid) {
+			rnd_message(RND_MSG_ERROR, "Invalid role: '%s'", arg);
 			return;
 		}
 		if (pcb_conf_main_root[role] != NULL)
@@ -102,25 +103,25 @@ void cmd_dump(char *arg)
 			printf("<empty>\n");
 	}
 	else
-		pcb_message(PCB_MSG_ERROR, "Invalid dump mode: '%s'", arg);
+		rnd_message(RND_MSG_ERROR, "Invalid dump mode: '%s'", arg);
 }
 
 void cmd_print(char *arg)
 {
-	conf_native_t *node;
+	rnd_conf_native_t *node;
 	gds_t s;
 
 	if (arg == NULL) {
-		pcb_message(PCB_MSG_ERROR, "Need an arg: a native path");
+		rnd_message(RND_MSG_ERROR, "Need an arg: a native path");
 		return;
 	}
-	node = pcb_conf_get_field(arg);
+	node = rnd_conf_get_field(arg);
 	if (node == NULL) {
-		pcb_message(PCB_MSG_ERROR, "No such path: '%s'", arg);
+		rnd_message(RND_MSG_ERROR, "No such path: '%s'", arg);
 		return;
 	}
 	gds_init(&s);
-	pcb_conf_print_native((conf_pfn)pcb_append_printf, &s, NULL, 0, node);
+	rnd_conf_print_native((rnd_conf_pfn)rnd_append_printf, &s, NULL, 0, node);
 	printf("%s='%s'\n", node->hash_path, s.array);
 	gds_uninit(&s);
 }
@@ -128,16 +129,16 @@ void cmd_print(char *arg)
 void cmd_load(char *arg, int is_text)
 {
 	char *fn;
-	conf_role_t role ;
+	rnd_conf_role_t role ;
 
 	if (arg == NULL) {
 		help:;
-		pcb_message(PCB_MSG_ERROR, "Need 2 args: role and %s", (is_text ? "lihata text" : "file name"));
+		rnd_message(RND_MSG_ERROR, "Need 2 args: role and %s", (is_text ? "lihata text" : "file name"));
 		return;
 	}
 
 	if (*arg == '*') {
-		pcb_conf_load_all(NULL, NULL);
+		rnd_conf_load_all(NULL, NULL);
 		return;
 	}
 
@@ -148,32 +149,32 @@ void cmd_load(char *arg, int is_text)
 	fn++;
 	while(isspace(*fn)) fn++;
 
-	role = pcb_conf_role_parse(arg);
-	if (role == CFR_invalid) {
-		pcb_message(PCB_MSG_ERROR, "Invalid role: '%s'", arg);
+	role = rnd_conf_role_parse(arg);
+	if (role == RND_CFR_invalid) {
+		rnd_message(RND_MSG_ERROR, "Invalid role: '%s'", arg);
 		return;
 	}
-	printf("Result: %d\n", pcb_conf_load_as(role, fn, is_text));
-	pcb_conf_update(NULL, -1);
+	printf("Result: %d\n", rnd_conf_load_as(role, fn, is_text));
+	rnd_conf_update(NULL, -1);
 }
 
-conf_policy_t current_policy = POL_OVERWRITE;
-conf_role_t current_role = CFR_DESIGN;
+rnd_conf_policy_t current_policy = RND_POL_OVERWRITE;
+rnd_conf_role_t current_role = RND_CFR_DESIGN;
 
 void cmd_policy(char *arg)
 {
-	conf_policy_t np = pcb_conf_policy_parse(arg);
-	if (np == POL_invalid)
-		pcb_message(PCB_MSG_ERROR, "Invalid/unknown policy: '%s'", arg);
+	rnd_conf_policy_t np = rnd_conf_policy_parse(arg);
+	if (np == RND_POL_invalid)
+		rnd_message(RND_MSG_ERROR, "Invalid/unknown policy: '%s'", arg);
 	else
 		current_policy = np;
 }
 
 void cmd_role(char *arg)
 {
-	conf_role_t nr = pcb_conf_role_parse(arg);
-	if (nr == CFR_invalid)
-		pcb_message(PCB_MSG_ERROR, "Invalid/unknown role: '%s'", arg);
+	rnd_conf_role_t nr = rnd_conf_role_parse(arg);
+	if (nr == RND_CFR_invalid)
+		rnd_message(RND_MSG_ERROR, "Invalid/unknown role: '%s'", arg);
 	else
 		current_role = nr;
 }
@@ -185,10 +186,10 @@ void cmd_chprio(char *arg)
 	lht_node_t *first;
 
 	if ((*end != '\0') || (np < 0)) {
-		pcb_message(PCB_MSG_ERROR, "Invalid integer prio: '%s'", arg);
+		rnd_message(RND_MSG_ERROR, "Invalid integer prio: '%s'", arg);
 		return;
 	}
-	first = pcb_conf_lht_get_first(current_role, 0);
+	first = rnd_conf_lht_get_first(current_role, 0);
 	if (first != NULL) {
 		char tmp[128];
 		char *end;
@@ -197,27 +198,27 @@ void cmd_chprio(char *arg)
 			*end = '\0';
 		sprintf(tmp, "%s-%d", first->name, np);
 		free(first->name);
-		first->name = pcb_strdup(tmp);
-		pcb_conf_update(NULL, -1);
+		first->name = rnd_strdup(tmp);
+		rnd_conf_update(NULL, -1);
 	}
 }
 
 void cmd_chpolicy(char *arg)
 {
-	conf_policy_t np;
+	rnd_conf_policy_t np;
 	lht_node_t *first;
 
 	if (arg == NULL) {
-		pcb_message(PCB_MSG_ERROR, "need a policy", arg);
+		rnd_message(RND_MSG_ERROR, "need a policy", arg);
 		return;
 	}
-	np = pcb_conf_policy_parse(arg);
-	if (np == POL_invalid) {
-		pcb_message(PCB_MSG_ERROR, "Invalid integer policy: '%s'", arg);
+	np = rnd_conf_policy_parse(arg);
+	if (np == RND_POL_invalid) {
+		rnd_message(RND_MSG_ERROR, "Invalid integer policy: '%s'", arg);
 		return;
 	}
 
-	first = pcb_conf_lht_get_first(current_role, 0);
+	first = rnd_conf_lht_get_first(current_role, 0);
 	if (first != NULL) {
 		char tmp[128];
 		char *end;
@@ -225,13 +226,13 @@ void cmd_chpolicy(char *arg)
 		if (end != NULL) {
 			sprintf(tmp, "%s%s", arg, end);
 			free(first->name);
-			first->name = pcb_strdup(tmp);
+			first->name = rnd_strdup(tmp);
 		}
 		else {
 			free(first->name);
-			first->name = pcb_strdup(arg);
+			first->name = rnd_strdup(arg);
 		}
-		pcb_conf_update(NULL, -1);
+		rnd_conf_update(NULL, -1);
 	}
 }
 
@@ -243,26 +244,26 @@ void cmd_set(char *arg)
 	path = arg;
 	val = strpbrk(path, " \t=");
 	if (val == NULL) {
-		pcb_message(PCB_MSG_ERROR, "set needs a value");
+		rnd_message(RND_MSG_ERROR, "set needs a value");
 		return;
 	}
 	*val = '\0';
 	val++;
 	while(isspace(*val) || (*val == '=')) val++;
 
-	res = pcb_conf_set(current_role, path, -1, val, current_policy);
+	res = rnd_conf_set(current_role, path, -1, val, current_policy);
 	if (res != 0)
 		printf("set error: %d\n", res);
 }
 
 void cmd_watch(char *arg, int add)
 {
-	conf_native_t *n = pcb_conf_get_field(arg);
+	rnd_conf_native_t *n = rnd_conf_get_field(arg);
 	if (n == NULL) {
-		pcb_message(PCB_MSG_ERROR, "unknown path");
+		rnd_message(RND_MSG_ERROR, "unknown path");
 		return;
 	}
-	pcb_conf_hid_set_cb(n, hid_id, (add ? &watch_cbs : NULL));
+	rnd_conf_hid_set_cb(n, hid_id, (add ? &watch_cbs : NULL));
 }
 
 void cmd_notify(char *arg)
@@ -285,22 +286,22 @@ void cmd_echo(char *arg)
 void cmd_reset(char *arg)
 {
 	if (arg == NULL) {
-		pcb_conf_reset(current_role, "<cmd_reset current>");
+		rnd_conf_reset(current_role, "<cmd_reset current>");
 	}
 	else if (*arg == '*') {
 		int n;
-		for(n = 0; n < CFR_max_real; n++)
-			pcb_conf_reset(n, "<cmd_reset *>");
+		for(n = 0; n < RND_CFR_max_real; n++)
+			rnd_conf_reset(n, "<cmd_reset *>");
 	}
 	else {
-		conf_role_t role = pcb_conf_role_parse(arg);
-		if (role == CFR_invalid) {
-			pcb_message(PCB_MSG_ERROR, "Invalid role: '%s'", arg);
+		rnd_conf_role_t role = rnd_conf_role_parse(arg);
+		if (role == RND_CFR_invalid) {
+			rnd_message(RND_MSG_ERROR, "Invalid role: '%s'", arg);
 			return;
 		}
-		pcb_conf_reset(role, "<cmd_reset role>");
+		rnd_conf_reset(role, "<cmd_reset role>");
 	}
-	pcb_conf_update(NULL, -1);
+	rnd_conf_update(NULL, -1);
 }
 
 extern void cmd_help(char *arg);
@@ -347,13 +348,13 @@ int getline_cont(FILE *f)
 int main()
 {
 
-	hid_id = pcb_conf_hid_reg(hid_cookie, &global_cbs);
+	hid_id = rnd_conf_hid_reg(hid_cookie, &global_cbs);
 
-	pcb_conf_init();
+	rnd_conf_init();
 	conf_core_init();
-	pcb_hidlib_conf_init();
-	pcb_conf_reset(CFR_SYSTEM, "<main>");
-	pcb_conf_reset(CFR_USER, "<main>");
+	rnd_hidlib_conf_init();
+	rnd_conf_reset(RND_CFR_SYSTEM, "<main>");
+	rnd_conf_reset(RND_CFR_USER, "<main>");
 
 	while(getline_cont(stdin)) {
 		char *arg, *cmd = line;
@@ -398,10 +399,11 @@ int main()
 		else if (strcmp(cmd, "help") == 0)
 			cmd_help(arg);
 		else
-			pcb_message(PCB_MSG_ERROR, "unknown command '%s'", cmd);
+			rnd_message(RND_MSG_ERROR, "unknown command '%s'", cmd);
 	}
 
-	pcb_conf_hid_unreg(hid_cookie);
-	pcb_conf_uninit();
+	conf_core_uninit_pre();
+	rnd_conf_hid_unreg(hid_cookie);
+	rnd_conf_uninit();
 	return 0;
 }
