@@ -19,21 +19,22 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <errno.h>
-#include "../src/error.h"
-#include "../src/event.h"
-#include "../src/plugins.h"
-#include "../src/hid.h"
-#include "../src/hidlib_conf.h"
+#include "config.h"
+#include <librnd/core/error.h>
+#include <librnd/core/event.h>
+#include <librnd/core/plugins.h>
+#include <librnd/core/hid.h>
+#include <librnd/core/hidlib_conf.h>
 #include "gsch2pcb_rnd_conf.h"
 #include <libfungw/fungw.h>
 
 /* glue for pcb-rnd core */
 
-const char *pcbhl_menu_file_paths[] = { "./", "~/.pcb-rnd/", PCBSHAREDIR "/", NULL };
-const char *pcbhl_menu_name_fmt = "pcb-menu-%s.lht";
+const char *rnd_menu_file_paths[4];
+const char *rnd_menu_name_fmt = "pcb-menu-%s.lht";
 
-const char *pcb_hidlib_default_embedded_menu = "";
+const char *rnd_hidlib_default_embedded_menu = "";
 
-void pcb_tool_gui_init(void) { }
+void rnd_hidlib_crosshair_move_to(rnd_hidlib_t *hl, rnd_coord_t abs_x, rnd_coord_t abs_y, int mouse_mot) { }
 
 
