@@ -29,14 +29,14 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include "../src/plug_footprint.h"
-#include "../src/paths.h"
-#include "../src/conf.h"
+#include <librnd/core/paths.h>
+#include <librnd/core/conf.h>
 #include "../src/conf_core.h"
 #include "../config.h"
-#include "../src/compat_misc.h"
+#include <librnd/core/compat_misc.h>
 #include "gsch2pcb_rnd_conf.h"
 #include "gsch2pcb.h"
-#include "../src/misc_util.h"
+#include <librnd/core/misc_util.h>
 #include "run.h"
 
 const char *gnetlist_name(void)
@@ -92,12 +92,12 @@ int run_gnetlist(const char *pins_file, const char *net_file, const char *pcb_fi
 		char *out_file;
 		char *backend;
 		if (!s2) {
-			out_file = pcb_concat(basename, ".", s, NULL);
-			backend = pcb_strdup(s);
+			out_file = rnd_concat(basename, ".", s, NULL);
+			backend = rnd_strdup(s);
 		}
 		else {
-			out_file = pcb_strdup(s2 + 4);
-			backend = pcb_strndup(s, s2 - s);
+			out_file = rnd_strdup(s2 + 4);
+			backend = rnd_strndup(s, s2 - s);
 		}
 
 		if (!build_and_run_command("%s %s -g %s -o %s %L %L",
